/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

// This file is a Mako template: http://www.makotemplates.org/

// Please note that valid Rust syntax may be mangled by the Mako parser.
// For example, Vec&Foo> will be mangled as Vec&Foo>. To work around these issues, the code
// can be escaped. In the above example, Vec<&Foo> or Vec< &Foo> achieves the desired result of Vec&Foo>.



#[cfg(feature = "servo")]
use app_units::Au;
use dom::TElement;
use custom_properties::CustomPropertiesBuilder;
use servo_arc::{Arc, UniqueArc};
use smallbitvec::SmallBitVec;
use std::borrow::Cow;
use std::{ops, ptr};
use std::cell::RefCell;
use std::fmt::{self, Write};
use std::mem::{self, ManuallyDrop};

#[cfg(feature = "servo")] use cssparser::RGBA;
use cssparser::{CowRcStr, Parser, TokenSerializationType, serialize_identifier};
use cssparser::ParserInput;
#[cfg(feature = "servo")] use euclid::SideOffsets2D;
use context::QuirksMode;
use font_metrics::FontMetricsProvider;
#[cfg(feature = "gecko")] use gecko_bindings::bindings;
#[cfg(feature = "gecko")] use gecko_bindings::structs::{self, nsCSSPropertyID};
#[cfg(feature = "servo")] use logical_geometry::LogicalMargin;
#[cfg(feature = "servo")] use computed_values;
use logical_geometry::WritingMode;
#[cfg(feature = "gecko")] use malloc_size_of::{MallocSizeOf, MallocSizeOfOps};
use media_queries::Device;
use parser::ParserContext;
#[cfg(feature = "gecko")] use properties::longhands::system_font::SystemFont;
use rule_cache::{RuleCache, RuleCacheConditions};
use selector_parser::PseudoElement;
use selectors::parser::SelectorParseErrorKind;
#[cfg(feature = "servo")] use servo_config::prefs::PREFS;
use shared_lock::StylesheetGuards;
use style_traits::{CssWriter, ParseError, ParsingMode, StyleParseErrorKind, ToCss};
use stylesheets::{CssRuleType, Origin, UrlExtraData};
#[cfg(feature = "servo")] use values::Either;
use values::generics::text::LineHeight;
use values::computed;
use values::computed::NonNegativeLength;
use rule_tree::{CascadeLevel, StrongRuleNode};
use self::computed_value_flags::*;
use str::{CssString, CssStringBorrow, CssStringWriter};
use style_adjuster::StyleAdjuster;

pub use self::declaration_block::*;

/// Generated
#[cfg(feature = "gecko")]
#[macro_export]
macro_rules! property_name {
    ($s: tt) => { atom!($s) }
}



#[path="/builddir/build/BUILD/thunderbird-60.6.1/servo/components/style/properties/computed_value_flags.rs"]
pub mod computed_value_flags;
#[path="/builddir/build/BUILD/thunderbird-60.6.1/servo/components/style/properties/declaration_block.rs"]
pub mod declaration_block;

/// Conversion with fewer impls than From/Into
pub trait MaybeBoxed<Out> {
    /// Convert
    fn maybe_boxed(self) -> Out;
}

impl<T> MaybeBoxed<T> for T {
    #[inline]
    fn maybe_boxed(self) -> T { self }
}

impl<T> MaybeBoxed<Box<T>> for T {
    #[inline]
    fn maybe_boxed(self) -> Box<T> { Box::new(self) }
}

macro_rules! expanded {
    ( $( $name: ident: $value: expr ),+ ) => {
        expanded!( $( $name: $value, )+ )
    };
    ( $( $name: ident: $value: expr, )+ ) => {
        Longhands {
            $(
                $name: MaybeBoxed::maybe_boxed($value),
            )+
        }
    }
}

/// A module with all the code for longhand properties.
#[allow(missing_docs)]
pub mod longhands {
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#background-color
    pub mod background_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::transparent() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { SpecifiedValue::transparent() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BackgroundColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_background_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundColor)
        }
    }




    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-image
    pub mod background_image {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ImageLayer as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ImageLayer as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::First(None_) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { Either::First(None_) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ImageLayer::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for background-image.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of background-image.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundImage(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BackgroundImage);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundImage);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_image(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_image();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_image();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundImage)
        }
    }




    
    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds-4/#propdef-background-position-x
    pub mod background_position_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::position::HorizontalPosition as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::position::HorizontalPosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentage::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { SpecifiedValue::initial_specified_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::position::HorizontalPosition::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for background-position-x.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Animate, ComputeSquaredDistance)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );

                use values::animated::{ToAnimatedZero};

                impl ToAnimatedZero for T {
                    #[inline]
                    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
                }

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of background-position-x.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundPositionX(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BackgroundPositionX);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundPositionX);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_position_x(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_position_x();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_position_x();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundPositionX)
        }
    }



    
    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds-4/#propdef-background-position-y
    pub mod background_position_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::position::VerticalPosition as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::position::VerticalPosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentage::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { SpecifiedValue::initial_specified_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::position::VerticalPosition::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for background-position-y.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Animate, ComputeSquaredDistance)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );

                use values::animated::{ToAnimatedZero};

                impl ToAnimatedZero for T {
                    #[inline]
                    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
                }

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of background-position-y.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundPositionY(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BackgroundPositionY);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundPositionY);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_position_y(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_position_y();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_position_y();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundPositionY)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-repeat
    pub mod background_repeat {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BackgroundRepeat as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BackgroundRepeat as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BackgroundRepeat::repeat() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BackgroundRepeat::repeat() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BackgroundRepeat::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for background-repeat.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of background-repeat.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundRepeat(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BackgroundRepeat);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundRepeat);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_repeat(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_repeat();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_repeat();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundRepeat)
        }
    }





    

    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-attachment
    pub mod background_attachment {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Scroll,
            
            Fixed,
            
            Local,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Scroll
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Scroll
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for background-attachment.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of background-attachment.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundAttachment(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BackgroundAttachment);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundAttachment);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_attachment(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_attachment();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_attachment();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundAttachment)
        }
    }





    

    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-clip
    pub mod background_clip {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            BorderBox,
            
            PaddingBox,
            
            ContentBox,
            
            Text,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::BorderBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::BorderBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for background-clip.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of background-clip.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundClip(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BackgroundClip);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundClip);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_clip(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_clip();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_clip();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundClip)
        }
    }





    

    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-origin
    pub mod background_origin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            PaddingBox,
            
            BorderBox,
            
            ContentBox,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::PaddingBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::PaddingBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for background-origin.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of background-origin.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundOrigin(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BackgroundOrigin);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundOrigin);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_origin(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_origin();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_origin();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundOrigin)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-size
    pub mod background_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BackgroundSize as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BackgroundSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BackgroundSize::auto() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BackgroundSize::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BackgroundSize::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for background-size.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Animate, ComputeSquaredDistance)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );

                use values::animated::{ToAnimatedZero};

                impl ToAnimatedZero for T {
                    #[inline]
                    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
                }

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of background-size.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BackgroundSize);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_size(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundSize)
        }
    }




// https://drafts.fxtf.org/compositing/#background-blend-mode

    

    
        
    
    
    /// https://drafts.fxtf.org/compositing/#background-blend-mode
    pub mod background_blend_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Normal,
            
            Multiply,
            
            Screen,
            
            Overlay,
            
            Darken,
            
            Lighten,
            
            ColorDodge,
            
            ColorBurn,
            
            HardLight,
            
            SoftLight,
            
            Difference,
            
            Exclusion,
            
            Hue,
            
            Saturation,
            
            Color,
            
            Luminosity,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for background-blend-mode.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of background-blend-mode.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundBlendMode(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BackgroundBlendMode);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundBlendMode);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_blend_mode(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_blend_mode();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_blend_mode();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundBlendMode)
        }
    }




    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-top-color
    pub mod border_top_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderTopColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderTopColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderTopColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_top_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_top_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_top_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderTopColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-top-style
    pub mod border_top_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderTopStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderTopStyle);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderTopStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_top_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_top_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_top_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderTopStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-top-width
    pub mod border_top_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderTopWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderTopWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderTopWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_top_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_top_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_top_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderTopWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-left-color
    pub mod border_left_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderLeftColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderLeftColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderLeftColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_left_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_left_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_left_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderLeftColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-left-style
    pub mod border_left_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderLeftStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderLeftStyle);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderLeftStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_left_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_left_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_left_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderLeftStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-left-width
    pub mod border_left_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderLeftWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderLeftWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderLeftWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_left_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_left_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_left_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderLeftWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-bottom-color
    pub mod border_bottom_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBottomColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderBottomColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBottomColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_bottom_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_bottom_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_bottom_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBottomColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-bottom-style
    pub mod border_bottom_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBottomStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderBottomStyle);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBottomStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_bottom_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_bottom_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_bottom_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBottomStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-bottom-width
    pub mod border_bottom_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBottomWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderBottomWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBottomWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_bottom_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_bottom_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_bottom_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBottomWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-right-color
    pub mod border_right_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderRightColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderRightColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderRightColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_right_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_right_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_right_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderRightColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-right-style
    pub mod border_right_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderRightStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderRightStyle);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderRightStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_right_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_right_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_right_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderRightStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-right-width
    pub mod border_right_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderRightWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderRightWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderRightWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_right_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_right_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_right_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderRightWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-start-color
    pub mod border_block_start_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBlockStartColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderBlockStartColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBlockStartColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_block_start_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_block_start_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_block_start_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockStartColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-start-style
    pub mod border_block_start_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBlockStartStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderBlockStartStyle);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBlockStartStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_block_start_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_block_start_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_block_start_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockStartStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-start-width
    pub mod border_block_start_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBlockStartWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderBlockStartWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBlockStartWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_block_start_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_block_start_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_block_start_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockStartWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-end-color
    pub mod border_block_end_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBlockEndColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderBlockEndColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBlockEndColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_block_end_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_block_end_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_block_end_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockEndColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-end-style
    pub mod border_block_end_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBlockEndStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderBlockEndStyle);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBlockEndStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_block_end_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_block_end_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_block_end_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockEndStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-end-width
    pub mod border_block_end_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBlockEndWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderBlockEndWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBlockEndWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_block_end_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_block_end_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_block_end_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockEndWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-start-color
    pub mod border_inline_start_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderInlineStartColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderInlineStartColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderInlineStartColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_inline_start_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_inline_start_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_inline_start_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineStartColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-start-style
    pub mod border_inline_start_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderInlineStartStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderInlineStartStyle);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderInlineStartStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_inline_start_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_inline_start_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_inline_start_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineStartStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-start-width
    pub mod border_inline_start_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderInlineStartWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderInlineStartWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderInlineStartWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_inline_start_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_inline_start_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_inline_start_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineStartWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-end-color
    pub mod border_inline_end_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderInlineEndColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderInlineEndColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderInlineEndColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_inline_end_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_inline_end_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_inline_end_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineEndColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-end-style
    pub mod border_inline_end_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderInlineEndStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderInlineEndStyle);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderInlineEndStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_inline_end_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_inline_end_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_inline_end_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineEndStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-end-width
    pub mod border_inline_end_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderInlineEndWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderInlineEndWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderInlineEndWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_inline_end_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_inline_end_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_inline_end_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineEndWidth)
        }
    }




    
    #[cfg(feature = "gecko")]
    impl ::values::specified::BorderStyle {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NONE: u32
                    = structs::NS_STYLE_BORDER_STYLE_NONE as u32;
                // We can't match on enum values if we're matching on a u32
                const SOLID: u32
                    = structs::NS_STYLE_BORDER_STYLE_SOLID as u32;
                // We can't match on enum values if we're matching on a u32
                const DOUBLE: u32
                    = structs::NS_STYLE_BORDER_STYLE_DOUBLE as u32;
                // We can't match on enum values if we're matching on a u32
                const DOTTED: u32
                    = structs::NS_STYLE_BORDER_STYLE_DOTTED as u32;
                // We can't match on enum values if we're matching on a u32
                const DASHED: u32
                    = structs::NS_STYLE_BORDER_STYLE_DASHED as u32;
                // We can't match on enum values if we're matching on a u32
                const HIDDEN: u32
                    = structs::NS_STYLE_BORDER_STYLE_HIDDEN as u32;
                // We can't match on enum values if we're matching on a u32
                const GROOVE: u32
                    = structs::NS_STYLE_BORDER_STYLE_GROOVE as u32;
                // We can't match on enum values if we're matching on a u32
                const RIDGE: u32
                    = structs::NS_STYLE_BORDER_STYLE_RIDGE as u32;
                // We can't match on enum values if we're matching on a u32
                const INSET: u32
                    = structs::NS_STYLE_BORDER_STYLE_INSET as u32;
                // We can't match on enum values if we're matching on a u32
                const OUTSET: u32
                    = structs::NS_STYLE_BORDER_STYLE_OUTSET as u32;
            match kw  {
                    NONE => ::values::specified::BorderStyle::None,
                    SOLID => ::values::specified::BorderStyle::Solid,
                    DOUBLE => ::values::specified::BorderStyle::Double,
                    DOTTED => ::values::specified::BorderStyle::Dotted,
                    DASHED => ::values::specified::BorderStyle::Dashed,
                    HIDDEN => ::values::specified::BorderStyle::Hidden,
                    GROOVE => ::values::specified::BorderStyle::Groove,
                    RIDGE => ::values::specified::BorderStyle::Ridge,
                    INSET => ::values::specified::BorderStyle::Inset,
                    OUTSET => ::values::specified::BorderStyle::Outset,
                _ => panic!("Found unexpected value in style struct for border-style property"),
            }
        }
    }


// FIXME(#4126): when gfx supports painting it, make this Size2D<LengthOrPercentage>
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-top-left-radius
    pub mod border_top_left_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderTopLeftRadius(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderTopLeftRadius);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderTopLeftRadius);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_top_left_radius(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_top_left_radius();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_top_left_radius();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderTopLeftRadius)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-top-right-radius
    pub mod border_top_right_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderTopRightRadius(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderTopRightRadius);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderTopRightRadius);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_top_right_radius(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_top_right_radius();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_top_right_radius();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderTopRightRadius)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-bottom-right-radius
    pub mod border_bottom_right_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBottomRightRadius(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderBottomRightRadius);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBottomRightRadius);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_bottom_right_radius(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_bottom_right_radius();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_bottom_right_radius();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderBottomRightRadius)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-bottom-left-radius
    pub mod border_bottom_left_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBottomLeftRadius(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderBottomLeftRadius);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBottomLeftRadius);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_bottom_left_radius(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_bottom_left_radius();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_bottom_left_radius();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderBottomLeftRadius)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-break/#propdef-box-decoration-break
    pub mod box_decoration_break {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Slice,
            
            Clone,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Slice
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Slice
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BoxDecorationBreak(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BoxDecorationBreak);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BoxDecorationBreak);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_box_decoration_break(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_box_decoration_break();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_box_decoration_break();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BoxDecorationBreak)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-float-edge)
    pub mod _moz_float_edge {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            ContentBox,
            
            MarginBox,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::ContentBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::ContentBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozFloatEdge(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozFloatEdge);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozFloatEdge);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_float_edge(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_float_edge();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_float_edge();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozFloatEdge)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-image
    pub mod border_image_source {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ImageLayer as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ImageLayer as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::First(None_) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { Either::First(None_) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ImageLayer::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderImageSource(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderImageSource);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderImageSource);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_image_source(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_image_source();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_image_source();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderImageSource)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-image-outset
    pub mod border_image_outset {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrNumberRect as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrNumberRect as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrNumberRect::all(computed::LengthOrNumber::zero()) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::LengthOrNumberRect::all(specified::LengthOrNumber::zero()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrNumberRect::parse_non_negative(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderImageOutset(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderImageOutset);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderImageOutset);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_image_outset(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_image_outset();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_image_outset();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderImageOutset)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#the-border-image-repeat
    pub mod border_image_repeat {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderImageRepeat as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderImageRepeat as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderImageRepeat::stretch() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BorderImageRepeat::stretch() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderImageRepeat::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderImageRepeat(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderImageRepeat);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderImageRepeat);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_image_repeat(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_image_repeat();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_image_repeat();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderImageRepeat)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-image-width
    pub mod border_image_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderImageWidth as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderImageWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderImageWidth::all(computed::BorderImageSideWidth::one()) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BorderImageWidth::all(specified::BorderImageSideWidth::one()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderImageWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderImageWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderImageWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderImageWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_image_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_image_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_image_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderImageWidth)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-image-slice
    pub mod border_image_slice {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderImageSlice as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderImageSlice as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NumberOrPercentage::Percentage(computed::Percentage(1.)).into() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::NumberOrPercentage::Percentage(specified::Percentage::new(1.)).into() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderImageSlice::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderImageSlice(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderImageSlice);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderImageSlice);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_image_slice(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_image_slice();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_image_slice();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderImageSlice)
        }
    }



#[cfg(feature = "gecko")]
impl ::values::computed::BorderImageWidth {
    pub fn to_gecko_rect(&self, sides: &mut ::gecko_bindings::structs::nsStyleSides) {
        use gecko_bindings::sugar::ns_style_coord::{CoordDataMut, CoordDataValue};
        use gecko::values::GeckoStyleCoordConvertible;
        use values::generics::border::BorderImageSideWidth;

        match self.0 {
            BorderImageSideWidth::Auto => {
                sides.data_at_mut(0).set_value(CoordDataValue::Auto)
            },
            BorderImageSideWidth::Length(l) => {
                l.to_gecko_style_coord(&mut sides.data_at_mut(0))
            },
            BorderImageSideWidth::Number(n) => {
                sides.data_at_mut(0).set_value(CoordDataValue::Factor(n))
            },
        }
        match self.1 {
            BorderImageSideWidth::Auto => {
                sides.data_at_mut(1).set_value(CoordDataValue::Auto)
            },
            BorderImageSideWidth::Length(l) => {
                l.to_gecko_style_coord(&mut sides.data_at_mut(1))
            },
            BorderImageSideWidth::Number(n) => {
                sides.data_at_mut(1).set_value(CoordDataValue::Factor(n))
            },
        }
        match self.2 {
            BorderImageSideWidth::Auto => {
                sides.data_at_mut(2).set_value(CoordDataValue::Auto)
            },
            BorderImageSideWidth::Length(l) => {
                l.to_gecko_style_coord(&mut sides.data_at_mut(2))
            },
            BorderImageSideWidth::Number(n) => {
                sides.data_at_mut(2).set_value(CoordDataValue::Factor(n))
            },
        }
        match self.3 {
            BorderImageSideWidth::Auto => {
                sides.data_at_mut(3).set_value(CoordDataValue::Auto)
            },
            BorderImageSideWidth::Length(l) => {
                l.to_gecko_style_coord(&mut sides.data_at_mut(3))
            },
            BorderImageSideWidth::Number(n) => {
                sides.data_at_mut(3).set_value(CoordDataValue::Factor(n))
            },
        }
    }

    pub fn from_gecko_rect(sides: &::gecko_bindings::structs::nsStyleSides)
                           -> Option<::values::computed::BorderImageWidth> {
        use gecko_bindings::structs::nsStyleUnit::{eStyleUnit_Factor, eStyleUnit_Auto};
        use gecko_bindings::sugar::ns_style_coord::CoordData;
        use gecko::values::GeckoStyleCoordConvertible;
        use values::computed::{LengthOrPercentage, Number};
        use values::generics::border::BorderImageSideWidth;

        Some(
            ::values::computed::BorderImageWidth::new(
                match sides.data_at(0).unit() {
                    eStyleUnit_Auto => {
                        BorderImageSideWidth::Auto
                    },
                    eStyleUnit_Factor => {
                        BorderImageSideWidth::Number(
                            Number::from_gecko_style_coord(&sides.data_at(0))
                                .expect("sides[0] could not convert to Number"))
                    },
                    _ => {
                        BorderImageSideWidth::Length(
                            LengthOrPercentage::from_gecko_style_coord(&sides.data_at(0))
                                .expect("sides[0] could not convert to LengthOrPercentager"))
                    },
                },
                match sides.data_at(1).unit() {
                    eStyleUnit_Auto => {
                        BorderImageSideWidth::Auto
                    },
                    eStyleUnit_Factor => {
                        BorderImageSideWidth::Number(
                            Number::from_gecko_style_coord(&sides.data_at(1))
                                .expect("sides[1] could not convert to Number"))
                    },
                    _ => {
                        BorderImageSideWidth::Length(
                            LengthOrPercentage::from_gecko_style_coord(&sides.data_at(1))
                                .expect("sides[1] could not convert to LengthOrPercentager"))
                    },
                },
                match sides.data_at(2).unit() {
                    eStyleUnit_Auto => {
                        BorderImageSideWidth::Auto
                    },
                    eStyleUnit_Factor => {
                        BorderImageSideWidth::Number(
                            Number::from_gecko_style_coord(&sides.data_at(2))
                                .expect("sides[2] could not convert to Number"))
                    },
                    _ => {
                        BorderImageSideWidth::Length(
                            LengthOrPercentage::from_gecko_style_coord(&sides.data_at(2))
                                .expect("sides[2] could not convert to LengthOrPercentager"))
                    },
                },
                match sides.data_at(3).unit() {
                    eStyleUnit_Auto => {
                        BorderImageSideWidth::Auto
                    },
                    eStyleUnit_Factor => {
                        BorderImageSideWidth::Number(
                            Number::from_gecko_style_coord(&sides.data_at(3))
                                .expect("sides[3] could not convert to Number"))
                    },
                    _ => {
                        BorderImageSideWidth::Length(
                            LengthOrPercentage::from_gecko_style_coord(&sides.data_at(3))
                                .expect("sides[3] could not convert to LengthOrPercentager"))
                    },
                },
            )
        )
    }
}

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






// TODO(SimonSapin): don't parse `inline-table`, since we don't support it
//
// We allow "display" to apply to placeholders because we need to make the
// placeholder pseudo-element an inline-block in the UA stylesheet in Gecko.

    
        
    
    /// https://drafts.csswg.org/css-display/#propdef-display
    pub mod display {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Display as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Display as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Display::inline() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Display::inline() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Display::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Display(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Display);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Display);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_display(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_display();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_display();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Display)
        }
    }



// FIXME(emilio): Listing all the display values here is very unfortunate, we should teach C++ to use the
// Rust enum directly, or generate the conversions to `StyleDisplay`.

    
    #[cfg(feature = "gecko")]
    impl ::values::specified::Display {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const INLINE: u32
                    = structs::StyleDisplay::Inline as u32;
                // We can't match on enum values if we're matching on a u32
                const BLOCK: u32
                    = structs::StyleDisplay::Block as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_BLOCK: u32
                    = structs::StyleDisplay::InlineBlock as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE: u32
                    = structs::StyleDisplay::Table as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_TABLE: u32
                    = structs::StyleDisplay::InlineTable as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_ROW_GROUP: u32
                    = structs::StyleDisplay::TableRowGroup as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_HEADER_GROUP: u32
                    = structs::StyleDisplay::TableHeaderGroup as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_FOOTER_GROUP: u32
                    = structs::StyleDisplay::TableFooterGroup as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_ROW: u32
                    = structs::StyleDisplay::TableRow as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_COLUMN_GROUP: u32
                    = structs::StyleDisplay::TableColumnGroup as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_COLUMN: u32
                    = structs::StyleDisplay::TableColumn as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_CELL: u32
                    = structs::StyleDisplay::TableCell as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_CAPTION: u32
                    = structs::StyleDisplay::TableCaption as u32;
                // We can't match on enum values if we're matching on a u32
                const LIST_ITEM: u32
                    = structs::StyleDisplay::ListItem as u32;
                // We can't match on enum values if we're matching on a u32
                const NONE: u32
                    = structs::StyleDisplay::None as u32;
                // We can't match on enum values if we're matching on a u32
                const FLEX: u32
                    = structs::StyleDisplay::Flex as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_FLEX: u32
                    = structs::StyleDisplay::InlineFlex as u32;
                // We can't match on enum values if we're matching on a u32
                const GRID: u32
                    = structs::StyleDisplay::Grid as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_GRID: u32
                    = structs::StyleDisplay::InlineGrid as u32;
                // We can't match on enum values if we're matching on a u32
                const RUBY: u32
                    = structs::StyleDisplay::Ruby as u32;
                // We can't match on enum values if we're matching on a u32
                const RUBY_BASE: u32
                    = structs::StyleDisplay::RubyBase as u32;
                // We can't match on enum values if we're matching on a u32
                const RUBY_BASE_CONTAINER: u32
                    = structs::StyleDisplay::RubyBaseContainer as u32;
                // We can't match on enum values if we're matching on a u32
                const RUBY_TEXT: u32
                    = structs::StyleDisplay::RubyText as u32;
                // We can't match on enum values if we're matching on a u32
                const RUBY_TEXT_CONTAINER: u32
                    = structs::StyleDisplay::RubyTextContainer as u32;
                // We can't match on enum values if we're matching on a u32
                const CONTENTS: u32
                    = structs::StyleDisplay::Contents as u32;
                // We can't match on enum values if we're matching on a u32
                const FLOW_ROOT: u32
                    = structs::StyleDisplay::FlowRoot as u32;
                // We can't match on enum values if we're matching on a u32
                const _WEBKIT_BOX: u32
                    = structs::StyleDisplay::WebkitBox as u32;
                // We can't match on enum values if we're matching on a u32
                const _WEBKIT_INLINE_BOX: u32
                    = structs::StyleDisplay::WebkitInlineBox as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_BOX: u32
                    = structs::StyleDisplay::MozBox as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_INLINE_BOX: u32
                    = structs::StyleDisplay::MozInlineBox as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_GRID: u32
                    = structs::StyleDisplay::MozGrid as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_INLINE_GRID: u32
                    = structs::StyleDisplay::MozInlineGrid as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_GRID_GROUP: u32
                    = structs::StyleDisplay::MozGridGroup as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_GRID_LINE: u32
                    = structs::StyleDisplay::MozGridLine as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_STACK: u32
                    = structs::StyleDisplay::MozStack as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_INLINE_STACK: u32
                    = structs::StyleDisplay::MozInlineStack as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_DECK: u32
                    = structs::StyleDisplay::MozDeck as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_POPUP: u32
                    = structs::StyleDisplay::MozPopup as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_GROUPBOX: u32
                    = structs::StyleDisplay::MozGroupbox as u32;
            match kw  {
                    INLINE => ::values::specified::Display::Inline,
                    BLOCK => ::values::specified::Display::Block,
                    INLINE_BLOCK => ::values::specified::Display::InlineBlock,
                    TABLE => ::values::specified::Display::Table,
                    INLINE_TABLE => ::values::specified::Display::InlineTable,
                    TABLE_ROW_GROUP => ::values::specified::Display::TableRowGroup,
                    TABLE_HEADER_GROUP => ::values::specified::Display::TableHeaderGroup,
                    TABLE_FOOTER_GROUP => ::values::specified::Display::TableFooterGroup,
                    TABLE_ROW => ::values::specified::Display::TableRow,
                    TABLE_COLUMN_GROUP => ::values::specified::Display::TableColumnGroup,
                    TABLE_COLUMN => ::values::specified::Display::TableColumn,
                    TABLE_CELL => ::values::specified::Display::TableCell,
                    TABLE_CAPTION => ::values::specified::Display::TableCaption,
                    LIST_ITEM => ::values::specified::Display::ListItem,
                    NONE => ::values::specified::Display::None,
                    FLEX => ::values::specified::Display::Flex,
                    INLINE_FLEX => ::values::specified::Display::InlineFlex,
                    GRID => ::values::specified::Display::Grid,
                    INLINE_GRID => ::values::specified::Display::InlineGrid,
                    RUBY => ::values::specified::Display::Ruby,
                    RUBY_BASE => ::values::specified::Display::RubyBase,
                    RUBY_BASE_CONTAINER => ::values::specified::Display::RubyBaseContainer,
                    RUBY_TEXT => ::values::specified::Display::RubyText,
                    RUBY_TEXT_CONTAINER => ::values::specified::Display::RubyTextContainer,
                    CONTENTS => ::values::specified::Display::Contents,
                    FLOW_ROOT => ::values::specified::Display::FlowRoot,
                    _WEBKIT_BOX => ::values::specified::Display::WebkitBox,
                    _WEBKIT_INLINE_BOX => ::values::specified::Display::WebkitInlineBox,
                    _MOZ_BOX => ::values::specified::Display::MozBox,
                    _MOZ_INLINE_BOX => ::values::specified::Display::MozInlineBox,
                    _MOZ_GRID => ::values::specified::Display::MozGrid,
                    _MOZ_INLINE_GRID => ::values::specified::Display::MozInlineGrid,
                    _MOZ_GRID_GROUP => ::values::specified::Display::MozGridGroup,
                    _MOZ_GRID_LINE => ::values::specified::Display::MozGridLine,
                    _MOZ_STACK => ::values::specified::Display::MozStack,
                    _MOZ_INLINE_STACK => ::values::specified::Display::MozInlineStack,
                    _MOZ_DECK => ::values::specified::Display::MozDeck,
                    _MOZ_POPUP => ::values::specified::Display::MozPopup,
                    _MOZ_GROUPBOX => ::values::specified::Display::MozGroupbox,
                _ => panic!("Found unexpected value in style struct for display property"),
            }
        }
    }



    

    
        
    
    /// Internal (not web-exposed)
    pub mod _moz_top_layer {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            None,
            
            Top,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozTopLayer(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozTopLayer);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozTopLayer);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_top_layer(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_top_layer();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_top_layer();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozTopLayer)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-position/#position-property
    pub mod position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Static,
            
            Absolute,
            
            Relative,
            
            Fixed,
            
            Sticky,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Static
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Static
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Position(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Position);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Position);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_position(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_position();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_position();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Position)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-float
    pub mod float {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, Parse, PartialEq, ToCss)]
            pub enum SpecifiedValue {
                
            
            None,
            
            Left,
            
            Right,
            
            InlineStart,
            
            InlineEnd,
        
            }
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            pub enum T {
                
            None,
            Left,
            Right,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NONE: u32
                    = structs::StyleFloat::None as u32;
                // We can't match on enum values if we're matching on a u32
                const LEFT: u32
                    = structs::StyleFloat::Left as u32;
                // We can't match on enum values if we're matching on a u32
                const RIGHT: u32
                    = structs::StyleFloat::Right as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_START: u32
                    = structs::StyleFloat::InlineStart as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_END: u32
                    = structs::StyleFloat::InlineEnd as u32;
            match kw  {
                    NONE => SpecifiedValue::None,
                    LEFT => SpecifiedValue::Left,
                    RIGHT => SpecifiedValue::Right,
                    INLINE_START => SpecifiedValue::InlineStart,
                    INLINE_END => SpecifiedValue::InlineEnd,
                _ => panic!("Found unexpected value in style struct for float property"),
            }
        }
    }

    
            
    impl ToComputedValue for SpecifiedValue {
        type ComputedValue = computed_value::T;

        #[inline]
        fn to_computed_value(&self, context: &Context) -> computed_value::T {
            let ltr = context.style().writing_mode.is_bidi_ltr();
            // https://drafts.csswg.org/css-logical-props/#float-clear
            match *self {
                SpecifiedValue::InlineStart => {
                    context.rule_cache_conditions.borrow_mut()
                        .set_writing_mode_dependency(context.builder.writing_mode);
                    if ltr {
                        computed_value::T::Left
                    } else {
                        computed_value::T::Right
                    }
                }
                SpecifiedValue::InlineEnd => {
                    context.rule_cache_conditions.borrow_mut()
                        .set_writing_mode_dependency(context.builder.writing_mode);
                    if ltr {
                        computed_value::T::Right
                    } else {
                        computed_value::T::Left
                    }
                }
                    SpecifiedValue::None => computed_value::T::None,
                    SpecifiedValue::Left => computed_value::T::Left,
                    SpecifiedValue::Right => computed_value::T::Right,
            }
        }
        #[inline]
        fn from_computed_value(computed: &computed_value::T) -> SpecifiedValue {
            match *computed {
                    computed_value::T::None => SpecifiedValue::None,
                    computed_value::T::Left => SpecifiedValue::Left,
                    computed_value::T::Right => SpecifiedValue::Right,
            }
        }
    }

        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Float(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Float);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Float);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_float(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_float();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_float();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Float)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-clear
    pub mod clear {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, Parse, PartialEq, ToCss)]
            pub enum SpecifiedValue {
                
            
            None,
            
            Left,
            
            Right,
            
            Both,
            
            InlineStart,
            
            InlineEnd,
        
            }
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            pub enum T {
                
            None,
            Left,
            Right,
            Both,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NONE: u32
                    = structs::StyleClear::None as u32;
                // We can't match on enum values if we're matching on a u32
                const LEFT: u32
                    = structs::StyleClear::Left as u32;
                // We can't match on enum values if we're matching on a u32
                const RIGHT: u32
                    = structs::StyleClear::Right as u32;
                // We can't match on enum values if we're matching on a u32
                const BOTH: u32
                    = structs::StyleClear::Both as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_START: u32
                    = structs::StyleClear::InlineStart as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_END: u32
                    = structs::StyleClear::InlineEnd as u32;
            match kw  {
                    NONE => SpecifiedValue::None,
                    LEFT => SpecifiedValue::Left,
                    RIGHT => SpecifiedValue::Right,
                    BOTH => SpecifiedValue::Both,
                    INLINE_START => SpecifiedValue::InlineStart,
                    INLINE_END => SpecifiedValue::InlineEnd,
                _ => panic!("Found unexpected value in style struct for clear property"),
            }
        }
    }

    
            
    impl ToComputedValue for SpecifiedValue {
        type ComputedValue = computed_value::T;

        #[inline]
        fn to_computed_value(&self, context: &Context) -> computed_value::T {
            let ltr = context.style().writing_mode.is_bidi_ltr();
            // https://drafts.csswg.org/css-logical-props/#float-clear
            match *self {
                SpecifiedValue::InlineStart => {
                    context.rule_cache_conditions.borrow_mut()
                        .set_writing_mode_dependency(context.builder.writing_mode);
                    if ltr {
                        computed_value::T::Left
                    } else {
                        computed_value::T::Right
                    }
                }
                SpecifiedValue::InlineEnd => {
                    context.rule_cache_conditions.borrow_mut()
                        .set_writing_mode_dependency(context.builder.writing_mode);
                    if ltr {
                        computed_value::T::Right
                    } else {
                        computed_value::T::Left
                    }
                }
                    SpecifiedValue::None => computed_value::T::None,
                    SpecifiedValue::Left => computed_value::T::Left,
                    SpecifiedValue::Right => computed_value::T::Right,
                    SpecifiedValue::Both => computed_value::T::Both,
            }
        }
        #[inline]
        fn from_computed_value(computed: &computed_value::T) -> SpecifiedValue {
            match *computed {
                    computed_value::T::None => SpecifiedValue::None,
                    computed_value::T::Left => SpecifiedValue::Left,
                    computed_value::T::Right => SpecifiedValue::Right,
                    computed_value::T::Both => SpecifiedValue::Both,
            }
        }
    }

        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Clear(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Clear);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Clear);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_clear(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_clear();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_clear();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Clear)
        }
    }




    
        
    
    /// https://www.w3.org/TR/CSS2/visudet.html#propdef-vertical-align
    pub mod vertical_align {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::VerticalAlign as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::VerticalAlign as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::VerticalAlign::baseline() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::VerticalAlign::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::VerticalAlign(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::VerticalAlign);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::VerticalAlign);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_vertical_align(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_vertical_align();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_vertical_align();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::VerticalAlign)
        }
    }



// CSS 2.1, Section 11 - Visual effects


    

    
        
    


    
    
        
    
    /// Internal, may be standardized in the future:               https://developer.mozilla.org/en-US/docs/Web/CSS/overflow-clip-box
    pub mod overflow_clip_box_inline {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::OverflowClipBox as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::OverflowClipBox as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverflowClipBox::PaddingBox }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::OverflowClipBox::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OverflowClipBoxInline(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::OverflowClipBoxInline);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OverflowClipBoxInline);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_overflow_clip_box_inline(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_overflow_clip_box_inline();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_overflow_clip_box_inline();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowClipBoxInline)
        }
    }


    
    
        
    
    /// Internal, may be standardized in the future:               https://developer.mozilla.org/en-US/docs/Web/CSS/overflow-clip-box
    pub mod overflow_clip_box_block {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::OverflowClipBox as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::OverflowClipBox as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverflowClipBox::PaddingBox }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::OverflowClipBox::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OverflowClipBoxBlock(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::OverflowClipBoxBlock);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OverflowClipBoxBlock);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_overflow_clip_box_block(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_overflow_clip_box_block();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_overflow_clip_box_block();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowClipBoxBlock)
        }
    }





// FIXME(pcwalton, #2742): Implement scrolling for `scroll` and `auto`.

    

    
        
    
    /// https://drafts.csswg.org/css-overflow/#propdef-overflow-x
    pub mod overflow_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Visible,
            
            Hidden,
            
            Scroll,
            
            Auto,
            
            MozHiddenUnscrollable,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Visible
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Visible
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OverflowX(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::OverflowX);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OverflowX);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_overflow_x(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_overflow_x();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_overflow_x();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowX)
        }
    }



// FIXME(pcwalton, #2742): Implement scrolling for `scroll` and `auto`.

    
    /// https://drafts.csswg.org/css-overflow/#propdef-overflow-y
    pub mod overflow_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
    pub use super::overflow_x::{SpecifiedValue, parse, get_initial_value, computed_value};

        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OverflowY(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::OverflowY);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OverflowY);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_overflow_y(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_overflow_y();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_overflow_y();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowY)
        }
    }



    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-transition-duration
    pub mod transition_duration {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Time as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Time as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Time::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Time::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Time::parse_non_negative(context, input)
        }
    
        
        }

        /// The definition of the computed value for transition-duration.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of transition-duration.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TransitionDuration(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TransitionDuration);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TransitionDuration);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_transition_duration(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transition_duration();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transition_duration();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransitionDuration)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-transition-timing-function
    pub mod transition_timing_function {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TimingFunction as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TimingFunction as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TimingFunction::ease() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::TimingFunction::ease() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TimingFunction::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for transition-timing-function.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of transition-timing-function.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TransitionTimingFunction(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TransitionTimingFunction);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TransitionTimingFunction);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_transition_timing_function(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transition_timing_function();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transition_timing_function();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransitionTimingFunction)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-transition-property
    pub mod transition_property {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TransitionProperty as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TransitionProperty as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TransitionProperty::all() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::TransitionProperty::all() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TransitionProperty::parse(input)
        }
    
        
        }

        /// The definition of the computed value for transition-property.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(if_empty = "none", iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of transition-property.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(if_empty = "none", iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

                if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                    return Ok(SpecifiedValue(Vec::new()))
                }

            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TransitionProperty(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TransitionProperty);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TransitionProperty);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_transition_property(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transition_property();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transition_property();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransitionProperty)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-transition-delay
    pub mod transition_delay {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Time as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Time as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Time::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Time::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Time::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for transition-delay.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of transition-delay.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TransitionDelay(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TransitionDelay);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TransitionDelay);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_transition_delay(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transition_delay();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transition_delay();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransitionDelay)
        }
    }






    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-name
    pub mod animation_name {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::AnimationName as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::AnimationName as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::AnimationName::none() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::AnimationName::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::AnimationName::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-name.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of animation-name.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationName(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::AnimationName);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationName);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_name(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_name();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_name();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationName)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-transition-duration
    pub mod animation_duration {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Time as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Time as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Time::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Time::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Time::parse_non_negative(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-duration.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of animation-duration.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationDuration(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::AnimationDuration);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationDuration);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_duration(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_duration();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_duration();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationDuration)
        }
    }




// animation-timing-function is the exception to the rule for allowed_in_keyframe_block:
// https://drafts.csswg.org/css-animations/#keyframes

    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-animation-timing-function
    pub mod animation_timing_function {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TimingFunction as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TimingFunction as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TimingFunction::ease() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::TimingFunction::ease() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TimingFunction::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-timing-function.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of animation-timing-function.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationTimingFunction(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::AnimationTimingFunction);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationTimingFunction);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_timing_function(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_timing_function();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_timing_function();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationTimingFunction)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-iteration-count
    pub mod animation_iteration_count {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::AnimationIterationCount as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::AnimationIterationCount as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::AnimationIterationCount::one() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::AnimationIterationCount::one() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::AnimationIterationCount::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-iteration-count.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of animation-iteration-count.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationIterationCount(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::AnimationIterationCount);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationIterationCount);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_iteration_count(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_iteration_count();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_iteration_count();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationIterationCount)
        }
    }






    

    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-direction
    pub mod animation_direction {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Normal,
            
            Reverse,
            
            Alternate,
            
            AlternateReverse,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for animation-direction.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of animation-direction.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationDirection(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::AnimationDirection);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationDirection);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_direction(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_direction();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_direction();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationDirection)
        }
    }





    

    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-play-state
    pub mod animation_play_state {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Running,
            
            Paused,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Running
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Running
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for animation-play-state.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of animation-play-state.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationPlayState(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::AnimationPlayState);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationPlayState);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_play_state(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_play_state();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_play_state();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationPlayState)
        }
    }





    

    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-fill-mode
    pub mod animation_fill_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            None,
            
            Forwards,
            
            Backwards,
            
            Both,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for animation-fill-mode.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of animation-fill-mode.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationFillMode(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::AnimationFillMode);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationFillMode);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_fill_mode(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_fill_mode();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_fill_mode();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationFillMode)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-delay
    pub mod animation_delay {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Time as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Time as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Time::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Time::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Time::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-delay.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of animation-delay.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationDelay(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::AnimationDelay);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationDelay);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_delay(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_delay();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_delay();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationDelay)
        }
    }




    
    
        
    
    /// Nonstandard (https://www.w3.org/TR/2015/WD-css-snappoints-1-20150326/#scroll-snap-points)
    pub mod scroll_snap_points_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ScrollSnapPoint as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ScrollSnapPoint as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollSnapPoint::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ScrollSnapPoint::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ScrollSnapPointsX(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ScrollSnapPointsX);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ScrollSnapPointsX);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_scroll_snap_points_x(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_scroll_snap_points_x();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_scroll_snap_points_x();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollSnapPointsX)
        }
    }


    
    
        
    
    /// Nonstandard (https://www.w3.org/TR/2015/WD-css-snappoints-1-20150326/#scroll-snap-points)
    pub mod scroll_snap_points_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ScrollSnapPoint as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ScrollSnapPoint as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollSnapPoint::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ScrollSnapPoint::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ScrollSnapPointsY(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ScrollSnapPointsY);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ScrollSnapPointsY);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_scroll_snap_points_y(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_scroll_snap_points_y();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_scroll_snap_points_y();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollSnapPointsY)
        }
    }




    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/scroll-snap-destination)
    pub mod scroll_snap_destination {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Position as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Position as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Position::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Position::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ScrollSnapDestination(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ScrollSnapDestination);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ScrollSnapDestination);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_scroll_snap_destination(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_scroll_snap_destination();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_scroll_snap_destination();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::ScrollSnapDestination)
        }
    }




    
        
    
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/scroll-snap-destination)
    pub mod scroll_snap_coordinate {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Position as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Position as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Position::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Position::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for scroll-snap-coordinate.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(if_empty = "none", iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of scroll-snap-coordinate.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(if_empty = "none", iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

                if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                    return Ok(SpecifiedValue(Vec::new()))
                }

            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ScrollSnapCoordinate(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ScrollSnapCoordinate);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ScrollSnapCoordinate);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_scroll_snap_coordinate(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_scroll_snap_coordinate();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_scroll_snap_coordinate();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollSnapCoordinate)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-transforms/#propdef-transform
    pub mod transform {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Transform as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Transform as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::transform::Transform::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Transform::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Transform(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Transform);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Transform);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_transform(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transform();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transform();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Transform)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms-2/#individual-transforms
    pub mod rotate {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Rotate as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Rotate as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::transform::Rotate::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Rotate::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Rotate(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Rotate);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Rotate);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_rotate(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_rotate();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_rotate();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Rotate)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms-2/#individual-transforms
    pub mod scale {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Scale as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Scale as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::transform::Scale::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Scale::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Scale(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Scale);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Scale);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_scale(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_scale();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_scale();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Scale)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms-2/#individual-transforms
    pub mod translate {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Translate as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Translate as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::transform::Translate::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Translate::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Translate(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Translate);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Translate);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_translate(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_translate();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_translate();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Translate)
        }
    }



// CSSOM View Module
// https://www.w3.org/TR/cssom-view-1/

    

    
        
    
    /// https://drafts.csswg.org/cssom-view/#propdef-scroll-behavior
    pub mod scroll_behavior {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            Smooth,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ScrollBehavior(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ScrollBehavior);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ScrollBehavior);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_scroll_behavior(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_scroll_behavior();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_scroll_behavior();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollBehavior)
        }
    }



    
    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/scroll-snap-type-x)
    pub mod scroll_snap_type_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ScrollSnapType as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ScrollSnapType as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollSnapType::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ScrollSnapType::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ScrollSnapTypeX(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ScrollSnapTypeX);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ScrollSnapTypeX);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_scroll_snap_type_x(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_scroll_snap_type_x();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_scroll_snap_type_x();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollSnapTypeX)
        }
    }


    
    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/scroll-snap-type-x)
    pub mod scroll_snap_type_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ScrollSnapType as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ScrollSnapType as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollSnapType::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ScrollSnapType::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ScrollSnapTypeY(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ScrollSnapTypeY);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ScrollSnapTypeY);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_scroll_snap_type_y(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_scroll_snap_type_y();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_scroll_snap_type_y();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollSnapTypeY)
        }
    }



    
    
        
    
    /// https://wicg.github.io/overscroll-behavior/#overscroll-behavior-properties
    pub mod overscroll_behavior_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::OverscrollBehavior as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::OverscrollBehavior as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverscrollBehavior::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::OverscrollBehavior::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OverscrollBehaviorX(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::OverscrollBehaviorX);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OverscrollBehaviorX);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_overscroll_behavior_x(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_overscroll_behavior_x();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_overscroll_behavior_x();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverscrollBehaviorX)
        }
    }


    
    
        
    
    /// https://wicg.github.io/overscroll-behavior/#overscroll-behavior-properties
    pub mod overscroll_behavior_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::OverscrollBehavior as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::OverscrollBehavior as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverscrollBehavior::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::OverscrollBehavior::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OverscrollBehaviorY(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::OverscrollBehaviorY);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OverscrollBehaviorY);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_overscroll_behavior_y(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_overscroll_behavior_y();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_overscroll_behavior_y();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverscrollBehaviorY)
        }
    }



// Compositing and Blending Level 1
// http://www.w3.org/TR/compositing-1/

    

    
        
    
    /// https://drafts.fxtf.org/compositing/#isolation
    pub mod isolation {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            Isolate,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Isolation(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Isolation);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Isolation);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_isolation(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_isolation();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_isolation();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Isolation)
        }
    }



// TODO add support for logical values recto and verso

    

    
        
    
    /// https://drafts.csswg.org/css2/page.html#propdef-page-break-after
    pub mod page_break_after {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            Always,
            
            Avoid,
            
            Left,
            
            Right,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PageBreakAfter(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::PageBreakAfter);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PageBreakAfter);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_page_break_after(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_page_break_after();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_page_break_after();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PageBreakAfter)
        }
    }



    

    
        
    
    /// https://drafts.csswg.org/css2/page.html#propdef-page-break-before
    pub mod page_break_before {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            Always,
            
            Avoid,
            
            Left,
            
            Right,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PageBreakBefore(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::PageBreakBefore);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PageBreakBefore);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_page_break_before(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_page_break_before();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_page_break_before();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PageBreakBefore)
        }
    }



    

    
        
    
    /// https://drafts.csswg.org/css2/page.html#propdef-page-break-inside
    pub mod page_break_inside {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            Avoid,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PageBreakInside(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::PageBreakInside);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PageBreakInside);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_page_break_inside(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_page_break_inside();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_page_break_inside();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PageBreakInside)
        }
    }



// CSS Basic User Interface Module Level 3
// http://dev.w3.org/csswg/css-ui
// FIXME support logical values `block` and `inline` (https://drafts.csswg.org/css-logical-props/#resize)
//
// This is APPLIES_TO_PLACEHOLDER so we can override, in the UA sheet, the
// 'resize' property we'd inherit from textarea otherwise.  Basically, just
// makes the UA rules easier to write.

    

    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-resize
    pub mod resize {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            None,
            
            Both,
            
            Horizontal,
            
            Vertical,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Resize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Resize);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Resize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_resize(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_resize();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_resize();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Resize)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms/#perspective
    pub mod perspective {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Perspective as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Perspective as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Perspective::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Perspective::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Perspective(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Perspective);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Perspective);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_perspective(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_perspective();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_perspective();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Perspective)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms-2/#perspective-origin-property
    pub mod perspective_origin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::position::Position as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::position::Position as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::position::Position::center() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::position::Position::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PerspectiveOrigin(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::PerspectiveOrigin);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PerspectiveOrigin);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_perspective_origin(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_perspective_origin();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_perspective_origin();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::PerspectiveOrigin)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-transforms/#backface-visibility-property
    pub mod backface_visibility {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Visible,
            
            Hidden,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Visible
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Visible
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackfaceVisibility(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BackfaceVisibility);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackfaceVisibility);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_backface_visibility(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_backface_visibility();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_backface_visibility();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackfaceVisibility)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-transforms/#transform-box
    pub mod transform_box {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            BorderBox,
            
            FillBox,
            
            ViewBox,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::BorderBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::BorderBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TransformBox(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TransformBox);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TransformBox);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_transform_box(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transform_box();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transform_box();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransformBox)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms-2/#transform-style-property
    pub mod transform_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TransformStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TransformStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TransformStyle::Flat }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TransformStyle::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TransformStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TransformStyle);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TransformStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_transform_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transform_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transform_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransformStyle)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms/#transform-origin-property
    pub mod transform_origin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TransformOrigin as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TransformOrigin as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TransformOrigin::initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TransformOrigin::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TransformOrigin(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TransformOrigin);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TransformOrigin);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_transform_origin(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transform_origin();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transform_origin();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::TransformOrigin)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-contain/#contain-property
    pub mod contain {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Contain as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Contain as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::Contain::empty() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Contain::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Contain(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Contain);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Contain);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_contain(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_contain();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_contain();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Contain)
        }
    }



// Non-standard

    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-appearance)
    pub mod _moz_appearance {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            None,
            
            Button,
            
            ButtonArrowDown,
            
            ButtonArrowNext,
            
            ButtonArrowPrevious,
            
            ButtonArrowUp,
            
            ButtonBevel,
            
            ButtonFocus,
            
            Caret,
            
            Checkbox,
            
            CheckboxContainer,
            
            CheckboxLabel,
            
            Checkmenuitem,
            
            Dialog,
            
            Dualbutton,
            
            Groupbox,
            
            InnerSpinButton,
            
            Listbox,
            
            Listitem,
            
            Menuarrow,
            
            Menubar,
            
            Menucheckbox,
            
            Menuimage,
            
            Menuitem,
            
            Menuitemtext,
            
            Menulist,
            
            MenulistButton,
            
            MenulistText,
            
            MenulistTextfield,
            
            Menupopup,
            
            Menuradio,
            
            Menuseparator,
            
            Meterbar,
            
            Meterchunk,
            
            NumberInput,
            
            Progressbar,
            
            ProgressbarVertical,
            
            Progresschunk,
            
            ProgresschunkVertical,
            
            Radio,
            
            RadioContainer,
            
            RadioLabel,
            
            Radiomenuitem,
            
            Range,
            
            RangeThumb,
            
            Resizer,
            
            Resizerpanel,
            
            ScaleHorizontal,
            
            Scalethumbend,
            
            ScalethumbHorizontal,
            
            Scalethumbstart,
            
            Scalethumbtick,
            
            ScalethumbVertical,
            
            ScaleVertical,
            
            Scrollbar,
            
            ScrollbarHorizontal,
            
            ScrollbarSmall,
            
            ScrollbarVertical,
            
            ScrollbarbuttonDown,
            
            ScrollbarbuttonLeft,
            
            ScrollbarbuttonRight,
            
            ScrollbarbuttonUp,
            
            ScrollbarthumbHorizontal,
            
            ScrollbarthumbVertical,
            
            ScrollbartrackHorizontal,
            
            ScrollbartrackVertical,
            
            Searchfield,
            
            Separator,
            
            Spinner,
            
            SpinnerDownbutton,
            
            SpinnerTextfield,
            
            SpinnerUpbutton,
            
            Splitter,
            
            Statusbar,
            
            Statusbarpanel,
            
            Tab,
            
            Tabpanel,
            
            Tabpanels,
            
            TabScrollArrowBack,
            
            TabScrollArrowForward,
            
            Textfield,
            
            TextfieldMultiline,
            
            Toolbar,
            
            Toolbarbutton,
            
            ToolbarbuttonDropdown,
            
            Toolbargripper,
            
            Toolbox,
            
            Tooltip,
            
            Treeheader,
            
            Treeheadercell,
            
            Treeheadersortarrow,
            
            Treeitem,
            
            Treeline,
            
            Treetwisty,
            
            Treetwistyopen,
            
            Treeview,
            
            Window,
            
            MozGtkInfoBar,
            
            MozMacActiveSourceListSelection,
            
            MozMacDisclosureButtonClosed,
            
            MozMacDisclosureButtonOpen,
            
            MozMacFullscreenButton,
            
            MozMacHelpButton,
            
            MozMacSourceList,
            
            MozMacSourceListSelection,
            
            MozMacVibrancyDark,
            
            MozMacVibrancyLight,
            
            MozMacVibrantTitlebarLight,
            
            MozMacVibrantTitlebarDark,
            
            MozWinBorderlessGlass,
            
            MozWinBrowsertabbarToolbox,
            
            MozWinCommunicationsToolbox,
            
            MozWinExcludeGlass,
            
            MozWinGlass,
            
            MozWinMediaToolbox,
            
            MozWindowButtonBox,
            
            MozWindowButtonBoxMaximized,
            
            MozWindowButtonClose,
            
            MozWindowButtonMaximize,
            
            MozWindowButtonMinimize,
            
            MozWindowButtonRestore,
            
            MozWindowFrameBottom,
            
            MozWindowFrameLeft,
            
            MozWindowFrameRight,
            
            MozWindowTitlebar,
            
            MozWindowTitlebarMaximized,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozAppearance(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozAppearance);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozAppearance);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_appearance(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_appearance();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_appearance();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozAppearance)
        }
    }




    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-binding)
    pub mod _moz_binding {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::UrlOrNone as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::UrlOrNone as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(None_) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::UrlOrNone::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBinding(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozBinding);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBinding);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_binding(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_binding();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_binding();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBinding)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-orient)
    pub mod _moz_orient {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Inline,
            
            Block,
            
            Horizontal,
            
            Vertical,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Inline
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Inline
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozOrient(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozOrient);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozOrient);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_orient(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_orient();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_orient();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozOrient)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-will-change/#will-change
    pub mod will_change {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::WillChange as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::WillChange as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::WillChange::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::WillChange::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WillChange(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::WillChange);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::WillChange);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_will_change(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_will_change();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_will_change();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WillChange)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-shapes/#shape-image-threshold-property
    pub mod shape_image_threshold {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Opacity as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Opacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 0.0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Opacity::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ShapeImageThreshold(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ShapeImageThreshold);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ShapeImageThreshold);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_shape_image_threshold(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_shape_image_threshold();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_shape_image_threshold();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ShapeImageThreshold)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-shapes/#shape-outside-property
    pub mod shape_outside {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::basic_shape::FloatAreaShape as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::basic_shape::FloatAreaShape as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::basic_shape::ShapeSource::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::basic_shape::FloatAreaShape::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ShapeOutside(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ShapeOutside);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ShapeOutside);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_shape_outside(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_shape_outside();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_shape_outside();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::ShapeOutside)
        }
    }




    
        
    
    /// https://compat.spec.whatwg.org/#touch-action
    pub mod touch_action {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TouchAction as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TouchAction as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TouchAction::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TouchAction::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TouchAction(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TouchAction);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TouchAction);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_touch_action(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_touch_action();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_touch_action();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TouchAction)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */








    
        
    
    /// https://drafts.csswg.org/css-color/#color
    pub mod color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ColorPropertyValue as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ColorPropertyValue as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::cssparser::RGBA::new(0, 0, 0, 255) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ColorPropertyValue::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Color(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Color);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_color();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Color)
        }
    }



// FIXME(#15973): Add servo support for system colors
//
// FIXME(emilio): Move outside of mako.
pub mod system_colors {
    
    use gecko_bindings::bindings::Gecko_GetLookAndFeelSystemColor;
    use gecko_bindings::structs::root::mozilla::LookAndFeel_ColorID;
    use std::fmt::{self, Write};
    use style_traits::{CssWriter, ToCss};
    use values::computed::{Context, ToComputedValue};

    pub type SystemColor = LookAndFeel_ColorID;

    // It's hard to implement MallocSizeOf for LookAndFeel_ColorID because it
    // is a bindgen type. So we implement it on the typedef instead.
    malloc_size_of_is_0!(SystemColor);

    impl ToCss for SystemColor {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
        where
            W: Write,
        {
            let s = match *self {
                    LookAndFeel_ColorID::eColorID_activeborder => "activeborder",
                    LookAndFeel_ColorID::eColorID_activecaption => "activecaption",
                    LookAndFeel_ColorID::eColorID_appworkspace => "appworkspace",
                    LookAndFeel_ColorID::eColorID_background => "background",
                    LookAndFeel_ColorID::eColorID_buttonface => "buttonface",
                    LookAndFeel_ColorID::eColorID_buttonhighlight => "buttonhighlight",
                    LookAndFeel_ColorID::eColorID_buttonshadow => "buttonshadow",
                    LookAndFeel_ColorID::eColorID_buttontext => "buttontext",
                    LookAndFeel_ColorID::eColorID_captiontext => "captiontext",
                    LookAndFeel_ColorID::eColorID_graytext => "graytext",
                    LookAndFeel_ColorID::eColorID_highlight => "highlight",
                    LookAndFeel_ColorID::eColorID_highlighttext => "highlighttext",
                    LookAndFeel_ColorID::eColorID_inactiveborder => "inactiveborder",
                    LookAndFeel_ColorID::eColorID_inactivecaption => "inactivecaption",
                    LookAndFeel_ColorID::eColorID_inactivecaptiontext => "inactivecaptiontext",
                    LookAndFeel_ColorID::eColorID_infobackground => "infobackground",
                    LookAndFeel_ColorID::eColorID_infotext => "infotext",
                    LookAndFeel_ColorID::eColorID_menu => "menu",
                    LookAndFeel_ColorID::eColorID_menutext => "menutext",
                    LookAndFeel_ColorID::eColorID_scrollbar => "scrollbar",
                    LookAndFeel_ColorID::eColorID_threeddarkshadow => "threeddarkshadow",
                    LookAndFeel_ColorID::eColorID_threedface => "threedface",
                    LookAndFeel_ColorID::eColorID_threedhighlight => "threedhighlight",
                    LookAndFeel_ColorID::eColorID_threedlightshadow => "threedlightshadow",
                    LookAndFeel_ColorID::eColorID_threedshadow => "threedshadow",
                    LookAndFeel_ColorID::eColorID_window => "window",
                    LookAndFeel_ColorID::eColorID_windowframe => "windowframe",
                    LookAndFeel_ColorID::eColorID_windowtext => "windowtext",
                    LookAndFeel_ColorID::eColorID__moz_buttondefault => "-moz-buttondefault",
                    LookAndFeel_ColorID::eColorID__moz_buttonhoverface => "-moz-buttonhoverface",
                    LookAndFeel_ColorID::eColorID__moz_buttonhovertext => "-moz-buttonhovertext",
                    LookAndFeel_ColorID::eColorID__moz_cellhighlight => "-moz-cellhighlight",
                    LookAndFeel_ColorID::eColorID__moz_cellhighlighttext => "-moz-cellhighlighttext",
                    LookAndFeel_ColorID::eColorID__moz_eventreerow => "-moz-eventreerow",
                    LookAndFeel_ColorID::eColorID__moz_field => "-moz-field",
                    LookAndFeel_ColorID::eColorID__moz_fieldtext => "-moz-fieldtext",
                    LookAndFeel_ColorID::eColorID__moz_dialog => "-moz-dialog",
                    LookAndFeel_ColorID::eColorID__moz_dialogtext => "-moz-dialogtext",
                    LookAndFeel_ColorID::eColorID__moz_dragtargetzone => "-moz-dragtargetzone",
                    LookAndFeel_ColorID::eColorID__moz_gtk_info_bar_text => "-moz-gtk-info-bar-text",
                    LookAndFeel_ColorID::eColorID__moz_html_cellhighlight => "-moz-html-cellhighlight",
                    LookAndFeel_ColorID::eColorID__moz_html_cellhighlighttext => "-moz-html-cellhighlighttext",
                    LookAndFeel_ColorID::eColorID__moz_mac_buttonactivetext => "-moz-mac-buttonactivetext",
                    LookAndFeel_ColorID::eColorID__moz_mac_chrome_active => "-moz-mac-chrome-active",
                    LookAndFeel_ColorID::eColorID__moz_mac_chrome_inactive => "-moz-mac-chrome-inactive",
                    LookAndFeel_ColorID::eColorID__moz_mac_defaultbuttontext => "-moz-mac-defaultbuttontext",
                    LookAndFeel_ColorID::eColorID__moz_mac_focusring => "-moz-mac-focusring",
                    LookAndFeel_ColorID::eColorID__moz_mac_menuselect => "-moz-mac-menuselect",
                    LookAndFeel_ColorID::eColorID__moz_mac_menushadow => "-moz-mac-menushadow",
                    LookAndFeel_ColorID::eColorID__moz_mac_menutextdisable => "-moz-mac-menutextdisable",
                    LookAndFeel_ColorID::eColorID__moz_mac_menutextselect => "-moz-mac-menutextselect",
                    LookAndFeel_ColorID::eColorID__moz_mac_disabledtoolbartext => "-moz-mac-disabledtoolbartext",
                    LookAndFeel_ColorID::eColorID__moz_mac_secondaryhighlight => "-moz-mac-secondaryhighlight",
                    LookAndFeel_ColorID::eColorID__moz_mac_vibrancy_light => "-moz-mac-vibrancy-light",
                    LookAndFeel_ColorID::eColorID__moz_mac_vibrancy_dark => "-moz-mac-vibrancy-dark",
                    LookAndFeel_ColorID::eColorID__moz_mac_vibrant_titlebar_light => "-moz-mac-vibrant-titlebar-light",
                    LookAndFeel_ColorID::eColorID__moz_mac_vibrant_titlebar_dark => "-moz-mac-vibrant-titlebar-dark",
                    LookAndFeel_ColorID::eColorID__moz_mac_menupopup => "-moz-mac-menupopup",
                    LookAndFeel_ColorID::eColorID__moz_mac_menuitem => "-moz-mac-menuitem",
                    LookAndFeel_ColorID::eColorID__moz_mac_active_menuitem => "-moz-mac-active-menuitem",
                    LookAndFeel_ColorID::eColorID__moz_mac_source_list => "-moz-mac-source-list",
                    LookAndFeel_ColorID::eColorID__moz_mac_source_list_selection => "-moz-mac-source-list-selection",
                    LookAndFeel_ColorID::eColorID__moz_mac_active_source_list_selection => "-moz-mac-active-source-list-selection",
                    LookAndFeel_ColorID::eColorID__moz_mac_tooltip => "-moz-mac-tooltip",
                    LookAndFeel_ColorID::eColorID__moz_menuhover => "-moz-menuhover",
                    LookAndFeel_ColorID::eColorID__moz_menuhovertext => "-moz-menuhovertext",
                    LookAndFeel_ColorID::eColorID__moz_menubartext => "-moz-menubartext",
                    LookAndFeel_ColorID::eColorID__moz_menubarhovertext => "-moz-menubarhovertext",
                    LookAndFeel_ColorID::eColorID__moz_oddtreerow => "-moz-oddtreerow",
                    LookAndFeel_ColorID::eColorID__moz_win_mediatext => "-moz-win-mediatext",
                    LookAndFeel_ColorID::eColorID__moz_win_communicationstext => "-moz-win-communicationstext",
                    LookAndFeel_ColorID::eColorID__moz_win_accentcolor => "-moz-win-accentcolor",
                    LookAndFeel_ColorID::eColorID__moz_win_accentcolortext => "-moz-win-accentcolortext",
                    LookAndFeel_ColorID::eColorID__moz_nativehyperlinktext => "-moz-nativehyperlinktext",
                    LookAndFeel_ColorID::eColorID__moz_comboboxtext => "-moz-comboboxtext",
                    LookAndFeel_ColorID::eColorID__moz_combobox => "-moz-combobox",
                    LookAndFeel_ColorID::eColorID_WindowBackground => "WindowBackground",
                    LookAndFeel_ColorID::eColorID_WindowForeground => "WindowForeground",
                    LookAndFeel_ColorID::eColorID_WidgetBackground => "WidgetBackground",
                    LookAndFeel_ColorID::eColorID_WidgetForeground => "WidgetForeground",
                    LookAndFeel_ColorID::eColorID_WidgetSelectBackground => "WidgetSelectBackground",
                    LookAndFeel_ColorID::eColorID_WidgetSelectForeground => "WidgetSelectForeground",
                    LookAndFeel_ColorID::eColorID_Widget3DHighlight => "Widget3DHighlight",
                    LookAndFeel_ColorID::eColorID_Widget3DShadow => "Widget3DShadow",
                    LookAndFeel_ColorID::eColorID_TextBackground => "TextBackground",
                    LookAndFeel_ColorID::eColorID_TextForeground => "TextForeground",
                    LookAndFeel_ColorID::eColorID_TextSelectBackground => "TextSelectBackground",
                    LookAndFeel_ColorID::eColorID_TextSelectForeground => "TextSelectForeground",
                    LookAndFeel_ColorID::eColorID_TextSelectForegroundCustom => "TextSelectForegroundCustom",
                    LookAndFeel_ColorID::eColorID_TextSelectBackgroundDisabled => "TextSelectBackgroundDisabled",
                    LookAndFeel_ColorID::eColorID_TextSelectBackgroundAttention => "TextSelectBackgroundAttention",
                    LookAndFeel_ColorID::eColorID_TextHighlightBackground => "TextHighlightBackground",
                    LookAndFeel_ColorID::eColorID_TextHighlightForeground => "TextHighlightForeground",
                    LookAndFeel_ColorID::eColorID_IMERawInputBackground => "IMERawInputBackground",
                    LookAndFeel_ColorID::eColorID_IMERawInputForeground => "IMERawInputForeground",
                    LookAndFeel_ColorID::eColorID_IMERawInputUnderline => "IMERawInputUnderline",
                    LookAndFeel_ColorID::eColorID_IMESelectedRawTextBackground => "IMESelectedRawTextBackground",
                    LookAndFeel_ColorID::eColorID_IMESelectedRawTextForeground => "IMESelectedRawTextForeground",
                    LookAndFeel_ColorID::eColorID_IMESelectedRawTextUnderline => "IMESelectedRawTextUnderline",
                    LookAndFeel_ColorID::eColorID_IMEConvertedTextBackground => "IMEConvertedTextBackground",
                    LookAndFeel_ColorID::eColorID_IMEConvertedTextForeground => "IMEConvertedTextForeground",
                    LookAndFeel_ColorID::eColorID_IMEConvertedTextUnderline => "IMEConvertedTextUnderline",
                    LookAndFeel_ColorID::eColorID_IMESelectedConvertedTextBackground => "IMESelectedConvertedTextBackground",
                    LookAndFeel_ColorID::eColorID_IMESelectedConvertedTextForeground => "IMESelectedConvertedTextForeground",
                    LookAndFeel_ColorID::eColorID_IMESelectedConvertedTextUnderline => "IMESelectedConvertedTextUnderline",
                    LookAndFeel_ColorID::eColorID_SpellCheckerUnderline => "SpellCheckerUnderline",
                LookAndFeel_ColorID::eColorID_LAST_COLOR => unreachable!(),
            };
            dest.write_str(s)
        }
    }

    impl ToComputedValue for SystemColor {
        type ComputedValue = u32; // nscolor

        #[inline]
        fn to_computed_value(&self, cx: &Context) -> Self::ComputedValue {
            unsafe {
                Gecko_GetLookAndFeelSystemColor(*self as i32,
                                                cx.device().pres_context())
            }
        }

        #[inline]
        fn from_computed_value(_: &Self::ComputedValue) -> Self {
            unreachable!()
        }
    }

    impl SystemColor {
        pub fn from_ident<'i, 't>(ident: &str) -> Result<Self, ()> {
            ascii_case_insensitive_phf_map! {
                color_name -> SystemColor = {
                        "activeborder" => LookAndFeel_ColorID::eColorID_activeborder,
                        "activecaption" => LookAndFeel_ColorID::eColorID_activecaption,
                        "appworkspace" => LookAndFeel_ColorID::eColorID_appworkspace,
                        "background" => LookAndFeel_ColorID::eColorID_background,
                        "buttonface" => LookAndFeel_ColorID::eColorID_buttonface,
                        "buttonhighlight" => LookAndFeel_ColorID::eColorID_buttonhighlight,
                        "buttonshadow" => LookAndFeel_ColorID::eColorID_buttonshadow,
                        "buttontext" => LookAndFeel_ColorID::eColorID_buttontext,
                        "captiontext" => LookAndFeel_ColorID::eColorID_captiontext,
                        "graytext" => LookAndFeel_ColorID::eColorID_graytext,
                        "highlight" => LookAndFeel_ColorID::eColorID_highlight,
                        "highlighttext" => LookAndFeel_ColorID::eColorID_highlighttext,
                        "inactiveborder" => LookAndFeel_ColorID::eColorID_inactiveborder,
                        "inactivecaption" => LookAndFeel_ColorID::eColorID_inactivecaption,
                        "inactivecaptiontext" => LookAndFeel_ColorID::eColorID_inactivecaptiontext,
                        "infobackground" => LookAndFeel_ColorID::eColorID_infobackground,
                        "infotext" => LookAndFeel_ColorID::eColorID_infotext,
                        "menu" => LookAndFeel_ColorID::eColorID_menu,
                        "menutext" => LookAndFeel_ColorID::eColorID_menutext,
                        "scrollbar" => LookAndFeel_ColorID::eColorID_scrollbar,
                        "threeddarkshadow" => LookAndFeel_ColorID::eColorID_threeddarkshadow,
                        "threedface" => LookAndFeel_ColorID::eColorID_threedface,
                        "threedhighlight" => LookAndFeel_ColorID::eColorID_threedhighlight,
                        "threedlightshadow" => LookAndFeel_ColorID::eColorID_threedlightshadow,
                        "threedshadow" => LookAndFeel_ColorID::eColorID_threedshadow,
                        "window" => LookAndFeel_ColorID::eColorID_window,
                        "windowframe" => LookAndFeel_ColorID::eColorID_windowframe,
                        "windowtext" => LookAndFeel_ColorID::eColorID_windowtext,
                        "-moz-buttondefault" => LookAndFeel_ColorID::eColorID__moz_buttondefault,
                        "-moz-buttonhoverface" => LookAndFeel_ColorID::eColorID__moz_buttonhoverface,
                        "-moz-buttonhovertext" => LookAndFeel_ColorID::eColorID__moz_buttonhovertext,
                        "-moz-cellhighlight" => LookAndFeel_ColorID::eColorID__moz_cellhighlight,
                        "-moz-cellhighlighttext" => LookAndFeel_ColorID::eColorID__moz_cellhighlighttext,
                        "-moz-eventreerow" => LookAndFeel_ColorID::eColorID__moz_eventreerow,
                        "-moz-field" => LookAndFeel_ColorID::eColorID__moz_field,
                        "-moz-fieldtext" => LookAndFeel_ColorID::eColorID__moz_fieldtext,
                        "-moz-dialog" => LookAndFeel_ColorID::eColorID__moz_dialog,
                        "-moz-dialogtext" => LookAndFeel_ColorID::eColorID__moz_dialogtext,
                        "-moz-dragtargetzone" => LookAndFeel_ColorID::eColorID__moz_dragtargetzone,
                        "-moz-gtk-info-bar-text" => LookAndFeel_ColorID::eColorID__moz_gtk_info_bar_text,
                        "-moz-html-cellhighlight" => LookAndFeel_ColorID::eColorID__moz_html_cellhighlight,
                        "-moz-html-cellhighlighttext" => LookAndFeel_ColorID::eColorID__moz_html_cellhighlighttext,
                        "-moz-mac-buttonactivetext" => LookAndFeel_ColorID::eColorID__moz_mac_buttonactivetext,
                        "-moz-mac-chrome-active" => LookAndFeel_ColorID::eColorID__moz_mac_chrome_active,
                        "-moz-mac-chrome-inactive" => LookAndFeel_ColorID::eColorID__moz_mac_chrome_inactive,
                        "-moz-mac-defaultbuttontext" => LookAndFeel_ColorID::eColorID__moz_mac_defaultbuttontext,
                        "-moz-mac-focusring" => LookAndFeel_ColorID::eColorID__moz_mac_focusring,
                        "-moz-mac-menuselect" => LookAndFeel_ColorID::eColorID__moz_mac_menuselect,
                        "-moz-mac-menushadow" => LookAndFeel_ColorID::eColorID__moz_mac_menushadow,
                        "-moz-mac-menutextdisable" => LookAndFeel_ColorID::eColorID__moz_mac_menutextdisable,
                        "-moz-mac-menutextselect" => LookAndFeel_ColorID::eColorID__moz_mac_menutextselect,
                        "-moz-mac-disabledtoolbartext" => LookAndFeel_ColorID::eColorID__moz_mac_disabledtoolbartext,
                        "-moz-mac-secondaryhighlight" => LookAndFeel_ColorID::eColorID__moz_mac_secondaryhighlight,
                        "-moz-mac-vibrancy-light" => LookAndFeel_ColorID::eColorID__moz_mac_vibrancy_light,
                        "-moz-mac-vibrancy-dark" => LookAndFeel_ColorID::eColorID__moz_mac_vibrancy_dark,
                        "-moz-mac-vibrant-titlebar-light" => LookAndFeel_ColorID::eColorID__moz_mac_vibrant_titlebar_light,
                        "-moz-mac-vibrant-titlebar-dark" => LookAndFeel_ColorID::eColorID__moz_mac_vibrant_titlebar_dark,
                        "-moz-mac-menupopup" => LookAndFeel_ColorID::eColorID__moz_mac_menupopup,
                        "-moz-mac-menuitem" => LookAndFeel_ColorID::eColorID__moz_mac_menuitem,
                        "-moz-mac-active-menuitem" => LookAndFeel_ColorID::eColorID__moz_mac_active_menuitem,
                        "-moz-mac-source-list" => LookAndFeel_ColorID::eColorID__moz_mac_source_list,
                        "-moz-mac-source-list-selection" => LookAndFeel_ColorID::eColorID__moz_mac_source_list_selection,
                        "-moz-mac-active-source-list-selection" => LookAndFeel_ColorID::eColorID__moz_mac_active_source_list_selection,
                        "-moz-mac-tooltip" => LookAndFeel_ColorID::eColorID__moz_mac_tooltip,
                        "-moz-menuhover" => LookAndFeel_ColorID::eColorID__moz_menuhover,
                        "-moz-menuhovertext" => LookAndFeel_ColorID::eColorID__moz_menuhovertext,
                        "-moz-menubartext" => LookAndFeel_ColorID::eColorID__moz_menubartext,
                        "-moz-menubarhovertext" => LookAndFeel_ColorID::eColorID__moz_menubarhovertext,
                        "-moz-oddtreerow" => LookAndFeel_ColorID::eColorID__moz_oddtreerow,
                        "-moz-win-mediatext" => LookAndFeel_ColorID::eColorID__moz_win_mediatext,
                        "-moz-win-communicationstext" => LookAndFeel_ColorID::eColorID__moz_win_communicationstext,
                        "-moz-win-accentcolor" => LookAndFeel_ColorID::eColorID__moz_win_accentcolor,
                        "-moz-win-accentcolortext" => LookAndFeel_ColorID::eColorID__moz_win_accentcolortext,
                        "-moz-nativehyperlinktext" => LookAndFeel_ColorID::eColorID__moz_nativehyperlinktext,
                        "-moz-comboboxtext" => LookAndFeel_ColorID::eColorID__moz_comboboxtext,
                        "-moz-combobox" => LookAndFeel_ColorID::eColorID__moz_combobox,
                }
            }

            color_name(ident).cloned().ok_or(())
        }
    }
}

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-width
    pub mod column_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::length::NonNegativeLengthOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::length::NonNegativeLengthOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(Auto) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { Either::Second(Auto) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::length::NonNegativeLengthOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ColumnWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnWidth)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-count
    pub mod column_count {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ColumnCount as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ColumnCount as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ColumnCount::auto() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::ColumnCount::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ColumnCount::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnCount(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ColumnCount);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnCount);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_count(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_count();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_count();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnCount)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-gap
    pub mod column_gap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::length::NonNegativeLengthOrNormal as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::length::NonNegativeLengthOrNormal as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(Normal) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::length::NonNegativeLengthOrNormal::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnGap(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ColumnGap);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnGap);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_gap(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_gap();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_gap();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnGap)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-fill
    pub mod column_fill {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Balance,
            
            Auto,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Balance
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Balance
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnFill(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ColumnFill);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnFill);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_fill(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_fill();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_fill();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnFill)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-rule-width
    pub mod column_rule_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BorderSideWidth::Medium }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnRuleWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ColumnRuleWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnRuleWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_rule_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_rule_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_rule_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnRuleWidth)
        }
    }



// https://drafts.csswg.org/css-multicol-1/#crc

    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-rule-color
    pub mod column_rule_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Color::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnRuleColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ColumnRuleColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnRuleColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_rule_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_rule_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_rule_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnRuleColor)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-span
    pub mod column_span {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            None,
            
            All,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnSpan(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ColumnSpan);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnSpan);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_span(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_span();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_span();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnSpan)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-rule-style
    pub mod column_rule_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            None,
            
            Hidden,
            
            Dotted,
            
            Dashed,
            
            Solid,
            
            Double,
            
            Groove,
            
            Ridge,
            
            Inset,
            
            Outset,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnRuleStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ColumnRuleStyle);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnRuleStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_rule_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_rule_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_rule_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnRuleStyle)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
        
    
    /// https://drafts.csswg.org/css-content/#propdef-content
    pub mod content {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Content as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Content as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Content::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Content::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Content::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Content(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Content);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Content);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_content(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_content();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_content();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Content)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-lists/#propdef-counter-increment
    pub mod counter_increment {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::CounterIncrement as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::CounterIncrement as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::CounterIncrement::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::CounterIncrement(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::CounterIncrement);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::CounterIncrement);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_counter_increment(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_counter_increment();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_counter_increment();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::CounterIncrement)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-lists-3/#propdef-counter-reset
    pub mod counter_reset {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::CounterReset as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::CounterReset as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::CounterReset::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::CounterReset(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::CounterReset);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::CounterReset);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_counter_reset(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_counter_reset();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_counter_reset();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::CounterReset)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */



// Box-shadow, etc.



    
        
    
    /// https://drafts.csswg.org/css-color/#opacity
    pub mod opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Opacity as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Opacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 1.0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Opacity::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Opacity(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Opacity);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Opacity);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_opacity(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_opacity();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_opacity();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Opacity)
        }
    }




    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#box-shadow
    pub mod box_shadow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BoxShadow as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BoxShadow as T;
        }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BoxShadow::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for box-shadow.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use std::vec::IntoIter;
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(if_empty = "none", iterable)]
                pub Vec<single_value::T>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<single_value::T>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of box-shadow.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(if_empty = "none", iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                computed_value::T(vec![])
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

                if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                    return Ok(SpecifiedValue(Vec::new()))
                }

            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BoxShadow(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BoxShadow);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BoxShadow);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_effects();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_box_shadow(iter);
                        }
                        context.builder.put_effects(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_box_shadow();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_box_shadow();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BoxShadow)
        }
    }





    
        
    
    /// https://drafts.fxtf.org/css-masking/#clip-property
    pub mod clip {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ClipRectOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ClipRectOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ClipRectOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ClipRectOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Clip(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Clip);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Clip);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_clip(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_clip();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_clip();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Clip)
        }
    }




    
        
    
    
    /// https://drafts.fxtf.org/filters/#propdef-filter
    pub mod filter {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Filter as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Filter as T;
        }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Filter::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for filter.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use std::vec::IntoIter;
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(if_empty = "none", iterable)]
                pub Vec<single_value::T>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<single_value::T>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of filter.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(if_empty = "none", iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                computed_value::T(vec![])
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

                if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                    return Ok(SpecifiedValue(Vec::new()))
                }

            ::style_traits::Space::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Filter(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Filter);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Filter);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_effects();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_filter(iter);
                        }
                        context.builder.put_effects(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_filter();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_filter();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Filter)
        }
    }





    

    
        
    
    /// https://drafts.fxtf.org/compositing/#propdef-mix-blend-mode
    pub mod mix_blend_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Normal,
            
            Multiply,
            
            Screen,
            
            Overlay,
            
            Darken,
            
            Lighten,
            
            ColorDodge,
            
            ColorBurn,
            
            HardLight,
            
            SoftLight,
            
            Difference,
            
            Exclusion,
            
            Hue,
            
            Saturation,
            
            Color,
            
            Luminosity,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MixBlendMode(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MixBlendMode);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MixBlendMode);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_mix_blend_mode(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mix_blend_mode();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mix_blend_mode();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MixBlendMode)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */







    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-family
    pub mod font_family {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontFamily as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontFamily as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontFamily::serif() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontFamily::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontFamily(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontFamily);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_family(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_family();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_family();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontFamily)
        }
    }




    
    
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-style
    pub mod font_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use properties::longhands::system_font::SystemFont;

        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, Hash, MallocSizeOf, Parse)]
            #[derive(PartialEq, ToCss)]
            pub enum T {
                Normal,
                Italic,
                Oblique,
            }

            
    
    #[cfg(feature = "gecko")]
    impl T {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: i32
                    = structs::NS_FONT_STYLE_NORMAL as i32;
                // We can't match on enum values if we're matching on a u32
                const ITALIC: i32
                    = structs::NS_FONT_STYLE_ITALIC as i32;
                // We can't match on enum values if we're matching on a u32
                const OBLIQUE: i32
                    = structs::NS_FONT_STYLE_OBLIQUE as i32;
            match kw as i32 {
                    NORMAL => T::Normal,
                    ITALIC => T::Italic,
                    OBLIQUE => T::Oblique,
                _ => panic!("Found unexpected value in style struct for font-style property"),
            }
        }
    }

        }

        #[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
        #[derive(Clone, Copy, Debug, Eq, PartialEq, ToCss)]
        pub enum SpecifiedValue {
            Keyword(computed_value::T),
            System(SystemFont),
        }

        pub fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<SpecifiedValue, ParseError<'i>> {
            Ok(SpecifiedValue::Keyword(computed_value::T::parse(input)?))
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            fn to_computed_value(&self, _cx: &Context) -> Self::ComputedValue {
                match *self {
                    SpecifiedValue::Keyword(v) => v,
                    SpecifiedValue::System(_) => {
                            _cx.cached_system_font.as_ref().unwrap().font_style
                    }
                }
            }
            fn from_computed_value(other: &computed_value::T) -> Self {
                SpecifiedValue::Keyword(*other)
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Keyword(computed_value::T::Normal)
        }

        impl SpecifiedValue {
            pub fn system_font(f: SystemFont) -> Self {
                SpecifiedValue::System(f)
            }
            pub fn get_system(&self) -> Option<SystemFont> {
                if let SpecifiedValue::System(s) = *self {
                    Some(s)
                } else {
                    None
                }
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontStyle);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_style();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontStyle)
        }
    }






    
    
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-caps
    pub mod font_variant_caps {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use properties::longhands::system_font::SystemFont;

        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, Hash, MallocSizeOf, Parse)]
            #[derive(PartialEq, ToCss)]
            pub enum T {
                Normal,
                SmallCaps,
                AllSmallCaps,
                PetiteCaps,
                AllPetiteCaps,
                Unicase,
                TitlingCaps,
            }

            
    
    #[cfg(feature = "gecko")]
    impl T {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: i32
                    = structs::NS_FONT_VARIANT_CAPS_NORMAL as i32;
                // We can't match on enum values if we're matching on a u32
                const SMALL_CAPS: i32
                    = structs::NS_FONT_VARIANT_CAPS_SMALLCAPS as i32;
                // We can't match on enum values if we're matching on a u32
                const ALL_SMALL_CAPS: i32
                    = structs::NS_FONT_VARIANT_CAPS_ALLSMALL as i32;
                // We can't match on enum values if we're matching on a u32
                const PETITE_CAPS: i32
                    = structs::NS_FONT_VARIANT_CAPS_PETITECAPS as i32;
                // We can't match on enum values if we're matching on a u32
                const ALL_PETITE_CAPS: i32
                    = structs::NS_FONT_VARIANT_CAPS_ALLPETITE as i32;
                // We can't match on enum values if we're matching on a u32
                const UNICASE: i32
                    = structs::NS_FONT_VARIANT_CAPS_UNICASE as i32;
                // We can't match on enum values if we're matching on a u32
                const TITLING_CAPS: i32
                    = structs::NS_FONT_VARIANT_CAPS_TITLING as i32;
            match kw as i32 {
                    NORMAL => T::Normal,
                    SMALL_CAPS => T::SmallCaps,
                    ALL_SMALL_CAPS => T::AllSmallCaps,
                    PETITE_CAPS => T::PetiteCaps,
                    ALL_PETITE_CAPS => T::AllPetiteCaps,
                    UNICASE => T::Unicase,
                    TITLING_CAPS => T::TitlingCaps,
                _ => panic!("Found unexpected value in style struct for font-variant-caps property"),
            }
        }
    }

        }

        #[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
        #[derive(Clone, Copy, Debug, Eq, PartialEq, ToCss)]
        pub enum SpecifiedValue {
            Keyword(computed_value::T),
            System(SystemFont),
        }

        pub fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<SpecifiedValue, ParseError<'i>> {
            Ok(SpecifiedValue::Keyword(computed_value::T::parse(input)?))
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            fn to_computed_value(&self, _cx: &Context) -> Self::ComputedValue {
                match *self {
                    SpecifiedValue::Keyword(v) => v,
                    SpecifiedValue::System(_) => {
                            _cx.cached_system_font.as_ref().unwrap().font_variant_caps
                    }
                }
            }
            fn from_computed_value(other: &computed_value::T) -> Self {
                SpecifiedValue::Keyword(*other)
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Keyword(computed_value::T::Normal)
        }

        impl SpecifiedValue {
            pub fn system_font(f: SystemFont) -> Self {
                SpecifiedValue::System(f)
            }
            pub fn get_system(&self) -> Option<SystemFont> {
                if let SpecifiedValue::System(s) = *self {
                    Some(s)
                } else {
                    None
                }
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontVariantCaps(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontVariantCaps);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_variant_caps(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_variant_caps();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_variant_caps();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantCaps)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-weight
    pub mod font_weight {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontWeight as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontWeight as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontWeight::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontWeight::Normal }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontWeight::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontWeight(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontWeight);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_weight(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_weight();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_weight();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontWeight)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-size
    pub mod font_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontSize as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontSize::medium() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontSize::medium() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontSize::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontSize);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                             specified::FontSize::cascade_specified_font_size(
                                 context,
                                 &specified_value,
                                 computed,
                             );
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            computed::FontSize::cascade_initial_font_size(context);
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            computed::FontSize::cascade_inherit_font_size(context);
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontSize)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-size-adjust
    pub mod font_size_adjust {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontSizeAdjust as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontSizeAdjust as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontSizeAdjust::none() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontSizeAdjust::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontSizeAdjust::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontSizeAdjust(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontSizeAdjust);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_size_adjust(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_size_adjust();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_size_adjust();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontSizeAdjust)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-synthesis
    pub mod font_synthesis {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontSynthesis as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontSynthesis as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::FontSynthesis::get_initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontSynthesis::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontSynthesis(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontSynthesis);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_synthesis(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_synthesis();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_synthesis();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontSynthesis)
        }
    }




    
    
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-stretch
    pub mod font_stretch {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use properties::longhands::system_font::SystemFont;

        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, Hash, MallocSizeOf, Parse)]
            #[derive(PartialEq, ToCss)]
            pub enum T {
                Normal,
                UltraCondensed,
                ExtraCondensed,
                Condensed,
                SemiCondensed,
                SemiExpanded,
                Expanded,
                ExtraExpanded,
                UltraExpanded,
            }

            
    
    #[cfg(feature = "gecko")]
    impl T {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: i32
                    = structs::NS_FONT_STRETCH_NORMAL as i32;
                // We can't match on enum values if we're matching on a u32
                const ULTRA_CONDENSED: i32
                    = structs::NS_FONT_STRETCH_ULTRA_CONDENSED as i32;
                // We can't match on enum values if we're matching on a u32
                const EXTRA_CONDENSED: i32
                    = structs::NS_FONT_STRETCH_EXTRA_CONDENSED as i32;
                // We can't match on enum values if we're matching on a u32
                const CONDENSED: i32
                    = structs::NS_FONT_STRETCH_CONDENSED as i32;
                // We can't match on enum values if we're matching on a u32
                const SEMI_CONDENSED: i32
                    = structs::NS_FONT_STRETCH_SEMI_CONDENSED as i32;
                // We can't match on enum values if we're matching on a u32
                const SEMI_EXPANDED: i32
                    = structs::NS_FONT_STRETCH_SEMI_EXPANDED as i32;
                // We can't match on enum values if we're matching on a u32
                const EXPANDED: i32
                    = structs::NS_FONT_STRETCH_EXPANDED as i32;
                // We can't match on enum values if we're matching on a u32
                const EXTRA_EXPANDED: i32
                    = structs::NS_FONT_STRETCH_EXTRA_EXPANDED as i32;
                // We can't match on enum values if we're matching on a u32
                const ULTRA_EXPANDED: i32
                    = structs::NS_FONT_STRETCH_ULTRA_EXPANDED as i32;
            match kw as i32 {
                    NORMAL => T::Normal,
                    ULTRA_CONDENSED => T::UltraCondensed,
                    EXTRA_CONDENSED => T::ExtraCondensed,
                    CONDENSED => T::Condensed,
                    SEMI_CONDENSED => T::SemiCondensed,
                    SEMI_EXPANDED => T::SemiExpanded,
                    EXPANDED => T::Expanded,
                    EXTRA_EXPANDED => T::ExtraExpanded,
                    ULTRA_EXPANDED => T::UltraExpanded,
                _ => panic!("Found unexpected value in style struct for font-stretch property"),
            }
        }
    }

        }

        #[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
        #[derive(Clone, Copy, Debug, Eq, PartialEq, ToCss)]
        pub enum SpecifiedValue {
            Keyword(computed_value::T),
            System(SystemFont),
        }

        pub fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<SpecifiedValue, ParseError<'i>> {
            Ok(SpecifiedValue::Keyword(computed_value::T::parse(input)?))
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            fn to_computed_value(&self, _cx: &Context) -> Self::ComputedValue {
                match *self {
                    SpecifiedValue::Keyword(v) => v,
                    SpecifiedValue::System(_) => {
                            _cx.cached_system_font.as_ref().unwrap().font_stretch
                    }
                }
            }
            fn from_computed_value(other: &computed_value::T) -> Self {
                SpecifiedValue::Keyword(*other)
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Keyword(computed_value::T::Normal)
        }

        impl SpecifiedValue {
            pub fn system_font(f: SystemFont) -> Self {
                SpecifiedValue::System(f)
            }
            pub fn get_system(&self) -> Option<SystemFont> {
                if let SpecifiedValue::System(s) = *self {
                    Some(s)
                } else {
                    None
                }
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontStretch(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontStretch);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_stretch(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_stretch();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_stretch();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontStretch)
        }
    }




    
    
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-kerning
    pub mod font_kerning {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use properties::longhands::system_font::SystemFont;

        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, Hash, MallocSizeOf, Parse)]
            #[derive(PartialEq, ToCss)]
            pub enum T {
                Auto,
                None,
                Normal,
            }

            
    
    #[cfg(feature = "gecko")]
    impl T {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const AUTO: i32
                    = structs::NS_FONT_KERNING_AUTO as i32;
                // We can't match on enum values if we're matching on a u32
                const NONE: i32
                    = structs::NS_FONT_KERNING_NONE as i32;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: i32
                    = structs::NS_FONT_KERNING_NORMAL as i32;
            match kw as i32 {
                    AUTO => T::Auto,
                    NONE => T::None,
                    NORMAL => T::Normal,
                _ => panic!("Found unexpected value in style struct for font-kerning property"),
            }
        }
    }

        }

        #[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
        #[derive(Clone, Copy, Debug, Eq, PartialEq, ToCss)]
        pub enum SpecifiedValue {
            Keyword(computed_value::T),
            System(SystemFont),
        }

        pub fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<SpecifiedValue, ParseError<'i>> {
            Ok(SpecifiedValue::Keyword(computed_value::T::parse(input)?))
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            fn to_computed_value(&self, _cx: &Context) -> Self::ComputedValue {
                match *self {
                    SpecifiedValue::Keyword(v) => v,
                    SpecifiedValue::System(_) => {
                            _cx.cached_system_font.as_ref().unwrap().font_kerning
                    }
                }
            }
            fn from_computed_value(other: &computed_value::T) -> Self {
                SpecifiedValue::Keyword(*other)
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Keyword(computed_value::T::Auto)
        }

        impl SpecifiedValue {
            pub fn system_font(f: SystemFont) -> Self {
                SpecifiedValue::System(f)
            }
            pub fn get_system(&self) -> Option<SystemFont> {
                if let SpecifiedValue::System(s) = *self {
                    Some(s)
                } else {
                    None
                }
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontKerning(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontKerning);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_kerning(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_kerning();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_kerning();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontKerning)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-alternates
    pub mod font_variant_alternates {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontVariantAlternates as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontVariantAlternates as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontVariantAlternates::get_initial_value() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontVariantAlternates::get_initial_specified_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontVariantAlternates::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontVariantAlternates(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontVariantAlternates);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_variant_alternates(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_variant_alternates();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_variant_alternates();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantAlternates)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-east-asian
    pub mod font_variant_east_asian {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontVariantEastAsian as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontVariantEastAsian as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontVariantEastAsian::empty() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontVariantEastAsian::empty() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontVariantEastAsian::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontVariantEastAsian(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontVariantEastAsian);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_variant_east_asian(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_variant_east_asian();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_variant_east_asian();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantEastAsian)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-ligatures
    pub mod font_variant_ligatures {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontVariantLigatures as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontVariantLigatures as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontVariantLigatures::empty() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontVariantLigatures::empty() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontVariantLigatures::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontVariantLigatures(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontVariantLigatures);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_variant_ligatures(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_variant_ligatures();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_variant_ligatures();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantLigatures)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-numeric
    pub mod font_variant_numeric {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontVariantNumeric as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontVariantNumeric as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontVariantNumeric::empty() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontVariantNumeric::empty() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontVariantNumeric::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontVariantNumeric(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontVariantNumeric);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_variant_numeric(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_variant_numeric();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_variant_numeric();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantNumeric)
        }
    }




    
    
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-position
    pub mod font_variant_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use properties::longhands::system_font::SystemFont;

        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, Hash, MallocSizeOf, Parse)]
            #[derive(PartialEq, ToCss)]
            pub enum T {
                Normal,
                Sub,
                Super,
            }

            
    
    #[cfg(feature = "gecko")]
    impl T {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: i32
                    = structs::NS_FONT_VARIANT_POSITION_NORMAL as i32;
                // We can't match on enum values if we're matching on a u32
                const SUB: i32
                    = structs::NS_FONT_VARIANT_POSITION_SUB as i32;
                // We can't match on enum values if we're matching on a u32
                const SUPER_: i32
                    = structs::NS_FONT_VARIANT_POSITION_SUPER as i32;
            match kw as i32 {
                    NORMAL => T::Normal,
                    SUB => T::Sub,
                    SUPER_ => T::Super,
                _ => panic!("Found unexpected value in style struct for font-variant-position property"),
            }
        }
    }

        }

        #[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
        #[derive(Clone, Copy, Debug, Eq, PartialEq, ToCss)]
        pub enum SpecifiedValue {
            Keyword(computed_value::T),
            System(SystemFont),
        }

        pub fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<SpecifiedValue, ParseError<'i>> {
            Ok(SpecifiedValue::Keyword(computed_value::T::parse(input)?))
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            fn to_computed_value(&self, _cx: &Context) -> Self::ComputedValue {
                match *self {
                    SpecifiedValue::Keyword(v) => v,
                    SpecifiedValue::System(_) => {
                            _cx.cached_system_font.as_ref().unwrap().font_variant_position
                    }
                }
            }
            fn from_computed_value(other: &computed_value::T) -> Self {
                SpecifiedValue::Keyword(*other)
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Keyword(computed_value::T::Normal)
        }

        impl SpecifiedValue {
            pub fn system_font(f: SystemFont) -> Self {
                SpecifiedValue::System(f)
            }
            pub fn get_system(&self) -> Option<SystemFont> {
                if let SpecifiedValue::System(s) = *self {
                    Some(s)
                } else {
                    None
                }
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontVariantPosition(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontVariantPosition);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_variant_position(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_variant_position();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_variant_position();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantPosition)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-feature-settings
    pub mod font_feature_settings {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontFeatureSettings as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontFeatureSettings as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontFeatureSettings::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontFeatureSettings::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontFeatureSettings::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontFeatureSettings(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontFeatureSettings);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_feature_settings(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_feature_settings();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_feature_settings();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontFeatureSettings)
        }
    }






    
        
    
    /// ${variation_spec}
    pub mod font_variation_settings {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontVariationSettings as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontVariationSettings as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontVariationSettings::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontVariationSettings::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontVariationSettings::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontVariationSettings(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontVariationSettings);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_variation_settings(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_variation_settings();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_variation_settings();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariationSettings)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts-3/#propdef-font-language-override
    pub mod font_language_override {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontLanguageOverride as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontLanguageOverride as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontLanguageOverride::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontLanguageOverride::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontLanguageOverride::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontLanguageOverride(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontLanguageOverride);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_language_override(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_language_override();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_language_override();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontLanguageOverride)
        }
    }




    
    
    
    /// https://www.w3.org/TR/css-fonts-4/#font-optical-sizing-def
    pub mod font_optical_sizing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use properties::longhands::system_font::SystemFont;

        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, Hash, MallocSizeOf, Parse)]
            #[derive(PartialEq, ToCss)]
            pub enum T {
                Auto,
                None,
            }

            
    
    #[cfg(feature = "gecko")]
    impl T {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const AUTO: i32
                    = structs::NS_FONT_OPTICAL_SIZING_AUTO as i32;
                // We can't match on enum values if we're matching on a u32
                const NONE: i32
                    = structs::NS_FONT_OPTICAL_SIZING_NONE as i32;
            match kw as i32 {
                    AUTO => T::Auto,
                    NONE => T::None,
                _ => panic!("Found unexpected value in style struct for font-optical-sizing property"),
            }
        }
    }

        }

        #[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
        #[derive(Clone, Copy, Debug, Eq, PartialEq, ToCss)]
        pub enum SpecifiedValue {
            Keyword(computed_value::T),
            System(SystemFont),
        }

        pub fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<SpecifiedValue, ParseError<'i>> {
            Ok(SpecifiedValue::Keyword(computed_value::T::parse(input)?))
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            fn to_computed_value(&self, _cx: &Context) -> Self::ComputedValue {
                match *self {
                    SpecifiedValue::Keyword(v) => v,
                    SpecifiedValue::System(_) => {
                            _cx.cached_system_font.as_ref().unwrap().font_optical_sizing
                    }
                }
            }
            fn from_computed_value(other: &computed_value::T) -> Self {
                SpecifiedValue::Keyword(*other)
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Keyword(computed_value::T::Auto)
        }

        impl SpecifiedValue {
            pub fn system_font(f: SystemFont) -> Self {
                SpecifiedValue::System(f)
            }
            pub fn get_system(&self) -> Option<SystemFont> {
                if let SpecifiedValue::System(s) = *self {
                    Some(s)
                } else {
                    None
                }
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontOpticalSizing(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FontOpticalSizing);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_optical_sizing(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_optical_sizing();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_optical_sizing();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontOpticalSizing)
        }
    }




    
        
    
    /// Internal (not web-exposed)
    pub mod _x_lang {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::XLang as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::XLang as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::XLang::get_initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::XLang::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::XLang(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::XLang);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__x_lang(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__x_lang();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__x_lang();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::XLang)
        }
    }




    
        
    
    /// Internal (not web-exposed)
    pub mod _moz_script_size_multiplier {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozScriptSizeMultiplier as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozScriptSizeMultiplier as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MozScriptSizeMultiplier::get_initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozScriptSizeMultiplier::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozScriptSizeMultiplier(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozScriptSizeMultiplier);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_script_size_multiplier(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_script_size_multiplier();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_script_size_multiplier();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozScriptSizeMultiplier)
        }
    }




    
        
    
    /// Internal (not web-exposed)
    pub mod _moz_script_level {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozScriptLevel as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozScriptLevel as T;
        }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozScriptLevel::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozScriptLevel(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozScriptLevel);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_script_level(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_script_level();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_script_level();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozScriptLevel)
        }
    }




    

    
        
    
    /// Internal (not web-exposed)
    pub mod _moz_math_display {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Inline,
            
            Block,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Inline
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Inline
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozMathDisplay(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozMathDisplay);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_math_display(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_math_display();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_math_display();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozMathDisplay)
        }
    }




    

    
        
    
    /// Internal (not web-exposed)
    pub mod _moz_math_variant {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            None,
            
            Normal,
            
            Bold,
            
            Italic,
            
            BoldItalic,
            
            Script,
            
            BoldScript,
            
            Fraktur,
            
            DoubleStruck,
            
            BoldFraktur,
            
            SansSerif,
            
            BoldSansSerif,
            
            SansSerifItalic,
            
            SansSerifBoldItalic,
            
            Monospace,
            
            Initial,
            
            Tailed,
            
            Looped,
            
            Stretched,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NONE: u32
                    = structs::NS_MATHML_MATHVARIANT_NONE as u32;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: u32
                    = structs::NS_MATHML_MATHVARIANT_NORMAL as u32;
                // We can't match on enum values if we're matching on a u32
                const BOLD: u32
                    = structs::NS_MATHML_MATHVARIANT_BOLD as u32;
                // We can't match on enum values if we're matching on a u32
                const ITALIC: u32
                    = structs::NS_MATHML_MATHVARIANT_ITALIC as u32;
                // We can't match on enum values if we're matching on a u32
                const BOLD_ITALIC: u32
                    = structs::NS_MATHML_MATHVARIANT_BOLD_ITALIC as u32;
                // We can't match on enum values if we're matching on a u32
                const SCRIPT: u32
                    = structs::NS_MATHML_MATHVARIANT_SCRIPT as u32;
                // We can't match on enum values if we're matching on a u32
                const BOLD_SCRIPT: u32
                    = structs::NS_MATHML_MATHVARIANT_BOLD_SCRIPT as u32;
                // We can't match on enum values if we're matching on a u32
                const FRAKTUR: u32
                    = structs::NS_MATHML_MATHVARIANT_FRAKTUR as u32;
                // We can't match on enum values if we're matching on a u32
                const DOUBLE_STRUCK: u32
                    = structs::NS_MATHML_MATHVARIANT_DOUBLE_STRUCK as u32;
                // We can't match on enum values if we're matching on a u32
                const BOLD_FRAKTUR: u32
                    = structs::NS_MATHML_MATHVARIANT_BOLD_FRAKTUR as u32;
                // We can't match on enum values if we're matching on a u32
                const SANS_SERIF: u32
                    = structs::NS_MATHML_MATHVARIANT_SANS_SERIF as u32;
                // We can't match on enum values if we're matching on a u32
                const BOLD_SANS_SERIF: u32
                    = structs::NS_MATHML_MATHVARIANT_BOLD_SANS_SERIF as u32;
                // We can't match on enum values if we're matching on a u32
                const SANS_SERIF_ITALIC: u32
                    = structs::NS_MATHML_MATHVARIANT_SANS_SERIF_ITALIC as u32;
                // We can't match on enum values if we're matching on a u32
                const SANS_SERIF_BOLD_ITALIC: u32
                    = structs::NS_MATHML_MATHVARIANT_SANS_SERIF_BOLD_ITALIC as u32;
                // We can't match on enum values if we're matching on a u32
                const MONOSPACE: u32
                    = structs::NS_MATHML_MATHVARIANT_MONOSPACE as u32;
                // We can't match on enum values if we're matching on a u32
                const INITIAL: u32
                    = structs::NS_MATHML_MATHVARIANT_INITIAL as u32;
                // We can't match on enum values if we're matching on a u32
                const TAILED: u32
                    = structs::NS_MATHML_MATHVARIANT_TAILED as u32;
                // We can't match on enum values if we're matching on a u32
                const LOOPED: u32
                    = structs::NS_MATHML_MATHVARIANT_LOOPED as u32;
                // We can't match on enum values if we're matching on a u32
                const STRETCHED: u32
                    = structs::NS_MATHML_MATHVARIANT_STRETCHED as u32;
            match kw  {
                    NONE => SpecifiedValue::None,
                    NORMAL => SpecifiedValue::Normal,
                    BOLD => SpecifiedValue::Bold,
                    ITALIC => SpecifiedValue::Italic,
                    BOLD_ITALIC => SpecifiedValue::BoldItalic,
                    SCRIPT => SpecifiedValue::Script,
                    BOLD_SCRIPT => SpecifiedValue::BoldScript,
                    FRAKTUR => SpecifiedValue::Fraktur,
                    DOUBLE_STRUCK => SpecifiedValue::DoubleStruck,
                    BOLD_FRAKTUR => SpecifiedValue::BoldFraktur,
                    SANS_SERIF => SpecifiedValue::SansSerif,
                    BOLD_SANS_SERIF => SpecifiedValue::BoldSansSerif,
                    SANS_SERIF_ITALIC => SpecifiedValue::SansSerifItalic,
                    SANS_SERIF_BOLD_ITALIC => SpecifiedValue::SansSerifBoldItalic,
                    MONOSPACE => SpecifiedValue::Monospace,
                    INITIAL => SpecifiedValue::Initial,
                    TAILED => SpecifiedValue::Tailed,
                    LOOPED => SpecifiedValue::Looped,
                    STRETCHED => SpecifiedValue::Stretched,
                _ => panic!("Found unexpected value in style struct for -moz-math-variant property"),
            }
        }
    }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozMathVariant(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozMathVariant);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_math_variant(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_math_variant();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_math_variant();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozMathVariant)
        }
    }




    
        
    
    /// Internal (not web-exposed)
    pub mod _moz_script_min_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozScriptMinSize as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozScriptMinSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::MozScriptMinSize::get_initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozScriptMinSize::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozScriptMinSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozScriptMinSize);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_script_min_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_script_min_size();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_script_min_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozScriptMinSize)
        }
    }




    
        
    
    /// Internal (not web-exposed)
    pub mod _x_text_zoom {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::XTextZoom as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::XTextZoom as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::XTextZoom(true) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::XTextZoom::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::XTextZoom(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::XTextZoom);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__x_text_zoom(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__x_text_zoom();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__x_text_zoom();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::XTextZoom)
        }
    }



    pub mod system_font {
        //! We deal with system fonts here
        //!
        //! System fonts can only be set as a group via the font shorthand.
        //! They resolve at compute time (not parse time -- this lets the
        //! browser respond to changes to the OS font settings).
        //!
        //! While Gecko handles these as a separate property and keyword
        //! values on each property indicating that the font should be picked
        //! from the -x-system-font property, we avoid this. Instead,
        //! each font longhand has a special SystemFont variant which contains
        //! the specified system font. When the cascade function (in helpers)
        //! detects that a value has a system font, it will resolve it, and
        //! cache it on the ComputedValues. After this, it can be just fetched
        //! whenever a font longhand on the same element needs the system font.

        use app_units::Au;
        use cssparser::{Parser, ToCss};
        use gecko_bindings::structs::FontFamilyType;
        use properties::longhands;
        use std::fmt;
        use std::hash::{Hash, Hasher};
        use style_traits::ParseError;
        use values::computed::{ToComputedValue, Context};

        
        #[derive(Clone, Copy, Debug, Eq, Hash, MallocSizeOf, PartialEq, ToCss)]
        pub enum SystemFont {
                Caption,
                Icon,
                Menu,
                MessageBox,
                SmallCaption,
                StatusBar,
                MozWindow,
                MozDocument,
                MozWorkspace,
                MozDesktop,
                MozInfo,
                MozDialog,
                MozButton,
                MozPullDownMenu,
                MozList,
                MozField,
        }

        // ComputedValues are compared at times
        // so we need these impls. We don't want to
        // add Eq to Number (which contains a float)
        // so instead we have an eq impl which skips the
        // cached values
        impl PartialEq for ComputedSystemFont {
            fn eq(&self, other: &Self) -> bool {
                self.system_font == other.system_font
            }
        }
        impl Eq for ComputedSystemFont {}

        impl Hash for ComputedSystemFont {
            fn hash<H: Hasher>(&self, hasher: &mut H) {
                self.system_font.hash(hasher)
            }
        }

        impl ToComputedValue for SystemFont {
            type ComputedValue = ComputedSystemFont;

            fn to_computed_value(&self, cx: &Context) -> Self::ComputedValue {
                use gecko_bindings::bindings;
                use gecko_bindings::structs::{LookAndFeel_FontID, nsFont};
                use std::mem;
                use values::computed::font::{FontSize, FontFamilyList};

                let id = match *self {
                        SystemFont::Caption => {
                            LookAndFeel_FontID::eFont_Caption
                        }
                        SystemFont::Icon => {
                            LookAndFeel_FontID::eFont_Icon
                        }
                        SystemFont::Menu => {
                            LookAndFeel_FontID::eFont_Menu
                        }
                        SystemFont::MessageBox => {
                            LookAndFeel_FontID::eFont_MessageBox
                        }
                        SystemFont::SmallCaption => {
                            LookAndFeel_FontID::eFont_SmallCaption
                        }
                        SystemFont::StatusBar => {
                            LookAndFeel_FontID::eFont_StatusBar
                        }
                        SystemFont::MozWindow => {
                            LookAndFeel_FontID::eFont_Window
                        }
                        SystemFont::MozDocument => {
                            LookAndFeel_FontID::eFont_Document
                        }
                        SystemFont::MozWorkspace => {
                            LookAndFeel_FontID::eFont_Workspace
                        }
                        SystemFont::MozDesktop => {
                            LookAndFeel_FontID::eFont_Desktop
                        }
                        SystemFont::MozInfo => {
                            LookAndFeel_FontID::eFont_Info
                        }
                        SystemFont::MozDialog => {
                            LookAndFeel_FontID::eFont_Dialog
                        }
                        SystemFont::MozButton => {
                            LookAndFeel_FontID::eFont_Button
                        }
                        SystemFont::MozPullDownMenu => {
                            LookAndFeel_FontID::eFont_PullDownMenu
                        }
                        SystemFont::MozList => {
                            LookAndFeel_FontID::eFont_List
                        }
                        SystemFont::MozField => {
                            LookAndFeel_FontID::eFont_Field
                        }
                };

                let mut system: nsFont = unsafe { mem::uninitialized() };
                unsafe {
                    bindings::Gecko_nsFont_InitSystem(
                        &mut system,
                        id as i32,
                        cx.style().get_font().gecko(),
                        cx.device().pres_context()
                    )
                }
                let weight = longhands::font_weight::computed_value::T::from_gecko_weight(system.weight);
                let ret = ComputedSystemFont {
                    font_family: longhands::font_family::computed_value::T(
                        FontFamilyList(
                            unsafe { system.fontlist.mFontlist.mBasePtr.to_safe() }
                        )
                    ),
                    font_size: FontSize {
                            size: Au(system.size).into(),
                            keyword_info: None
                    },
                    font_weight: weight,
                    font_size_adjust: longhands::font_size_adjust::computed_value
                                               ::T::from_gecko_adjust(system.sizeAdjust),
                        font_style: longhands::font_style::computed_value::T::from_gecko_keyword(
                            system.style
                                as u32
                        ),
                        font_variant_caps: longhands::font_variant_caps::computed_value::T::from_gecko_keyword(
                            system.variantCaps
                                as u32
                        ),
                        font_stretch: longhands::font_stretch::computed_value::T::from_gecko_keyword(
                            system.stretch
                                as u32
                        ),
                        font_kerning: longhands::font_kerning::computed_value::T::from_gecko_keyword(
                            system.kerning
                                as u32
                        ),
                        font_variant_position: longhands::font_variant_position::computed_value::T::from_gecko_keyword(
                            system.variantPosition
                                as u32
                        ),
                        font_variant_ligatures: longhands::font_variant_ligatures::computed_value::T::from_gecko_keyword(
                            system.variantLigatures
                        ),
                        font_variant_east_asian: longhands::font_variant_east_asian::computed_value::T::from_gecko_keyword(
                            system.variantEastAsian
                        ),
                        font_variant_numeric: longhands::font_variant_numeric::computed_value::T::from_gecko_keyword(
                            system.variantNumeric
                        ),
                        font_optical_sizing: longhands::font_optical_sizing::computed_value::T::from_gecko_keyword(
                            system.opticalSizing
                                as u32
                        ),
                    font_language_override: longhands::font_language_override::computed_value
                                                     ::T(system.languageOverride),
                    font_feature_settings: longhands::font_feature_settings::get_initial_value(),
                    font_variation_settings: longhands::font_variation_settings::get_initial_value(),
                    font_variant_alternates: longhands::font_variant_alternates::get_initial_value(),
                    system_font: *self,
                    default_font_type: system.fontlist.mDefaultFontType,
                };
                unsafe { bindings::Gecko_nsFont_Destroy(&mut system); }
                ret
            }

            fn from_computed_value(_: &ComputedSystemFont) -> Self {
                unreachable!()
            }
        }

        #[inline]
        /// Compute and cache a system font
        ///
        /// Must be called before attempting to compute a system font
        /// specified value
        pub fn resolve_system_font(system: SystemFont, context: &mut Context) {
            // Checking if context.cached_system_font.is_none() isn't enough,
            // if animating from one system font to another the cached system font
            // may change
            if Some(system) != context.cached_system_font.as_ref().map(|x| x.system_font) {
                let computed = system.to_computed_value(context);
                context.cached_system_font = Some(computed);
            }
        }

        #[derive(Clone, Debug)]
        pub struct ComputedSystemFont {
                pub font_family: longhands::font_family::computed_value::T,
                pub font_size: longhands::font_size::computed_value::T,
                pub font_style: longhands::font_style::computed_value::T,
                pub font_variant_caps: longhands::font_variant_caps::computed_value::T,
                pub font_stretch: longhands::font_stretch::computed_value::T,
                pub font_kerning: longhands::font_kerning::computed_value::T,
                pub font_variant_position: longhands::font_variant_position::computed_value::T,
                pub font_weight: longhands::font_weight::computed_value::T,
                pub font_size_adjust: longhands::font_size_adjust::computed_value::T,
                pub font_variant_alternates: longhands::font_variant_alternates::computed_value::T,
                pub font_variant_ligatures: longhands::font_variant_ligatures::computed_value::T,
                pub font_variant_east_asian: longhands::font_variant_east_asian::computed_value::T,
                pub font_variant_numeric: longhands::font_variant_numeric::computed_value::T,
                pub font_language_override: longhands::font_language_override::computed_value::T,
                pub font_feature_settings: longhands::font_feature_settings::computed_value::T,
                pub font_variation_settings: longhands::font_variation_settings::computed_value::T,
                pub font_optical_sizing: longhands::font_optical_sizing::computed_value::T,
            pub system_font: SystemFont,
            pub default_font_type: FontFamilyType,
        }

        impl SystemFont {
            pub fn parse<'i, 't>(input: &mut Parser<'i, 't>) -> Result<Self, ParseError<'i>> {
                try_match_ident_ignore_ascii_case! { input,
                        "caption" => Ok(SystemFont::Caption),
                        "icon" => Ok(SystemFont::Icon),
                        "menu" => Ok(SystemFont::Menu),
                        "message-box" => Ok(SystemFont::MessageBox),
                        "small-caption" => Ok(SystemFont::SmallCaption),
                        "status-bar" => Ok(SystemFont::StatusBar),
                        "-moz-window" => Ok(SystemFont::MozWindow),
                        "-moz-document" => Ok(SystemFont::MozDocument),
                        "-moz-workspace" => Ok(SystemFont::MozWorkspace),
                        "-moz-desktop" => Ok(SystemFont::MozDesktop),
                        "-moz-info" => Ok(SystemFont::MozInfo),
                        "-moz-dialog" => Ok(SystemFont::MozDialog),
                        "-moz-button" => Ok(SystemFont::MozButton),
                        "-moz-pull-down-menu" => Ok(SystemFont::MozPullDownMenu),
                        "-moz-list" => Ok(SystemFont::MozList),
                        "-moz-field" => Ok(SystemFont::MozField),
                }
            }
        }

        impl ToCss for SystemFont {
            fn to_css<W>(&self, dest: &mut W) -> fmt::Result where W: fmt::Write {
                // We may want to do something better in the future, see
                // w3c/csswg-drafts#1586.
                dest.write_str("-moz-use-system-font")
            }
        }
    }


    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/font-smooth)
    pub mod _moz_osx_font_smoothing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            Grayscale,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozOsxFontSmoothing(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozOsxFontSmoothing);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_osx_font_smoothing(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_osx_font_smoothing();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_osx_font_smoothing();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozOsxFontSmoothing)
        }
    }




    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_font_smoothing_background_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::RGBAColor as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::RGBAColor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { RGBA::transparent() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::RGBAColor::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozFontSmoothingBackgroundColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozFontSmoothingBackgroundColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_font_smoothing_background_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_font_smoothing_background_color();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_font_smoothing_background_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozFontSmoothingBackgroundColor)
        }
    }




    
        
    
    /// Nonstandard (Internal-only)
    pub mod _moz_min_font_size_ratio {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Percentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Percentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Percentage::hundred() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Percentage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozMinFontSizeRatio(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozMinFontSizeRatio);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_min_font_size_ratio(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_min_font_size_ratio();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_min_font_size_ratio();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozMinFontSizeRatio)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





// TODO: collapse. Well, do tables first.

    

    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-visibility
    pub mod visibility {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Visible,
            
            Hidden,
            
            Collapse,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Visible
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Visible
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Visibility(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Visibility);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_visibility(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_visibility();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_visibility();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Visibility)
        }
    }



// CSS Writing Modes Level 3
// https://drafts.csswg.org/css-writing-modes-3

    

    
        
    
    /// https://drafts.csswg.org/css-writing-modes/#propdef-writing-mode
    pub mod writing_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            #[css(aliases = "rl-tb,lr,rl,lr-tb")]
            HorizontalTb,
            
            #[css(aliases = "tb-rl,tb")]
            VerticalRl,
            
            VerticalLr,
            
            SidewaysRl,
            
            SidewaysLr,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::HorizontalTb
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::HorizontalTb
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WritingMode(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::WritingMode);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_writing_mode(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_writing_mode();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_writing_mode();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WritingMode)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-writing-modes/#propdef-direction
    pub mod direction {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Ltr,
            
            Rtl,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Ltr
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Ltr
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const LTR: u32
                    = structs::NS_STYLE_DIRECTION_LTR as u32;
                // We can't match on enum values if we're matching on a u32
                const RTL: u32
                    = structs::NS_STYLE_DIRECTION_RTL as u32;
            match kw  {
                    LTR => SpecifiedValue::Ltr,
                    RTL => SpecifiedValue::Rtl,
                _ => panic!("Found unexpected value in style struct for direction property"),
            }
        }
    }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Direction(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Direction);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_direction(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_direction();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_direction();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Direction)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-writing-modes/#propdef-text-orientation
    pub mod text_orientation {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Mixed,
            
            Upright,
            
            #[css(aliases = "sideways-right")]
            Sideways,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Mixed
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Mixed
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextOrientation(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextOrientation);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_orientation(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_orientation();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_orientation();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextOrientation)
        }
    }



// CSS Color Module Level 4
// https://drafts.csswg.org/css-color/

    

    
        
    
    /// https://drafts.csswg.org/css-color/#propdef-color-adjust
    pub mod color_adjust {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Economy,
            
            Exact,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Economy
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Economy
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColorAdjust(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ColorAdjust);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_color_adjust(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_color_adjust();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_color_adjust();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColorAdjust)
        }
    }




// According to to CSS-IMAGES-3, `optimizespeed` and `optimizequality` are synonyms for `auto`
// And, firefox doesn't support `pixelated` yet (https://bugzilla.mozilla.org/show_bug.cgi?id=856337)

    

    
        
    
    /// https://drafts.csswg.org/css-images/#propdef-image-rendering
    pub mod image_rendering {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            Optimizespeed,
            
            Optimizequality,
            
            MozCrispEdges,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ImageRendering(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ImageRendering);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_image_rendering(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_image_rendering();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_image_rendering();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ImageRendering)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-images/#propdef-image-orientation,                     /// additional values in https://developer.mozilla.org/en-US/docs/Web/CSS/image-orientation
    pub mod image_orientation {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ImageOrientation as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ImageOrientation as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ImageOrientation::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ImageOrientation::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ImageOrientation(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ImageOrientation);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_image_orientation(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_image_orientation();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_image_orientation();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ImageOrientation)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    

    
        
    
    /// https://drafts.csswg.org/css-tables/#propdef-border-collapse
    pub mod border_collapse {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Separate,
            
            Collapse,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Separate
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Separate
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderCollapse(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderCollapse);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_collapse(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_collapse();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_border_collapse();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderCollapse)
        }
    }



    

    
        
    
    /// https://drafts.csswg.org/css-tables/#propdef-empty-cells
    pub mod empty_cells {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Show,
            
            Hide,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Show
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Show
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::EmptyCells(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::EmptyCells);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_empty_cells(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_empty_cells();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_empty_cells();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::EmptyCells)
        }
    }



    

    
        
    
    /// https://drafts.csswg.org/css-tables/#propdef-caption-side
    pub mod caption_side {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Top,
            
            Bottom,
            
            Right,
            
            Left,
            
            TopOutside,
            
            BottomOutside,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Top
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Top
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const TOP: u32
                    = structs::NS_STYLE_CAPTION_SIDE_TOP as u32;
                // We can't match on enum values if we're matching on a u32
                const BOTTOM: u32
                    = structs::NS_STYLE_CAPTION_SIDE_BOTTOM as u32;
                // We can't match on enum values if we're matching on a u32
                const RIGHT: u32
                    = structs::NS_STYLE_CAPTION_SIDE_RIGHT as u32;
                // We can't match on enum values if we're matching on a u32
                const LEFT: u32
                    = structs::NS_STYLE_CAPTION_SIDE_LEFT as u32;
                // We can't match on enum values if we're matching on a u32
                const TOP_OUTSIDE: u32
                    = structs::NS_STYLE_CAPTION_SIDE_TOP_OUTSIDE as u32;
                // We can't match on enum values if we're matching on a u32
                const BOTTOM_OUTSIDE: u32
                    = structs::NS_STYLE_CAPTION_SIDE_BOTTOM_OUTSIDE as u32;
            match kw  {
                    TOP => SpecifiedValue::Top,
                    BOTTOM => SpecifiedValue::Bottom,
                    RIGHT => SpecifiedValue::Right,
                    LEFT => SpecifiedValue::Left,
                    TOP_OUTSIDE => SpecifiedValue::TopOutside,
                    BOTTOM_OUTSIDE => SpecifiedValue::BottomOutside,
                _ => panic!("Found unexpected value in style struct for caption-side property"),
            }
        }
    }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::CaptionSide(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::CaptionSide);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_caption_side(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_caption_side();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_caption_side();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::CaptionSide)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-tables/#propdef-border-spacing
    pub mod border_spacing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSpacing as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderSpacing as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderSpacing::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSpacing::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderSpacing(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BorderSpacing);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_spacing(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_spacing();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_border_spacing();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderSpacing)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
        
    
    /// https://drafts.csswg.org/css2/visudet.html#propdef-line-height
    pub mod line_height {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LineHeight as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LineHeight as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LineHeight::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LineHeight::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::LineHeight(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::LineHeight);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_line_height(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_line_height();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_line_height();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::LineHeight)
        }
    }



// CSS Text Module Level 3

// TODO(pcwalton): `full-width`

    

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-text-transform
    pub mod text_transform {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            None,
            
            Capitalize,
            
            Uppercase,
            
            Lowercase,
            
            FullWidth,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextTransform(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextTransform);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_transform(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_transform();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_transform();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextTransform)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-hyphens
    pub mod hyphens {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Manual,
            
            None,
            
            Auto,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Manual
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Manual
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Hyphens(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Hyphens);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_hyphens(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_hyphens();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_hyphens();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Hyphens)
        }
    }



// TODO: Support <percentage>

    

    
        
    
    /// https://drafts.csswg.org/css-size-adjust/#adjustment-control
    pub mod _moz_text_size_adjust {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            None,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozTextSizeAdjust(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozTextSizeAdjust);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_text_size_adjust(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_text_size_adjust();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_text_size_adjust();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozTextSizeAdjust)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-text-indent
    pub mod text_indent {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentage::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentage::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextIndent(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextIndent);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_indent(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_indent();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_indent();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextIndent)
        }
    }



// Also known as "word-wrap" (which is more popular because of IE), but this is the preferred
// name per CSS-TEXT 6.2.

    

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-overflow-wrap
    pub mod overflow_wrap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Normal,
            
            BreakWord,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OverflowWrap(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::OverflowWrap);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_overflow_wrap(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_overflow_wrap();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_overflow_wrap();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowWrap)
        }
    }



// TODO(pcwalton): Support `word-break: keep-all` once we have better CJK support.

    

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-word-break
    pub mod word_break {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Normal,
            
            BreakAll,
            
            KeepAll,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WordBreak(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::WordBreak);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_word_break(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_word_break();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_word_break();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WordBreak)
        }
    }



// TODO(pcwalton): Support `text-justify: distribute`.

    

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-text-justify
    pub mod text_justify {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, Parse, PartialEq, ToCss)]
            pub enum SpecifiedValue {
                
            
            Auto,
            
            None,
            
            InterWord,
            
            InterCharacter,
            
            Distribute,
        
            }
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            pub enum T {
                
            Auto,
            None,
            InterWord,
            InterCharacter,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
            
    impl ToComputedValue for SpecifiedValue {
        type ComputedValue = computed_value::T;

        #[inline]
        fn to_computed_value(&self, _: &Context) -> computed_value::T {
            match *self {
                SpecifiedValue::Auto => computed_value::T::Auto,
                SpecifiedValue::None => computed_value::T::None,
                SpecifiedValue::InterCharacter => computed_value::T::InterCharacter,
                SpecifiedValue::InterWord => computed_value::T::InterWord,
                // https://drafts.csswg.org/css-text-3/#valdef-text-justify-distribute
                SpecifiedValue::Distribute => computed_value::T::InterCharacter,
            }
        }

        #[inline]
        fn from_computed_value(computed: &computed_value::T) -> SpecifiedValue {
            match *computed {
                computed_value::T::Auto => SpecifiedValue::Auto,
                computed_value::T::None => SpecifiedValue::None,
                computed_value::T::InterCharacter => SpecifiedValue::InterCharacter,
                computed_value::T::InterWord => SpecifiedValue::InterWord,
            }
        }
    }

        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextJustify(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextJustify);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_justify(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_justify();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_justify();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextJustify)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-text-align-last
    pub mod text_align_last {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            Start,
            
            End,
            
            Left,
            
            Right,
            
            Center,
            
            Justify,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextAlignLast(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextAlignLast);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_align_last(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_align_last();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_align_last();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextAlignLast)
        }
    }



// TODO make this a shorthand and implement text-align-last/text-align-all
//
// FIXME(emilio): This can't really be that complicated.

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-text-align
    pub mod text_align {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TextAlign as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TextAlign as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TextAlign::start() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TextAlign::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextAlign(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextAlign);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_align(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_align();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_align();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextAlign)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-letter-spacing
    pub mod letter_spacing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LetterSpacing as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LetterSpacing as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LetterSpacing::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LetterSpacing::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::LetterSpacing(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::LetterSpacing);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_letter_spacing(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_letter_spacing();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_letter_spacing();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::LetterSpacing)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-word-spacing
    pub mod word_spacing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::WordSpacing as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::WordSpacing as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::WordSpacing::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::WordSpacing::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WordSpacing(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::WordSpacing);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_word_spacing(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_word_spacing();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_word_spacing();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WordSpacing)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-white-space
    pub mod white_space {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Normal,
            
            Pre,
            
            Nowrap,
            
            PreWrap,
            
            PreLine,
            
            MozPreSpace,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: u32
                    = structs::StyleWhiteSpace::Normal as u32;
                // We can't match on enum values if we're matching on a u32
                const PRE: u32
                    = structs::StyleWhiteSpace::Pre as u32;
                // We can't match on enum values if we're matching on a u32
                const NOWRAP: u32
                    = structs::StyleWhiteSpace::Nowrap as u32;
                // We can't match on enum values if we're matching on a u32
                const PRE_WRAP: u32
                    = structs::StyleWhiteSpace::PreWrap as u32;
                // We can't match on enum values if we're matching on a u32
                const PRE_LINE: u32
                    = structs::StyleWhiteSpace::PreLine as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_PRE_SPACE: u32
                    = structs::StyleWhiteSpace::PreSpace as u32;
            match kw  {
                    NORMAL => SpecifiedValue::Normal,
                    PRE => SpecifiedValue::Pre,
                    NOWRAP => SpecifiedValue::Nowrap,
                    PRE_WRAP => SpecifiedValue::PreWrap,
                    PRE_LINE => SpecifiedValue::PreLine,
                    _MOZ_PRE_SPACE => SpecifiedValue::MozPreSpace,
                _ => panic!("Found unexpected value in style struct for white-space property"),
            }
        }
    }

    
            

        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WhiteSpace(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::WhiteSpace);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_white_space(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_white_space();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_white_space();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WhiteSpace)
        }
    }




    
        
    
    
    /// https://drafts.csswg.org/css-text-decor-3/#text-shadow-property
    pub mod text_shadow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SimpleShadow as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SimpleShadow as T;
        }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SimpleShadow::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for text-shadow.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use std::vec::IntoIter;
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(if_empty = "none", iterable)]
                pub Vec<single_value::T>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<single_value::T>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of text-shadow.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(if_empty = "none", iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                computed_value::T(vec![])
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

                if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                    return Ok(SpecifiedValue(Vec::new()))
                }

            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextShadow(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextShadow);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_inheritedtext();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_text_shadow(iter);
                        }
                        context.builder.put_inheritedtext(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_shadow();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_shadow();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextShadow)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-emphasis-style
    pub mod text_emphasis_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TextEmphasisStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TextEmphasisStyle as T;
        }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { SpecifiedValue::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TextEmphasisStyle::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextEmphasisStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextEmphasisStyle);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_text_emphasis_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_emphasis_style();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_emphasis_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::TextEmphasisStyle)
        }
    }




    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-emphasis-position
    pub mod text_emphasis_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
    #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, Parse, PartialEq)]
    #[derive(ToComputedValue, ToCss)]
    pub enum HorizontalWritingModeValue {
        Over,
        Under,
    }

    #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, Parse, PartialEq)]
    #[derive(ToComputedValue, ToCss)]
    pub enum VerticalWritingModeValue {
        Right,
        Left,
    }

    #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToComputedValue, ToCss)]
    pub struct SpecifiedValue(pub HorizontalWritingModeValue, pub VerticalWritingModeValue);

    pub mod computed_value {
        pub type T = super::SpecifiedValue;
    }

    pub fn get_initial_value() -> computed_value::T {
        SpecifiedValue(HorizontalWritingModeValue::Over, VerticalWritingModeValue::Right)
    }

    pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                         -> Result<SpecifiedValue, ParseError<'i>> {
       if let Ok(horizontal) = input.try(|input| HorizontalWritingModeValue::parse(input)) {
            let vertical = VerticalWritingModeValue::parse(input)?;
            Ok(SpecifiedValue(horizontal, vertical))
        } else {
            let vertical = VerticalWritingModeValue::parse(input)?;
            let horizontal = HorizontalWritingModeValue::parse(input)?;
            Ok(SpecifiedValue(horizontal, vertical))
        }
    }

        impl SpecifiedValue {
            pub fn from_gecko_keyword(kw: u32) -> Self {
                use gecko_bindings::structs;

                let vert = if kw & structs::NS_STYLE_TEXT_EMPHASIS_POSITION_RIGHT != 0 {
                    VerticalWritingModeValue::Right
                } else {
                    debug_assert!(kw & structs::NS_STYLE_TEXT_EMPHASIS_POSITION_LEFT != 0);
                    VerticalWritingModeValue::Left
                };
                let horiz = if kw & structs::NS_STYLE_TEXT_EMPHASIS_POSITION_OVER != 0 {
                    HorizontalWritingModeValue::Over
                } else {
                    debug_assert!(kw & structs::NS_STYLE_TEXT_EMPHASIS_POSITION_UNDER != 0);
                    HorizontalWritingModeValue::Under
                };
                SpecifiedValue(horiz, vert)
            }
        }

        impl From<u8> for SpecifiedValue {
            fn from(bits: u8) -> SpecifiedValue {
                SpecifiedValue::from_gecko_keyword(bits as u32)
            }
        }

        impl From<SpecifiedValue> for u8 {
            fn from(v: SpecifiedValue) -> u8 {
                use gecko_bindings::structs;

                let mut result = match v.0 {
                    HorizontalWritingModeValue::Over => structs::NS_STYLE_TEXT_EMPHASIS_POSITION_OVER,
                    HorizontalWritingModeValue::Under => structs::NS_STYLE_TEXT_EMPHASIS_POSITION_UNDER,
                };
                match v.1 {
                    VerticalWritingModeValue::Right => {
                        result |= structs::NS_STYLE_TEXT_EMPHASIS_POSITION_RIGHT;
                    }
                    VerticalWritingModeValue::Left => {
                        result |= structs::NS_STYLE_TEXT_EMPHASIS_POSITION_LEFT;
                    }
                };
                result as u8
            }
        }

        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextEmphasisPosition(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextEmphasisPosition);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_emphasis_position(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_emphasis_position();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_emphasis_position();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextEmphasisPosition)
        }
    }



    
        
    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-emphasis-color
    pub mod text_emphasis_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Color::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextEmphasisColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextEmphasisColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_emphasis_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_emphasis_color();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_emphasis_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextEmphasisColor)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text-3/#tab-size-property
    pub mod _moz_tab_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozTabSize as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozTabSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::text::MozTabSize::Number(From::from(8.0)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozTabSize::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozTabSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozTabSize);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_tab_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_tab_size();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_tab_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozTabSize)
        }
    }



// CSS Compatibility
// https://compat.spec.whatwg.org

    
        
    
    /// https://compat.spec.whatwg.org/#the-webkit-text-fill-color
    pub mod _webkit_text_fill_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WebkitTextFillColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::WebkitTextFillColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__webkit_text_fill_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__webkit_text_fill_color();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__webkit_text_fill_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WebkitTextFillColor)
        }
    }




    
        
    
    /// https://compat.spec.whatwg.org/#the-webkit-text-stroke-color
    pub mod _webkit_text_stroke_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Color::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WebkitTextStrokeColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::WebkitTextStrokeColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__webkit_text_stroke_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__webkit_text_stroke_color();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__webkit_text_stroke_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WebkitTextStrokeColor)
        }
    }




    
        
    
    /// https://compat.spec.whatwg.org/#the-webkit-text-stroke-width
    pub mod _webkit_text_stroke_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(0.) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BorderSideWidth::Length(specified::Length::zero()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WebkitTextStrokeWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::WebkitTextStrokeWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__webkit_text_stroke_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__webkit_text_stroke_width();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__webkit_text_stroke_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WebkitTextStrokeWidth)
        }
    }



// CSS Ruby Layout Module Level 1
// https://drafts.csswg.org/css-ruby/

    

    
        
    
    /// https://drafts.csswg.org/css-ruby/#ruby-align-property
    pub mod ruby_align {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            SpaceAround,
            
            Start,
            
            Center,
            
            SpaceBetween,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::SpaceAround
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::SpaceAround
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::RubyAlign(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::RubyAlign);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_ruby_align(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_ruby_align();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_ruby_align();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::RubyAlign)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-ruby/#ruby-position-property
    pub mod ruby_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Over,
            
            Under,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Over
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Over
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::RubyPosition(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::RubyPosition);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_ruby_position(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_ruby_position();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_ruby_position();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::RubyPosition)
        }
    }



// CSS Writing Modes Module Level 3
// https://drafts.csswg.org/css-writing-modes-3/


    

    
        
    
    /// https://drafts.csswg.org/css-writing-modes-3/#text-combine-upright
    pub mod text_combine_upright {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            None,
            
            All,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextCombineUpright(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextCombineUpright);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_combine_upright(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_combine_upright();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_combine_upright();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextCombineUpright)
        }
    }



// SVG 1.1: Section 11 - Painting: Filling, Stroking and Marker Symbols

    

    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#TextRenderingProperty
    pub mod text_rendering {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            Optimizespeed,
            
            Optimizelegibility,
            
            Geometricprecision,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextRendering(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextRendering);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_rendering(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_rendering();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_rendering();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextRendering)
        }
    }



// FIXME Firefox expects the initial value of this property to change depending
// on the value of the layout.css.control-characters.visible pref.

    

    
        
    
    /// Nonstandard
    pub mod _moz_control_character_visibility {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Hidden,
            
            Visible,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Hidden
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Hidden
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozControlCharacterVisibility(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozControlCharacterVisibility);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_control_character_visibility(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_control_character_visibility();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_control_character_visibility();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozControlCharacterVisibility)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    

    
        
    
    /// https://drafts.csswg.org/css-lists/#propdef-list-style-position
    pub mod list_style_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Outside,
            
            Inside,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Outside
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Outside
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ListStylePosition(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ListStylePosition);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_list_style_position(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_list_style_position();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_list_style_position();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ListStylePosition)
        }
    }



// TODO(pcwalton): Implement the full set of counter styles per CSS-COUNTER-STYLES [1] 6.1:
//
//     decimal-leading-zero, armenian, upper-armenian, lower-armenian, georgian, lower-roman,
//     upper-roman
//
// [1]: http://dev.w3.org/csswg/css-counter-styles/
    
    
        
    
    /// https://drafts.csswg.org/css-lists/#propdef-list-style-type
    pub mod list_style_type {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ListStyleType as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ListStyleType as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ListStyleType::disc() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::ListStyleType::disc() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ListStyleType::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ListStyleType(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ListStyleType);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_list_style_type(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_list_style_type();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_list_style_type();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::ListStyleType)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-lists/#propdef-list-style-image
    pub mod list_style_image {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ListStyleImage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ListStyleImage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::ListStyleImage::none() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::ListStyleImage::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ListStyleImage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ListStyleImage(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ListStyleImage);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_list_style_image(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_list_style_image();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_list_style_image();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ListStyleImage)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-content/#propdef-quotes
    pub mod quotes {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Quotes as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Quotes as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Quotes::get_initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Quotes::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Quotes(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Quotes);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_quotes(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_quotes();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_quotes();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Quotes)
        }
    }




    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-image-region)
    pub mod _moz_image_region {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ClipRectOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ClipRectOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ClipRectOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ClipRectOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozImageRegion(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozImageRegion);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set__moz_image_region(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_image_region();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_image_region();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MozImageRegion)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-margin-top
    pub mod margin_top {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginTop(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MarginTop);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginTop);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_top(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_top();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_top();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginTop)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-margin-left
    pub mod margin_left {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginLeft(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MarginLeft);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginLeft);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_left(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_left();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_left();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginLeft)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-margin-bottom
    pub mod margin_bottom {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginBottom(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MarginBottom);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginBottom);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_bottom(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_bottom();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_bottom();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginBottom)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-margin-right
    pub mod margin_right {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginRight(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MarginRight);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginRight);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_right(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_right();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_right();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginRight)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-margin-True
    pub mod margin_block_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginBlockStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MarginBlockStart);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginBlockStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_block_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_block_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_block_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginBlockStart)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-margin-True
    pub mod margin_block_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginBlockEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MarginBlockEnd);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginBlockEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_block_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_block_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_block_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginBlockEnd)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-margin-True
    pub mod margin_inline_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginInlineStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MarginInlineStart);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginInlineStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_inline_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_inline_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_inline_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginInlineStart)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-margin-True
    pub mod margin_inline_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginInlineEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MarginInlineEnd);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginInlineEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_inline_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_inline_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_inline_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginInlineEnd)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






// TODO(pcwalton): `invert`

    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-outline-color
    pub mod outline_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Color::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OutlineColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::OutlineColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OutlineColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_outline_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_outline_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_outline_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OutlineColor)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-outline-style
    pub mod outline_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::OutlineStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::OutlineStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OutlineStyle::none() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::OutlineStyle::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::OutlineStyle::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OutlineStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::OutlineStyle);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OutlineStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_outline_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_outline_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_outline_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OutlineStyle)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-outline-width
    pub mod outline_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BorderSideWidth::Medium }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OutlineWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::OutlineWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OutlineWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_outline_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_outline_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_outline_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OutlineWidth)
        }
    }



// The -moz-outline-radius-* properties are non-standard and not on a standards track.
    
    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-outline-radius)
    pub mod _moz_outline_radius_topleft {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozOutlineRadiusTopleft(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozOutlineRadiusTopleft);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozOutlineRadiusTopleft);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set__moz_outline_radius_topleft(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_outline_radius_topleft();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_outline_radius_topleft();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MozOutlineRadiusTopleft)
        }
    }


    
    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-outline-radius)
    pub mod _moz_outline_radius_topright {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozOutlineRadiusTopright(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozOutlineRadiusTopright);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozOutlineRadiusTopright);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set__moz_outline_radius_topright(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_outline_radius_topright();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_outline_radius_topright();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MozOutlineRadiusTopright)
        }
    }


    
    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-outline-radius)
    pub mod _moz_outline_radius_bottomright {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozOutlineRadiusBottomright(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozOutlineRadiusBottomright);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozOutlineRadiusBottomright);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set__moz_outline_radius_bottomright(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_outline_radius_bottomright();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_outline_radius_bottomright();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MozOutlineRadiusBottomright)
        }
    }


    
    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-outline-radius)
    pub mod _moz_outline_radius_bottomleft {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozOutlineRadiusBottomleft(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozOutlineRadiusBottomleft);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozOutlineRadiusBottomleft);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set__moz_outline_radius_bottomleft(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_outline_radius_bottomleft();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_outline_radius_bottomleft();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MozOutlineRadiusBottomleft)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-outline-offset
    pub mod outline_offset {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Length as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Length as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::Length::new(0.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Length::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OutlineOffset(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::OutlineOffset);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OutlineOffset);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_outline_offset(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_outline_offset();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_outline_offset();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OutlineOffset)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





// APPLIES_TO_PLACEHOLDER so we can set it in UA  stylesheets.  But we use a
// !important value there, so pages can't set it.
    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-padding-top
    pub mod padding_top {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingTop(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::PaddingTop);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingTop);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_top(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_top();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_top();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingTop)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-padding-left
    pub mod padding_left {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingLeft(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::PaddingLeft);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingLeft);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_left(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_left();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_left();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingLeft)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-padding-bottom
    pub mod padding_bottom {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingBottom(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::PaddingBottom);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingBottom);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_bottom(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_bottom();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_bottom();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingBottom)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-padding-right
    pub mod padding_right {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingRight(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::PaddingRight);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingRight);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_right(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_right();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_right();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingRight)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-padding-True
    pub mod padding_block_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingBlockStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::PaddingBlockStart);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingBlockStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_block_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_block_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_block_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingBlockStart)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-padding-True
    pub mod padding_block_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingBlockEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::PaddingBlockEnd);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingBlockEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_block_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_block_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_block_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingBlockEnd)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-padding-True
    pub mod padding_inline_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingInlineStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::PaddingInlineStart);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingInlineStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_inline_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_inline_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_inline_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingInlineStart)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-padding-True
    pub mod padding_inline_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingInlineEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::PaddingInlineEnd);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingInlineEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_inline_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_inline_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_inline_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingInlineEnd)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
        
    
    /// https://drafts.csswg.org/css-ui/#cursor
    pub mod cursor {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Cursor as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Cursor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Cursor::auto() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Cursor::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Cursor::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Cursor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Cursor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_cursor(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_cursor();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_cursor();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Cursor)
        }
    }



// NB: `pointer-events: auto` (and use of `pointer-events` in anything that isn't SVG, in fact)
// is nonstandard, slated for CSS4-UI.
// TODO(pcwalton): SVG-only values.

    

    
        
    
    /// https://www.w3.org/TR/SVG11/interact.html#PointerEventsProperty
    pub mod pointer_events {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            None,
            
            Visiblepainted,
            
            Visiblefill,
            
            Visiblestroke,
            
            Visible,
            
            Painted,
            
            Fill,
            
            Stroke,
            
            All,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PointerEvents(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::PointerEvents);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_pointer_events(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_pointer_events();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_pointer_events();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PointerEvents)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-user-input)
    pub mod _moz_user_input {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            None,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozUserInput(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozUserInput);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_user_input(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_user_input();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_user_input();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozUserInput)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-user-modify)
    pub mod _moz_user_modify {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            ReadOnly,
            
            ReadWrite,
            
            WriteOnly,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::ReadOnly
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::ReadOnly
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const READ_ONLY: u32
                    = structs::StyleUserModify::ReadOnly as u32;
                // We can't match on enum values if we're matching on a u32
                const READ_WRITE: u32
                    = structs::StyleUserModify::ReadWrite as u32;
                // We can't match on enum values if we're matching on a u32
                const WRITE_ONLY: u32
                    = structs::StyleUserModify::WriteOnly as u32;
            match kw  {
                    READ_ONLY => SpecifiedValue::ReadOnly,
                    READ_WRITE => SpecifiedValue::ReadWrite,
                    WRITE_ONLY => SpecifiedValue::WriteOnly,
                _ => panic!("Found unexpected value in style struct for -moz-user-modify property"),
            }
        }
    }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozUserModify(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozUserModify);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_user_modify(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_user_modify();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_user_modify();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozUserModify)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-user-focus)
    pub mod _moz_user_focus {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            None,
            
            Ignore,
            
            Normal,
            
            SelectAfter,
            
            SelectBefore,
            
            SelectMenu,
            
            SelectSame,
            
            SelectAll,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozUserFocus(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozUserFocus);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_user_focus(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_user_focus();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_user_focus();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozUserFocus)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-ui/#caret-color
    pub mod caret_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::CaretColor as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::CaretColor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::pointing::CaretColor::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::CaretColor::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::CaretColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::CaretColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_caret_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_caret_color();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_caret_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::CaretColor)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */







// "top" / "left" / "bottom" / "right"
    
    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#propdef-top
    pub mod top {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Top(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Top);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Top);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_top(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_top();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_top();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Top)
        }
    }


    
    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#propdef-left
    pub mod left {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Left(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Left);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Left);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_left(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_left();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_left();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Left)
        }
    }


    
    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#propdef-bottom
    pub mod bottom {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Bottom(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Bottom);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Bottom);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_bottom(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_bottom();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_bottom();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Bottom)
        }
    }


    
    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#propdef-right
    pub mod right {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Right(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Right);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Right);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_right(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_right();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_right();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Right)
        }
    }


// offset-* logical properties, map to "top" / "left" / "bottom" / "right"
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-offset-block-start
    pub mod offset_block_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OffsetBlockStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::OffsetBlockStart);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OffsetBlockStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_offset_block_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_offset_block_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_offset_block_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OffsetBlockStart)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-offset-block-end
    pub mod offset_block_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OffsetBlockEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::OffsetBlockEnd);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OffsetBlockEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_offset_block_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_offset_block_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_offset_block_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OffsetBlockEnd)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-offset-inline-start
    pub mod offset_inline_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OffsetInlineStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::OffsetInlineStart);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OffsetInlineStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_offset_inline_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_offset_inline_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_offset_inline_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OffsetInlineStart)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-offset-inline-end
    pub mod offset_inline_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OffsetInlineEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::OffsetInlineEnd);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OffsetInlineEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_offset_inline_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_offset_inline_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_offset_inline_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OffsetInlineEnd)
        }
    }



#[cfg(feature = "gecko")]
macro_rules! impl_align_conversions {
    ($name: path) => {
        impl From<u8> for $name {
            fn from(bits: u8) -> $name {
                $name(::values::specified::align::AlignFlags::from_bits(bits)
                      .expect("bits contain valid flag"))
            }
        }

        impl From<$name> for u8 {
            fn from(v: $name) -> u8 {
                v.0.bits()
            }
        }
    };
}


    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#z-index
    pub mod z_index {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ZIndex as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ZIndex as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ZIndex::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ZIndex::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ZIndex(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ZIndex);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ZIndex);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_z_index(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_z_index();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_z_index();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ZIndex)
        }
    }



// CSS Flexible Box Layout Module Level 1
// http://www.w3.org/TR/css3-flexbox/

// Flex container properties

    

    
        
    
    /// https://drafts.csswg.org/css-flexbox/#flex-direction-property
    pub mod flex_direction {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Row,
            
            RowReverse,
            
            Column,
            
            ColumnReverse,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Row
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Row
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FlexDirection(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FlexDirection);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::FlexDirection);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_flex_direction(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_flex_direction();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_flex_direction();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FlexDirection)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-flexbox/#flex-wrap-property
    pub mod flex_wrap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Nowrap,
            
            Wrap,
            
            WrapReverse,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Nowrap
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Nowrap
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FlexWrap(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FlexWrap);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::FlexWrap);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_flex_wrap(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_flex_wrap();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_flex_wrap();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FlexWrap)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-align/#propdef-justify-content
    pub mod justify_content {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::JustifyContent as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::JustifyContent as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::JustifyContent(specified::ContentDistribution::normal()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::JustifyContent::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::JustifyContent(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::JustifyContent);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::JustifyContent);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_justify_content(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_justify_content();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_justify_content();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::JustifyContent)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-align/#propdef-align-content
    pub mod align_content {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::AlignContent as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::AlignContent as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::AlignContent(specified::ContentDistribution::normal()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::AlignContent::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AlignContent(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::AlignContent);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AlignContent);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_align_content(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_align_content();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_align_content();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AlignContent)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-align/#propdef-align-items
    pub mod align_items {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::AlignItems as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::AlignItems as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::AlignItems::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::AlignItems::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AlignItems(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::AlignItems);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AlignItems);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_align_items(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_align_items();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_align_items();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AlignItems)
        }
    }



    #[cfg(feature = "gecko")]
    impl_align_conversions!(::values::specified::align::AlignItems);

    
    
        
    
    /// https://drafts.csswg.org/css-align/#propdef-justify-items
    pub mod justify_items {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::JustifyItems as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::JustifyItems as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::JustifyItems::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::JustifyItems::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::JustifyItems(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::JustifyItems);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::JustifyItems);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_justify_items(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_justify_items();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_justify_items();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::JustifyItems)
        }
    }



    #[cfg(feature = "gecko")]
    impl_align_conversions!(::values::specified::align::JustifyItems);

// Flex item properties

    
        
    
    /// https://drafts.csswg.org/css-flexbox/#flex-grow-property
    pub mod flex_grow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeNumber as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeNumber as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { From::from(0.0) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeNumber::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FlexGrow(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FlexGrow);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::FlexGrow);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_flex_grow(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_flex_grow();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_flex_grow();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FlexGrow)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-flexbox/#flex-shrink-property
    pub mod flex_shrink {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeNumber as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeNumber as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { From::from(1.0) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeNumber::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FlexShrink(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FlexShrink);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::FlexShrink);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_flex_shrink(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_flex_shrink();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_flex_shrink();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FlexShrink)
        }
    }



// https://drafts.csswg.org/css-align/#align-self-property
    
    
        
    
    /// https://drafts.csswg.org/css-align/#align-self-property
    pub mod align_self {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::AlignSelf as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::AlignSelf as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::AlignSelf(specified::SelfAlignment::auto()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::AlignSelf::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AlignSelf(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::AlignSelf);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AlignSelf);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_align_self(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_align_self();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_align_self();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AlignSelf)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-align/#justify-self-property
    pub mod justify_self {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::JustifySelf as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::JustifySelf as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::JustifySelf(specified::SelfAlignment::auto()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::JustifySelf::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::JustifySelf(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::JustifySelf);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::JustifySelf);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_justify_self(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_justify_self();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_justify_self();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::JustifySelf)
        }
    }



    #[cfg(feature = "gecko")]
    impl_align_conversions!(::values::specified::align::SelfAlignment);

// https://drafts.csswg.org/css-flexbox/#propdef-order

    
        
    
    /// https://drafts.csswg.org/css-flexbox/#order-property
    pub mod order {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Integer as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Integer as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Integer::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Order(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Order);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Order);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_order(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_order();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_order();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Order)
        }
    }



    // FIXME: Gecko doesn't support content value yet.
    //
    // FIXME(emilio): I suspect this property shouldn't allow quirks, and this
    // was just a mistake, it's kind of justificable to support it given the
    // spec grammar is just `content | <width>`, but other browsers don't...
    
    
        
    
    /// https://drafts.csswg.org/css-flexbox/#flex-basis-property
    pub mod flex_basis {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozLength as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MozLength::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozLength::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FlexBasis(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FlexBasis);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::FlexBasis);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_flex_basis(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_flex_basis();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_flex_basis();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FlexBasis)
        }
    }


    
    // NOTE: Block-size doesn't support -moz-*-content keywords, since they make
    // no sense on the block axis, but it simplifies things the have that it has
    // the same type as the other properties, since otherwise we'd need to
    // handle logical props where the types are different, which looks like a
    // pain.
        
        // width, height, block-size, inline-size
        
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-width
    pub mod width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozLength as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MozLength::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozLength::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Width(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Width);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Width);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Width)
        }
    }


        // min-width, min-height, min-block-size, min-inline-size,
        
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-width
    pub mod min_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozLength as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MozLength::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozLength::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MinWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MinWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MinWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_min_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_min_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_min_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MinWidth)
        }
    }


        
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-width
    pub mod max_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MaxLength as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MaxLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MaxLength::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MaxLength::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaxWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MaxWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaxWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_max_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_max_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_max_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaxWidth)
        }
    }


    
    // NOTE: Block-size doesn't support -moz-*-content keywords, since they make
    // no sense on the block axis, but it simplifies things the have that it has
    // the same type as the other properties, since otherwise we'd need to
    // handle logical props where the types are different, which looks like a
    // pain.
        
        // width, height, block-size, inline-size
        
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-height
    pub mod height {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozLength as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MozLength::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozLength::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Height(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Height);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Height);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_height(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_height();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_height();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Height)
        }
    }


        // min-width, min-height, min-block-size, min-inline-size,
        
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-height
    pub mod min_height {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozLength as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MozLength::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozLength::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MinHeight(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MinHeight);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MinHeight);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_min_height(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_min_height();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_min_height();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MinHeight)
        }
    }


        
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-height
    pub mod max_height {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MaxLength as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MaxLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MaxLength::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MaxLength::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaxHeight(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MaxHeight);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaxHeight);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_max_height(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_max_height();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_max_height();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaxHeight)
        }
    }


    
    // NOTE: Block-size doesn't support -moz-*-content keywords, since they make
    // no sense on the block axis, but it simplifies things the have that it has
    // the same type as the other properties, since otherwise we'd need to
    // handle logical props where the types are different, which looks like a
    // pain.
        
        // width, height, block-size, inline-size
        
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-block-size
    pub mod block_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozLength as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MozLength::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozLength::parse_disallow_keyword(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BlockSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BlockSize);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BlockSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_block_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_block_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_block_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BlockSize)
        }
    }


        // min-width, min-height, min-block-size, min-inline-size,
        
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-block-size
    pub mod min_block_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozLength as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MozLength::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozLength::parse_disallow_keyword(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MinBlockSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MinBlockSize);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MinBlockSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_min_block_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_min_block_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_min_block_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MinBlockSize)
        }
    }


        
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-block-size
    pub mod max_block_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MaxLength as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MaxLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MaxLength::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MaxLength::parse_disallow_keyword(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaxBlockSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MaxBlockSize);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaxBlockSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_max_block_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_max_block_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_max_block_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaxBlockSize)
        }
    }


    
    // NOTE: Block-size doesn't support -moz-*-content keywords, since they make
    // no sense on the block axis, but it simplifies things the have that it has
    // the same type as the other properties, since otherwise we'd need to
    // handle logical props where the types are different, which looks like a
    // pain.
        
        // width, height, block-size, inline-size
        
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-inline-size
    pub mod inline_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozLength as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MozLength::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozLength::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::InlineSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::InlineSize);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::InlineSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_inline_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_inline_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_inline_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::InlineSize)
        }
    }


        // min-width, min-height, min-block-size, min-inline-size,
        
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-inline-size
    pub mod min_inline_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozLength as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MozLength::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozLength::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MinInlineSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MinInlineSize);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MinInlineSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_min_inline_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_min_inline_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_min_inline_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MinInlineSize)
        }
    }


        
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-inline-size
    pub mod max_inline_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MaxLength as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MaxLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MaxLength::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MaxLength::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaxInlineSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MaxInlineSize);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaxInlineSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_max_inline_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_max_inline_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_max_inline_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaxInlineSize)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-box-sizing
    pub mod box_sizing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            ContentBox,
            
            BorderBox,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::ContentBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::ContentBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BoxSizing(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::BoxSizing);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BoxSizing);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_box_sizing(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_box_sizing();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_box_sizing();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BoxSizing)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-images/#propdef-object-fit
    pub mod object_fit {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Fill,
            
            Contain,
            
            Cover,
            
            None,
            
            ScaleDown,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Fill
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Fill
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ObjectFit(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ObjectFit);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ObjectFit);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_object_fit(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_object_fit();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_object_fit();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ObjectFit)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-images-3/#the-object-position
    pub mod object_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Position as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Position as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Position::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Position::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ObjectPosition(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ObjectPosition);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ObjectPosition);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_object_position(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_object_position();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_object_position();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::ObjectPosition)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-row-gap
    pub mod grid_row_gap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridRowGap(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::GridRowGap);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridRowGap);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_grid_row_gap(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_row_gap();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_row_gap();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridRowGap)
        }
    }



        
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-row-start
    pub mod grid_row_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridLine as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridLine as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridLine::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridRowStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::GridRowStart);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridRowStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_row_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_row_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_row_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridRowStart)
        }
    }


        
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-row-end
    pub mod grid_row_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridLine as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridLine as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridLine::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridRowEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::GridRowEnd);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridRowEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_row_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_row_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_row_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridRowEnd)
        }
    }



    // NOTE: According to the spec, this should handle multiple values of `<track-size>`,
    // but gecko supports only a single value
    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-auto-rows
    pub mod grid_auto_rows {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TrackSize as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TrackSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TrackSize::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridAutoRows(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::GridAutoRows);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridAutoRows);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_auto_rows(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_auto_rows();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_auto_rows();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridAutoRows)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-template-rows
    pub mod grid_template_rows {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridTemplateComponent as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridTemplateComponent as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::GenericGridTemplateComponent::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridTemplateComponent::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridTemplateRows(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::GridTemplateRows);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridTemplateRows);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_template_rows(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_template_rows();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_template_rows();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridTemplateRows)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-column-gap
    pub mod grid_column_gap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridColumnGap(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::GridColumnGap);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridColumnGap);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_grid_column_gap(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_column_gap();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_column_gap();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridColumnGap)
        }
    }



        
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-column-start
    pub mod grid_column_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridLine as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridLine as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridLine::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridColumnStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::GridColumnStart);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridColumnStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_column_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_column_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_column_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridColumnStart)
        }
    }


        
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-column-end
    pub mod grid_column_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridLine as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridLine as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridLine::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridColumnEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::GridColumnEnd);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridColumnEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_column_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_column_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_column_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridColumnEnd)
        }
    }



    // NOTE: According to the spec, this should handle multiple values of `<track-size>`,
    // but gecko supports only a single value
    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-auto-columns
    pub mod grid_auto_columns {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TrackSize as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TrackSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TrackSize::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridAutoColumns(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::GridAutoColumns);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridAutoColumns);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_auto_columns(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_auto_columns();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_auto_columns();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridAutoColumns)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-template-columns
    pub mod grid_template_columns {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridTemplateComponent as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridTemplateComponent as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::GenericGridTemplateComponent::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridTemplateComponent::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridTemplateColumns(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::GridTemplateColumns);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridTemplateColumns);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_template_columns(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_template_columns();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_template_columns();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridTemplateColumns)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-auto-flow
    pub mod grid_auto_flow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridAutoFlow as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridAutoFlow as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::GridAutoFlow::row() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridAutoFlow::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridAutoFlow(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::GridAutoFlow);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridAutoFlow);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_grid_auto_flow(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_auto_flow();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_auto_flow();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridAutoFlow)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-template-areas
    pub mod grid_template_areas {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridTemplateAreas as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridTemplateAreas as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::GridTemplateAreas::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridTemplateAreas::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridTemplateAreas(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::GridTemplateAreas);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridTemplateAreas);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_grid_template_areas(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_template_areas();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_template_areas();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridTemplateAreas)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    

    
        
    
    /// https://drafts.csswg.org/css-tables/#propdef-table-layout
    pub mod table_layout {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            Fixed,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TableLayout(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TableLayout);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TableLayout);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_table_layout(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_table_layout();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_table_layout();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TableLayout)
        }
    }




    
        
    
    /// Internal-only (for `<col span>` pres attr)
    pub mod _x_span {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::XSpan as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::XSpan as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::XSpan(1) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::XSpan::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::XSpan(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::XSpan);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::XSpan);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__x_span(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__x_span();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__x_span();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::XSpan)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */







    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-text-overflow
    pub mod text_overflow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TextOverflow as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TextOverflow as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TextOverflow::get_initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TextOverflow::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextOverflow(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextOverflow);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TextOverflow);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_text_overflow(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_overflow();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_text_overflow();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::TextOverflow)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-writing-modes/#propdef-unicode-bidi
    pub mod unicode_bidi {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Normal,
            
            Embed,
            
            Isolate,
            
            BidiOverride,
            
            IsolateOverride,
            
            Plaintext,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::UnicodeBidi(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::UnicodeBidi);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::UnicodeBidi);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_unicode_bidi(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_unicode_bidi();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_unicode_bidi();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::UnicodeBidi)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-decoration-line
    pub mod text_decoration_line {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TextDecorationLine as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TextDecorationLine as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::TextDecorationLine::none() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::TextDecorationLine::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TextDecorationLine::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextDecorationLine(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextDecorationLine);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TextDecorationLine);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_decoration_line(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_decoration_line();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_text_decoration_line();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextDecorationLine)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-decoration-style
    pub mod text_decoration_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Solid,
            
            Double,
            
            Dotted,
            
            Dashed,
            
            Wavy,
            
            MozNone,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Solid
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Solid
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextDecorationStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextDecorationStyle);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TextDecorationStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_decoration_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_decoration_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_text_decoration_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextDecorationStyle)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-decoration-color
    pub mod text_decoration_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Color::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextDecorationColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextDecorationColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TextDecorationColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_decoration_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_decoration_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_text_decoration_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextDecorationColor)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-inline/#sizing-drop-initials
    pub mod initial_letter {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::InitialLetter as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::InitialLetter as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::InitialLetter::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::InitialLetter::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::InitialLetter::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::InitialLetter(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::InitialLetter);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::InitialLetter);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_initial_letter(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_initial_letter();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_initial_letter();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::InitialLetter)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */




// CSS Basic User Interface Module Level 1
// https://drafts.csswg.org/css-ui-3/


// TODO spec says that UAs should not support this
// we should probably remove from gecko (https://bugzilla.mozilla.org/show_bug.cgi?id=1328331)

    

    
        
    
    /// https://drafts.csswg.org/css-ui/#input-method-editor
    pub mod ime_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            Normal,
            
            Active,
            
            Disabled,
            
            Inactive,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ImeMode(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ImeMode);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ImeMode);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_ime_mode(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_ime_mode();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_ime_mode();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ImeMode)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-ui-4/#propdef-user-select
    pub mod _moz_user_select {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            Text,
            
            #[css(aliases = "-moz-none")]
            None,
            
            All,
            
            Element,
            
            Elements,
            
            Toggle,
            
            TriState,
            
            MozAll,
            
            MozText,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozUserSelect(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozUserSelect);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozUserSelect);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_user_select(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_user_select();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_user_select();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozUserSelect)
        }
    }



// TODO(emilio): This probably should be hidden from content.

    

    
        
    
    /// None (Nonstandard Firefox-only property)
    pub mod _moz_window_dragging {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Default,
            
            Drag,
            
            NoDrag,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Default
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Default
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozWindowDragging(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozWindowDragging);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozWindowDragging);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_window_dragging(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_window_dragging();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_window_dragging();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozWindowDragging)
        }
    }




    

    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_window_shadow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            None,
            
            Default,
            
            Menu,
            
            Tooltip,
            
            Sheet,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozWindowShadow(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozWindowShadow);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozWindowShadow);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_window_shadow(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_window_shadow();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_window_shadow();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozWindowShadow)
        }
    }




    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_window_opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Opacity as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Opacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 1.0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Opacity::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozWindowOpacity(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozWindowOpacity);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozWindowOpacity);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_window_opacity(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_window_opacity();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_window_opacity();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozWindowOpacity)
        }
    }




    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_window_transform {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Transform as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Transform as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::transform::Transform::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Transform::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozWindowTransform(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozWindowTransform);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozWindowTransform);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_window_transform(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_window_transform();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_window_transform();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozWindowTransform)
        }
    }




    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_window_transform_origin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TransformOrigin as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TransformOrigin as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TransformOrigin::initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TransformOrigin::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozWindowTransformOrigin(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozWindowTransformOrigin);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozWindowTransformOrigin);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set__moz_window_transform_origin(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_window_transform_origin();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_window_transform_origin();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MozWindowTransformOrigin)
        }
    }



// TODO(emilio): Probably also should be hidden from content.

    
        
    
    /// None (Nonstandard Firefox-only property)
    pub mod _moz_force_broken_image_icon {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozForceBrokenImageIcon as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozForceBrokenImageIcon as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MozForceBrokenImageIcon::false_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozForceBrokenImageIcon::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozForceBrokenImageIcon(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozForceBrokenImageIcon);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozForceBrokenImageIcon);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_force_broken_image_icon(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_force_broken_image_icon();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_force_broken_image_icon();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozForceBrokenImageIcon)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */



// SVG 1.1 (Second Edition)
// https://www.w3.org/TR/SVG/


// Section 10 - Text


    

    
        
    
    /// https://www.w3.org/TR/SVG/text.html#TextAnchorProperty
    pub mod text_anchor {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Start,
            
            Middle,
            
            End,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Start
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Start
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextAnchor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::TextAnchor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_anchor(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_anchor();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_anchor();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextAnchor)
        }
    }



// Section 11 - Painting: Filling, Stroking and Marker Symbols

    

    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#ColorInterpolationProperty
    pub mod color_interpolation {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Srgb,
            
            Auto,
            
            Linearrgb,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Srgb
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Srgb
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColorInterpolation(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ColorInterpolation);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_color_interpolation(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_color_interpolation();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_color_interpolation();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColorInterpolation)
        }
    }




    

    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#ColorInterpolationFiltersProperty
    pub mod color_interpolation_filters {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Linearrgb,
            
            Auto,
            
            Srgb,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Linearrgb
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Linearrgb
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColorInterpolationFilters(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ColorInterpolationFilters);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_color_interpolation_filters(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_color_interpolation_filters();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_color_interpolation_filters();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColorInterpolationFilters)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#SpecifyingFillPaint
    pub mod fill {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGPaint as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGPaint as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::SVGPaint::black() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGPaint::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Fill(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Fill);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_fill(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_fill();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_fill();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Fill)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#FillOpacityProperty
    pub mod fill_opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGOpacity as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGOpacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGOpacity::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FillOpacity(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FillOpacity);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_fill_opacity(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_fill_opacity();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_fill_opacity();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FillOpacity)
        }
    }




    

    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#FillRuleProperty
    pub mod fill_rule {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Nonzero,
            
            Evenodd,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Nonzero
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Nonzero
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FillRule(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FillRule);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_fill_rule(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_fill_rule();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_fill_rule();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FillRule)
        }
    }




    

    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#ShapeRenderingProperty
    pub mod shape_rendering {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            Optimizespeed,
            
            Crispedges,
            
            Geometricprecision,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ShapeRendering(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ShapeRendering);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_shape_rendering(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_shape_rendering();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_shape_rendering();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ShapeRendering)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#SpecifyingStrokePaint
    pub mod stroke {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGPaint as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGPaint as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGPaint::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Stroke(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::Stroke);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_stroke(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Stroke)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#StrokeWidth
    pub mod stroke_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGWidth as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(1.).into() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StrokeWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::StrokeWidth);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stroke_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke_width();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeWidth)
        }
    }




    

    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#StrokeLinecapProperty
    pub mod stroke_linecap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Butt,
            
            Round,
            
            Square,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Butt
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Butt
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StrokeLinecap(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::StrokeLinecap);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stroke_linecap(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke_linecap();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke_linecap();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeLinecap)
        }
    }




    

    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#StrokeLinejoinProperty
    pub mod stroke_linejoin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Miter,
            
            Round,
            
            Bevel,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Miter
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Miter
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StrokeLinejoin(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::StrokeLinejoin);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stroke_linejoin(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke_linejoin();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke_linejoin();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeLinejoin)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#StrokeMiterlimitProperty
    pub mod stroke_miterlimit {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GreaterThanOrEqualToOneNumber as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GreaterThanOrEqualToOneNumber as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { From::from(4.0) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GreaterThanOrEqualToOneNumber::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StrokeMiterlimit(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::StrokeMiterlimit);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stroke_miterlimit(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke_miterlimit();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke_miterlimit();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeMiterlimit)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#StrokeOpacityProperty
    pub mod stroke_opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGOpacity as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGOpacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGOpacity::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StrokeOpacity(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::StrokeOpacity);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stroke_opacity(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke_opacity();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke_opacity();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeOpacity)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#StrokeDashing
    pub mod stroke_dasharray {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGStrokeDashArray as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGStrokeDashArray as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGStrokeDashArray::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StrokeDasharray(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::StrokeDasharray);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stroke_dasharray(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke_dasharray();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke_dasharray();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeDasharray)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#StrokeDashing
    pub mod stroke_dashoffset {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGLength as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Au(0).into() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGLength::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StrokeDashoffset(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::StrokeDashoffset);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stroke_dashoffset(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke_dashoffset();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke_dashoffset();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeDashoffset)
        }
    }



// Section 14 - Clipping, Masking and Compositing

    

    
        
    
    /// https://www.w3.org/TR/SVG11/masking.html#ClipRuleProperty
    pub mod clip_rule {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Nonzero,
            
            Evenodd,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Nonzero
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Nonzero
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ClipRule(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ClipRule);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_clip_rule(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_clip_rule();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_clip_rule();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ClipRule)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#VertexMarkerProperties
    pub mod marker_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::UrlOrNone as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::UrlOrNone as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(None_) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::UrlOrNone::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarkerStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MarkerStart);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_marker_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_marker_start();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_marker_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarkerStart)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#VertexMarkerProperties
    pub mod marker_mid {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::UrlOrNone as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::UrlOrNone as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(None_) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::UrlOrNone::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarkerMid(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MarkerMid);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_marker_mid(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_marker_mid();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_marker_mid();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarkerMid)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#VertexMarkerProperties
    pub mod marker_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::UrlOrNone as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::UrlOrNone as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(None_) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::UrlOrNone::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarkerEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MarkerEnd);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_marker_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_marker_end();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_marker_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarkerEnd)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#PaintOrder
    pub mod paint_order {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGPaintOrder as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGPaintOrder as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::SVGPaintOrder::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGPaintOrder::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaintOrder(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::PaintOrder);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_paint_order(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_paint_order();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_paint_order();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaintOrder)
        }
    }




    
        
    
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-context-properties)
    pub mod _moz_context_properties {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozContextProperties as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozContextProperties as T;
        }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozContextProperties::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for -moz-context-properties.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use std::vec::IntoIter;
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(if_empty = "none", iterable)]
                pub Vec<single_value::T>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<single_value::T>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of -moz-context-properties.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(if_empty = "none", iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                computed_value::T(vec![])
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

                if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                    return Ok(SpecifiedValue(Vec::new()))
                }

            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozContextProperties(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozContextProperties);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_inheritedsvg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set__moz_context_properties(iter);
                        }
                        context.builder.put_inheritedsvg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_context_properties();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_context_properties();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozContextProperties)
        }
    }




    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    

    
        
    
    /// https://www.w3.org/TR/SVG11/text.html#DominantBaselineProperty
    pub mod dominant_baseline {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Auto,
            
            UseScript,
            
            NoChange,
            
            ResetSize,
            
            Ideographic,
            
            Alphabetic,
            
            Hanging,
            
            Mathematical,
            
            Central,
            
            Middle,
            
            TextAfterEdge,
            
            TextBeforeEdge,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::DominantBaseline(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::DominantBaseline);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::DominantBaseline);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_dominant_baseline(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_dominant_baseline();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_dominant_baseline();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::DominantBaseline)
        }
    }




    

    
        
    
    /// https://www.w3.org/TR/SVGTiny12/painting.html#VectorEffectProperty
    pub mod vector_effect {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            None,
            
            NonScalingStroke,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::VectorEffect(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::VectorEffect);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::VectorEffect);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_vector_effect(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_vector_effect();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_vector_effect();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::VectorEffect)
        }
    }



// Section 13 - Gradients and Patterns


    
        
    
    /// https://www.w3.org/TR/SVGTiny12/painting.html#StopColorProperty
    pub mod stop_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::RGBAColor as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::RGBAColor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { RGBA::new(0, 0, 0, 255) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::RGBAColor::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StopColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::StopColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::StopColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stop_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stop_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_stop_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StopColor)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVGTiny12/painting.html#propdef-stop-opacity
    pub mod stop_opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Opacity as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Opacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 1.0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Opacity::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StopOpacity(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::StopOpacity);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::StopOpacity);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stop_opacity(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stop_opacity();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_stop_opacity();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StopOpacity)
        }
    }



// Section 15 - Filter Effects


    
        
    
    /// https://www.w3.org/TR/SVG/filters.html#FloodColorProperty
    pub mod flood_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::RGBAColor as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::RGBAColor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { RGBA::new(0, 0, 0, 255) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::RGBAColor::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FloodColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FloodColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::FloodColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_flood_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_flood_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_flood_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FloodColor)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG/filters.html#FloodOpacityProperty
    pub mod flood_opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Opacity as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Opacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 1.0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Opacity::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FloodOpacity(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::FloodOpacity);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::FloodOpacity);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_flood_opacity(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_flood_opacity();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_flood_opacity();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FloodOpacity)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG/filters.html#LightingColorProperty
    pub mod lighting_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::RGBAColor as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::RGBAColor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { RGBA::new(255, 255, 255, 255) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::RGBAColor::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::LightingColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::LightingColor);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::LightingColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_lighting_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_lighting_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_lighting_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::LightingColor)
        }
    }



// CSS Masking Module Level 1
// https://drafts.fxtf.org/css-masking

    

    
        
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-type
    pub mod mask_type {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Luminance,
            
            Alpha,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Luminance
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Luminance
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskType(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MaskType);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskType);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_mask_type(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_type();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_type();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskType)
        }
    }




    
        
    
    /// https://drafts.fxtf.org/css-masking/#propdef-clip-path
    pub mod clip_path {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::basic_shape::ClippingShape as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::basic_shape::ClippingShape as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::basic_shape::ShapeSource::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::basic_shape::ClippingShape::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ClipPath(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::ClipPath);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ClipPath);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_clip_path(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_clip_path();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_clip_path();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::ClipPath)
        }
    }




    

    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-mode
    pub mod mask_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            MatchSource,
            
            Alpha,
            
            Luminance,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::MatchSource
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::MatchSource
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for mask-mode.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of mask-mode.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskMode(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MaskMode);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskMode);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_mode(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_mode();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_mode();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskMode)
        }
    }





    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-repeat
    pub mod mask_repeat {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BackgroundRepeat as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BackgroundRepeat as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BackgroundRepeat::repeat() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BackgroundRepeat::repeat() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BackgroundRepeat::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for mask-repeat.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of mask-repeat.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskRepeat(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MaskRepeat);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskRepeat);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_repeat(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_repeat();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_repeat();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskRepeat)
        }
    }




    
    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-position
    pub mod mask_position_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::position::HorizontalPosition as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::position::HorizontalPosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentage::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::PositionComponent::Center }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::position::HorizontalPosition::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for mask-position-x.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Animate, ComputeSquaredDistance)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );

                use values::animated::{ToAnimatedZero};

                impl ToAnimatedZero for T {
                    #[inline]
                    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
                }

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of mask-position-x.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskPositionX(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MaskPositionX);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskPositionX);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_position_x(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_position_x();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_position_x();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskPositionX)
        }
    }



    
    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-position
    pub mod mask_position_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::position::VerticalPosition as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::position::VerticalPosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentage::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::PositionComponent::Center }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::position::VerticalPosition::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for mask-position-y.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Animate, ComputeSquaredDistance)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );

                use values::animated::{ToAnimatedZero};

                impl ToAnimatedZero for T {
                    #[inline]
                    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
                }

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of mask-position-y.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskPositionY(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MaskPositionY);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskPositionY);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_position_y(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_position_y();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_position_y();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskPositionY)
        }
    }





    

    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-clip
    pub mod mask_clip {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            BorderBox,
            
            ContentBox,
            
            PaddingBox,
            
            FillBox,
            
            StrokeBox,
            
            ViewBox,
            
            NoClip,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::BorderBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::BorderBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for mask-clip.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of mask-clip.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskClip(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MaskClip);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskClip);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_clip(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_clip();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_clip();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskClip)
        }
    }





    

    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-origin
    pub mod mask_origin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            BorderBox,
            
            ContentBox,
            
            PaddingBox,
            
            FillBox,
            
            StrokeBox,
            
            ViewBox,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::BorderBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::BorderBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for mask-origin.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of mask-origin.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskOrigin(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MaskOrigin);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskOrigin);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_origin(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_origin();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_origin();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskOrigin)
        }
    }





    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-size
    pub mod mask_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
    use properties::longhands::background_size;
    pub use ::properties::longhands::background_size::SpecifiedValue;
    pub use ::properties::longhands::background_size::single_value as single_value;
    pub use ::properties::longhands::background_size::computed_value as computed_value;

    #[inline]
    pub fn get_initial_value() -> computed_value::T {
        background_size::get_initial_value()
    }

    pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                         -> Result<SpecifiedValue,ParseError<'i>> {
        background_size::parse(context, input)
    }

        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MaskSize);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_mask_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskSize)
        }
    }



    

    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-composite
    pub mod mask_composite {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Add,
            
            Subtract,
            
            Intersect,
            
            Exclude,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Add
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Add
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for mask-composite.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of mask-composite.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskComposite(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MaskComposite);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskComposite);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_composite(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_composite();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_composite();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskComposite)
        }
    }





    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-image
    pub mod mask_image {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ImageLayer as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ImageLayer as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::First(None_) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { Either::First(None_) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ImageLayer::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for mask-image.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[css(comma)]
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            pub struct T(
                #[css(iterable)]
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        /// The specified value of mask-image.
        #[css(comma)]
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub Vec<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskImage(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MaskImage);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskImage);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_image(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_image();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_image();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskImage)
        }
    }




    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */




// Non-standard properties that Gecko uses for XUL elements.



    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/box-align)
    pub mod _moz_box_align {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Stretch,
            
            Start,
            
            Center,
            
            Baseline,
            
            End,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Stretch
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Stretch
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBoxAlign(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozBoxAlign);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBoxAlign);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_box_align(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_box_align();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_box_align();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxAlign)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/box-direction)
    pub mod _moz_box_direction {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Normal,
            
            Reverse,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBoxDirection(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozBoxDirection);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBoxDirection);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_box_direction(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_box_direction();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_box_direction();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxDirection)
        }
    }




    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/box-flex)
    pub mod _moz_box_flex {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeNumber as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeNumber as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { From::from(0.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeNumber::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBoxFlex(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozBoxFlex);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBoxFlex);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_box_flex(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_box_flex();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_box_flex();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxFlex)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/box-orient)
    pub mod _moz_box_orient {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            #[css(aliases = "inline-axis")]
            Horizontal,
            
            #[css(aliases = "block-axis")]
            Vertical,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Horizontal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Horizontal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBoxOrient(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozBoxOrient);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBoxOrient);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_box_orient(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_box_orient();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_box_orient();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxOrient)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/box-pack)
    pub mod _moz_box_pack {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            Start,
            
            Center,
            
            End,
            
            Justify,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Start
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Start
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBoxPack(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozBoxPack);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBoxPack);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_box_pack(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_box_pack();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_box_pack();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxPack)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-stack-sizing)
    pub mod _moz_stack_sizing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
            #[derive(Parse, ToComputedValue)]
            pub enum T {
                
            
            StretchToFit,
            
            Ignore,
            
            IgnoreHorizontal,
            
            IgnoreVertical,
        
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::StretchToFit
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::StretchToFit
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozStackSizing(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozStackSizing);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozStackSizing);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_stack_sizing(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_stack_sizing();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_stack_sizing();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozStackSizing)
        }
    }




    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-box-ordinal-group)
    pub mod _moz_box_ordinal_group {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Integer as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Integer as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Integer::parse_non_negative(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBoxOrdinalGroup(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                    debug_assert_eq!(declaration.id, LonghandId::MozBoxOrdinalGroup);
                    DeclaredValue::CSSWideKeyword(declaration.keyword)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBoxOrdinalGroup);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_box_ordinal_group(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_box_ordinal_group();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_box_ordinal_group();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxOrdinalGroup)
        }
    }



}

macro_rules! unwrap_or_initial {
    ($prop: ident) => (unwrap_or_initial!($prop, $prop));
    ($prop: ident, $expr: expr) =>
        ($expr.unwrap_or_else(|| $prop::get_initial_specified_value()));
}

/// A module with code for all the shorthand css properties, and a few
/// serialization helpers.
#[allow(missing_docs)]
pub mod shorthands {
    use cssparser::Parser;
    use parser::{Parse, ParserContext};
    use style_traits::{ParseError, StyleParseErrorKind};
    use values::specified;

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

use style_traits::{CssWriter, ToCss};
use values::specified::{BorderStyle, Color};
use std::fmt::{self, Write};

fn serialize_directional_border<W, I,>(
    dest: &mut CssWriter<W>,
    width: &I,
    style: &BorderStyle,
    color: &Color,
) -> fmt::Result
where
    W: Write,
    I: ToCss,
{
    width.to_css(dest)?;
    dest.write_str(" ")?;
    style.to_css(dest)?;
    if *color != Color::CurrentColor {
        dest.write_str(" ")?;
        color.to_css(dest)?;
    }
    Ok(())
}

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */



// TODO: other background-* properties


    /// https://drafts.csswg.org/css-backgrounds/#the-background
    pub mod background {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub background_color:
                    longhands::background_color::SpecifiedValue
                    ,
                pub background_position_x:
                    longhands::background_position_x::SpecifiedValue
                    ,
                pub background_position_y:
                    longhands::background_position_y::SpecifiedValue
                    ,
                pub background_repeat:
                    longhands::background_repeat::SpecifiedValue
                    ,
                pub background_attachment:
                    longhands::background_attachment::SpecifiedValue
                    ,
                pub background_image:
                    longhands::background_image::SpecifiedValue
                    ,
                pub background_size:
                    longhands::background_size::SpecifiedValue
                    ,
                pub background_origin:
                    longhands::background_origin::SpecifiedValue
                    ,
                pub background_clip:
                    longhands::background_clip::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub background_color:
                    &'a longhands::background_color::SpecifiedValue,
                pub background_position_x:
                    &'a longhands::background_position_x::SpecifiedValue,
                pub background_position_y:
                    &'a longhands::background_position_y::SpecifiedValue,
                pub background_repeat:
                    &'a longhands::background_repeat::SpecifiedValue,
                pub background_attachment:
                    &'a longhands::background_attachment::SpecifiedValue,
                pub background_image:
                    &'a longhands::background_image::SpecifiedValue,
                pub background_size:
                    &'a longhands::background_size::SpecifiedValue,
                pub background_origin:
                    &'a longhands::background_origin::SpecifiedValue,
                pub background_clip:
                    &'a longhands::background_clip::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut background_color = None;
                    let mut background_position_x = None;
                    let mut background_position_y = None;
                    let mut background_repeat = None;
                    let mut background_attachment = None;
                    let mut background_image = None;
                    let mut background_size = None;
                    let mut background_origin = None;
                    let mut background_clip = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BackgroundColor(ref value) => {
                                background_color = Some(value)
                            },
                            PropertyDeclaration::BackgroundPositionX(ref value) => {
                                background_position_x = Some(value)
                            },
                            PropertyDeclaration::BackgroundPositionY(ref value) => {
                                background_position_y = Some(value)
                            },
                            PropertyDeclaration::BackgroundRepeat(ref value) => {
                                background_repeat = Some(value)
                            },
                            PropertyDeclaration::BackgroundAttachment(ref value) => {
                                background_attachment = Some(value)
                            },
                            PropertyDeclaration::BackgroundImage(ref value) => {
                                background_image = Some(value)
                            },
                            PropertyDeclaration::BackgroundSize(ref value) => {
                                background_size = Some(value)
                            },
                            PropertyDeclaration::BackgroundOrigin(ref value) => {
                                background_origin = Some(value)
                            },
                            PropertyDeclaration::BackgroundClip(ref value) => {
                                background_clip = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        background_color,
                        background_position_x,
                        background_position_y,
                        background_repeat,
                        background_attachment,
                        background_image,
                        background_size,
                        background_origin,
                        background_clip,
                ) {

                    (
                        Some(background_color),
                        Some(background_position_x),
                        Some(background_position_y),
                        Some(background_repeat),
                        Some(background_attachment),
                        Some(background_image),
                        Some(background_size),
                        Some(background_origin),
                        Some(background_clip),
                    ) =>
                    Ok(LonghandsToSerialize {
                            background_color,
                            background_position_x,
                            background_position_y,
                            background_repeat,
                            background_attachment,
                            background_image,
                            background_size,
                            background_origin,
                            background_clip,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BackgroundColor(
                        longhands.background_color
                    ));
                    declarations.push(PropertyDeclaration::BackgroundPositionX(
                        longhands.background_position_x
                    ));
                    declarations.push(PropertyDeclaration::BackgroundPositionY(
                        longhands.background_position_y
                    ));
                    declarations.push(PropertyDeclaration::BackgroundRepeat(
                        longhands.background_repeat
                    ));
                    declarations.push(PropertyDeclaration::BackgroundAttachment(
                        longhands.background_attachment
                    ));
                    declarations.push(PropertyDeclaration::BackgroundImage(
                        longhands.background_image
                    ));
                    declarations.push(PropertyDeclaration::BackgroundSize(
                        longhands.background_size
                    ));
                    declarations.push(PropertyDeclaration::BackgroundOrigin(
                        longhands.background_origin
                    ));
                    declarations.push(PropertyDeclaration::BackgroundClip(
                        longhands.background_clip
                    ));
            })
        }

        
    use properties::longhands::{background_position_x, background_position_y, background_repeat};
    use properties::longhands::{background_attachment, background_image, background_size, background_origin};
    use properties::longhands::background_clip;
    use properties::longhands::background_clip::single_value::computed_value::T as Clip;
    use properties::longhands::background_origin::single_value::computed_value::T as Origin;
    use values::specified::{Color, Position, PositionComponent};
    use parser::Parse;

    // FIXME(emilio): Should be the same type!
    impl From<background_origin::single_value::SpecifiedValue> for background_clip::single_value::SpecifiedValue {
        fn from(origin: background_origin::single_value::SpecifiedValue) ->
            background_clip::single_value::SpecifiedValue {
            match origin {
                background_origin::single_value::SpecifiedValue::ContentBox =>
                    background_clip::single_value::SpecifiedValue::ContentBox,
                background_origin::single_value::SpecifiedValue::PaddingBox =>
                    background_clip::single_value::SpecifiedValue::PaddingBox,
                background_origin::single_value::SpecifiedValue::BorderBox =>
                    background_clip::single_value::SpecifiedValue::BorderBox,
            }
        }
    }

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut background_color = None;

            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_image = background_image::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_position_x = background_position_x::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_position_y = background_position_y::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_repeat = background_repeat::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_size = background_size::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_attachment = background_attachment::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_origin = background_origin::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_clip = background_clip::SpecifiedValue(Vec::with_capacity(1));
        input.parse_comma_separated(|input| {
            // background-color can only be in the last element, so if it
            // is parsed anywhere before, the value is invalid.
            if background_color.is_some() {
                return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
            }

                let mut image = None;
                let mut position = None;
                let mut repeat = None;
                let mut size = None;
                let mut attachment = None;
                let mut origin = None;
                let mut clip = None;
            loop {
                if background_color.is_none() {
                    if let Ok(value) = input.try(|i| Color::parse(context, i)) {
                        background_color = Some(value);
                        continue
                    }
                }
                if position.is_none() {
                    if let Ok(value) = input.try(|input| Position::parse(context, input)) {
                        position = Some(value);

                        // Parse background size, if applicable.
                        size = input.try(|input| {
                            input.expect_delim('/')?;
                            background_size::single_value::parse(context, input)
                        }).ok();

                        continue
                    }
                }
                    if image.is_none() {
                        if let Ok(value) = input.try(|input| background_image::single_value
                                                                               ::parse(context, input)) {
                            image = Some(value);
                            continue
                        }
                    }
                    if repeat.is_none() {
                        if let Ok(value) = input.try(|input| background_repeat::single_value
                                                                               ::parse(context, input)) {
                            repeat = Some(value);
                            continue
                        }
                    }
                    if attachment.is_none() {
                        if let Ok(value) = input.try(|input| background_attachment::single_value
                                                                               ::parse(context, input)) {
                            attachment = Some(value);
                            continue
                        }
                    }
                    if origin.is_none() {
                        if let Ok(value) = input.try(|input| background_origin::single_value
                                                                               ::parse(context, input)) {
                            origin = Some(value);
                            continue
                        }
                    }
                    if clip.is_none() {
                        if let Ok(value) = input.try(|input| background_clip::single_value
                                                                               ::parse(context, input)) {
                            clip = Some(value);
                            continue
                        }
                    }
                break
            }
            if clip.is_none() {
                if let Some(origin) = origin {
                    clip = Some(background_clip::single_value::SpecifiedValue::from(origin));
                }
            }
            let mut any = false;
                any = any || image.is_some();
                any = any || position.is_some();
                any = any || repeat.is_some();
                any = any || size.is_some();
                any = any || attachment.is_some();
                any = any || origin.is_some();
                any = any || clip.is_some();
            any = any || background_color.is_some();
            if any {
                if let Some(position) = position {
                    background_position_x.0.push(position.horizontal);
                    background_position_y.0.push(position.vertical);
                } else {
                    background_position_x.0.push(PositionComponent::zero());
                    background_position_y.0.push(PositionComponent::zero());
                }
                    if let Some(bg_image) = image {
                        background_image.0.push(bg_image);
                    } else {
                        background_image.0.push(background_image::single_value
                                                                    ::get_initial_specified_value());
                    }
                    if let Some(bg_repeat) = repeat {
                        background_repeat.0.push(bg_repeat);
                    } else {
                        background_repeat.0.push(background_repeat::single_value
                                                                    ::get_initial_specified_value());
                    }
                    if let Some(bg_size) = size {
                        background_size.0.push(bg_size);
                    } else {
                        background_size.0.push(background_size::single_value
                                                                    ::get_initial_specified_value());
                    }
                    if let Some(bg_attachment) = attachment {
                        background_attachment.0.push(bg_attachment);
                    } else {
                        background_attachment.0.push(background_attachment::single_value
                                                                    ::get_initial_specified_value());
                    }
                    if let Some(bg_origin) = origin {
                        background_origin.0.push(bg_origin);
                    } else {
                        background_origin.0.push(background_origin::single_value
                                                                    ::get_initial_specified_value());
                    }
                    if let Some(bg_clip) = clip {
                        background_clip.0.push(bg_clip);
                    } else {
                        background_clip.0.push(background_clip::single_value
                                                                    ::get_initial_specified_value());
                    }
                Ok(())
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        })?;

        Ok(expanded! {
             background_color: background_color.unwrap_or(Color::transparent()),
             background_image: background_image,
             background_position_x: background_position_x,
             background_position_y: background_position_y,
             background_repeat: background_repeat,
             background_attachment: background_attachment,
             background_size: background_size,
             background_origin: background_origin,
             background_clip: background_clip,
         })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let len = self.background_image.0.len();
            // There should be at least one declared value
            if len == 0 {
                return Ok(());
            }

            // If a value list length is differs then we don't do a shorthand serialization.
            // The exceptions to this is color which appears once only and is serialized
            // with the last item.
                if len != self.background_image.0.len() {
                    return Ok(());
                }
                if len != self.background_position_x.0.len() {
                    return Ok(());
                }
                if len != self.background_position_y.0.len() {
                    return Ok(());
                }
                if len != self.background_size.0.len() {
                    return Ok(());
                }
                if len != self.background_repeat.0.len() {
                    return Ok(());
                }
                if len != self.background_origin.0.len() {
                    return Ok(());
                }
                if len != self.background_clip.0.len() {
                    return Ok(());
                }
                if len != self.background_attachment.0.len() {
                    return Ok(());
                }

            for i in 0..len {
                    let image = &self.background_image.0[i];
                    let position_x = &self.background_position_x.0[i];
                    let position_y = &self.background_position_y.0[i];
                    let repeat = &self.background_repeat.0[i];
                    let size = &self.background_size.0[i];
                    let attachment = &self.background_attachment.0[i];
                    let origin = &self.background_origin.0[i];
                    let clip = &self.background_clip.0[i];

                if i != 0 {
                    dest.write_str(", ")?;
                }

                if i == len - 1 {
                    self.background_color.to_css(dest)?;
                    dest.write_str(" ")?;
                }

                image.to_css(dest)?;
                    dest.write_str(" ")?;
                    repeat.to_css(dest)?;
                    dest.write_str(" ")?;
                    attachment.to_css(dest)?;

                dest.write_str(" ")?;
                Position {
                    horizontal: position_x.clone(),
                    vertical: position_y.clone()
                }.to_css(dest)?;

                if *size != background_size::single_value::get_initial_specified_value() {
                    dest.write_str(" / ")?;
                    size.to_css(dest)?;
                }

                if *origin != Origin::PaddingBox || *clip != Clip::BorderBox {
                    dest.write_str(" ")?;
                    origin.to_css(dest)?;
                    if *clip != From::from(*origin) {
                        dest.write_str(" ")?;
                        clip.to_css(dest)?;
                    }
                }
            }

            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-backgrounds-4/#the-background-position
    pub mod background_position {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub background_position_x:
                    longhands::background_position_x::SpecifiedValue
                    ,
                pub background_position_y:
                    longhands::background_position_y::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub background_position_x:
                    &'a longhands::background_position_x::SpecifiedValue,
                pub background_position_y:
                    &'a longhands::background_position_y::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut background_position_x = None;
                    let mut background_position_y = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BackgroundPositionX(ref value) => {
                                background_position_x = Some(value)
                            },
                            PropertyDeclaration::BackgroundPositionY(ref value) => {
                                background_position_y = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        background_position_x,
                        background_position_y,
                ) {

                    (
                        Some(background_position_x),
                        Some(background_position_y),
                    ) =>
                    Ok(LonghandsToSerialize {
                            background_position_x,
                            background_position_y,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BackgroundPositionX(
                        longhands.background_position_x
                    ));
                    declarations.push(PropertyDeclaration::BackgroundPositionY(
                        longhands.background_position_y
                    ));
            })
        }

        
    use properties::longhands::{background_position_x, background_position_y};
    use values::specified::AllowQuirks;
    use values::specified::position::Position;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate.  Note that we always push at least one item if parsing
        // succeeds.
        let mut position_x = background_position_x::SpecifiedValue(Vec::with_capacity(1));
        let mut position_y = background_position_y::SpecifiedValue(Vec::with_capacity(1));
        let mut any = false;

        input.parse_comma_separated(|input| {
            let value = Position::parse_quirky(context, input, AllowQuirks::Yes)?;
            position_x.0.push(value.horizontal);
            position_y.0.push(value.vertical);
            any = true;
            Ok(())
        })?;
        if !any {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }

        Ok(expanded! {
            background_position_x: position_x,
            background_position_y: position_y,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let len = self.background_position_x.0.len();
            if len == 0 || len != self.background_position_y.0.len() {
                return Ok(());
            }
            for i in 0..len {
                Position {
                    horizontal: self.background_position_x.0[i].clone(),
                    vertical: self.background_position_y.0[i].clone()
                }.to_css(dest)?;

                if i < len - 1 {
                    dest.write_str(", ")?;
                }
            }
            Ok(())
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-color
    pub mod border_color {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_top_color:
                    longhands::border_top_color::SpecifiedValue
                    ,
                pub border_right_color:
                    longhands::border_right_color::SpecifiedValue
                    ,
                pub border_bottom_color:
                    longhands::border_bottom_color::SpecifiedValue
                    ,
                pub border_left_color:
                    longhands::border_left_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_color:
                    &'a longhands::border_top_color::SpecifiedValue,
                pub border_right_color:
                    &'a longhands::border_right_color::SpecifiedValue,
                pub border_bottom_color:
                    &'a longhands::border_bottom_color::SpecifiedValue,
                pub border_left_color:
                    &'a longhands::border_left_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_color = None;
                    let mut border_right_color = None;
                    let mut border_bottom_color = None;
                    let mut border_left_color = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderTopColor(ref value) => {
                                border_top_color = Some(value)
                            },
                            PropertyDeclaration::BorderRightColor(ref value) => {
                                border_right_color = Some(value)
                            },
                            PropertyDeclaration::BorderBottomColor(ref value) => {
                                border_bottom_color = Some(value)
                            },
                            PropertyDeclaration::BorderLeftColor(ref value) => {
                                border_left_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_color,
                        border_right_color,
                        border_bottom_color,
                        border_left_color,
                ) {

                    (
                        Some(border_top_color),
                        Some(border_right_color),
                        Some(border_bottom_color),
                        Some(border_left_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_color,
                            border_right_color,
                            border_bottom_color,
                            border_left_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopColor(
                        longhands.border_top_color
                    ));
                    declarations.push(PropertyDeclaration::BorderRightColor(
                        longhands.border_right_color
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomColor(
                        longhands.border_bottom_color
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftColor(
                        longhands.border_left_color
                    ));
            })
        }

        
        #[allow(unused_imports)]
        use parser::Parse;
        use values::generics::rect::Rect;
        use values::specified;

        pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                   -> Result<Longhands, ParseError<'i>> {
            let rect = Rect::parse_with(context, input, |_c, i| {
                specified::Color::parse_quirky(_c, i, specified::AllowQuirks::Yes)
            })?;
            Ok(expanded! {
                    border_top_color: rect.0,
                    border_right_color: rect.1,
                    border_bottom_color: rect.2,
                    border_left_color: rect.3,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a> {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let rect = Rect::new(
                    &self.border_top_color,
                    &self.border_right_color,
                    &self.border_bottom_color,
                    &self.border_left_color,
                );
                rect.to_css(dest)
            }
        }
    
    }




    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-style
    pub mod border_style {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_top_style:
                    longhands::border_top_style::SpecifiedValue
                    ,
                pub border_right_style:
                    longhands::border_right_style::SpecifiedValue
                    ,
                pub border_bottom_style:
                    longhands::border_bottom_style::SpecifiedValue
                    ,
                pub border_left_style:
                    longhands::border_left_style::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_style:
                    &'a longhands::border_top_style::SpecifiedValue,
                pub border_right_style:
                    &'a longhands::border_right_style::SpecifiedValue,
                pub border_bottom_style:
                    &'a longhands::border_bottom_style::SpecifiedValue,
                pub border_left_style:
                    &'a longhands::border_left_style::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_style = None;
                    let mut border_right_style = None;
                    let mut border_bottom_style = None;
                    let mut border_left_style = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderTopStyle(ref value) => {
                                border_top_style = Some(value)
                            },
                            PropertyDeclaration::BorderRightStyle(ref value) => {
                                border_right_style = Some(value)
                            },
                            PropertyDeclaration::BorderBottomStyle(ref value) => {
                                border_bottom_style = Some(value)
                            },
                            PropertyDeclaration::BorderLeftStyle(ref value) => {
                                border_left_style = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_style,
                        border_right_style,
                        border_bottom_style,
                        border_left_style,
                ) {

                    (
                        Some(border_top_style),
                        Some(border_right_style),
                        Some(border_bottom_style),
                        Some(border_left_style),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_style,
                            border_right_style,
                            border_bottom_style,
                            border_left_style,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopStyle(
                        longhands.border_top_style
                    ));
                    declarations.push(PropertyDeclaration::BorderRightStyle(
                        longhands.border_right_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomStyle(
                        longhands.border_bottom_style
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftStyle(
                        longhands.border_left_style
                    ));
            })
        }

        
        #[allow(unused_imports)]
        use parser::Parse;
        use values::generics::rect::Rect;
        use values::specified;

        pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                   -> Result<Longhands, ParseError<'i>> {
            let rect = Rect::parse_with(context, input, |_c, i| {
                specified::BorderStyle::parse(i)
            })?;
            Ok(expanded! {
                    border_top_style: rect.0,
                    border_right_style: rect.1,
                    border_bottom_style: rect.2,
                    border_left_style: rect.3,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a> {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let rect = Rect::new(
                    &self.border_top_style,
                    &self.border_right_style,
                    &self.border_bottom_style,
                    &self.border_left_style,
                );
                rect.to_css(dest)
            }
        }
    
    }





    /// https://drafts.csswg.org/css-backgrounds/#border-width
    pub mod border_width {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_top_width:
                    longhands::border_top_width::SpecifiedValue
                    ,
                pub border_left_width:
                    longhands::border_left_width::SpecifiedValue
                    ,
                pub border_bottom_width:
                    longhands::border_bottom_width::SpecifiedValue
                    ,
                pub border_right_width:
                    longhands::border_right_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_width:
                    &'a longhands::border_top_width::SpecifiedValue,
                pub border_left_width:
                    &'a longhands::border_left_width::SpecifiedValue,
                pub border_bottom_width:
                    &'a longhands::border_bottom_width::SpecifiedValue,
                pub border_right_width:
                    &'a longhands::border_right_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_width = None;
                    let mut border_left_width = None;
                    let mut border_bottom_width = None;
                    let mut border_right_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderTopWidth(ref value) => {
                                border_top_width = Some(value)
                            },
                            PropertyDeclaration::BorderLeftWidth(ref value) => {
                                border_left_width = Some(value)
                            },
                            PropertyDeclaration::BorderBottomWidth(ref value) => {
                                border_bottom_width = Some(value)
                            },
                            PropertyDeclaration::BorderRightWidth(ref value) => {
                                border_right_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_width,
                        border_left_width,
                        border_bottom_width,
                        border_right_width,
                ) {

                    (
                        Some(border_top_width),
                        Some(border_left_width),
                        Some(border_bottom_width),
                        Some(border_right_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_width,
                            border_left_width,
                            border_bottom_width,
                            border_right_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopWidth(
                        longhands.border_top_width
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftWidth(
                        longhands.border_left_width
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomWidth(
                        longhands.border_bottom_width
                    ));
                    declarations.push(PropertyDeclaration::BorderRightWidth(
                        longhands.border_right_width
                    ));
            })
        }

        
    use values::generics::rect::Rect;
    use values::specified::{AllowQuirks, BorderSideWidth};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let rect = Rect::parse_with(context, input, |_, i| {
            BorderSideWidth::parse_quirky(context, i, AllowQuirks::Yes)
        })?;
        Ok(expanded! {
            border_top_width: rect.0,
            border_right_width: rect.1,
            border_bottom_width: rect.2,
            border_left_width: rect.3,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let top = &self.border_top_width;
            let left = &self.border_left_width;
            let bottom = &self.border_bottom_width;
            let right = &self.border_right_width;
            Rect::new(top, right, bottom, left).to_css(dest)
        }
    }

    }



pub fn parse_border<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                            -> Result<(specified::Color,
                                       specified::BorderStyle,
                                       specified::BorderSideWidth), ParseError<'i>> {
    use values::specified::{Color, BorderStyle, BorderSideWidth};
    let _unused = context;
    let mut color = None;
    let mut style = None;
    let mut width = None;
    let mut any = false;
    loop {
        if color.is_none() {
            if let Ok(value) = input.try(|i| Color::parse(context, i)) {
                color = Some(value);
                any = true;
                continue
            }
        }
        if style.is_none() {
            if let Ok(value) = input.try(BorderStyle::parse) {
                style = Some(value);
                any = true;
                continue
            }
        }
        if width.is_none() {
            if let Ok(value) = input.try(|i| BorderSideWidth::parse(context, i)) {
                width = Some(value);
                any = true;
                continue
            }
        }
        break
    }
    if any {
        Ok((color.unwrap_or_else(|| Color::currentcolor()),
            style.unwrap_or(BorderStyle::None),
            width.unwrap_or(BorderSideWidth::Medium)))
    } else {
        Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
    }
}

    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-top
    pub mod border_top {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_top_color:
                    longhands::border_top_color::SpecifiedValue
                    ,
                pub border_top_style:
                    longhands::border_top_style::SpecifiedValue
                    ,
                pub border_top_width:
                    longhands::border_top_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_color:
                    &'a longhands::border_top_color::SpecifiedValue,
                pub border_top_style:
                    &'a longhands::border_top_style::SpecifiedValue,
                pub border_top_width:
                    &'a longhands::border_top_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_color = None;
                    let mut border_top_style = None;
                    let mut border_top_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderTopColor(ref value) => {
                                border_top_color = Some(value)
                            },
                            PropertyDeclaration::BorderTopStyle(ref value) => {
                                border_top_style = Some(value)
                            },
                            PropertyDeclaration::BorderTopWidth(ref value) => {
                                border_top_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_color,
                        border_top_style,
                        border_top_width,
                ) {

                    (
                        Some(border_top_color),
                        Some(border_top_style),
                        Some(border_top_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_color,
                            border_top_style,
                            border_top_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopColor(
                        longhands.border_top_color
                    ));
                    declarations.push(PropertyDeclaration::BorderTopStyle(
                        longhands.border_top_style
                    ));
                    declarations.push(PropertyDeclaration::BorderTopWidth(
                        longhands.border_top_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_top_color: color,
            border_top_style: style,
            border_top_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_top_width,
                self.border_top_style,
                self.border_top_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-left
    pub mod border_left {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_left_color:
                    longhands::border_left_color::SpecifiedValue
                    ,
                pub border_left_style:
                    longhands::border_left_style::SpecifiedValue
                    ,
                pub border_left_width:
                    longhands::border_left_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_left_color:
                    &'a longhands::border_left_color::SpecifiedValue,
                pub border_left_style:
                    &'a longhands::border_left_style::SpecifiedValue,
                pub border_left_width:
                    &'a longhands::border_left_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_left_color = None;
                    let mut border_left_style = None;
                    let mut border_left_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderLeftColor(ref value) => {
                                border_left_color = Some(value)
                            },
                            PropertyDeclaration::BorderLeftStyle(ref value) => {
                                border_left_style = Some(value)
                            },
                            PropertyDeclaration::BorderLeftWidth(ref value) => {
                                border_left_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_left_color,
                        border_left_style,
                        border_left_width,
                ) {

                    (
                        Some(border_left_color),
                        Some(border_left_style),
                        Some(border_left_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_left_color,
                            border_left_style,
                            border_left_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderLeftColor(
                        longhands.border_left_color
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftStyle(
                        longhands.border_left_style
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftWidth(
                        longhands.border_left_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_left_color: color,
            border_left_style: style,
            border_left_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_left_width,
                self.border_left_style,
                self.border_left_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-bottom
    pub mod border_bottom {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_bottom_color:
                    longhands::border_bottom_color::SpecifiedValue
                    ,
                pub border_bottom_style:
                    longhands::border_bottom_style::SpecifiedValue
                    ,
                pub border_bottom_width:
                    longhands::border_bottom_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_bottom_color:
                    &'a longhands::border_bottom_color::SpecifiedValue,
                pub border_bottom_style:
                    &'a longhands::border_bottom_style::SpecifiedValue,
                pub border_bottom_width:
                    &'a longhands::border_bottom_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_bottom_color = None;
                    let mut border_bottom_style = None;
                    let mut border_bottom_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderBottomColor(ref value) => {
                                border_bottom_color = Some(value)
                            },
                            PropertyDeclaration::BorderBottomStyle(ref value) => {
                                border_bottom_style = Some(value)
                            },
                            PropertyDeclaration::BorderBottomWidth(ref value) => {
                                border_bottom_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_bottom_color,
                        border_bottom_style,
                        border_bottom_width,
                ) {

                    (
                        Some(border_bottom_color),
                        Some(border_bottom_style),
                        Some(border_bottom_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_bottom_color,
                            border_bottom_style,
                            border_bottom_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderBottomColor(
                        longhands.border_bottom_color
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomStyle(
                        longhands.border_bottom_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomWidth(
                        longhands.border_bottom_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_bottom_color: color,
            border_bottom_style: style,
            border_bottom_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_bottom_width,
                self.border_bottom_style,
                self.border_bottom_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-right
    pub mod border_right {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_right_color:
                    longhands::border_right_color::SpecifiedValue
                    ,
                pub border_right_style:
                    longhands::border_right_style::SpecifiedValue
                    ,
                pub border_right_width:
                    longhands::border_right_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_right_color:
                    &'a longhands::border_right_color::SpecifiedValue,
                pub border_right_style:
                    &'a longhands::border_right_style::SpecifiedValue,
                pub border_right_width:
                    &'a longhands::border_right_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_right_color = None;
                    let mut border_right_style = None;
                    let mut border_right_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderRightColor(ref value) => {
                                border_right_color = Some(value)
                            },
                            PropertyDeclaration::BorderRightStyle(ref value) => {
                                border_right_style = Some(value)
                            },
                            PropertyDeclaration::BorderRightWidth(ref value) => {
                                border_right_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_right_color,
                        border_right_style,
                        border_right_width,
                ) {

                    (
                        Some(border_right_color),
                        Some(border_right_style),
                        Some(border_right_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_right_color,
                            border_right_style,
                            border_right_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderRightColor(
                        longhands.border_right_color
                    ));
                    declarations.push(PropertyDeclaration::BorderRightStyle(
                        longhands.border_right_style
                    ));
                    declarations.push(PropertyDeclaration::BorderRightWidth(
                        longhands.border_right_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_right_color: color,
            border_right_style: style,
            border_right_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_right_width,
                self.border_right_style,
                self.border_right_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-start
    pub mod border_block_start {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_block_start_color:
                    longhands::border_block_start_color::SpecifiedValue
                    ,
                pub border_block_start_style:
                    longhands::border_block_start_style::SpecifiedValue
                    ,
                pub border_block_start_width:
                    longhands::border_block_start_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_block_start_color:
                    &'a longhands::border_block_start_color::SpecifiedValue,
                pub border_block_start_style:
                    &'a longhands::border_block_start_style::SpecifiedValue,
                pub border_block_start_width:
                    &'a longhands::border_block_start_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_block_start_color = None;
                    let mut border_block_start_style = None;
                    let mut border_block_start_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderBlockStartColor(ref value) => {
                                border_block_start_color = Some(value)
                            },
                            PropertyDeclaration::BorderBlockStartStyle(ref value) => {
                                border_block_start_style = Some(value)
                            },
                            PropertyDeclaration::BorderBlockStartWidth(ref value) => {
                                border_block_start_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_block_start_color,
                        border_block_start_style,
                        border_block_start_width,
                ) {

                    (
                        Some(border_block_start_color),
                        Some(border_block_start_style),
                        Some(border_block_start_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_block_start_color,
                            border_block_start_style,
                            border_block_start_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderBlockStartColor(
                        longhands.border_block_start_color
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockStartStyle(
                        longhands.border_block_start_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockStartWidth(
                        longhands.border_block_start_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_block_start_color: color,
            border_block_start_style: style,
            border_block_start_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_block_start_width,
                self.border_block_start_style,
                self.border_block_start_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-end
    pub mod border_block_end {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_block_end_color:
                    longhands::border_block_end_color::SpecifiedValue
                    ,
                pub border_block_end_style:
                    longhands::border_block_end_style::SpecifiedValue
                    ,
                pub border_block_end_width:
                    longhands::border_block_end_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_block_end_color:
                    &'a longhands::border_block_end_color::SpecifiedValue,
                pub border_block_end_style:
                    &'a longhands::border_block_end_style::SpecifiedValue,
                pub border_block_end_width:
                    &'a longhands::border_block_end_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_block_end_color = None;
                    let mut border_block_end_style = None;
                    let mut border_block_end_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderBlockEndColor(ref value) => {
                                border_block_end_color = Some(value)
                            },
                            PropertyDeclaration::BorderBlockEndStyle(ref value) => {
                                border_block_end_style = Some(value)
                            },
                            PropertyDeclaration::BorderBlockEndWidth(ref value) => {
                                border_block_end_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_block_end_color,
                        border_block_end_style,
                        border_block_end_width,
                ) {

                    (
                        Some(border_block_end_color),
                        Some(border_block_end_style),
                        Some(border_block_end_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_block_end_color,
                            border_block_end_style,
                            border_block_end_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderBlockEndColor(
                        longhands.border_block_end_color
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockEndStyle(
                        longhands.border_block_end_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockEndWidth(
                        longhands.border_block_end_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_block_end_color: color,
            border_block_end_style: style,
            border_block_end_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_block_end_width,
                self.border_block_end_style,
                self.border_block_end_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-start
    pub mod border_inline_start {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_inline_start_color:
                    longhands::border_inline_start_color::SpecifiedValue
                    ,
                pub border_inline_start_style:
                    longhands::border_inline_start_style::SpecifiedValue
                    ,
                pub border_inline_start_width:
                    longhands::border_inline_start_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_inline_start_color:
                    &'a longhands::border_inline_start_color::SpecifiedValue,
                pub border_inline_start_style:
                    &'a longhands::border_inline_start_style::SpecifiedValue,
                pub border_inline_start_width:
                    &'a longhands::border_inline_start_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_inline_start_color = None;
                    let mut border_inline_start_style = None;
                    let mut border_inline_start_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderInlineStartColor(ref value) => {
                                border_inline_start_color = Some(value)
                            },
                            PropertyDeclaration::BorderInlineStartStyle(ref value) => {
                                border_inline_start_style = Some(value)
                            },
                            PropertyDeclaration::BorderInlineStartWidth(ref value) => {
                                border_inline_start_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_inline_start_color,
                        border_inline_start_style,
                        border_inline_start_width,
                ) {

                    (
                        Some(border_inline_start_color),
                        Some(border_inline_start_style),
                        Some(border_inline_start_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_inline_start_color,
                            border_inline_start_style,
                            border_inline_start_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderInlineStartColor(
                        longhands.border_inline_start_color
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineStartStyle(
                        longhands.border_inline_start_style
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineStartWidth(
                        longhands.border_inline_start_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_inline_start_color: color,
            border_inline_start_style: style,
            border_inline_start_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_inline_start_width,
                self.border_inline_start_style,
                self.border_inline_start_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-end
    pub mod border_inline_end {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_inline_end_color:
                    longhands::border_inline_end_color::SpecifiedValue
                    ,
                pub border_inline_end_style:
                    longhands::border_inline_end_style::SpecifiedValue
                    ,
                pub border_inline_end_width:
                    longhands::border_inline_end_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_inline_end_color:
                    &'a longhands::border_inline_end_color::SpecifiedValue,
                pub border_inline_end_style:
                    &'a longhands::border_inline_end_style::SpecifiedValue,
                pub border_inline_end_width:
                    &'a longhands::border_inline_end_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_inline_end_color = None;
                    let mut border_inline_end_style = None;
                    let mut border_inline_end_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderInlineEndColor(ref value) => {
                                border_inline_end_color = Some(value)
                            },
                            PropertyDeclaration::BorderInlineEndStyle(ref value) => {
                                border_inline_end_style = Some(value)
                            },
                            PropertyDeclaration::BorderInlineEndWidth(ref value) => {
                                border_inline_end_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_inline_end_color,
                        border_inline_end_style,
                        border_inline_end_width,
                ) {

                    (
                        Some(border_inline_end_color),
                        Some(border_inline_end_style),
                        Some(border_inline_end_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_inline_end_color,
                            border_inline_end_style,
                            border_inline_end_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderInlineEndColor(
                        longhands.border_inline_end_color
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineEndStyle(
                        longhands.border_inline_end_style
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineEndWidth(
                        longhands.border_inline_end_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_inline_end_color: color,
            border_inline_end_style: style,
            border_inline_end_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_inline_end_width,
                self.border_inline_end_style,
                self.border_inline_end_color
            )
        }
    }

    
    }




    /// https://drafts.csswg.org/css-backgrounds/#border
    pub mod border {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_top_color:
                    longhands::border_top_color::SpecifiedValue
                    ,
                pub border_top_style:
                    longhands::border_top_style::SpecifiedValue
                    ,
                pub border_top_width:
                    longhands::border_top_width::SpecifiedValue
                    ,
                pub border_left_color:
                    longhands::border_left_color::SpecifiedValue
                    ,
                pub border_left_style:
                    longhands::border_left_style::SpecifiedValue
                    ,
                pub border_left_width:
                    longhands::border_left_width::SpecifiedValue
                    ,
                pub border_bottom_color:
                    longhands::border_bottom_color::SpecifiedValue
                    ,
                pub border_bottom_style:
                    longhands::border_bottom_style::SpecifiedValue
                    ,
                pub border_bottom_width:
                    longhands::border_bottom_width::SpecifiedValue
                    ,
                pub border_right_color:
                    longhands::border_right_color::SpecifiedValue
                    ,
                pub border_right_style:
                    longhands::border_right_style::SpecifiedValue
                    ,
                pub border_right_width:
                    longhands::border_right_width::SpecifiedValue
                    ,
                pub border_image_outset:
                        Box<
                    longhands::border_image_outset::SpecifiedValue
                        >
                    ,
                pub border_image_repeat:
                    longhands::border_image_repeat::SpecifiedValue
                    ,
                pub border_image_slice:
                        Box<
                    longhands::border_image_slice::SpecifiedValue
                        >
                    ,
                pub border_image_source:
                        Box<
                    longhands::border_image_source::SpecifiedValue
                        >
                    ,
                pub border_image_width:
                        Box<
                    longhands::border_image_width::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_color:
                    &'a longhands::border_top_color::SpecifiedValue,
                pub border_top_style:
                    &'a longhands::border_top_style::SpecifiedValue,
                pub border_top_width:
                    &'a longhands::border_top_width::SpecifiedValue,
                pub border_left_color:
                    &'a longhands::border_left_color::SpecifiedValue,
                pub border_left_style:
                    &'a longhands::border_left_style::SpecifiedValue,
                pub border_left_width:
                    &'a longhands::border_left_width::SpecifiedValue,
                pub border_bottom_color:
                    &'a longhands::border_bottom_color::SpecifiedValue,
                pub border_bottom_style:
                    &'a longhands::border_bottom_style::SpecifiedValue,
                pub border_bottom_width:
                    &'a longhands::border_bottom_width::SpecifiedValue,
                pub border_right_color:
                    &'a longhands::border_right_color::SpecifiedValue,
                pub border_right_style:
                    &'a longhands::border_right_style::SpecifiedValue,
                pub border_right_width:
                    &'a longhands::border_right_width::SpecifiedValue,
                pub border_image_outset:
                    &'a longhands::border_image_outset::SpecifiedValue,
                pub border_image_repeat:
                    &'a longhands::border_image_repeat::SpecifiedValue,
                pub border_image_slice:
                    &'a longhands::border_image_slice::SpecifiedValue,
                pub border_image_source:
                    &'a longhands::border_image_source::SpecifiedValue,
                pub border_image_width:
                    &'a longhands::border_image_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_color = None;
                    let mut border_top_style = None;
                    let mut border_top_width = None;
                    let mut border_left_color = None;
                    let mut border_left_style = None;
                    let mut border_left_width = None;
                    let mut border_bottom_color = None;
                    let mut border_bottom_style = None;
                    let mut border_bottom_width = None;
                    let mut border_right_color = None;
                    let mut border_right_style = None;
                    let mut border_right_width = None;
                    let mut border_image_outset = None;
                    let mut border_image_repeat = None;
                    let mut border_image_slice = None;
                    let mut border_image_source = None;
                    let mut border_image_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderTopColor(ref value) => {
                                border_top_color = Some(value)
                            },
                            PropertyDeclaration::BorderTopStyle(ref value) => {
                                border_top_style = Some(value)
                            },
                            PropertyDeclaration::BorderTopWidth(ref value) => {
                                border_top_width = Some(value)
                            },
                            PropertyDeclaration::BorderLeftColor(ref value) => {
                                border_left_color = Some(value)
                            },
                            PropertyDeclaration::BorderLeftStyle(ref value) => {
                                border_left_style = Some(value)
                            },
                            PropertyDeclaration::BorderLeftWidth(ref value) => {
                                border_left_width = Some(value)
                            },
                            PropertyDeclaration::BorderBottomColor(ref value) => {
                                border_bottom_color = Some(value)
                            },
                            PropertyDeclaration::BorderBottomStyle(ref value) => {
                                border_bottom_style = Some(value)
                            },
                            PropertyDeclaration::BorderBottomWidth(ref value) => {
                                border_bottom_width = Some(value)
                            },
                            PropertyDeclaration::BorderRightColor(ref value) => {
                                border_right_color = Some(value)
                            },
                            PropertyDeclaration::BorderRightStyle(ref value) => {
                                border_right_style = Some(value)
                            },
                            PropertyDeclaration::BorderRightWidth(ref value) => {
                                border_right_width = Some(value)
                            },
                            PropertyDeclaration::BorderImageOutset(ref value) => {
                                border_image_outset = Some(value)
                            },
                            PropertyDeclaration::BorderImageRepeat(ref value) => {
                                border_image_repeat = Some(value)
                            },
                            PropertyDeclaration::BorderImageSlice(ref value) => {
                                border_image_slice = Some(value)
                            },
                            PropertyDeclaration::BorderImageSource(ref value) => {
                                border_image_source = Some(value)
                            },
                            PropertyDeclaration::BorderImageWidth(ref value) => {
                                border_image_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_color,
                        border_top_style,
                        border_top_width,
                        border_left_color,
                        border_left_style,
                        border_left_width,
                        border_bottom_color,
                        border_bottom_style,
                        border_bottom_width,
                        border_right_color,
                        border_right_style,
                        border_right_width,
                        border_image_outset,
                        border_image_repeat,
                        border_image_slice,
                        border_image_source,
                        border_image_width,
                ) {

                    (
                        Some(border_top_color),
                        Some(border_top_style),
                        Some(border_top_width),
                        Some(border_left_color),
                        Some(border_left_style),
                        Some(border_left_width),
                        Some(border_bottom_color),
                        Some(border_bottom_style),
                        Some(border_bottom_width),
                        Some(border_right_color),
                        Some(border_right_style),
                        Some(border_right_width),
                        Some(border_image_outset),
                        Some(border_image_repeat),
                        Some(border_image_slice),
                        Some(border_image_source),
                        Some(border_image_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_color,
                            border_top_style,
                            border_top_width,
                            border_left_color,
                            border_left_style,
                            border_left_width,
                            border_bottom_color,
                            border_bottom_style,
                            border_bottom_width,
                            border_right_color,
                            border_right_style,
                            border_right_width,
                            border_image_outset,
                            border_image_repeat,
                            border_image_slice,
                            border_image_source,
                            border_image_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopColor(
                        longhands.border_top_color
                    ));
                    declarations.push(PropertyDeclaration::BorderTopStyle(
                        longhands.border_top_style
                    ));
                    declarations.push(PropertyDeclaration::BorderTopWidth(
                        longhands.border_top_width
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftColor(
                        longhands.border_left_color
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftStyle(
                        longhands.border_left_style
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftWidth(
                        longhands.border_left_width
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomColor(
                        longhands.border_bottom_color
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomStyle(
                        longhands.border_bottom_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomWidth(
                        longhands.border_bottom_width
                    ));
                    declarations.push(PropertyDeclaration::BorderRightColor(
                        longhands.border_right_color
                    ));
                    declarations.push(PropertyDeclaration::BorderRightStyle(
                        longhands.border_right_style
                    ));
                    declarations.push(PropertyDeclaration::BorderRightWidth(
                        longhands.border_right_width
                    ));
                    declarations.push(PropertyDeclaration::BorderImageOutset(
                        longhands.border_image_outset
                    ));
                    declarations.push(PropertyDeclaration::BorderImageRepeat(
                        longhands.border_image_repeat
                    ));
                    declarations.push(PropertyDeclaration::BorderImageSlice(
                        longhands.border_image_slice
                    ));
                    declarations.push(PropertyDeclaration::BorderImageSource(
                        longhands.border_image_source
                    ));
                    declarations.push(PropertyDeclaration::BorderImageWidth(
                        longhands.border_image_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        use properties::longhands::{border_image_outset, border_image_repeat, border_image_slice};
        use properties::longhands::{border_image_source, border_image_width};

        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
                border_top_color: color.clone(),
                border_top_style: style,
                border_top_width: width.clone(),
                border_left_color: color.clone(),
                border_left_style: style,
                border_left_width: width.clone(),
                border_bottom_color: color.clone(),
                border_bottom_style: style,
                border_bottom_width: width.clone(),
                border_right_color: color.clone(),
                border_right_style: style,
                border_right_width: width.clone(),

            // The ‘border’ shorthand resets ‘border-image’ to its initial value.
            // See https://drafts.csswg.org/css-backgrounds-3/#the-border-shorthands
                border_image_outset: border_image_outset::get_initial_specified_value(),
                border_image_repeat: border_image_repeat::get_initial_specified_value(),
                border_image_slice: border_image_slice::get_initial_specified_value(),
                border_image_source: border_image_source::get_initial_specified_value(),
                border_image_width: border_image_width::get_initial_specified_value(),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let all_equal = {
                  let border_top_width = self.border_top_width;
                  let border_top_style = self.border_top_style;
                  let border_top_color = self.border_top_color;
                  let border_left_width = self.border_left_width;
                  let border_left_style = self.border_left_style;
                  let border_left_color = self.border_left_color;
                  let border_bottom_width = self.border_bottom_width;
                  let border_bottom_style = self.border_bottom_style;
                  let border_bottom_color = self.border_bottom_color;
                  let border_right_width = self.border_right_width;
                  let border_right_style = self.border_right_style;
                  let border_right_color = self.border_right_color;

                border_top_width == border_right_width &&
                border_right_width == border_bottom_width &&
                border_bottom_width == border_left_width &&

                border_top_style == border_right_style &&
                border_right_style == border_bottom_style &&
                border_bottom_style == border_left_style &&

                border_top_color == border_right_color &&
                border_right_color == border_bottom_color &&
                border_bottom_color == border_left_color
            };

            // If all longhands are all present, then all sides should be the same,
            // so we can just one set of color/style/width
            if all_equal {
                super::serialize_directional_border(
                    dest,
                    self.border_right_width,
                    self.border_right_style,
                    self.border_right_color
                )
            } else {
                Ok(())
            }
        }
    }


    }




    /// https://drafts.csswg.org/css-backgrounds/#border-radius
    pub mod border_radius {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_top_left_radius:
                        Box<
                    longhands::border_top_left_radius::SpecifiedValue
                        >
                    ,
                pub border_top_right_radius:
                        Box<
                    longhands::border_top_right_radius::SpecifiedValue
                        >
                    ,
                pub border_bottom_right_radius:
                        Box<
                    longhands::border_bottom_right_radius::SpecifiedValue
                        >
                    ,
                pub border_bottom_left_radius:
                        Box<
                    longhands::border_bottom_left_radius::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_left_radius:
                    &'a longhands::border_top_left_radius::SpecifiedValue,
                pub border_top_right_radius:
                    &'a longhands::border_top_right_radius::SpecifiedValue,
                pub border_bottom_right_radius:
                    &'a longhands::border_bottom_right_radius::SpecifiedValue,
                pub border_bottom_left_radius:
                    &'a longhands::border_bottom_left_radius::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_left_radius = None;
                    let mut border_top_right_radius = None;
                    let mut border_bottom_right_radius = None;
                    let mut border_bottom_left_radius = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderTopLeftRadius(ref value) => {
                                border_top_left_radius = Some(value)
                            },
                            PropertyDeclaration::BorderTopRightRadius(ref value) => {
                                border_top_right_radius = Some(value)
                            },
                            PropertyDeclaration::BorderBottomRightRadius(ref value) => {
                                border_bottom_right_radius = Some(value)
                            },
                            PropertyDeclaration::BorderBottomLeftRadius(ref value) => {
                                border_bottom_left_radius = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_left_radius,
                        border_top_right_radius,
                        border_bottom_right_radius,
                        border_bottom_left_radius,
                ) {

                    (
                        Some(border_top_left_radius),
                        Some(border_top_right_radius),
                        Some(border_bottom_right_radius),
                        Some(border_bottom_left_radius),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_left_radius,
                            border_top_right_radius,
                            border_bottom_right_radius,
                            border_bottom_left_radius,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopLeftRadius(
                        longhands.border_top_left_radius
                    ));
                    declarations.push(PropertyDeclaration::BorderTopRightRadius(
                        longhands.border_top_right_radius
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomRightRadius(
                        longhands.border_bottom_right_radius
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomLeftRadius(
                        longhands.border_bottom_left_radius
                    ));
            })
        }

        
    use values::generics::rect::Rect;
    use values::generics::border::BorderCornerRadius;
    use values::specified::border::BorderRadius;
    use parser::Parse;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let radii = BorderRadius::parse(context, input)?;
        Ok(expanded! {
            border_top_left_radius: radii.top_left,
            border_top_right_radius: radii.top_right,
            border_bottom_right_radius: radii.bottom_right,
            border_bottom_left_radius: radii.bottom_left,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let LonghandsToSerialize {
                border_top_left_radius: &BorderCornerRadius(ref tl),
                border_top_right_radius: &BorderCornerRadius(ref tr),
                border_bottom_right_radius: &BorderCornerRadius(ref br),
                border_bottom_left_radius: &BorderCornerRadius(ref bl),
            } = *self;


            let widths = Rect::new(tl.width(), tr.width(), br.width(), bl.width());
            let heights = Rect::new(tl.height(), tr.height(), br.height(), bl.height());

            BorderRadius::serialize_rects(widths, heights, dest)
        }
    }

    }




    /// https://drafts.csswg.org/css-backgrounds-3/#border-image
    pub mod border_image {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_image_outset:
                        Box<
                    longhands::border_image_outset::SpecifiedValue
                        >
                    ,
                pub border_image_repeat:
                    longhands::border_image_repeat::SpecifiedValue
                    ,
                pub border_image_slice:
                        Box<
                    longhands::border_image_slice::SpecifiedValue
                        >
                    ,
                pub border_image_source:
                        Box<
                    longhands::border_image_source::SpecifiedValue
                        >
                    ,
                pub border_image_width:
                        Box<
                    longhands::border_image_width::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_image_outset:
                    &'a longhands::border_image_outset::SpecifiedValue,
                pub border_image_repeat:
                    &'a longhands::border_image_repeat::SpecifiedValue,
                pub border_image_slice:
                    &'a longhands::border_image_slice::SpecifiedValue,
                pub border_image_source:
                    &'a longhands::border_image_source::SpecifiedValue,
                pub border_image_width:
                    &'a longhands::border_image_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_image_outset = None;
                    let mut border_image_repeat = None;
                    let mut border_image_slice = None;
                    let mut border_image_source = None;
                    let mut border_image_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderImageOutset(ref value) => {
                                border_image_outset = Some(value)
                            },
                            PropertyDeclaration::BorderImageRepeat(ref value) => {
                                border_image_repeat = Some(value)
                            },
                            PropertyDeclaration::BorderImageSlice(ref value) => {
                                border_image_slice = Some(value)
                            },
                            PropertyDeclaration::BorderImageSource(ref value) => {
                                border_image_source = Some(value)
                            },
                            PropertyDeclaration::BorderImageWidth(ref value) => {
                                border_image_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_image_outset,
                        border_image_repeat,
                        border_image_slice,
                        border_image_source,
                        border_image_width,
                ) {

                    (
                        Some(border_image_outset),
                        Some(border_image_repeat),
                        Some(border_image_slice),
                        Some(border_image_source),
                        Some(border_image_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_image_outset,
                            border_image_repeat,
                            border_image_slice,
                            border_image_source,
                            border_image_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderImageOutset(
                        longhands.border_image_outset
                    ));
                    declarations.push(PropertyDeclaration::BorderImageRepeat(
                        longhands.border_image_repeat
                    ));
                    declarations.push(PropertyDeclaration::BorderImageSlice(
                        longhands.border_image_slice
                    ));
                    declarations.push(PropertyDeclaration::BorderImageSource(
                        longhands.border_image_source
                    ));
                    declarations.push(PropertyDeclaration::BorderImageWidth(
                        longhands.border_image_width
                    ));
            })
        }

        
    use properties::longhands::{border_image_outset, border_image_repeat, border_image_slice};
    use properties::longhands::{border_image_source, border_image_width};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
            let mut border_image_outset = border_image_outset::get_initial_specified_value();
            let mut border_image_repeat = border_image_repeat::get_initial_specified_value();
            let mut border_image_slice = border_image_slice::get_initial_specified_value();
            let mut border_image_source = border_image_source::get_initial_specified_value();
            let mut border_image_width = border_image_width::get_initial_specified_value();

        let result: Result<_, ParseError> = input.try(|input| {
                let mut outset = None;
                let mut repeat = None;
                let mut slice = None;
                let mut source = None;
                let mut width = None;
            loop {
                if slice.is_none() {
                    if let Ok(value) = input.try(|input| border_image_slice::parse(context, input)) {
                        slice = Some(value);
                        // Parse border image width and outset, if applicable.
                        let maybe_width_outset: Result<_, ParseError> = input.try(|input| {
                            input.expect_delim('/')?;

                            // Parse border image width, if applicable.
                            let w = input.try(|input|
                                border_image_width::parse(context, input)).ok();

                            // Parse border image outset if applicable.
                            let o = input.try(|input| {
                                input.expect_delim('/')?;
                                border_image_outset::parse(context, input)
                            }).ok();
                            if w.is_none() && o.is_none() {
                               Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
                            }
                            else {
                               Ok((w, o))
                            }
                        });
                        if let Ok((w, o)) = maybe_width_outset {
                            width = w;
                            outset = o;
                        }

                        continue
                    }
                }
                    if source.is_none() {
                        if let Ok(value) = input.try(|input| border_image_source::parse(context, input)) {
                            source = Some(value);
                            continue
                        }
                    }
                    if repeat.is_none() {
                        if let Ok(value) = input.try(|input| border_image_repeat::parse(context, input)) {
                            repeat = Some(value);
                            continue
                        }
                    }
                break
            }
            let mut any = false;
                any = any || outset.is_some();
                any = any || repeat.is_some();
                any = any || slice.is_some();
                any = any || source.is_some();
                any = any || width.is_some();
            if any {
                    if let Some(b_outset) = outset {
                        border_image_outset = b_outset;
                    }
                    if let Some(b_repeat) = repeat {
                        border_image_repeat = b_repeat;
                    }
                    if let Some(b_slice) = slice {
                        border_image_slice = b_slice;
                    }
                    if let Some(b_source) = source {
                        border_image_source = b_source;
                    }
                    if let Some(b_width) = width {
                        border_image_width = b_width;
                    }
                Ok(())
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        });
        result?;

        Ok(expanded! {
                border_image_outset: border_image_outset,
                border_image_repeat: border_image_repeat,
                border_image_slice: border_image_slice,
                border_image_source: border_image_source,
                border_image_width: border_image_width,
         })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.border_image_source.to_css(dest)?;
            dest.write_str(" ")?;
            self.border_image_slice.to_css(dest)?;
            dest.write_str(" / ")?;
            self.border_image_width.to_css(dest)?;
            dest.write_str(" / ")?;
            self.border_image_outset.to_css(dest)?;
            dest.write_str(" ")?;
            self.border_image_repeat.to_css(dest)
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-overflow/#propdef-overflow
    pub mod overflow {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub overflow_x:
                    longhands::overflow_x::SpecifiedValue
                    ,
                pub overflow_y:
                    longhands::overflow_y::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub overflow_x:
                    &'a longhands::overflow_x::SpecifiedValue,
                pub overflow_y:
                    &'a longhands::overflow_y::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut overflow_x = None;
                    let mut overflow_y = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::OverflowX(ref value) => {
                                overflow_x = Some(value)
                            },
                            PropertyDeclaration::OverflowY(ref value) => {
                                overflow_y = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        overflow_x,
                        overflow_y,
                ) {

                    (
                        Some(overflow_x),
                        Some(overflow_y),
                    ) =>
                    Ok(LonghandsToSerialize {
                            overflow_x,
                            overflow_y,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::OverflowX(
                        longhands.overflow_x
                    ));
                    declarations.push(PropertyDeclaration::OverflowY(
                        longhands.overflow_y
                    ));
            })
        }

        
    use properties::longhands::overflow_x::parse as parse_overflow;
        use properties::longhands::overflow_x::SpecifiedValue;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
            let moz_kw_found = input.try(|input| {
                try_match_ident_ignore_ascii_case! { input,
                    "-moz-scrollbars-horizontal" => {
                        Ok(expanded! {
                            overflow_x: SpecifiedValue::Scroll,
                            overflow_y: SpecifiedValue::Hidden,
                        })
                    }
                    "-moz-scrollbars-vertical" => {
                        Ok(expanded! {
                            overflow_x: SpecifiedValue::Hidden,
                            overflow_y: SpecifiedValue::Scroll,
                        })
                    }
                    "-moz-scrollbars-none" => {
                        Ok(expanded! {
                            overflow_x: SpecifiedValue::Hidden,
                            overflow_y: SpecifiedValue::Hidden,
                        })
                    }
                }
            });
            if moz_kw_found.is_ok() {
                return moz_kw_found
            }
        let overflow = parse_overflow(context, input)?;
        Ok(expanded! {
            overflow_x: overflow,
            overflow_y: overflow,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if self.overflow_x == self.overflow_y {
                self.overflow_x.to_css(dest)
            } else {
                Ok(())
            }
        }
    }

    }




    /// Internal, may be standardized in the future 
    pub mod overflow_clip_box {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub overflow_clip_box_block:
                    longhands::overflow_clip_box_block::SpecifiedValue
                    ,
                pub overflow_clip_box_inline:
                    longhands::overflow_clip_box_inline::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub overflow_clip_box_block:
                    &'a longhands::overflow_clip_box_block::SpecifiedValue,
                pub overflow_clip_box_inline:
                    &'a longhands::overflow_clip_box_inline::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut overflow_clip_box_block = None;
                    let mut overflow_clip_box_inline = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::OverflowClipBoxBlock(ref value) => {
                                overflow_clip_box_block = Some(value)
                            },
                            PropertyDeclaration::OverflowClipBoxInline(ref value) => {
                                overflow_clip_box_inline = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        overflow_clip_box_block,
                        overflow_clip_box_inline,
                ) {

                    (
                        Some(overflow_clip_box_block),
                        Some(overflow_clip_box_inline),
                    ) =>
                    Ok(LonghandsToSerialize {
                            overflow_clip_box_block,
                            overflow_clip_box_inline,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::OverflowClipBoxBlock(
                        longhands.overflow_clip_box_block
                    ));
                    declarations.push(PropertyDeclaration::OverflowClipBoxInline(
                        longhands.overflow_clip_box_inline
                    ));
            })
        }

        
    use values::specified::OverflowClipBox;
    pub fn parse_value<'i, 't>(
        _: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let block_value = OverflowClipBox::parse(input)?;
        let inline_value =
            input.try(|input| OverflowClipBox::parse(input)).unwrap_or(block_value);

        Ok(expanded! {
          overflow_clip_box_block: block_value,
          overflow_clip_box_inline: inline_value,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.overflow_clip_box_block.to_css(dest)?;

            if self.overflow_clip_box_block != self.overflow_clip_box_inline {
                dest.write_str(" ")?;
                self.overflow_clip_box_inline.to_css(dest)?;
            }

            Ok(())
        }
    }

    }


macro_rules! try_parse_one {
    ($context: expr, $input: expr, $var: ident, $prop_module: ident) => {
        if $var.is_none() {
            if let Ok(value) = $input.try(|i| {
                $prop_module::single_value::parse($context, i)
            }) {
                $var = Some(value);
                continue;
            }
        }
    };
}



    /// https://drafts.csswg.org/css-transitions/#propdef-transition
    pub mod transition {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub transition_property:
                    longhands::transition_property::SpecifiedValue
                    ,
                pub transition_duration:
                    longhands::transition_duration::SpecifiedValue
                    ,
                pub transition_timing_function:
                    longhands::transition_timing_function::SpecifiedValue
                    ,
                pub transition_delay:
                    longhands::transition_delay::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub transition_property:
                    &'a longhands::transition_property::SpecifiedValue,
                pub transition_duration:
                    &'a longhands::transition_duration::SpecifiedValue,
                pub transition_timing_function:
                    &'a longhands::transition_timing_function::SpecifiedValue,
                pub transition_delay:
                    &'a longhands::transition_delay::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut transition_property = None;
                    let mut transition_duration = None;
                    let mut transition_timing_function = None;
                    let mut transition_delay = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::TransitionProperty(ref value) => {
                                transition_property = Some(value)
                            },
                            PropertyDeclaration::TransitionDuration(ref value) => {
                                transition_duration = Some(value)
                            },
                            PropertyDeclaration::TransitionTimingFunction(ref value) => {
                                transition_timing_function = Some(value)
                            },
                            PropertyDeclaration::TransitionDelay(ref value) => {
                                transition_delay = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        transition_property,
                        transition_duration,
                        transition_timing_function,
                        transition_delay,
                ) {

                    (
                        Some(transition_property),
                        Some(transition_duration),
                        Some(transition_timing_function),
                        Some(transition_delay),
                    ) =>
                    Ok(LonghandsToSerialize {
                            transition_property,
                            transition_duration,
                            transition_timing_function,
                            transition_delay,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::TransitionProperty(
                        longhands.transition_property
                    ));
                    declarations.push(PropertyDeclaration::TransitionDuration(
                        longhands.transition_duration
                    ));
                    declarations.push(PropertyDeclaration::TransitionTimingFunction(
                        longhands.transition_timing_function
                    ));
                    declarations.push(PropertyDeclaration::TransitionDelay(
                        longhands.transition_delay
                    ));
            })
        }

        
    use properties::longhands::transition_delay;
    use properties::longhands::transition_duration;
    use properties::longhands::transition_property;
    use properties::longhands::transition_timing_function;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        struct SingleTransition {
            transition_duration: transition_duration::SingleSpecifiedValue,
            transition_timing_function: transition_timing_function::SingleSpecifiedValue,
            transition_delay: transition_delay::SingleSpecifiedValue,
            // Unlike other properties, transition-property uses an Option<> to
            // represent 'none' as `None`.
            transition_property: Option<transition_property::SingleSpecifiedValue>,
        }

        fn parse_one_transition<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                        -> Result<SingleTransition,ParseError<'i>> {
            let mut property = None;
            let mut duration = None;
            let mut timing_function = None;
            let mut delay = None;

            let mut parsed = 0;
            loop {
                parsed += 1;

                try_parse_one!(context, input, duration, transition_duration);
                try_parse_one!(context, input, timing_function, transition_timing_function);
                try_parse_one!(context, input, delay, transition_delay);
                // Must check 'transition-property' after 'transition-timing-function' since
                // 'transition-property' accepts any keyword.
                if property.is_none() {
                    if let Ok(value) = input.try(|i| transition_property::SingleSpecifiedValue::parse(i)) {
                        property = Some(Some(value));
                        continue;
                    } else if input.try(|i| i.expect_ident_matching("none")).is_ok() {
                        // 'none' is not a valid value for <single-transition-property>,
                        // so it's not acceptable in the function above.
                        property = Some(None);
                        continue;
                    }
                }

                parsed -= 1;
                break
            }

            if parsed != 0 {
                Ok(SingleTransition {
                    transition_duration: duration.unwrap_or_else(transition_duration::single_value
                                                                                 ::get_initial_specified_value),
                    transition_timing_function: timing_function.unwrap_or_else(transition_timing_function::single_value
                                                                                 ::get_initial_specified_value),
                    transition_delay: delay.unwrap_or_else(transition_delay::single_value
                                                                                 ::get_initial_specified_value),
                    transition_property: property.unwrap_or(
                        Some(transition_property::single_value::get_initial_specified_value())),
                })
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        }

        let mut propertys = Vec::new();
        let mut durations = Vec::new();
        let mut timing_functions = Vec::new();
        let mut delays = Vec::new();

        let results = input.parse_comma_separated(|i| parse_one_transition(context, i))?;
        let multiple_items = results.len() >= 2;
        for result in results {
            if let Some(value) = result.transition_property {
                propertys.push(value);
            } else if multiple_items {
                // If there is more than one item, and any of transitions has 'none',
                // then it's invalid. Othersize, leave propertys to be empty (which
                // means "transition-property: none");
                return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
            }

            durations.push(result.transition_duration);
            timing_functions.push(result.transition_timing_function);
            delays.push(result.transition_delay);
        }

        Ok(expanded! {
            transition_property: transition_property::SpecifiedValue(propertys),
            transition_duration: transition_duration::SpecifiedValue(durations),
            transition_timing_function: transition_timing_function::SpecifiedValue(timing_functions),
            transition_delay: transition_delay::SpecifiedValue(delays),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let property_len = self.transition_property.0.len();

            // There are two cases that we can do shorthand serialization:
            // * when all value lists have the same length, or
            // * when transition-property is none, and other value lists have exactly one item.
            if property_len == 0 {
                    if self.transition_duration.0.len() != 1 {
                        return Ok(());
                    }
                    if self.transition_delay.0.len() != 1 {
                        return Ok(());
                    }
                    if self.transition_timing_function.0.len() != 1 {
                        return Ok(());
                    }
            } else {
                    if self.transition_duration.0.len() != property_len {
                        return Ok(());
                    }
                    if self.transition_delay.0.len() != property_len {
                        return Ok(());
                    }
                    if self.transition_timing_function.0.len() != property_len {
                        return Ok(());
                    }
            }

            // Representative length.
            let len = self.transition_duration.0.len();

            for i in 0..len {
                if i != 0 {
                    dest.write_str(", ")?;
                }
                if property_len == 0 {
                    dest.write_str("none")?;
                } else {
                    self.transition_property.0[i].to_css(dest)?;
                }
                    dest.write_str(" ")?;
                    self.transition_duration.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.transition_timing_function.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.transition_delay.0[i].to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-animations/#propdef-animation
    pub mod animation {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub animation_name:
                    longhands::animation_name::SpecifiedValue
                    ,
                pub animation_duration:
                    longhands::animation_duration::SpecifiedValue
                    ,
                pub animation_timing_function:
                    longhands::animation_timing_function::SpecifiedValue
                    ,
                pub animation_delay:
                    longhands::animation_delay::SpecifiedValue
                    ,
                pub animation_iteration_count:
                    longhands::animation_iteration_count::SpecifiedValue
                    ,
                pub animation_direction:
                    longhands::animation_direction::SpecifiedValue
                    ,
                pub animation_fill_mode:
                    longhands::animation_fill_mode::SpecifiedValue
                    ,
                pub animation_play_state:
                    longhands::animation_play_state::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub animation_name:
                    &'a longhands::animation_name::SpecifiedValue,
                pub animation_duration:
                    &'a longhands::animation_duration::SpecifiedValue,
                pub animation_timing_function:
                    &'a longhands::animation_timing_function::SpecifiedValue,
                pub animation_delay:
                    &'a longhands::animation_delay::SpecifiedValue,
                pub animation_iteration_count:
                    &'a longhands::animation_iteration_count::SpecifiedValue,
                pub animation_direction:
                    &'a longhands::animation_direction::SpecifiedValue,
                pub animation_fill_mode:
                    &'a longhands::animation_fill_mode::SpecifiedValue,
                pub animation_play_state:
                    &'a longhands::animation_play_state::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut animation_name = None;
                    let mut animation_duration = None;
                    let mut animation_timing_function = None;
                    let mut animation_delay = None;
                    let mut animation_iteration_count = None;
                    let mut animation_direction = None;
                    let mut animation_fill_mode = None;
                    let mut animation_play_state = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::AnimationName(ref value) => {
                                animation_name = Some(value)
                            },
                            PropertyDeclaration::AnimationDuration(ref value) => {
                                animation_duration = Some(value)
                            },
                            PropertyDeclaration::AnimationTimingFunction(ref value) => {
                                animation_timing_function = Some(value)
                            },
                            PropertyDeclaration::AnimationDelay(ref value) => {
                                animation_delay = Some(value)
                            },
                            PropertyDeclaration::AnimationIterationCount(ref value) => {
                                animation_iteration_count = Some(value)
                            },
                            PropertyDeclaration::AnimationDirection(ref value) => {
                                animation_direction = Some(value)
                            },
                            PropertyDeclaration::AnimationFillMode(ref value) => {
                                animation_fill_mode = Some(value)
                            },
                            PropertyDeclaration::AnimationPlayState(ref value) => {
                                animation_play_state = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        animation_name,
                        animation_duration,
                        animation_timing_function,
                        animation_delay,
                        animation_iteration_count,
                        animation_direction,
                        animation_fill_mode,
                        animation_play_state,
                ) {

                    (
                        Some(animation_name),
                        Some(animation_duration),
                        Some(animation_timing_function),
                        Some(animation_delay),
                        Some(animation_iteration_count),
                        Some(animation_direction),
                        Some(animation_fill_mode),
                        Some(animation_play_state),
                    ) =>
                    Ok(LonghandsToSerialize {
                            animation_name,
                            animation_duration,
                            animation_timing_function,
                            animation_delay,
                            animation_iteration_count,
                            animation_direction,
                            animation_fill_mode,
                            animation_play_state,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::AnimationName(
                        longhands.animation_name
                    ));
                    declarations.push(PropertyDeclaration::AnimationDuration(
                        longhands.animation_duration
                    ));
                    declarations.push(PropertyDeclaration::AnimationTimingFunction(
                        longhands.animation_timing_function
                    ));
                    declarations.push(PropertyDeclaration::AnimationDelay(
                        longhands.animation_delay
                    ));
                    declarations.push(PropertyDeclaration::AnimationIterationCount(
                        longhands.animation_iteration_count
                    ));
                    declarations.push(PropertyDeclaration::AnimationDirection(
                        longhands.animation_direction
                    ));
                    declarations.push(PropertyDeclaration::AnimationFillMode(
                        longhands.animation_fill_mode
                    ));
                    declarations.push(PropertyDeclaration::AnimationPlayState(
                        longhands.animation_play_state
                    ));
            })
        }

        
    
    use properties::longhands::animation_name;
    use properties::longhands::animation_duration;
    use properties::longhands::animation_timing_function;
    use properties::longhands::animation_delay;
    use properties::longhands::animation_iteration_count;
    use properties::longhands::animation_direction;
    use properties::longhands::animation_fill_mode;
    use properties::longhands::animation_play_state;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        struct SingleAnimation {
            animation_name: animation_name::SingleSpecifiedValue,
            animation_duration: animation_duration::SingleSpecifiedValue,
            animation_timing_function: animation_timing_function::SingleSpecifiedValue,
            animation_delay: animation_delay::SingleSpecifiedValue,
            animation_iteration_count: animation_iteration_count::SingleSpecifiedValue,
            animation_direction: animation_direction::SingleSpecifiedValue,
            animation_fill_mode: animation_fill_mode::SingleSpecifiedValue,
            animation_play_state: animation_play_state::SingleSpecifiedValue,
        }

        fn parse_one_animation<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                       -> Result<SingleAnimation,ParseError<'i>> {
            let mut name = None;
            let mut duration = None;
            let mut timing_function = None;
            let mut delay = None;
            let mut iteration_count = None;
            let mut direction = None;
            let mut fill_mode = None;
            let mut play_state = None;

            let mut parsed = 0;
            // NB: Name must be the last one here so that keywords valid for other
            // longhands are not interpreted as names.
            //
            // Also, duration must be before delay, see
            // https://drafts.csswg.org/css-animations/#typedef-single-animation
            loop {
                parsed += 1;
                try_parse_one!(context, input, duration, animation_duration);
                try_parse_one!(context, input, timing_function, animation_timing_function);
                try_parse_one!(context, input, delay, animation_delay);
                try_parse_one!(context, input, iteration_count, animation_iteration_count);
                try_parse_one!(context, input, direction, animation_direction);
                try_parse_one!(context, input, fill_mode, animation_fill_mode);
                try_parse_one!(context, input, play_state, animation_play_state);
                try_parse_one!(context, input, name, animation_name);

                parsed -= 1;
                break
            }

            // If nothing is parsed, this is an invalid entry.
            if parsed == 0 {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            } else {
                Ok(SingleAnimation {
                    animation_name: name.unwrap_or_else(animation_name::single_value
                                                              ::get_initial_specified_value),
                    animation_duration: duration.unwrap_or_else(animation_duration::single_value
                                                              ::get_initial_specified_value),
                    animation_timing_function: timing_function.unwrap_or_else(animation_timing_function::single_value
                                                              ::get_initial_specified_value),
                    animation_delay: delay.unwrap_or_else(animation_delay::single_value
                                                              ::get_initial_specified_value),
                    animation_iteration_count: iteration_count.unwrap_or_else(animation_iteration_count::single_value
                                                              ::get_initial_specified_value),
                    animation_direction: direction.unwrap_or_else(animation_direction::single_value
                                                              ::get_initial_specified_value),
                    animation_fill_mode: fill_mode.unwrap_or_else(animation_fill_mode::single_value
                                                              ::get_initial_specified_value),
                    animation_play_state: play_state.unwrap_or_else(animation_play_state::single_value
                                                              ::get_initial_specified_value),
                })
            }
        }

        let mut names = vec![];
        let mut durations = vec![];
        let mut timing_functions = vec![];
        let mut delays = vec![];
        let mut iteration_counts = vec![];
        let mut directions = vec![];
        let mut fill_modes = vec![];
        let mut play_states = vec![];

        let results = input.parse_comma_separated(|i| parse_one_animation(context, i))?;
        for result in results.into_iter() {
            names.push(result.animation_name);
            durations.push(result.animation_duration);
            timing_functions.push(result.animation_timing_function);
            delays.push(result.animation_delay);
            iteration_counts.push(result.animation_iteration_count);
            directions.push(result.animation_direction);
            fill_modes.push(result.animation_fill_mode);
            play_states.push(result.animation_play_state);
        }

        Ok(expanded! {
            animation_name: animation_name::SpecifiedValue(names),
            animation_duration: animation_duration::SpecifiedValue(durations),
            animation_timing_function: animation_timing_function::SpecifiedValue(timing_functions),
            animation_delay: animation_delay::SpecifiedValue(delays),
            animation_iteration_count: animation_iteration_count::SpecifiedValue(iteration_counts),
            animation_direction: animation_direction::SpecifiedValue(directions),
            animation_fill_mode: animation_fill_mode::SpecifiedValue(fill_modes),
            animation_play_state: animation_play_state::SpecifiedValue(play_states),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let len = self.animation_name.0.len();
            // There should be at least one declared value
            if len == 0 {
                return Ok(());
            }

            // If any value list length is differs then we don't do a shorthand serialization
            // either.
                if len != self.animation_duration.0.len() {
                    return Ok(())
                }
                if len != self.animation_timing_function.0.len() {
                    return Ok(())
                }
                if len != self.animation_delay.0.len() {
                    return Ok(())
                }
                if len != self.animation_iteration_count.0.len() {
                    return Ok(())
                }
                if len != self.animation_direction.0.len() {
                    return Ok(())
                }
                if len != self.animation_fill_mode.0.len() {
                    return Ok(())
                }
                if len != self.animation_play_state.0.len() {
                    return Ok(())
                }

            for i in 0..len {
                if i != 0 {
                    dest.write_str(", ")?;
                }

                    self.animation_duration.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.animation_timing_function.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.animation_delay.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.animation_iteration_count.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.animation_direction.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.animation_fill_mode.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.animation_play_state.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                self.animation_name.0[i].to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-scroll-snap/#propdef-scroll-snap-type
    pub mod scroll_snap_type {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub scroll_snap_type_x:
                    longhands::scroll_snap_type_x::SpecifiedValue
                    ,
                pub scroll_snap_type_y:
                    longhands::scroll_snap_type_y::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub scroll_snap_type_x:
                    &'a longhands::scroll_snap_type_x::SpecifiedValue,
                pub scroll_snap_type_y:
                    &'a longhands::scroll_snap_type_y::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut scroll_snap_type_x = None;
                    let mut scroll_snap_type_y = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::ScrollSnapTypeX(ref value) => {
                                scroll_snap_type_x = Some(value)
                            },
                            PropertyDeclaration::ScrollSnapTypeY(ref value) => {
                                scroll_snap_type_y = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        scroll_snap_type_x,
                        scroll_snap_type_y,
                ) {

                    (
                        Some(scroll_snap_type_x),
                        Some(scroll_snap_type_y),
                    ) =>
                    Ok(LonghandsToSerialize {
                            scroll_snap_type_x,
                            scroll_snap_type_y,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ScrollSnapTypeX(
                        longhands.scroll_snap_type_x
                    ));
                    declarations.push(PropertyDeclaration::ScrollSnapTypeY(
                        longhands.scroll_snap_type_y
                    ));
            })
        }

        
    use properties::longhands::scroll_snap_type_x;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let result = scroll_snap_type_x::parse(context, input)?;
        Ok(expanded! {
            scroll_snap_type_x: result,
            scroll_snap_type_y: result,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        // Serializes into the single keyword value if both scroll-snap-type-x and scroll-snap-type-y are same.
        // Otherwise into an empty string. This is done to match Gecko's behaviour.
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if self.scroll_snap_type_x == self.scroll_snap_type_y {
                self.scroll_snap_type_x.to_css(dest)
            } else {
                Ok(())
            }
        }
    }

    }




    /// https://wicg.github.io/overscroll-behavior/#overscroll-behavior-properties
    pub mod overscroll_behavior {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub overscroll_behavior_x:
                    longhands::overscroll_behavior_x::SpecifiedValue
                    ,
                pub overscroll_behavior_y:
                    longhands::overscroll_behavior_y::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub overscroll_behavior_x:
                    &'a longhands::overscroll_behavior_x::SpecifiedValue,
                pub overscroll_behavior_y:
                    &'a longhands::overscroll_behavior_y::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut overscroll_behavior_x = None;
                    let mut overscroll_behavior_y = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::OverscrollBehaviorX(ref value) => {
                                overscroll_behavior_x = Some(value)
                            },
                            PropertyDeclaration::OverscrollBehaviorY(ref value) => {
                                overscroll_behavior_y = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        overscroll_behavior_x,
                        overscroll_behavior_y,
                ) {

                    (
                        Some(overscroll_behavior_x),
                        Some(overscroll_behavior_y),
                    ) =>
                    Ok(LonghandsToSerialize {
                            overscroll_behavior_x,
                            overscroll_behavior_y,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::OverscrollBehaviorX(
                        longhands.overscroll_behavior_x
                    ));
                    declarations.push(PropertyDeclaration::OverscrollBehaviorY(
                        longhands.overscroll_behavior_y
                    ));
            })
        }

        
    pub fn parse_value<'i, 't>(
        _: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        use values::specified::OverscrollBehavior;
        let behavior_x = OverscrollBehavior::parse(input)?;
        let behavior_y = input.try(OverscrollBehavior::parse).unwrap_or(behavior_x);
        Ok(expanded! {
            overscroll_behavior_x: behavior_x,
            overscroll_behavior_y: behavior_y,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        // Serializes into the single keyword value if both overscroll-behavior-x and overscroll-behavior-y are same.
        // Otherwise into two values separated by a space.
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.overscroll_behavior_x.to_css(dest)?;
            if self.overscroll_behavior_y != self.overscroll_behavior_x {
                dest.write_str(" ")?;
                self.overscroll_behavior_y.to_css(dest)?;
            }
            Ok(())
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-multicol/#propdef-columns
    pub mod columns {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub column_width:
                    longhands::column_width::SpecifiedValue
                    ,
                pub column_count:
                    longhands::column_count::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub column_width:
                    &'a longhands::column_width::SpecifiedValue,
                pub column_count:
                    &'a longhands::column_count::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut column_width = None;
                    let mut column_count = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::ColumnWidth(ref value) => {
                                column_width = Some(value)
                            },
                            PropertyDeclaration::ColumnCount(ref value) => {
                                column_count = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        column_width,
                        column_count,
                ) {

                    (
                        Some(column_width),
                        Some(column_count),
                    ) =>
                    Ok(LonghandsToSerialize {
                            column_width,
                            column_count,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ColumnWidth(
                        longhands.column_width
                    ));
                    declarations.push(PropertyDeclaration::ColumnCount(
                        longhands.column_count
                    ));
            })
        }

        
    use properties::longhands::{column_count, column_width};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {

        let mut column_count = None;
        let mut column_width = None;
        let mut autos = 0;

        loop {
            if input.try(|input| input.expect_ident_matching("auto")).is_ok() {
                // Leave the options to None, 'auto' is the initial value.
                autos += 1;
                continue
            }

            if column_count.is_none() {
                if let Ok(value) = input.try(|input| column_count::parse(context, input)) {
                    column_count = Some(value);
                    continue
                }
            }

            if column_width.is_none() {
                if let Ok(value) = input.try(|input| column_width::parse(context, input)) {
                    column_width = Some(value);
                    continue
                }
            }

            break
        }

        let values = autos + column_count.iter().len() + column_width.iter().len();
        if values == 0 || values > 2 {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        } else {
            Ok(expanded! {
                column_count: unwrap_or_initial!(column_count),
                column_width: unwrap_or_initial!(column_width),
            })
        }
    }

    }




    /// https://drafts.csswg.org/css-multicol/#propdef-column-rule
    pub mod column_rule {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub column_rule_width:
                    longhands::column_rule_width::SpecifiedValue
                    ,
                pub column_rule_style:
                    longhands::column_rule_style::SpecifiedValue
                    ,
                pub column_rule_color:
                    longhands::column_rule_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub column_rule_width:
                    &'a longhands::column_rule_width::SpecifiedValue,
                pub column_rule_style:
                    &'a longhands::column_rule_style::SpecifiedValue,
                pub column_rule_color:
                    &'a longhands::column_rule_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut column_rule_width = None;
                    let mut column_rule_style = None;
                    let mut column_rule_color = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::ColumnRuleWidth(ref value) => {
                                column_rule_width = Some(value)
                            },
                            PropertyDeclaration::ColumnRuleStyle(ref value) => {
                                column_rule_style = Some(value)
                            },
                            PropertyDeclaration::ColumnRuleColor(ref value) => {
                                column_rule_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        column_rule_width,
                        column_rule_style,
                        column_rule_color,
                ) {

                    (
                        Some(column_rule_width),
                        Some(column_rule_style),
                        Some(column_rule_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            column_rule_width,
                            column_rule_style,
                            column_rule_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ColumnRuleWidth(
                        longhands.column_rule_width
                    ));
                    declarations.push(PropertyDeclaration::ColumnRuleStyle(
                        longhands.column_rule_style
                    ));
                    declarations.push(PropertyDeclaration::ColumnRuleColor(
                        longhands.column_rule_color
                    ));
            })
        }

        
    use properties::longhands::{column_rule_width, column_rule_style};
    use properties::longhands::column_rule_color;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut column_rule_width = None;
        let mut column_rule_style = None;
        let mut column_rule_color = None;
        let mut any = false;

        loop {
            if column_rule_width.is_none() {
                if let Ok(value) = input.try(|input|
                        column_rule_width::parse(context, input)) {
                    column_rule_width = Some(value);
                    any = true;
                    continue
                }
            }
            if column_rule_style.is_none() {
                if let Ok(value) = input.try(|input|
                        column_rule_style::parse(context, input)) {
                    column_rule_style = Some(value);
                    any = true;
                    continue
                }
            }
            if column_rule_color.is_none() {
                if let Ok(value) = input.try(|input|
                        column_rule_color::parse(context, input)) {
                    column_rule_color = Some(value);
                    any = true;
                    continue
                }
            }

            break
        }
        if any {
            Ok(expanded! {
                column_rule_width: unwrap_or_initial!(column_rule_width),
                column_rule_style: unwrap_or_initial!(column_rule_style),
                column_rule_color: unwrap_or_initial!(column_rule_color),
            })
        } else {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    /// https://drafts.csswg.org/css-fonts-3/#propdef-font
    pub mod font {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub font_style:
                    longhands::font_style::SpecifiedValue
                    ,
                pub font_variant_caps:
                    longhands::font_variant_caps::SpecifiedValue
                    ,
                pub font_weight:
                    longhands::font_weight::SpecifiedValue
                    ,
                pub font_stretch:
                    longhands::font_stretch::SpecifiedValue
                    ,
                pub font_size:
                    longhands::font_size::SpecifiedValue
                    ,
                pub line_height:
                    longhands::line_height::SpecifiedValue
                    ,
                pub font_family:
                    longhands::font_family::SpecifiedValue
                    ,
                pub font_size_adjust:
                    longhands::font_size_adjust::SpecifiedValue
                    ,
                pub font_kerning:
                    longhands::font_kerning::SpecifiedValue
                    ,
                pub font_optical_sizing:
                    longhands::font_optical_sizing::SpecifiedValue
                    ,
                pub font_variant_alternates:
                    longhands::font_variant_alternates::SpecifiedValue
                    ,
                pub font_variant_east_asian:
                    longhands::font_variant_east_asian::SpecifiedValue
                    ,
                pub font_variant_ligatures:
                    longhands::font_variant_ligatures::SpecifiedValue
                    ,
                pub font_variant_numeric:
                    longhands::font_variant_numeric::SpecifiedValue
                    ,
                pub font_variant_position:
                    longhands::font_variant_position::SpecifiedValue
                    ,
                pub font_language_override:
                    longhands::font_language_override::SpecifiedValue
                    ,
                pub font_feature_settings:
                    longhands::font_feature_settings::SpecifiedValue
                    ,
                pub font_variation_settings:
                    longhands::font_variation_settings::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub font_style:
                    &'a longhands::font_style::SpecifiedValue,
                pub font_variant_caps:
                    &'a longhands::font_variant_caps::SpecifiedValue,
                pub font_weight:
                    &'a longhands::font_weight::SpecifiedValue,
                pub font_stretch:
                    &'a longhands::font_stretch::SpecifiedValue,
                pub font_size:
                    &'a longhands::font_size::SpecifiedValue,
                pub line_height:
                    &'a longhands::line_height::SpecifiedValue,
                pub font_family:
                    &'a longhands::font_family::SpecifiedValue,
                pub font_size_adjust:
                    &'a longhands::font_size_adjust::SpecifiedValue,
                pub font_kerning:
                    &'a longhands::font_kerning::SpecifiedValue,
                pub font_optical_sizing:
                    Option<
                    &'a longhands::font_optical_sizing::SpecifiedValue,
                    >,
                pub font_variant_alternates:
                    &'a longhands::font_variant_alternates::SpecifiedValue,
                pub font_variant_east_asian:
                    &'a longhands::font_variant_east_asian::SpecifiedValue,
                pub font_variant_ligatures:
                    &'a longhands::font_variant_ligatures::SpecifiedValue,
                pub font_variant_numeric:
                    &'a longhands::font_variant_numeric::SpecifiedValue,
                pub font_variant_position:
                    &'a longhands::font_variant_position::SpecifiedValue,
                pub font_language_override:
                    &'a longhands::font_language_override::SpecifiedValue,
                pub font_feature_settings:
                    &'a longhands::font_feature_settings::SpecifiedValue,
                pub font_variation_settings:
                    Option<
                    &'a longhands::font_variation_settings::SpecifiedValue,
                    >,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut font_style = None;
                    let mut font_variant_caps = None;
                    let mut font_weight = None;
                    let mut font_stretch = None;
                    let mut font_size = None;
                    let mut line_height = None;
                    let mut font_family = None;
                    let mut font_size_adjust = None;
                    let mut font_kerning = None;
                    let mut font_optical_sizing = None;
                    let mut font_variant_alternates = None;
                    let mut font_variant_east_asian = None;
                    let mut font_variant_ligatures = None;
                    let mut font_variant_numeric = None;
                    let mut font_variant_position = None;
                    let mut font_language_override = None;
                    let mut font_feature_settings = None;
                    let mut font_variation_settings = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::FontStyle(ref value) => {
                                font_style = Some(value)
                            },
                            PropertyDeclaration::FontVariantCaps(ref value) => {
                                font_variant_caps = Some(value)
                            },
                            PropertyDeclaration::FontWeight(ref value) => {
                                font_weight = Some(value)
                            },
                            PropertyDeclaration::FontStretch(ref value) => {
                                font_stretch = Some(value)
                            },
                            PropertyDeclaration::FontSize(ref value) => {
                                font_size = Some(value)
                            },
                            PropertyDeclaration::LineHeight(ref value) => {
                                line_height = Some(value)
                            },
                            PropertyDeclaration::FontFamily(ref value) => {
                                font_family = Some(value)
                            },
                            PropertyDeclaration::FontSizeAdjust(ref value) => {
                                font_size_adjust = Some(value)
                            },
                            PropertyDeclaration::FontKerning(ref value) => {
                                font_kerning = Some(value)
                            },
                            PropertyDeclaration::FontOpticalSizing(ref value) => {
                                font_optical_sizing = Some(value)
                            },
                            PropertyDeclaration::FontVariantAlternates(ref value) => {
                                font_variant_alternates = Some(value)
                            },
                            PropertyDeclaration::FontVariantEastAsian(ref value) => {
                                font_variant_east_asian = Some(value)
                            },
                            PropertyDeclaration::FontVariantLigatures(ref value) => {
                                font_variant_ligatures = Some(value)
                            },
                            PropertyDeclaration::FontVariantNumeric(ref value) => {
                                font_variant_numeric = Some(value)
                            },
                            PropertyDeclaration::FontVariantPosition(ref value) => {
                                font_variant_position = Some(value)
                            },
                            PropertyDeclaration::FontLanguageOverride(ref value) => {
                                font_language_override = Some(value)
                            },
                            PropertyDeclaration::FontFeatureSettings(ref value) => {
                                font_feature_settings = Some(value)
                            },
                            PropertyDeclaration::FontVariationSettings(ref value) => {
                                font_variation_settings = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        font_style,
                        font_variant_caps,
                        font_weight,
                        font_stretch,
                        font_size,
                        line_height,
                        font_family,
                        font_size_adjust,
                        font_kerning,
                        font_optical_sizing,
                        font_variant_alternates,
                        font_variant_east_asian,
                        font_variant_ligatures,
                        font_variant_numeric,
                        font_variant_position,
                        font_language_override,
                        font_feature_settings,
                        font_variation_settings,
                ) {

                    (
                        Some(font_style),
                        Some(font_variant_caps),
                        Some(font_weight),
                        Some(font_stretch),
                        Some(font_size),
                        Some(line_height),
                        Some(font_family),
                        Some(font_size_adjust),
                        Some(font_kerning),
                        font_optical_sizing,
                        Some(font_variant_alternates),
                        Some(font_variant_east_asian),
                        Some(font_variant_ligatures),
                        Some(font_variant_numeric),
                        Some(font_variant_position),
                        Some(font_language_override),
                        Some(font_feature_settings),
                        font_variation_settings,
                    ) =>
                    Ok(LonghandsToSerialize {
                            font_style,
                            font_variant_caps,
                            font_weight,
                            font_stretch,
                            font_size,
                            line_height,
                            font_family,
                            font_size_adjust,
                            font_kerning,
                            font_optical_sizing,
                            font_variant_alternates,
                            font_variant_east_asian,
                            font_variant_ligatures,
                            font_variant_numeric,
                            font_variant_position,
                            font_language_override,
                            font_feature_settings,
                            font_variation_settings,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::FontStyle(
                        longhands.font_style
                    ));
                    declarations.push(PropertyDeclaration::FontVariantCaps(
                        longhands.font_variant_caps
                    ));
                    declarations.push(PropertyDeclaration::FontWeight(
                        longhands.font_weight
                    ));
                    declarations.push(PropertyDeclaration::FontStretch(
                        longhands.font_stretch
                    ));
                    declarations.push(PropertyDeclaration::FontSize(
                        longhands.font_size
                    ));
                    declarations.push(PropertyDeclaration::LineHeight(
                        longhands.line_height
                    ));
                    declarations.push(PropertyDeclaration::FontFamily(
                        longhands.font_family
                    ));
                    declarations.push(PropertyDeclaration::FontSizeAdjust(
                        longhands.font_size_adjust
                    ));
                    declarations.push(PropertyDeclaration::FontKerning(
                        longhands.font_kerning
                    ));
                if NonCustomPropertyId::from(LonghandId::FontOpticalSizing).allowed_in(context) {
                    declarations.push(PropertyDeclaration::FontOpticalSizing(
                        longhands.font_optical_sizing
                    ));
                }
                    declarations.push(PropertyDeclaration::FontVariantAlternates(
                        longhands.font_variant_alternates
                    ));
                    declarations.push(PropertyDeclaration::FontVariantEastAsian(
                        longhands.font_variant_east_asian
                    ));
                    declarations.push(PropertyDeclaration::FontVariantLigatures(
                        longhands.font_variant_ligatures
                    ));
                    declarations.push(PropertyDeclaration::FontVariantNumeric(
                        longhands.font_variant_numeric
                    ));
                    declarations.push(PropertyDeclaration::FontVariantPosition(
                        longhands.font_variant_position
                    ));
                    declarations.push(PropertyDeclaration::FontLanguageOverride(
                        longhands.font_language_override
                    ));
                    declarations.push(PropertyDeclaration::FontFeatureSettings(
                        longhands.font_feature_settings
                    ));
                if NonCustomPropertyId::from(LonghandId::FontVariationSettings).allowed_in(context) {
                    declarations.push(PropertyDeclaration::FontVariationSettings(
                        longhands.font_variation_settings
                    ));
                }
            })
        }

        
    use parser::Parse;
    use properties::longhands::{font_family, font_style, font_weight, font_stretch};
    use properties::longhands::font_variant_caps;
    #[cfg(feature = "gecko")]
    use properties::longhands::system_font::SystemFont;
    use values::specified::text::LineHeight;
    use values::specified::FontSize;

    
            use properties::longhands::font_kerning;
            use properties::longhands::font_language_override;
            use properties::longhands::font_size_adjust;
            use properties::longhands::font_variant_alternates;
            use properties::longhands::font_variant_east_asian;
            use properties::longhands::font_variant_ligatures;
            use properties::longhands::font_variant_numeric;
            use properties::longhands::font_variant_position;
            use properties::longhands::font_feature_settings;
            use properties::longhands::font_variation_settings;
            use properties::longhands::font_optical_sizing;
    use self::font_family::SpecifiedValue as FontFamily;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut nb_normals = 0;
        let mut style = None;
        let mut variant_caps = None;
        let mut weight = None;
        let mut stretch = None;
        let size;
            if let Ok(sys) = input.try(SystemFont::parse) {
                return Ok(expanded! {
                             font_family: font_family::SpecifiedValue::system_font(sys),
                             font_size: FontSize::system_font(sys),
                             font_style: font_style::SpecifiedValue::system_font(sys),
                             font_variant_caps: font_variant_caps::SpecifiedValue::system_font(sys),
                             font_stretch: font_stretch::SpecifiedValue::system_font(sys),
                             font_kerning: font_kerning::SpecifiedValue::system_font(sys),
                             font_variant_position: font_variant_position::SpecifiedValue::system_font(sys),
                             font_weight: font_weight::SpecifiedValue::system_font(sys),
                             font_size_adjust: font_size_adjust::SpecifiedValue::system_font(sys),
                             font_variant_alternates: font_variant_alternates::SpecifiedValue::system_font(sys),
                             font_variant_ligatures: font_variant_ligatures::SpecifiedValue::system_font(sys),
                             font_variant_east_asian: font_variant_east_asian::SpecifiedValue::system_font(sys),
                             font_variant_numeric: font_variant_numeric::SpecifiedValue::system_font(sys),
                             font_language_override: font_language_override::SpecifiedValue::system_font(sys),
                             font_feature_settings: font_feature_settings::SpecifiedValue::system_font(sys),
                             font_variation_settings: font_variation_settings::SpecifiedValue::system_font(sys),
                             font_optical_sizing: font_optical_sizing::SpecifiedValue::system_font(sys),
                     // line-height is just reset to initial
                     line_height: LineHeight::normal(),
                 })
            }
        loop {
            // Special-case 'normal' because it is valid in each of
            // font-style, font-weight, font-variant and font-stretch.
            // Leaves the values to None, 'normal' is the initial value for each of them.
            if input.try(|input| input.expect_ident_matching("normal")).is_ok() {
                nb_normals += 1;
                continue;
            }
            if style.is_none() {
                if let Ok(value) = input.try(|input| font_style::parse(context, input)) {
                    style = Some(value);
                    continue
                }
            }
            if weight.is_none() {
                if let Ok(value) = input.try(|input| font_weight::parse(context, input)) {
                    weight = Some(value);
                    continue
                }
            }
            if variant_caps.is_none() {
                if let Ok(value) = input.try(|input| font_variant_caps::parse(context, input)) {
                    variant_caps = Some(value);
                    continue
                }
            }
            if stretch.is_none() {
                if let Ok(value) = input.try(|input| font_stretch::parse(context, input)) {
                    stretch = Some(value);
                    continue
                }
            }
            size = Some(FontSize::parse(context, input)?);
            break
        }

        let size = match size {
            Some(s) => s,
            None => {
                return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        };

        let line_height = if input.try(|input| input.expect_delim('/')).is_ok() {
            Some(LineHeight::parse(context, input)?)
        } else {
            None
        };

        #[inline]
        fn count<T>(opt: &Option<T>) -> u8 {
            if opt.is_some() { 1 } else { 0 }
        }

        if (count(&style) + count(&weight) + count(&variant_caps) + count(&stretch) + nb_normals) > 4 {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }

        let family = FontFamily::parse_specified(input)?;
        Ok(expanded! {
                font_style: unwrap_or_initial!(font_style, style),
                font_weight: unwrap_or_initial!(font_weight, weight),
                font_stretch: unwrap_or_initial!(font_stretch, stretch),
                font_variant_caps: unwrap_or_initial!(font_variant_caps, variant_caps),
            font_size: size,
            line_height: line_height.unwrap_or(LineHeight::normal()),
            font_family: family,
                    font_kerning: font_kerning::get_initial_specified_value(),
                    font_language_override: font_language_override::get_initial_specified_value(),
                    font_size_adjust: font_size_adjust::get_initial_specified_value(),
                    font_variant_alternates: font_variant_alternates::get_initial_specified_value(),
                    font_variant_east_asian: font_variant_east_asian::get_initial_specified_value(),
                    font_variant_ligatures: font_variant_ligatures::get_initial_specified_value(),
                    font_variant_numeric: font_variant_numeric::get_initial_specified_value(),
                    font_variant_position: font_variant_position::get_initial_specified_value(),
                    font_feature_settings: font_feature_settings::get_initial_specified_value(),
                    font_variation_settings: font_variation_settings::get_initial_specified_value(),
                    font_optical_sizing: font_optical_sizing::get_initial_specified_value(),
        })
    }

        enum CheckSystemResult {
            AllSystem(SystemFont),
            SomeSystem,
            None
        }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                match self.check_system() {
                    CheckSystemResult::AllSystem(sys) => return sys.to_css(dest),
                    CheckSystemResult::SomeSystem => return Ok(()),
                    CheckSystemResult::None => {}
                }

            if let Some(v) = self.font_optical_sizing {
                if v != &font_optical_sizing::get_initial_specified_value() {
                    return Ok(());
                }
            }
            if let Some(v) = self.font_variation_settings {
                if v != &font_variation_settings::get_initial_specified_value() {
                    return Ok(());
                }
            }

            if self.font_kerning != &font_kerning::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_language_override != &font_language_override::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_size_adjust != &font_size_adjust::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_variant_alternates != &font_variant_alternates::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_variant_east_asian != &font_variant_east_asian::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_variant_ligatures != &font_variant_ligatures::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_variant_numeric != &font_variant_numeric::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_variant_position != &font_variant_position::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_feature_settings != &font_feature_settings::get_initial_specified_value() {
                return Ok(());
            }

            // In case of serialization for canvas font, we need to drop
            // initial values of properties other than size and family.
                if self.font_style != &font_style::get_initial_specified_value() {
                    self.font_style.to_css(dest)?;
                    dest.write_str(" ")?;
                }
                if self.font_variant_caps != &font_variant_caps::get_initial_specified_value() {
                    self.font_variant_caps.to_css(dest)?;
                    dest.write_str(" ")?;
                }
                if self.font_weight != &font_weight::get_initial_specified_value() {
                    self.font_weight.to_css(dest)?;
                    dest.write_str(" ")?;
                }
                if self.font_stretch != &font_stretch::get_initial_specified_value() {
                    self.font_stretch.to_css(dest)?;
                    dest.write_str(" ")?;
                }

            self.font_size.to_css(dest)?;

            if *self.line_height != LineHeight::normal() {
                dest.write_str("/")?;
                self.line_height.to_css(dest)?;
            }

            dest.write_str(" ")?;
            self.font_family.to_css(dest)?;

            Ok(())
        }
    }

    impl<'a> LonghandsToSerialize<'a> {
        /// Check if some or all members are system fonts
        fn check_system(&self) -> CheckSystemResult {
            let mut sys = None;
            let mut all = true;

            {
                let value = self.font_family;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_size;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_style;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_variant_caps;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_stretch;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_kerning;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_variant_position;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_weight;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_size_adjust;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_variant_alternates;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_variant_ligatures;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_variant_east_asian;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_variant_numeric;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_language_override;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_feature_settings;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            if let Some(value) = self.font_variation_settings {
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            if let Some(value) = self.font_optical_sizing {
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            if self.line_height != &LineHeight::normal() {
                all = false
            }
            if all {
                CheckSystemResult::AllSystem(sys.unwrap())
            } else if sys.is_some() {
                CheckSystemResult::SomeSystem
            } else {
                CheckSystemResult::None
            }
        }
    }

    }




    /// https://drafts.csswg.org/css-fonts-3/#propdef-font-variant
    pub mod font_variant {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub font_variant_caps:
                    longhands::font_variant_caps::SpecifiedValue
                    ,
                pub font_variant_alternates:
                    longhands::font_variant_alternates::SpecifiedValue
                    ,
                pub font_variant_east_asian:
                    longhands::font_variant_east_asian::SpecifiedValue
                    ,
                pub font_variant_ligatures:
                    longhands::font_variant_ligatures::SpecifiedValue
                    ,
                pub font_variant_numeric:
                    longhands::font_variant_numeric::SpecifiedValue
                    ,
                pub font_variant_position:
                    longhands::font_variant_position::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub font_variant_caps:
                    &'a longhands::font_variant_caps::SpecifiedValue,
                pub font_variant_alternates:
                    &'a longhands::font_variant_alternates::SpecifiedValue,
                pub font_variant_east_asian:
                    &'a longhands::font_variant_east_asian::SpecifiedValue,
                pub font_variant_ligatures:
                    &'a longhands::font_variant_ligatures::SpecifiedValue,
                pub font_variant_numeric:
                    &'a longhands::font_variant_numeric::SpecifiedValue,
                pub font_variant_position:
                    &'a longhands::font_variant_position::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut font_variant_caps = None;
                    let mut font_variant_alternates = None;
                    let mut font_variant_east_asian = None;
                    let mut font_variant_ligatures = None;
                    let mut font_variant_numeric = None;
                    let mut font_variant_position = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::FontVariantCaps(ref value) => {
                                font_variant_caps = Some(value)
                            },
                            PropertyDeclaration::FontVariantAlternates(ref value) => {
                                font_variant_alternates = Some(value)
                            },
                            PropertyDeclaration::FontVariantEastAsian(ref value) => {
                                font_variant_east_asian = Some(value)
                            },
                            PropertyDeclaration::FontVariantLigatures(ref value) => {
                                font_variant_ligatures = Some(value)
                            },
                            PropertyDeclaration::FontVariantNumeric(ref value) => {
                                font_variant_numeric = Some(value)
                            },
                            PropertyDeclaration::FontVariantPosition(ref value) => {
                                font_variant_position = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        font_variant_caps,
                        font_variant_alternates,
                        font_variant_east_asian,
                        font_variant_ligatures,
                        font_variant_numeric,
                        font_variant_position,
                ) {

                    (
                        Some(font_variant_caps),
                        Some(font_variant_alternates),
                        Some(font_variant_east_asian),
                        Some(font_variant_ligatures),
                        Some(font_variant_numeric),
                        Some(font_variant_position),
                    ) =>
                    Ok(LonghandsToSerialize {
                            font_variant_caps,
                            font_variant_alternates,
                            font_variant_east_asian,
                            font_variant_ligatures,
                            font_variant_numeric,
                            font_variant_position,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::FontVariantCaps(
                        longhands.font_variant_caps
                    ));
                    declarations.push(PropertyDeclaration::FontVariantAlternates(
                        longhands.font_variant_alternates
                    ));
                    declarations.push(PropertyDeclaration::FontVariantEastAsian(
                        longhands.font_variant_east_asian
                    ));
                    declarations.push(PropertyDeclaration::FontVariantLigatures(
                        longhands.font_variant_ligatures
                    ));
                    declarations.push(PropertyDeclaration::FontVariantNumeric(
                        longhands.font_variant_numeric
                    ));
                    declarations.push(PropertyDeclaration::FontVariantPosition(
                        longhands.font_variant_position
                    ));
            })
        }

        
    
    

    use properties::longhands::font_variant_caps;
    use properties::longhands::font_variant_alternates;
    use properties::longhands::font_variant_east_asian;
    use properties::longhands::font_variant_ligatures;
    use properties::longhands::font_variant_numeric;
    use properties::longhands::font_variant_position;
    #[allow(unused_imports)]
    use values::specified::FontVariantLigatures;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut caps = None;
        let mut alternates = None;
        let mut east_asian = None;
        let mut ligatures = None;
        let mut numeric = None;
        let mut position = None;

        if input.try(|input| input.expect_ident_matching("normal")).is_ok() {
            // Leave the values to None, 'normal' is the initial value for all the sub properties.
        } else if input.try(|input| input.expect_ident_matching("none")).is_ok() {
            // The 'none' value sets 'font-variant-ligatures' to 'none' and resets all other sub properties
            // to their initial value.
            ligatures = Some(FontVariantLigatures::none());
        } else {
            let mut has_custom_value: bool = false;
            loop {
                if input.try(|input| input.expect_ident_matching("normal")).is_ok() ||
                   input.try(|input| input.expect_ident_matching("none")).is_ok() {
                    return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
                }
                if caps.is_none() {
                    if let Ok(value) = input.try(|i| font_variant_caps::parse(context, i)) {
                        has_custom_value = true;
                        caps = Some(value);
                        continue
                    }
                }
                if alternates.is_none() {
                    if let Ok(value) = input.try(|i| font_variant_alternates::parse(context, i)) {
                        has_custom_value = true;
                        alternates = Some(value);
                        continue
                    }
                }
                if east_asian.is_none() {
                    if let Ok(value) = input.try(|i| font_variant_east_asian::parse(context, i)) {
                        has_custom_value = true;
                        east_asian = Some(value);
                        continue
                    }
                }
                if ligatures.is_none() {
                    if let Ok(value) = input.try(|i| font_variant_ligatures::parse(context, i)) {
                        has_custom_value = true;
                        ligatures = Some(value);
                        continue
                    }
                }
                if numeric.is_none() {
                    if let Ok(value) = input.try(|i| font_variant_numeric::parse(context, i)) {
                        has_custom_value = true;
                        numeric = Some(value);
                        continue
                    }
                }
                if position.is_none() {
                    if let Ok(value) = input.try(|i| font_variant_position::parse(context, i)) {
                        has_custom_value = true;
                        position = Some(value);
                        continue
                    }
                }

                break
            }

            if !has_custom_value {
                return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        }

        Ok(expanded! {
            font_variant_caps: unwrap_or_initial!(font_variant_caps, caps),
            font_variant_alternates: unwrap_or_initial!(font_variant_alternates, alternates),
            font_variant_east_asian: unwrap_or_initial!(font_variant_east_asian, east_asian),
            font_variant_ligatures: unwrap_or_initial!(font_variant_ligatures, ligatures),
            font_variant_numeric: unwrap_or_initial!(font_variant_numeric, numeric),
            font_variant_position: unwrap_or_initial!(font_variant_position, position),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        #[allow(unused_assignments)]
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {

            let has_none_ligatures =
                self.font_variant_ligatures == &FontVariantLigatures::none();

            const TOTAL_SUBPROPS: usize = 6;
            let mut nb_normals = 0;
            if self.font_variant_caps == &font_variant_caps::get_initial_specified_value() {
                nb_normals += 1;
            }
            if self.font_variant_alternates == &font_variant_alternates::get_initial_specified_value() {
                nb_normals += 1;
            }
            if self.font_variant_east_asian == &font_variant_east_asian::get_initial_specified_value() {
                nb_normals += 1;
            }
            if self.font_variant_ligatures == &font_variant_ligatures::get_initial_specified_value() {
                nb_normals += 1;
            }
            if self.font_variant_numeric == &font_variant_numeric::get_initial_specified_value() {
                nb_normals += 1;
            }
            if self.font_variant_position == &font_variant_position::get_initial_specified_value() {
                nb_normals += 1;
            }


            if nb_normals > 0 && nb_normals == TOTAL_SUBPROPS {
                dest.write_str("normal")?;
            } else if has_none_ligatures {
                if nb_normals == TOTAL_SUBPROPS - 1 {
                    // Serialize to 'none' if 'font-variant-ligatures' is set to 'none' and all other
                    // font feature properties are reset to their initial value.
                    dest.write_str("none")?;
                } else {
                    return Ok(())
                }
            } else {
                let mut has_any = false;
                if self.font_variant_caps != &font_variant_caps::get_initial_specified_value() {
                    if has_any {
                        dest.write_str(" ")?;
                    }
                    has_any = true;
                    self.font_variant_caps.to_css(dest)?;
                }
                if self.font_variant_alternates != &font_variant_alternates::get_initial_specified_value() {
                    if has_any {
                        dest.write_str(" ")?;
                    }
                    has_any = true;
                    self.font_variant_alternates.to_css(dest)?;
                }
                if self.font_variant_east_asian != &font_variant_east_asian::get_initial_specified_value() {
                    if has_any {
                        dest.write_str(" ")?;
                    }
                    has_any = true;
                    self.font_variant_east_asian.to_css(dest)?;
                }
                if self.font_variant_ligatures != &font_variant_ligatures::get_initial_specified_value() {
                    if has_any {
                        dest.write_str(" ")?;
                    }
                    has_any = true;
                    self.font_variant_ligatures.to_css(dest)?;
                }
                if self.font_variant_numeric != &font_variant_numeric::get_initial_specified_value() {
                    if has_any {
                        dest.write_str(" ")?;
                    }
                    has_any = true;
                    self.font_variant_numeric.to_css(dest)?;
                }
                if self.font_variant_position != &font_variant_position::get_initial_specified_value() {
                    if has_any {
                        dest.write_str(" ")?;
                    }
                    has_any = true;
                    self.font_variant_position.to_css(dest)?;
                }
            }

            Ok(())
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-text-decor-3/#text-emphasis-property
    pub mod text_emphasis {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub text_emphasis_style:
                        Box<
                    longhands::text_emphasis_style::SpecifiedValue
                        >
                    ,
                pub text_emphasis_color:
                    longhands::text_emphasis_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub text_emphasis_style:
                    &'a longhands::text_emphasis_style::SpecifiedValue,
                pub text_emphasis_color:
                    &'a longhands::text_emphasis_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut text_emphasis_style = None;
                    let mut text_emphasis_color = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::TextEmphasisStyle(ref value) => {
                                text_emphasis_style = Some(value)
                            },
                            PropertyDeclaration::TextEmphasisColor(ref value) => {
                                text_emphasis_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        text_emphasis_style,
                        text_emphasis_color,
                ) {

                    (
                        Some(text_emphasis_style),
                        Some(text_emphasis_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            text_emphasis_style,
                            text_emphasis_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::TextEmphasisStyle(
                        longhands.text_emphasis_style
                    ));
                    declarations.push(PropertyDeclaration::TextEmphasisColor(
                        longhands.text_emphasis_color
                    ));
            })
        }

        
    use properties::longhands::{text_emphasis_color, text_emphasis_style};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut color = None;
        let mut style = None;

        loop {
            if color.is_none() {
                if let Ok(value) = input.try(|input| text_emphasis_color::parse(context, input)) {
                    color = Some(value);
                    continue
                }
            }
            if style.is_none() {
                if let Ok(value) = input.try(|input| text_emphasis_style::parse(context, input)) {
                    style = Some(value);
                    continue
                }
            }
            break
        }
        if color.is_some() || style.is_some() {
            Ok(expanded! {
                text_emphasis_color: unwrap_or_initial!(text_emphasis_color, color),
                text_emphasis_style: unwrap_or_initial!(text_emphasis_style, style),
            })
        } else {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }

    }


// CSS Compatibility
// https://compat.spec.whatwg.org/


    /// https://compat.spec.whatwg.org/#the-webkit-text-stroke
    pub mod _webkit_text_stroke {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub _webkit_text_stroke_width:
                    longhands::_webkit_text_stroke_width::SpecifiedValue
                    ,
                pub _webkit_text_stroke_color:
                    longhands::_webkit_text_stroke_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub _webkit_text_stroke_width:
                    &'a longhands::_webkit_text_stroke_width::SpecifiedValue,
                pub _webkit_text_stroke_color:
                    &'a longhands::_webkit_text_stroke_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut _webkit_text_stroke_width = None;
                    let mut _webkit_text_stroke_color = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::WebkitTextStrokeWidth(ref value) => {
                                _webkit_text_stroke_width = Some(value)
                            },
                            PropertyDeclaration::WebkitTextStrokeColor(ref value) => {
                                _webkit_text_stroke_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        _webkit_text_stroke_width,
                        _webkit_text_stroke_color,
                ) {

                    (
                        Some(_webkit_text_stroke_width),
                        Some(_webkit_text_stroke_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            _webkit_text_stroke_width,
                            _webkit_text_stroke_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::WebkitTextStrokeWidth(
                        longhands._webkit_text_stroke_width
                    ));
                    declarations.push(PropertyDeclaration::WebkitTextStrokeColor(
                        longhands._webkit_text_stroke_color
                    ));
            })
        }

        
    use properties::longhands::{_webkit_text_stroke_color, _webkit_text_stroke_width};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut color = None;
        let mut width = None;
        loop {
            if color.is_none() {
                if let Ok(value) = input.try(|input| _webkit_text_stroke_color::parse(context, input)) {
                    color = Some(value);
                    continue
                }
            }

            if width.is_none() {
                if let Ok(value) = input.try(|input| _webkit_text_stroke_width::parse(context, input)) {
                    width = Some(value);
                    continue
                }
            }
            break
        }

        if color.is_some() || width.is_some() {
            Ok(expanded! {
                _webkit_text_stroke_color: unwrap_or_initial!(_webkit_text_stroke_color, color),
                _webkit_text_stroke_width: unwrap_or_initial!(_webkit_text_stroke_width, width),
            })
        } else {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-lists/#propdef-list-style
    pub mod list_style {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub list_style_position:
                    longhands::list_style_position::SpecifiedValue
                    ,
                pub list_style_image:
                    longhands::list_style_image::SpecifiedValue
                    ,
                pub list_style_type:
                        Box<
                    longhands::list_style_type::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub list_style_position:
                    &'a longhands::list_style_position::SpecifiedValue,
                pub list_style_image:
                    &'a longhands::list_style_image::SpecifiedValue,
                pub list_style_type:
                    &'a longhands::list_style_type::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut list_style_position = None;
                    let mut list_style_image = None;
                    let mut list_style_type = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::ListStylePosition(ref value) => {
                                list_style_position = Some(value)
                            },
                            PropertyDeclaration::ListStyleImage(ref value) => {
                                list_style_image = Some(value)
                            },
                            PropertyDeclaration::ListStyleType(ref value) => {
                                list_style_type = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        list_style_position,
                        list_style_image,
                        list_style_type,
                ) {

                    (
                        Some(list_style_position),
                        Some(list_style_image),
                        Some(list_style_type),
                    ) =>
                    Ok(LonghandsToSerialize {
                            list_style_position,
                            list_style_image,
                            list_style_type,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ListStylePosition(
                        longhands.list_style_position
                    ));
                    declarations.push(PropertyDeclaration::ListStyleImage(
                        longhands.list_style_image
                    ));
                    declarations.push(PropertyDeclaration::ListStyleType(
                        longhands.list_style_type
                    ));
            })
        }

        
    use properties::longhands::{list_style_image, list_style_position, list_style_type};
    use values::{Either, None_};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        // `none` is ambiguous until we've finished parsing the shorthands, so we count the number
        // of times we see it.
        let mut nones = 0u8;
        let (mut image, mut position, mut list_style_type, mut any) = (None, None, None, false);
        loop {
            if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                nones = nones + 1;
                if nones > 2 {
                    return Err(input.new_custom_error(SelectorParseErrorKind::UnexpectedIdent("none".into())))
                }
                any = true;
                continue
            }

            if image.is_none() {
                if let Ok(value) = input.try(|input| list_style_image::parse(context, input)) {
                    image = Some(value);
                    any = true;
                    continue
                }
            }

            if position.is_none() {
                if let Ok(value) = input.try(|input| list_style_position::parse(context, input)) {
                    position = Some(value);
                    any = true;
                    continue
                }
            }

            // list-style-type must be checked the last, because it accepts
            // arbitrary identifier for custom counter style, and thus may
            // affect values of list-style-position.
            if list_style_type.is_none() {
                if let Ok(value) = input.try(|input| list_style_type::parse(context, input)) {
                    list_style_type = Some(value);
                    any = true;
                    continue
                }
            }
            break
        }

        let position = unwrap_or_initial!(list_style_position, position);

        fn list_style_type_none() -> list_style_type::SpecifiedValue {
            use values::generics::CounterStyleOrNone;
            list_style_type::SpecifiedValue::CounterStyle(CounterStyleOrNone::None)
        }

        // If there are two `none`s, then we can't have a type or image; if there is one `none`,
        // then we can't have both a type *and* an image; if there is no `none` then we're fine as
        // long as we parsed something.
        match (any, nones, list_style_type, image) {
            (true, 2, None, None) => {
                Ok(expanded! {
                    list_style_position: position,
                    list_style_image: list_style_image::SpecifiedValue(Either::Second(None_)),
                    list_style_type: list_style_type_none(),
                })
            }
            (true, 1, None, Some(image)) => {
                Ok(expanded! {
                    list_style_position: position,
                    list_style_image: image,
                    list_style_type: list_style_type_none(),
                })
            }
            (true, 1, Some(list_style_type), None) => {
                Ok(expanded! {
                    list_style_position: position,
                    list_style_image: list_style_image::SpecifiedValue(Either::Second(None_)),
                    list_style_type: list_style_type,
                })
            }
            (true, 1, None, None) => {
                Ok(expanded! {
                    list_style_position: position,
                    list_style_image: list_style_image::SpecifiedValue(Either::Second(None_)),
                    list_style_type: list_style_type_none(),
                })
            }
            (true, 0, list_style_type, image) => {
                Ok(expanded! {
                    list_style_position: position,
                    list_style_image: unwrap_or_initial!(list_style_image, image),
                    list_style_type: unwrap_or_initial!(list_style_type),
                })
            }
            _ => Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError)),
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */




    
    

    /// https://drafts.csswg.org/css-box/#propdef-margin
    pub mod margin {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub margin_top:
                    longhands::margin_top::SpecifiedValue
                    ,
                pub margin_right:
                    longhands::margin_right::SpecifiedValue
                    ,
                pub margin_bottom:
                    longhands::margin_bottom::SpecifiedValue
                    ,
                pub margin_left:
                    longhands::margin_left::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub margin_top:
                    &'a longhands::margin_top::SpecifiedValue,
                pub margin_right:
                    &'a longhands::margin_right::SpecifiedValue,
                pub margin_bottom:
                    &'a longhands::margin_bottom::SpecifiedValue,
                pub margin_left:
                    &'a longhands::margin_left::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut margin_top = None;
                    let mut margin_right = None;
                    let mut margin_bottom = None;
                    let mut margin_left = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::MarginTop(ref value) => {
                                margin_top = Some(value)
                            },
                            PropertyDeclaration::MarginRight(ref value) => {
                                margin_right = Some(value)
                            },
                            PropertyDeclaration::MarginBottom(ref value) => {
                                margin_bottom = Some(value)
                            },
                            PropertyDeclaration::MarginLeft(ref value) => {
                                margin_left = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        margin_top,
                        margin_right,
                        margin_bottom,
                        margin_left,
                ) {

                    (
                        Some(margin_top),
                        Some(margin_right),
                        Some(margin_bottom),
                        Some(margin_left),
                    ) =>
                    Ok(LonghandsToSerialize {
                            margin_top,
                            margin_right,
                            margin_bottom,
                            margin_left,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MarginTop(
                        longhands.margin_top
                    ));
                    declarations.push(PropertyDeclaration::MarginRight(
                        longhands.margin_right
                    ));
                    declarations.push(PropertyDeclaration::MarginBottom(
                        longhands.margin_bottom
                    ));
                    declarations.push(PropertyDeclaration::MarginLeft(
                        longhands.margin_left
                    ));
            })
        }

        
        #[allow(unused_imports)]
        use parser::Parse;
        use values::generics::rect::Rect;
        use values::specified;

        pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                   -> Result<Longhands, ParseError<'i>> {
            let rect = Rect::parse_with(context, input, |_c, i| {
                specified::LengthOrPercentageOrAuto::parse_quirky(_c, i, specified::AllowQuirks::Yes)
            })?;
            Ok(expanded! {
                    margin_top: rect.0,
                    margin_right: rect.1,
                    margin_bottom: rect.2,
                    margin_left: rect.3,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a> {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let rect = Rect::new(
                    &self.margin_top,
                    &self.margin_right,
                    &self.margin_bottom,
                    &self.margin_left,
                );
                rect.to_css(dest)
            }
        }
    
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.fxtf.org/css-masking/#propdef-mask
    pub mod mask {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub mask_mode:
                    longhands::mask_mode::SpecifiedValue
                    ,
                pub mask_repeat:
                    longhands::mask_repeat::SpecifiedValue
                    ,
                pub mask_clip:
                    longhands::mask_clip::SpecifiedValue
                    ,
                pub mask_origin:
                    longhands::mask_origin::SpecifiedValue
                    ,
                pub mask_composite:
                    longhands::mask_composite::SpecifiedValue
                    ,
                pub mask_position_x:
                    longhands::mask_position_x::SpecifiedValue
                    ,
                pub mask_position_y:
                    longhands::mask_position_y::SpecifiedValue
                    ,
                pub mask_size:
                    longhands::mask_size::SpecifiedValue
                    ,
                pub mask_image:
                    longhands::mask_image::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub mask_mode:
                    &'a longhands::mask_mode::SpecifiedValue,
                pub mask_repeat:
                    &'a longhands::mask_repeat::SpecifiedValue,
                pub mask_clip:
                    &'a longhands::mask_clip::SpecifiedValue,
                pub mask_origin:
                    &'a longhands::mask_origin::SpecifiedValue,
                pub mask_composite:
                    &'a longhands::mask_composite::SpecifiedValue,
                pub mask_position_x:
                    &'a longhands::mask_position_x::SpecifiedValue,
                pub mask_position_y:
                    &'a longhands::mask_position_y::SpecifiedValue,
                pub mask_size:
                    &'a longhands::mask_size::SpecifiedValue,
                pub mask_image:
                    &'a longhands::mask_image::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut mask_mode = None;
                    let mut mask_repeat = None;
                    let mut mask_clip = None;
                    let mut mask_origin = None;
                    let mut mask_composite = None;
                    let mut mask_position_x = None;
                    let mut mask_position_y = None;
                    let mut mask_size = None;
                    let mut mask_image = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::MaskMode(ref value) => {
                                mask_mode = Some(value)
                            },
                            PropertyDeclaration::MaskRepeat(ref value) => {
                                mask_repeat = Some(value)
                            },
                            PropertyDeclaration::MaskClip(ref value) => {
                                mask_clip = Some(value)
                            },
                            PropertyDeclaration::MaskOrigin(ref value) => {
                                mask_origin = Some(value)
                            },
                            PropertyDeclaration::MaskComposite(ref value) => {
                                mask_composite = Some(value)
                            },
                            PropertyDeclaration::MaskPositionX(ref value) => {
                                mask_position_x = Some(value)
                            },
                            PropertyDeclaration::MaskPositionY(ref value) => {
                                mask_position_y = Some(value)
                            },
                            PropertyDeclaration::MaskSize(ref value) => {
                                mask_size = Some(value)
                            },
                            PropertyDeclaration::MaskImage(ref value) => {
                                mask_image = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        mask_mode,
                        mask_repeat,
                        mask_clip,
                        mask_origin,
                        mask_composite,
                        mask_position_x,
                        mask_position_y,
                        mask_size,
                        mask_image,
                ) {

                    (
                        Some(mask_mode),
                        Some(mask_repeat),
                        Some(mask_clip),
                        Some(mask_origin),
                        Some(mask_composite),
                        Some(mask_position_x),
                        Some(mask_position_y),
                        Some(mask_size),
                        Some(mask_image),
                    ) =>
                    Ok(LonghandsToSerialize {
                            mask_mode,
                            mask_repeat,
                            mask_clip,
                            mask_origin,
                            mask_composite,
                            mask_position_x,
                            mask_position_y,
                            mask_size,
                            mask_image,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MaskMode(
                        longhands.mask_mode
                    ));
                    declarations.push(PropertyDeclaration::MaskRepeat(
                        longhands.mask_repeat
                    ));
                    declarations.push(PropertyDeclaration::MaskClip(
                        longhands.mask_clip
                    ));
                    declarations.push(PropertyDeclaration::MaskOrigin(
                        longhands.mask_origin
                    ));
                    declarations.push(PropertyDeclaration::MaskComposite(
                        longhands.mask_composite
                    ));
                    declarations.push(PropertyDeclaration::MaskPositionX(
                        longhands.mask_position_x
                    ));
                    declarations.push(PropertyDeclaration::MaskPositionY(
                        longhands.mask_position_y
                    ));
                    declarations.push(PropertyDeclaration::MaskSize(
                        longhands.mask_size
                    ));
                    declarations.push(PropertyDeclaration::MaskImage(
                        longhands.mask_image
                    ));
            })
        }

        
    use properties::longhands::{mask_mode, mask_repeat, mask_clip, mask_origin, mask_composite, mask_position_x,
                                mask_position_y};
    use properties::longhands::{mask_size, mask_image};
    use values::specified::{Position, PositionComponent};
    use parser::Parse;

    // FIXME(emilio): These two mask types should be the same!
    impl From<mask_origin::single_value::SpecifiedValue> for mask_clip::single_value::SpecifiedValue {
        fn from(origin: mask_origin::single_value::SpecifiedValue) -> mask_clip::single_value::SpecifiedValue {
            match origin {
                mask_origin::single_value::SpecifiedValue::ContentBox =>
                    mask_clip::single_value::SpecifiedValue::ContentBox,
                mask_origin::single_value::SpecifiedValue::PaddingBox =>
                    mask_clip::single_value::SpecifiedValue::PaddingBox ,
                mask_origin::single_value::SpecifiedValue::BorderBox =>
                    mask_clip::single_value::SpecifiedValue::BorderBox,
                mask_origin::single_value::SpecifiedValue::FillBox =>
                    mask_clip::single_value::SpecifiedValue::FillBox ,
                mask_origin::single_value::SpecifiedValue::StrokeBox =>
                    mask_clip::single_value::SpecifiedValue::StrokeBox,
                mask_origin::single_value::SpecifiedValue::ViewBox=>
                    mask_clip::single_value::SpecifiedValue::ViewBox,
            }
        }
    }

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_image = mask_image::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_mode = mask_mode::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_position_x = mask_position_x::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_position_y = mask_position_y::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_size = mask_size::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_repeat = mask_repeat::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_origin = mask_origin::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_clip = mask_clip::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_composite = mask_composite::SpecifiedValue(Vec::with_capacity(1));

        input.parse_comma_separated(|input| {
                let mut image = None;
                let mut mode = None;
                let mut position = None;
                let mut size = None;
                let mut repeat = None;
                let mut origin = None;
                let mut clip = None;
                let mut composite = None;
            loop {
                if image.is_none() {
                    if let Ok(value) = input.try(|input| mask_image::single_value
                                                                   ::parse(context, input)) {
                        image = Some(value);
                        continue
                    }
                }
                if position.is_none() {
                    if let Ok(value) = input.try(|input| Position::parse(context, input)) {
                        position = Some(value);

                        // Parse mask size, if applicable.
                        size = input.try(|input| {
                            input.expect_delim('/')?;
                            mask_size::single_value::parse(context, input)
                        }).ok();

                        continue
                    }
                }
                    if repeat.is_none() {
                        if let Ok(value) = input.try(|input| mask_repeat::single_value
                                                                               ::parse(context, input)) {
                            repeat = Some(value);
                            continue
                        }
                    }
                    if origin.is_none() {
                        if let Ok(value) = input.try(|input| mask_origin::single_value
                                                                               ::parse(context, input)) {
                            origin = Some(value);
                            continue
                        }
                    }
                    if clip.is_none() {
                        if let Ok(value) = input.try(|input| mask_clip::single_value
                                                                               ::parse(context, input)) {
                            clip = Some(value);
                            continue
                        }
                    }
                    if composite.is_none() {
                        if let Ok(value) = input.try(|input| mask_composite::single_value
                                                                               ::parse(context, input)) {
                            composite = Some(value);
                            continue
                        }
                    }
                    if mode.is_none() {
                        if let Ok(value) = input.try(|input| mask_mode::single_value
                                                                               ::parse(context, input)) {
                            mode = Some(value);
                            continue
                        }
                    }
                break
            }
            if clip.is_none() {
                if let Some(origin) = origin {
                    clip = Some(mask_clip::single_value::SpecifiedValue::from(origin));
                }
            }
            let mut any = false;
                any = any || image.is_some();
                any = any || mode.is_some();
                any = any || position.is_some();
                any = any || size.is_some();
                any = any || repeat.is_some();
                any = any || origin.is_some();
                any = any || clip.is_some();
                any = any || composite.is_some();
            if any {
                if let Some(position) = position {
                    mask_position_x.0.push(position.horizontal);
                    mask_position_y.0.push(position.vertical);
                } else {
                    mask_position_x.0.push(PositionComponent::zero());
                    mask_position_y.0.push(PositionComponent::zero());
                }
                    if let Some(m_image) = image {
                        mask_image.0.push(m_image);
                    } else {
                        mask_image.0.push(mask_image::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_mode) = mode {
                        mask_mode.0.push(m_mode);
                    } else {
                        mask_mode.0.push(mask_mode::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_size) = size {
                        mask_size.0.push(m_size);
                    } else {
                        mask_size.0.push(mask_size::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_repeat) = repeat {
                        mask_repeat.0.push(m_repeat);
                    } else {
                        mask_repeat.0.push(mask_repeat::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_origin) = origin {
                        mask_origin.0.push(m_origin);
                    } else {
                        mask_origin.0.push(mask_origin::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_clip) = clip {
                        mask_clip.0.push(m_clip);
                    } else {
                        mask_clip.0.push(mask_clip::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_composite) = composite {
                        mask_composite.0.push(m_composite);
                    } else {
                        mask_composite.0.push(mask_composite::single_value
                                                        ::get_initial_specified_value());
                    }
                Ok(())
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        })?;

        Ok(expanded! {
                mask_image: mask_image,
                mask_mode: mask_mode,
                mask_position_x: mask_position_x,
                mask_position_y: mask_position_y,
                mask_size: mask_size,
                mask_repeat: mask_repeat,
                mask_origin: mask_origin,
                mask_clip: mask_clip,
                mask_composite: mask_composite,
         })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            use properties::longhands::mask_origin::single_value::computed_value::T as Origin;
            use properties::longhands::mask_clip::single_value::computed_value::T as Clip;

            let len = self.mask_image.0.len();
            if len == 0 {
                return Ok(());
            }
                if self.mask_mode.0.len() != len {
                    return Ok(());
                }
                if self.mask_position_x.0.len() != len {
                    return Ok(());
                }
                if self.mask_position_y.0.len() != len {
                    return Ok(());
                }
                if self.mask_size.0.len() != len {
                    return Ok(());
                }
                if self.mask_repeat.0.len() != len {
                    return Ok(());
                }
                if self.mask_origin.0.len() != len {
                    return Ok(());
                }
                if self.mask_clip.0.len() != len {
                    return Ok(());
                }
                if self.mask_composite.0.len() != len {
                    return Ok(());
                }

            for i in 0..len {
                if i > 0 {
                    dest.write_str(", ")?;
                }

                    let image = &self.mask_image.0[i];
                    let mode = &self.mask_mode.0[i];
                    let position_x = &self.mask_position_x.0[i];
                    let position_y = &self.mask_position_y.0[i];
                    let size = &self.mask_size.0[i];
                    let repeat = &self.mask_repeat.0[i];
                    let origin = &self.mask_origin.0[i];
                    let clip = &self.mask_clip.0[i];
                    let composite = &self.mask_composite.0[i];

                image.to_css(dest)?;
                dest.write_str(" ")?;
                mode.to_css(dest)?;
                dest.write_str(" ")?;

                Position {
                    horizontal: position_x.clone(),
                    vertical: position_y.clone()
                }.to_css(dest)?;

                if *size != mask_size::single_value::get_initial_specified_value() {
                    dest.write_str(" / ")?;
                    size.to_css(dest)?;
                }
                dest.write_str(" ")?;
                repeat.to_css(dest)?;

                if *origin != Origin::BorderBox || *clip != Clip::BorderBox {
                    dest.write_str(" ")?;
                    origin.to_css(dest)?;
                    if *clip != From::from(*origin) {
                        dest.write_str(" ")?;
                        clip.to_css(dest)?;
                    }
                }

                dest.write_str(" ")?;
                composite.to_css(dest)?;
            }

            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-masks-4/#the-mask-position
    pub mod mask_position {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub mask_position_x:
                    longhands::mask_position_x::SpecifiedValue
                    ,
                pub mask_position_y:
                    longhands::mask_position_y::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub mask_position_x:
                    &'a longhands::mask_position_x::SpecifiedValue,
                pub mask_position_y:
                    &'a longhands::mask_position_y::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut mask_position_x = None;
                    let mut mask_position_y = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::MaskPositionX(ref value) => {
                                mask_position_x = Some(value)
                            },
                            PropertyDeclaration::MaskPositionY(ref value) => {
                                mask_position_y = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        mask_position_x,
                        mask_position_y,
                ) {

                    (
                        Some(mask_position_x),
                        Some(mask_position_y),
                    ) =>
                    Ok(LonghandsToSerialize {
                            mask_position_x,
                            mask_position_y,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MaskPositionX(
                        longhands.mask_position_x
                    ));
                    declarations.push(PropertyDeclaration::MaskPositionY(
                        longhands.mask_position_y
                    ));
            })
        }

        
    use properties::longhands::{mask_position_x,mask_position_y};
    use values::specified::position::Position;
    use parser::Parse;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate.  Note that we always push at least one item if parsing
        // succeeds.
        let mut position_x = mask_position_x::SpecifiedValue(Vec::with_capacity(1));
        let mut position_y = mask_position_y::SpecifiedValue(Vec::with_capacity(1));
        let mut any = false;

        input.parse_comma_separated(|input| {
            let value = Position::parse(context, input)?;
            position_x.0.push(value.horizontal);
            position_y.0.push(value.vertical);
            any = true;
            Ok(())
        })?;
        if any == false {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }

        Ok(expanded! {
            mask_position_x: position_x,
            mask_position_y: position_y,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let len = self.mask_position_x.0.len();
            if len == 0 || self.mask_position_y.0.len() != len {
                return Ok(());
            }

            for i in 0..len {
                Position {
                    horizontal: self.mask_position_x.0[i].clone(),
                    vertical: self.mask_position_y.0[i].clone()
                }.to_css(dest)?;

                if i < len - 1 {
                    dest.write_str(", ")?;
                }
            }

            Ok(())
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-ui/#propdef-outline
    pub mod outline {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub outline_width:
                    longhands::outline_width::SpecifiedValue
                    ,
                pub outline_style:
                    longhands::outline_style::SpecifiedValue
                    ,
                pub outline_color:
                    longhands::outline_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub outline_width:
                    &'a longhands::outline_width::SpecifiedValue,
                pub outline_style:
                    &'a longhands::outline_style::SpecifiedValue,
                pub outline_color:
                    &'a longhands::outline_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut outline_width = None;
                    let mut outline_style = None;
                    let mut outline_color = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::OutlineWidth(ref value) => {
                                outline_width = Some(value)
                            },
                            PropertyDeclaration::OutlineStyle(ref value) => {
                                outline_style = Some(value)
                            },
                            PropertyDeclaration::OutlineColor(ref value) => {
                                outline_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        outline_width,
                        outline_style,
                        outline_color,
                ) {

                    (
                        Some(outline_width),
                        Some(outline_style),
                        Some(outline_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            outline_width,
                            outline_style,
                            outline_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::OutlineWidth(
                        longhands.outline_width
                    ));
                    declarations.push(PropertyDeclaration::OutlineStyle(
                        longhands.outline_style
                    ));
                    declarations.push(PropertyDeclaration::OutlineColor(
                        longhands.outline_color
                    ));
            })
        }

        
    use properties::longhands::{outline_color, outline_width, outline_style};
    use values::specified;
    use parser::Parse;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let _unused = context;
        let mut color = None;
        let mut style = None;
        let mut width = None;
        let mut any = false;
        loop {
            if color.is_none() {
                if let Ok(value) = input.try(|i| specified::Color::parse(context, i)) {
                    color = Some(value);
                    any = true;
                    continue
                }
            }
            if style.is_none() {
                if let Ok(value) = input.try(|input| outline_style::parse(context, input)) {
                    style = Some(value);
                    any = true;
                    continue
                }
            }
            if width.is_none() {
                if let Ok(value) = input.try(|input| outline_width::parse(context, input)) {
                    width = Some(value);
                    any = true;
                    continue
                }
            }
            break
        }
        if any {
            Ok(expanded! {
                outline_color: unwrap_or_initial!(outline_color, color),
                outline_style: unwrap_or_initial!(outline_style, style),
                outline_width: unwrap_or_initial!(outline_width, width),
            })
        } else {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }

    }


// The -moz-outline-radius shorthand is non-standard and not on a standards track.


    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-outline-radius)
    pub mod _moz_outline_radius {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub _moz_outline_radius_topleft:
                        Box<
                    longhands::_moz_outline_radius_topleft::SpecifiedValue
                        >
                    ,
                pub _moz_outline_radius_topright:
                        Box<
                    longhands::_moz_outline_radius_topright::SpecifiedValue
                        >
                    ,
                pub _moz_outline_radius_bottomright:
                        Box<
                    longhands::_moz_outline_radius_bottomright::SpecifiedValue
                        >
                    ,
                pub _moz_outline_radius_bottomleft:
                        Box<
                    longhands::_moz_outline_radius_bottomleft::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub _moz_outline_radius_topleft:
                    &'a longhands::_moz_outline_radius_topleft::SpecifiedValue,
                pub _moz_outline_radius_topright:
                    &'a longhands::_moz_outline_radius_topright::SpecifiedValue,
                pub _moz_outline_radius_bottomright:
                    &'a longhands::_moz_outline_radius_bottomright::SpecifiedValue,
                pub _moz_outline_radius_bottomleft:
                    &'a longhands::_moz_outline_radius_bottomleft::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut _moz_outline_radius_topleft = None;
                    let mut _moz_outline_radius_topright = None;
                    let mut _moz_outline_radius_bottomright = None;
                    let mut _moz_outline_radius_bottomleft = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::MozOutlineRadiusTopleft(ref value) => {
                                _moz_outline_radius_topleft = Some(value)
                            },
                            PropertyDeclaration::MozOutlineRadiusTopright(ref value) => {
                                _moz_outline_radius_topright = Some(value)
                            },
                            PropertyDeclaration::MozOutlineRadiusBottomright(ref value) => {
                                _moz_outline_radius_bottomright = Some(value)
                            },
                            PropertyDeclaration::MozOutlineRadiusBottomleft(ref value) => {
                                _moz_outline_radius_bottomleft = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        _moz_outline_radius_topleft,
                        _moz_outline_radius_topright,
                        _moz_outline_radius_bottomright,
                        _moz_outline_radius_bottomleft,
                ) {

                    (
                        Some(_moz_outline_radius_topleft),
                        Some(_moz_outline_radius_topright),
                        Some(_moz_outline_radius_bottomright),
                        Some(_moz_outline_radius_bottomleft),
                    ) =>
                    Ok(LonghandsToSerialize {
                            _moz_outline_radius_topleft,
                            _moz_outline_radius_topright,
                            _moz_outline_radius_bottomright,
                            _moz_outline_radius_bottomleft,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MozOutlineRadiusTopleft(
                        longhands._moz_outline_radius_topleft
                    ));
                    declarations.push(PropertyDeclaration::MozOutlineRadiusTopright(
                        longhands._moz_outline_radius_topright
                    ));
                    declarations.push(PropertyDeclaration::MozOutlineRadiusBottomright(
                        longhands._moz_outline_radius_bottomright
                    ));
                    declarations.push(PropertyDeclaration::MozOutlineRadiusBottomleft(
                        longhands._moz_outline_radius_bottomleft
                    ));
            })
        }

        
    use values::generics::rect::Rect;
    use values::specified::border::BorderRadius;
    use parser::Parse;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let radii = BorderRadius::parse(context, input)?;
        Ok(expanded! {
            _moz_outline_radius_topleft: radii.top_left,
            _moz_outline_radius_topright: radii.top_right,
            _moz_outline_radius_bottomright: radii.bottom_right,
            _moz_outline_radius_bottomleft: radii.bottom_left,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            use values::generics::border::BorderCornerRadius;

            let LonghandsToSerialize {
                _moz_outline_radius_topleft: &BorderCornerRadius(ref tl),
                _moz_outline_radius_topright: &BorderCornerRadius(ref tr),
                _moz_outline_radius_bottomright: &BorderCornerRadius(ref br),
                _moz_outline_radius_bottomleft: &BorderCornerRadius(ref bl),
            } = *self;

            let widths = Rect::new(tl.width(), tr.width(), br.width(), bl.width());
            let heights = Rect::new(tl.height(), tr.height(), br.height(), bl.height());

            BorderRadius::serialize_rects(widths, heights, dest)
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */




    
    

    /// https://drafts.csswg.org/css-box-3/#propdef-padding
    pub mod padding {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub padding_top:
                    longhands::padding_top::SpecifiedValue
                    ,
                pub padding_right:
                    longhands::padding_right::SpecifiedValue
                    ,
                pub padding_bottom:
                    longhands::padding_bottom::SpecifiedValue
                    ,
                pub padding_left:
                    longhands::padding_left::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub padding_top:
                    &'a longhands::padding_top::SpecifiedValue,
                pub padding_right:
                    &'a longhands::padding_right::SpecifiedValue,
                pub padding_bottom:
                    &'a longhands::padding_bottom::SpecifiedValue,
                pub padding_left:
                    &'a longhands::padding_left::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut padding_top = None;
                    let mut padding_right = None;
                    let mut padding_bottom = None;
                    let mut padding_left = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::PaddingTop(ref value) => {
                                padding_top = Some(value)
                            },
                            PropertyDeclaration::PaddingRight(ref value) => {
                                padding_right = Some(value)
                            },
                            PropertyDeclaration::PaddingBottom(ref value) => {
                                padding_bottom = Some(value)
                            },
                            PropertyDeclaration::PaddingLeft(ref value) => {
                                padding_left = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        padding_top,
                        padding_right,
                        padding_bottom,
                        padding_left,
                ) {

                    (
                        Some(padding_top),
                        Some(padding_right),
                        Some(padding_bottom),
                        Some(padding_left),
                    ) =>
                    Ok(LonghandsToSerialize {
                            padding_top,
                            padding_right,
                            padding_bottom,
                            padding_left,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::PaddingTop(
                        longhands.padding_top
                    ));
                    declarations.push(PropertyDeclaration::PaddingRight(
                        longhands.padding_right
                    ));
                    declarations.push(PropertyDeclaration::PaddingBottom(
                        longhands.padding_bottom
                    ));
                    declarations.push(PropertyDeclaration::PaddingLeft(
                        longhands.padding_left
                    ));
            })
        }

        
        #[allow(unused_imports)]
        use parser::Parse;
        use values::generics::rect::Rect;
        use values::specified;

        pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                   -> Result<Longhands, ParseError<'i>> {
            let rect = Rect::parse_with(context, input, |_c, i| {
                specified::NonNegativeLengthOrPercentage::parse_quirky(_c, i, specified::AllowQuirks::Yes)
            })?;
            Ok(expanded! {
                    padding_top: rect.0,
                    padding_right: rect.1,
                    padding_bottom: rect.2,
                    padding_left: rect.3,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a> {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let rect = Rect::new(
                    &self.padding_top,
                    &self.padding_right,
                    &self.padding_bottom,
                    &self.padding_left,
                );
                rect.to_css(dest)
            }
        }
    
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-flexbox/#flex-flow-property
    pub mod flex_flow {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub flex_direction:
                    longhands::flex_direction::SpecifiedValue
                    ,
                pub flex_wrap:
                    longhands::flex_wrap::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub flex_direction:
                    &'a longhands::flex_direction::SpecifiedValue,
                pub flex_wrap:
                    &'a longhands::flex_wrap::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut flex_direction = None;
                    let mut flex_wrap = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::FlexDirection(ref value) => {
                                flex_direction = Some(value)
                            },
                            PropertyDeclaration::FlexWrap(ref value) => {
                                flex_wrap = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        flex_direction,
                        flex_wrap,
                ) {

                    (
                        Some(flex_direction),
                        Some(flex_wrap),
                    ) =>
                    Ok(LonghandsToSerialize {
                            flex_direction,
                            flex_wrap,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::FlexDirection(
                        longhands.flex_direction
                    ));
                    declarations.push(PropertyDeclaration::FlexWrap(
                        longhands.flex_wrap
                    ));
            })
        }

        
    use properties::longhands::{flex_direction, flex_wrap};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut direction = None;
        let mut wrap = None;
        loop {
            if direction.is_none() {
                if let Ok(value) = input.try(|input| flex_direction::parse(context, input)) {
                    direction = Some(value);
                    continue
                }
            }
            if wrap.is_none() {
                if let Ok(value) = input.try(|input| flex_wrap::parse(context, input)) {
                    wrap = Some(value);
                    continue
                }
            }
            break
        }

        if direction.is_none() && wrap.is_none() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
        Ok(expanded! {
            flex_direction: unwrap_or_initial!(flex_direction, direction),
            flex_wrap: unwrap_or_initial!(flex_wrap, wrap),
        })
    }

    }




    /// https://drafts.csswg.org/css-flexbox/#flex-property
    pub mod flex {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub flex_grow:
                    longhands::flex_grow::SpecifiedValue
                    ,
                pub flex_shrink:
                    longhands::flex_shrink::SpecifiedValue
                    ,
                pub flex_basis:
                    longhands::flex_basis::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub flex_grow:
                    &'a longhands::flex_grow::SpecifiedValue,
                pub flex_shrink:
                    &'a longhands::flex_shrink::SpecifiedValue,
                pub flex_basis:
                    &'a longhands::flex_basis::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut flex_grow = None;
                    let mut flex_shrink = None;
                    let mut flex_basis = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::FlexGrow(ref value) => {
                                flex_grow = Some(value)
                            },
                            PropertyDeclaration::FlexShrink(ref value) => {
                                flex_shrink = Some(value)
                            },
                            PropertyDeclaration::FlexBasis(ref value) => {
                                flex_basis = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        flex_grow,
                        flex_shrink,
                        flex_basis,
                ) {

                    (
                        Some(flex_grow),
                        Some(flex_shrink),
                        Some(flex_basis),
                    ) =>
                    Ok(LonghandsToSerialize {
                            flex_grow,
                            flex_shrink,
                            flex_basis,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::FlexGrow(
                        longhands.flex_grow
                    ));
                    declarations.push(PropertyDeclaration::FlexShrink(
                        longhands.flex_shrink
                    ));
                    declarations.push(PropertyDeclaration::FlexBasis(
                        longhands.flex_basis
                    ));
            })
        }

        
    use parser::Parse;
    use values::specified::NonNegativeNumber;
    use properties::longhands::flex_basis::SpecifiedValue as FlexBasis;

    fn parse_flexibility<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                 -> Result<(NonNegativeNumber, Option<NonNegativeNumber>),ParseError<'i>> {
        let grow = NonNegativeNumber::parse(context, input)?;
        let shrink = input.try(|i| NonNegativeNumber::parse(context, i)).ok();
        Ok((grow, shrink))
    }

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut grow = None;
        let mut shrink = None;
        let mut basis = None;

        if input.try(|input| input.expect_ident_matching("none")).is_ok() {
            return Ok(expanded! {
                flex_grow: NonNegativeNumber::new(0.0),
                flex_shrink: NonNegativeNumber::new(0.0),
                flex_basis: FlexBasis::auto(),
            })
        }
        loop {
            if grow.is_none() {
                if let Ok((flex_grow, flex_shrink)) = input.try(|i| parse_flexibility(context, i)) {
                    grow = Some(flex_grow);
                    shrink = flex_shrink;
                    continue
                }
            }
            if basis.is_none() {
                if let Ok(value) = input.try(|input| FlexBasis::parse(context, input)) {
                    basis = Some(value);
                    continue
                }
            }
            break
        }

        if grow.is_none() && basis.is_none() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
        Ok(expanded! {
            flex_grow: grow.unwrap_or(NonNegativeNumber::new(1.0)),
            flex_shrink: shrink.unwrap_or(NonNegativeNumber::new(1.0)),
            // Per spec, this should be SpecifiedValue::zero(), but all
            // browsers currently agree on using `0%`. This is a spec
            // change which hasn't been adopted by browsers:
            // https://github.com/w3c/csswg-drafts/commit/2c446befdf0f686217905bdd7c92409f6bd3921b
            flex_basis: basis.unwrap_or(FlexBasis::zero_percent()),
        })
    }

    }




    /// https://drafts.csswg.org/css-grid/#propdef-grid-gap
    pub mod grid_gap {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub grid_row_gap:
                    longhands::grid_row_gap::SpecifiedValue
                    ,
                pub grid_column_gap:
                    longhands::grid_column_gap::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_row_gap:
                    &'a longhands::grid_row_gap::SpecifiedValue,
                pub grid_column_gap:
                    &'a longhands::grid_column_gap::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_row_gap = None;
                    let mut grid_column_gap = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::GridRowGap(ref value) => {
                                grid_row_gap = Some(value)
                            },
                            PropertyDeclaration::GridColumnGap(ref value) => {
                                grid_column_gap = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_row_gap,
                        grid_column_gap,
                ) {

                    (
                        Some(grid_row_gap),
                        Some(grid_column_gap),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_row_gap,
                            grid_column_gap,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridRowGap(
                        longhands.grid_row_gap
                    ));
                    declarations.push(PropertyDeclaration::GridColumnGap(
                        longhands.grid_column_gap
                    ));
            })
        }

        
  use properties::longhands::{grid_row_gap, grid_column_gap};

  pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<Longhands, ParseError<'i>> {
      let row_gap = grid_row_gap::parse(context, input)?;
      let column_gap = input.try(|input| grid_column_gap::parse(context, input)).unwrap_or(row_gap.clone());

      Ok(expanded! {
        grid_row_gap: row_gap,
        grid_column_gap: column_gap,
      })
  }

  impl<'a> ToCss for LonghandsToSerialize<'a>  {
      fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
          if self.grid_row_gap == self.grid_column_gap {
            self.grid_row_gap.to_css(dest)
          } else {
            self.grid_row_gap.to_css(dest)?;
            dest.write_str(" ")?;
            self.grid_column_gap.to_css(dest)
          }
      }
  }


    }




    /// https://drafts.csswg.org/css-grid/#propdef-grid-row
    pub mod grid_row {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub grid_row_start:
                        Box<
                    longhands::grid_row_start::SpecifiedValue
                        >
                    ,
                pub grid_row_end:
                        Box<
                    longhands::grid_row_end::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_row_start:
                    &'a longhands::grid_row_start::SpecifiedValue,
                pub grid_row_end:
                    &'a longhands::grid_row_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_row_start = None;
                    let mut grid_row_end = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::GridRowStart(ref value) => {
                                grid_row_start = Some(value)
                            },
                            PropertyDeclaration::GridRowEnd(ref value) => {
                                grid_row_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_row_start,
                        grid_row_end,
                ) {

                    (
                        Some(grid_row_start),
                        Some(grid_row_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_row_start,
                            grid_row_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridRowStart(
                        longhands.grid_row_start
                    ));
                    declarations.push(PropertyDeclaration::GridRowEnd(
                        longhands.grid_row_end
                    ));
            })
        }

        
    use values::specified::GridLine;
    use parser::Parse;

    // NOTE: Since both the shorthands have the same code, we should (re-)use code from one to implement
    // the other. This might not be a big deal for now, but we should consider looking into this in the future
    // to limit the amount of code generated.
    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let start = input.try(|i| GridLine::parse(context, i))?;
        let end = if input.try(|i| i.expect_delim('/')).is_ok() {
            GridLine::parse(context, input)?
        } else {
            let mut line = GridLine::auto();
            if start.line_num.is_none() && !start.is_span {
                line.ident = start.ident.clone();       // ident from start value should be taken
            }

            line
        };

        Ok(expanded! {
            grid_row_start: start,
            grid_row_end: end,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.grid_row_start.to_css(dest)?;
            dest.write_str(" / ")?;
            self.grid_row_end.to_css(dest)
        }
    }

    }



    /// https://drafts.csswg.org/css-grid/#propdef-grid-column
    pub mod grid_column {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub grid_column_start:
                        Box<
                    longhands::grid_column_start::SpecifiedValue
                        >
                    ,
                pub grid_column_end:
                        Box<
                    longhands::grid_column_end::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_column_start:
                    &'a longhands::grid_column_start::SpecifiedValue,
                pub grid_column_end:
                    &'a longhands::grid_column_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_column_start = None;
                    let mut grid_column_end = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::GridColumnStart(ref value) => {
                                grid_column_start = Some(value)
                            },
                            PropertyDeclaration::GridColumnEnd(ref value) => {
                                grid_column_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_column_start,
                        grid_column_end,
                ) {

                    (
                        Some(grid_column_start),
                        Some(grid_column_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_column_start,
                            grid_column_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridColumnStart(
                        longhands.grid_column_start
                    ));
                    declarations.push(PropertyDeclaration::GridColumnEnd(
                        longhands.grid_column_end
                    ));
            })
        }

        
    use values::specified::GridLine;
    use parser::Parse;

    // NOTE: Since both the shorthands have the same code, we should (re-)use code from one to implement
    // the other. This might not be a big deal for now, but we should consider looking into this in the future
    // to limit the amount of code generated.
    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let start = input.try(|i| GridLine::parse(context, i))?;
        let end = if input.try(|i| i.expect_delim('/')).is_ok() {
            GridLine::parse(context, input)?
        } else {
            let mut line = GridLine::auto();
            if start.line_num.is_none() && !start.is_span {
                line.ident = start.ident.clone();       // ident from start value should be taken
            }

            line
        };

        Ok(expanded! {
            grid_column_start: start,
            grid_column_end: end,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.grid_column_start.to_css(dest)?;
            dest.write_str(" / ")?;
            self.grid_column_end.to_css(dest)
        }
    }

    }




    /// https://drafts.csswg.org/css-grid/#propdef-grid-area
    pub mod grid_area {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub grid_row_start:
                        Box<
                    longhands::grid_row_start::SpecifiedValue
                        >
                    ,
                pub grid_row_end:
                        Box<
                    longhands::grid_row_end::SpecifiedValue
                        >
                    ,
                pub grid_column_start:
                        Box<
                    longhands::grid_column_start::SpecifiedValue
                        >
                    ,
                pub grid_column_end:
                        Box<
                    longhands::grid_column_end::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_row_start:
                    &'a longhands::grid_row_start::SpecifiedValue,
                pub grid_row_end:
                    &'a longhands::grid_row_end::SpecifiedValue,
                pub grid_column_start:
                    &'a longhands::grid_column_start::SpecifiedValue,
                pub grid_column_end:
                    &'a longhands::grid_column_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_row_start = None;
                    let mut grid_row_end = None;
                    let mut grid_column_start = None;
                    let mut grid_column_end = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::GridRowStart(ref value) => {
                                grid_row_start = Some(value)
                            },
                            PropertyDeclaration::GridRowEnd(ref value) => {
                                grid_row_end = Some(value)
                            },
                            PropertyDeclaration::GridColumnStart(ref value) => {
                                grid_column_start = Some(value)
                            },
                            PropertyDeclaration::GridColumnEnd(ref value) => {
                                grid_column_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_row_start,
                        grid_row_end,
                        grid_column_start,
                        grid_column_end,
                ) {

                    (
                        Some(grid_row_start),
                        Some(grid_row_end),
                        Some(grid_column_start),
                        Some(grid_column_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_row_start,
                            grid_row_end,
                            grid_column_start,
                            grid_column_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridRowStart(
                        longhands.grid_row_start
                    ));
                    declarations.push(PropertyDeclaration::GridRowEnd(
                        longhands.grid_row_end
                    ));
                    declarations.push(PropertyDeclaration::GridColumnStart(
                        longhands.grid_column_start
                    ));
                    declarations.push(PropertyDeclaration::GridColumnEnd(
                        longhands.grid_column_end
                    ));
            })
        }

        
    use values::specified::GridLine;
    use parser::Parse;

    // The code is the same as `grid-{row,column}` except that this can have four values at most.
    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        fn line_with_ident_from(other: &GridLine) -> GridLine {
            let mut this = GridLine::auto();
            if other.line_num.is_none() && !other.is_span {
                this.ident = other.ident.clone();
            }

            this
        }

        let row_start = input.try(|i| GridLine::parse(context, i))?;
        let (column_start, row_end, column_end) = if input.try(|i| i.expect_delim('/')).is_ok() {
            let column_start = GridLine::parse(context, input)?;
            let (row_end, column_end) = if input.try(|i| i.expect_delim('/')).is_ok() {
                let row_end = GridLine::parse(context, input)?;
                let column_end = if input.try(|i| i.expect_delim('/')).is_ok() {
                    GridLine::parse(context, input)?
                } else {        // grid-column-end has not been given
                    line_with_ident_from(&column_start)
                };

                (row_end, column_end)
            } else {        // grid-row-start and grid-column-start has been given
                let row_end = line_with_ident_from(&row_start);
                let column_end = line_with_ident_from(&column_start);
                (row_end, column_end)
            };

            (column_start, row_end, column_end)
        } else {        // only grid-row-start is given
            let line = line_with_ident_from(&row_start);
            (line.clone(), line.clone(), line)
        };

        Ok(expanded! {
            grid_row_start: row_start,
            grid_row_end: row_end,
            grid_column_start: column_start,
            grid_column_end: column_end,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.grid_row_start.to_css(dest)?;
            let values = [&self.grid_column_start, &self.grid_row_end, &self.grid_column_end];
            for value in &values {
                dest.write_str(" / ")?;
                value.to_css(dest)?;
            }

            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-grid/#propdef-grid-template
    pub mod grid_template {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub grid_template_rows:
                        Box<
                    longhands::grid_template_rows::SpecifiedValue
                        >
                    ,
                pub grid_template_columns:
                        Box<
                    longhands::grid_template_columns::SpecifiedValue
                        >
                    ,
                pub grid_template_areas:
                    longhands::grid_template_areas::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_template_rows:
                    &'a longhands::grid_template_rows::SpecifiedValue,
                pub grid_template_columns:
                    &'a longhands::grid_template_columns::SpecifiedValue,
                pub grid_template_areas:
                    &'a longhands::grid_template_areas::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_template_rows = None;
                    let mut grid_template_columns = None;
                    let mut grid_template_areas = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::GridTemplateRows(ref value) => {
                                grid_template_rows = Some(value)
                            },
                            PropertyDeclaration::GridTemplateColumns(ref value) => {
                                grid_template_columns = Some(value)
                            },
                            PropertyDeclaration::GridTemplateAreas(ref value) => {
                                grid_template_areas = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_template_rows,
                        grid_template_columns,
                        grid_template_areas,
                ) {

                    (
                        Some(grid_template_rows),
                        Some(grid_template_columns),
                        Some(grid_template_areas),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_template_rows,
                            grid_template_columns,
                            grid_template_areas,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridTemplateRows(
                        longhands.grid_template_rows
                    ));
                    declarations.push(PropertyDeclaration::GridTemplateColumns(
                        longhands.grid_template_columns
                    ));
                    declarations.push(PropertyDeclaration::GridTemplateAreas(
                        longhands.grid_template_areas
                    ));
            })
        }

        
    use parser::Parse;
    use servo_arc::Arc;
    use values::{Either, None_};
    use values::generics::grid::{LineNameList, TrackSize, TrackList, TrackListType};
    use values::generics::grid::{TrackListValue, concat_serialize_idents};
    use values::specified::{GridTemplateComponent, GenericGridTemplateComponent};
    use values::specified::grid::parse_line_names;
    use values::specified::position::{TemplateAreas, TemplateAreasArc};

    /// Parsing for `<grid-template>` shorthand (also used by `grid` shorthand).
    pub fn parse_grid_template<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                       -> Result<(GridTemplateComponent,
                                                  GridTemplateComponent,
                                                  Either<TemplateAreasArc, None_>), ParseError<'i>> {
        // Other shorthand sub properties also parse `none` and `subgrid` keywords and this
        // shorthand should know after these keywords there is nothing to parse. Otherwise it
        // gets confused and rejects the sub properties that contains `none` or `subgrid`.
        
            if let Ok(x) = input.try(|i| {
                if i.try(|i| i.expect_ident_matching("subgrid")).is_ok() {
                    if i.is_exhausted() {
                        return Ok((GenericGridTemplateComponent::Subgrid(LineNameList::default()),
                                   GenericGridTemplateComponent::Subgrid(LineNameList::default()),
                                   Either::Second(None_)))
                    } else {
                        return Err(());
                    }
                }
                Err(())
            }) {
                return Ok(x);
            }
            if let Ok(x) = input.try(|i| {
                if i.try(|i| i.expect_ident_matching("none")).is_ok() {
                    if i.is_exhausted() {
                        return Ok((GenericGridTemplateComponent::None,
                                   GenericGridTemplateComponent::None,
                                   Either::Second(None_)))
                    } else {
                        return Err(());
                    }
                }
                Err(())
            }) {
                return Ok(x);
            }

        let first_line_names = input.try(parse_line_names).unwrap_or(vec![].into_boxed_slice());
        if let Ok(mut string) = input.try(|i| i.expect_string().map(|s| s.as_ref().into())) {
            let mut strings = vec![];
            let mut values = vec![];
            let mut line_names = vec![];
            let mut names = first_line_names.into_vec();
            loop {
                line_names.push(names.into_boxed_slice());
                strings.push(string);
                let size = input.try(|i| TrackSize::parse(context, i)).unwrap_or_default();
                values.push(TrackListValue::TrackSize(size));
                names = input.try(parse_line_names).unwrap_or(vec![].into_boxed_slice()).into_vec();
                if let Ok(v) = input.try(parse_line_names) {
                    names.extend(v.into_vec());
                }

                string = match input.try(|i| i.expect_string().map(|s| s.as_ref().into())) {
                    Ok(s) => s,
                    _ => {      // only the named area determines whether we should bail out
                        line_names.push(names.into_boxed_slice());
                        break
                    },
                };
            }

            if line_names.len() == values.len() {
                // should be one longer than track sizes
                line_names.push(vec![].into_boxed_slice());
            }

            let template_areas = TemplateAreas::from_vec(strings)
                .map_err(|()| input.new_custom_error(StyleParseErrorKind::UnspecifiedError))?;
            let template_rows = TrackList {
                list_type: TrackListType::Normal,
                values: values,
                line_names: line_names.into_boxed_slice(),
                auto_repeat: None,
            };

            let template_cols = if input.try(|i| i.expect_delim('/')).is_ok() {
                let value = GridTemplateComponent::parse_without_none(context, input)?;
                if let GenericGridTemplateComponent::TrackList(ref list) = value {
                    if list.list_type != TrackListType::Explicit {
                        return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
                    }
                }

                value
            } else {
                GenericGridTemplateComponent::None
            };

            Ok((GenericGridTemplateComponent::TrackList(template_rows),
                template_cols, Either::First(TemplateAreasArc(Arc::new(template_areas)))))
        } else {
            let mut template_rows = GridTemplateComponent::parse(context, input)?;
            if let GenericGridTemplateComponent::TrackList(ref mut list) = template_rows {
                // Fist line names are parsed already and it shouldn't be parsed again.
                // If line names are not empty, that means given property value is not acceptable
                if list.line_names[0].is_empty() {
                    list.line_names[0] = first_line_names;      // won't panic
                } else {
                    return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
                }
            }

            input.expect_delim('/')?;
            Ok((template_rows, GridTemplateComponent::parse(context, input)?, Either::Second(None_)))
        }
    }

    #[inline]
    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (rows, columns, areas) = parse_grid_template(context, input)?;
        Ok(expanded! {
            grid_template_rows: rows,
            grid_template_columns: columns,
            grid_template_areas: areas,
        })
    }

    /// Serialization for `<grid-template>` shorthand (also used by `grid` shorthand).
    pub fn serialize_grid_template<W>(
        template_rows: &GridTemplateComponent,
        template_columns: &GridTemplateComponent,
        template_areas: &Either<TemplateAreasArc, None_>,
        dest: &mut CssWriter<W>,
    ) -> fmt::Result
    where
        W: Write {
        match *template_areas {
            Either::Second(_none) => {
                template_rows.to_css(dest)?;
                dest.write_str(" / ")?;
                template_columns.to_css(dest)
            },
            Either::First(ref areas) => {
                // The length of template-area and template-rows values should be equal.
                if areas.0.strings.len() != template_rows.track_list_len() {
                    return Ok(());
                }

                let track_list = match *template_rows {
                    GenericGridTemplateComponent::TrackList(ref list) => {
                        // We should fail if there is a `repeat` function. `grid` and
                        // `grid-template` shorthands doesn't accept that. Only longhand accepts.
                        if list.auto_repeat.is_some() ||
                           list.values.iter().any(|v| match *v {
                               TrackListValue::TrackRepeat(_) => true,
                               _ => false,
                           }) {
                            return Ok(());
                        }
                        list
                    },
                    // Others template components shouldn't exist with normal shorthand values.
                    // But if we need to serialize a group of longhand sub-properties for
                    // the shorthand, we should be able to return empty string instead of crashing.
                    _ => return Ok(()),
                };

                // We need to check some values that longhand accepts but shorthands don't.
                match *template_columns {
                    // We should fail if there is a `repeat` function. `grid` and
                    // `grid-template` shorthands doesn't accept that. Only longhand accepts that.
                    GenericGridTemplateComponent::TrackList(ref list) => {
                        if list.auto_repeat.is_some() ||
                           list.values.iter().any(|v| match *v {
                               TrackListValue::TrackRepeat(_) => true,
                               _ => false,
                           }) {
                            return Ok(());
                        }
                    },
                    // Also the shorthands don't accept subgrids unlike longhand.
                    // We should fail without an error here.
                    GenericGridTemplateComponent::Subgrid(_) => {
                        return Ok(());
                    },
                    _ => {},
                }

                let mut names_iter = track_list.line_names.iter();
                for (((i, string), names), value) in areas.0.strings.iter().enumerate()
                                                                  .zip(&mut names_iter)
                                                                  .zip(track_list.values.iter()) {
                    if i > 0 {
                        dest.write_str(" ")?;
                    }

                    if !names.is_empty() {
                        concat_serialize_idents("[", "] ", names, " ", dest)?;
                    }

                    string.to_css(dest)?;
                    dest.write_str(" ")?;
                    value.to_css(dest)?;
                }

                if let Some(names) = names_iter.next() {
                    concat_serialize_idents(" [", "]", names, " ", dest)?;
                }

                if let GenericGridTemplateComponent::TrackList(ref list) = *template_columns {
                    dest.write_str(" / ")?;
                    list.to_css(dest)?;
                }

                Ok(())
            },
        }
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        #[inline]
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            serialize_grid_template(
                self.grid_template_rows,
                self.grid_template_columns,
                self.grid_template_areas,
                dest
            )
        }
    }

    }




    /// https://drafts.csswg.org/css-grid/#propdef-grid
    pub mod grid {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub grid_template_rows:
                        Box<
                    longhands::grid_template_rows::SpecifiedValue
                        >
                    ,
                pub grid_template_columns:
                        Box<
                    longhands::grid_template_columns::SpecifiedValue
                        >
                    ,
                pub grid_template_areas:
                    longhands::grid_template_areas::SpecifiedValue
                    ,
                pub grid_auto_rows:
                        Box<
                    longhands::grid_auto_rows::SpecifiedValue
                        >
                    ,
                pub grid_auto_columns:
                        Box<
                    longhands::grid_auto_columns::SpecifiedValue
                        >
                    ,
                pub grid_auto_flow:
                    longhands::grid_auto_flow::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_template_rows:
                    &'a longhands::grid_template_rows::SpecifiedValue,
                pub grid_template_columns:
                    &'a longhands::grid_template_columns::SpecifiedValue,
                pub grid_template_areas:
                    &'a longhands::grid_template_areas::SpecifiedValue,
                pub grid_auto_rows:
                    &'a longhands::grid_auto_rows::SpecifiedValue,
                pub grid_auto_columns:
                    &'a longhands::grid_auto_columns::SpecifiedValue,
                pub grid_auto_flow:
                    &'a longhands::grid_auto_flow::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_template_rows = None;
                    let mut grid_template_columns = None;
                    let mut grid_template_areas = None;
                    let mut grid_auto_rows = None;
                    let mut grid_auto_columns = None;
                    let mut grid_auto_flow = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::GridTemplateRows(ref value) => {
                                grid_template_rows = Some(value)
                            },
                            PropertyDeclaration::GridTemplateColumns(ref value) => {
                                grid_template_columns = Some(value)
                            },
                            PropertyDeclaration::GridTemplateAreas(ref value) => {
                                grid_template_areas = Some(value)
                            },
                            PropertyDeclaration::GridAutoRows(ref value) => {
                                grid_auto_rows = Some(value)
                            },
                            PropertyDeclaration::GridAutoColumns(ref value) => {
                                grid_auto_columns = Some(value)
                            },
                            PropertyDeclaration::GridAutoFlow(ref value) => {
                                grid_auto_flow = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_template_rows,
                        grid_template_columns,
                        grid_template_areas,
                        grid_auto_rows,
                        grid_auto_columns,
                        grid_auto_flow,
                ) {

                    (
                        Some(grid_template_rows),
                        Some(grid_template_columns),
                        Some(grid_template_areas),
                        Some(grid_auto_rows),
                        Some(grid_auto_columns),
                        Some(grid_auto_flow),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_template_rows,
                            grid_template_columns,
                            grid_template_areas,
                            grid_auto_rows,
                            grid_auto_columns,
                            grid_auto_flow,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridTemplateRows(
                        longhands.grid_template_rows
                    ));
                    declarations.push(PropertyDeclaration::GridTemplateColumns(
                        longhands.grid_template_columns
                    ));
                    declarations.push(PropertyDeclaration::GridTemplateAreas(
                        longhands.grid_template_areas
                    ));
                    declarations.push(PropertyDeclaration::GridAutoRows(
                        longhands.grid_auto_rows
                    ));
                    declarations.push(PropertyDeclaration::GridAutoColumns(
                        longhands.grid_auto_columns
                    ));
                    declarations.push(PropertyDeclaration::GridAutoFlow(
                        longhands.grid_auto_flow
                    ));
            })
        }

        
    use parser::Parse;
    use properties::longhands::{grid_auto_columns, grid_auto_rows, grid_auto_flow};
    use values::{Either, None_};
    use values::generics::grid::{GridTemplateComponent, TrackListType};
    use values::specified::{GenericGridTemplateComponent, TrackSize};
    use values::specified::position::{AutoFlow, GridAutoFlow};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut temp_rows = GridTemplateComponent::None;
        let mut temp_cols = GridTemplateComponent::None;
        let mut temp_areas = Either::Second(None_);
        let mut auto_rows = TrackSize::default();
        let mut auto_cols = TrackSize::default();
        let mut flow = grid_auto_flow::get_initial_value();

        fn parse_auto_flow<'i, 't>(input: &mut Parser<'i, 't>, is_row: bool)
                                   -> Result<GridAutoFlow, ParseError<'i>> {
            let mut auto_flow = None;
            let mut dense = false;
            for _ in 0..2 {
                if input.try(|i| i.expect_ident_matching("auto-flow")).is_ok() {
                    auto_flow = if is_row {
                        Some(AutoFlow::Row)
                    } else {
                        Some(AutoFlow::Column)
                    };
                } else if input.try(|i| i.expect_ident_matching("dense")).is_ok() {
                    dense = true;
                } else {
                    break
                }
            }

            auto_flow.map(|flow| {
                GridAutoFlow {
                    autoflow: flow,
                    dense: dense,
                }
            }).ok_or(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }

        if let Ok((rows, cols, areas)) = input.try(|i| super::grid_template::parse_grid_template(context, i)) {
            temp_rows = rows;
            temp_cols = cols;
            temp_areas = areas;
        } else if let Ok(rows) = input.try(|i| GridTemplateComponent::parse(context, i)) {
            temp_rows = rows;
            input.expect_delim('/')?;
            flow = parse_auto_flow(input, false)?;
            auto_cols = grid_auto_columns::parse(context, input).unwrap_or_default();
        } else {
            flow = parse_auto_flow(input, true)?;
            auto_rows = input.try(|i| grid_auto_rows::parse(context, i)).unwrap_or_default();
            input.expect_delim('/')?;
            temp_cols = GridTemplateComponent::parse(context, input)?;
        }

        Ok(expanded! {
            grid_template_rows: temp_rows,
            grid_template_columns: temp_cols,
            grid_template_areas: temp_areas,
            grid_auto_rows: auto_rows,
            grid_auto_columns: auto_cols,
            grid_auto_flow: flow,
        })
    }

    impl<'a> LonghandsToSerialize<'a> {
        /// Returns true if other sub properties except template-{rows,columns} are initial.
        fn is_grid_template(&self) -> bool {
            *self.grid_template_areas == Either::Second(None_) &&
            *self.grid_auto_rows == TrackSize::default() &&
            *self.grid_auto_columns == TrackSize::default() &&
            *self.grid_auto_flow == grid_auto_flow::get_initial_value()
        }
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if *self.grid_template_areas != Either::Second(None_) ||
               (*self.grid_template_rows != GridTemplateComponent::None &&
                   *self.grid_template_columns != GridTemplateComponent::None) ||
               self.is_grid_template() {
                return super::grid_template::serialize_grid_template(self.grid_template_rows,
                                                                     self.grid_template_columns,
                                                                     self.grid_template_areas, dest);
            }

            if self.grid_auto_flow.autoflow == AutoFlow::Column {
                // It should fail to serialize if other branch of the if condition's values are set.
                if *self.grid_auto_rows != TrackSize::default() ||
                   *self.grid_template_columns != GridTemplateComponent::None {
                    return Ok(());
                }

                // It should fail to serialize if template-rows value is not Explicit.
                if let GenericGridTemplateComponent::TrackList(ref list) = *self.grid_template_rows {
                    if list.list_type != TrackListType::Explicit {
                        return Ok(());
                    }
                }

                self.grid_template_rows.to_css(dest)?;
                dest.write_str(" / auto-flow")?;
                if self.grid_auto_flow.dense {
                    dest.write_str(" dense")?;
                }

                if !self.grid_auto_columns.is_default() {
                    dest.write_str(" ")?;
                    self.grid_auto_columns.to_css(dest)?;
                }
            } else {
                // It should fail to serialize if other branch of the if condition's values are set.
                if *self.grid_auto_columns != TrackSize::default() ||
                   *self.grid_template_rows != GridTemplateComponent::None {
                    return Ok(());
                }

                // It should fail to serialize if template-column value is not Explicit.
                if let GenericGridTemplateComponent::TrackList(ref list) = *self.grid_template_columns {
                    if list.list_type != TrackListType::Explicit {
                        return Ok(());
                    }
                }

                dest.write_str("auto-flow")?;
                if self.grid_auto_flow.dense {
                    dest.write_str(" dense")?;
                }

                if !self.grid_auto_rows.is_default() {
                    dest.write_str(" ")?;
                    self.grid_auto_rows.to_css(dest)?;
                }

                dest.write_str(" / ")?;
                self.grid_template_columns.to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-align/#propdef-place-content
    pub mod place_content {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub align_content:
                    longhands::align_content::SpecifiedValue
                    ,
                pub justify_content:
                    longhands::justify_content::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub align_content:
                    &'a longhands::align_content::SpecifiedValue,
                pub justify_content:
                    &'a longhands::justify_content::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut align_content = None;
                    let mut justify_content = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::AlignContent(ref value) => {
                                align_content = Some(value)
                            },
                            PropertyDeclaration::JustifyContent(ref value) => {
                                justify_content = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        align_content,
                        justify_content,
                ) {

                    (
                        Some(align_content),
                        Some(justify_content),
                    ) =>
                    Ok(LonghandsToSerialize {
                            align_content,
                            justify_content,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::AlignContent(
                        longhands.align_content
                    ));
                    declarations.push(PropertyDeclaration::JustifyContent(
                        longhands.justify_content
                    ));
            })
        }

        
    use values::specified::align::{AlignContent, JustifyContent, ContentDistribution, AxisDirection};

    pub fn parse_value<'i, 't>(
        _: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let align_content =
            ContentDistribution::parse(input, AxisDirection::Block)?;

        let justify_content = input.try(|input| {
            ContentDistribution::parse(input, AxisDirection::Inline)
        });

        let justify_content = match justify_content {
            Ok(v) => v,
            Err(err) => {
                if !align_content.is_valid_on_both_axes() {
                    return Err(err);
                }

                align_content
            }
        };

        if align_content.has_extra_flags() || justify_content.has_extra_flags() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }

        Ok(expanded! {
            align_content: AlignContent(align_content),
            justify_content: JustifyContent(justify_content),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.align_content.to_css(dest)?;
            if self.align_content.0 != self.justify_content.0 {
                dest.write_str(" ")?;
                self.justify_content.to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-align/#place-self-property
    pub mod place_self {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub align_self:
                    longhands::align_self::SpecifiedValue
                    ,
                pub justify_self:
                    longhands::justify_self::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub align_self:
                    &'a longhands::align_self::SpecifiedValue,
                pub justify_self:
                    &'a longhands::justify_self::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut align_self = None;
                    let mut justify_self = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::AlignSelf(ref value) => {
                                align_self = Some(value)
                            },
                            PropertyDeclaration::JustifySelf(ref value) => {
                                justify_self = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        align_self,
                        justify_self,
                ) {

                    (
                        Some(align_self),
                        Some(justify_self),
                    ) =>
                    Ok(LonghandsToSerialize {
                            align_self,
                            justify_self,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::AlignSelf(
                        longhands.align_self
                    ));
                    declarations.push(PropertyDeclaration::JustifySelf(
                        longhands.justify_self
                    ));
            })
        }

        
    use values::specified::align::{AlignSelf, JustifySelf, SelfAlignment, AxisDirection};

    pub fn parse_value<'i, 't>(
        _: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let align = SelfAlignment::parse(input, AxisDirection::Block)?;
        let justify = input.try(|input| SelfAlignment::parse(input, AxisDirection::Inline));

        let justify = match justify {
            Ok(v) => v,
            Err(err) => {
                if !align.is_valid_on_both_axes() {
                    return Err(err);
                }
                align
            }
        };

        if justify.has_extra_flags() || align.has_extra_flags() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }

        Ok(expanded! {
            align_self: AlignSelf(align),
            justify_self: JustifySelf(justify),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.align_self.to_css(dest)?;
            if self.align_self.0 != self.justify_self.0 {
                dest.write_str(" ")?;
                self.justify_self.to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-align/#place-items-property
    pub mod place_items {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub align_items:
                    longhands::align_items::SpecifiedValue
                    ,
                pub justify_items:
                    longhands::justify_items::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub align_items:
                    &'a longhands::align_items::SpecifiedValue,
                pub justify_items:
                    &'a longhands::justify_items::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut align_items = None;
                    let mut justify_items = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::AlignItems(ref value) => {
                                align_items = Some(value)
                            },
                            PropertyDeclaration::JustifyItems(ref value) => {
                                justify_items = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        align_items,
                        justify_items,
                ) {

                    (
                        Some(align_items),
                        Some(justify_items),
                    ) =>
                    Ok(LonghandsToSerialize {
                            align_items,
                            justify_items,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::AlignItems(
                        longhands.align_items
                    ));
                    declarations.push(PropertyDeclaration::JustifyItems(
                        longhands.justify_items
                    ));
            })
        }

        
    use values::specified::align::{AlignItems, JustifyItems};
    use parser::Parse;

    impl From<AlignItems> for JustifyItems {
        fn from(align: AlignItems) -> JustifyItems {
            JustifyItems(align.0)
        }
    }

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let align = AlignItems::parse(context, input)?;
        if align.has_extra_flags() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }
        let justify = input.try(|input| JustifyItems::parse(context, input))
                           .unwrap_or(JustifyItems::from(align));
        if justify.has_extra_flags() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }

        Ok(expanded! {
            align_items: align,
            justify_items: justify,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if self.align_items.has_extra_flags() ||
               self.justify_items.has_extra_flags() {
                return Ok(());
            }

            self.align_items.to_css(dest)?;
            if self.align_items.0 != self.justify_items.0 {
                dest.write_str(" ")?;
                self.justify_items.to_css(dest)?;
            }

            Ok(())
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://www.w3.org/TR/SVG2/painting.html#MarkerShorthand
    pub mod marker {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub marker_start:
                    longhands::marker_start::SpecifiedValue
                    ,
                pub marker_end:
                    longhands::marker_end::SpecifiedValue
                    ,
                pub marker_mid:
                    longhands::marker_mid::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub marker_start:
                    &'a longhands::marker_start::SpecifiedValue,
                pub marker_end:
                    &'a longhands::marker_end::SpecifiedValue,
                pub marker_mid:
                    &'a longhands::marker_mid::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut marker_start = None;
                    let mut marker_end = None;
                    let mut marker_mid = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::MarkerStart(ref value) => {
                                marker_start = Some(value)
                            },
                            PropertyDeclaration::MarkerEnd(ref value) => {
                                marker_end = Some(value)
                            },
                            PropertyDeclaration::MarkerMid(ref value) => {
                                marker_mid = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        marker_start,
                        marker_end,
                        marker_mid,
                ) {

                    (
                        Some(marker_start),
                        Some(marker_end),
                        Some(marker_mid),
                    ) =>
                    Ok(LonghandsToSerialize {
                            marker_start,
                            marker_end,
                            marker_mid,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MarkerStart(
                        longhands.marker_start
                    ));
                    declarations.push(PropertyDeclaration::MarkerEnd(
                        longhands.marker_end
                    ));
                    declarations.push(PropertyDeclaration::MarkerMid(
                        longhands.marker_mid
                    ));
            })
        }

        
    use values::specified::UrlOrNone;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        use parser::Parse;
        let url = UrlOrNone::parse(context, input)?;

        Ok(expanded! {
            marker_start: url.clone(),
            marker_mid: url.clone(),
            marker_end: url,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if self.marker_start == self.marker_mid && self.marker_mid == self.marker_end {
                self.marker_start.to_css(dest)
            } else {
                Ok(())
            }
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-text-decor/#propdef-text-decoration
    pub mod text_decoration {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub text_decoration_line:
                    longhands::text_decoration_line::SpecifiedValue
                    ,
                pub text_decoration_style:
                    longhands::text_decoration_style::SpecifiedValue
                    ,
                pub text_decoration_color:
                    longhands::text_decoration_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub text_decoration_line:
                    &'a longhands::text_decoration_line::SpecifiedValue,
                pub text_decoration_style:
                    &'a longhands::text_decoration_style::SpecifiedValue,
                pub text_decoration_color:
                    &'a longhands::text_decoration_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
            where
                I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut text_decoration_line = None;
                    let mut text_decoration_style = None;
                    let mut text_decoration_color = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::TextDecorationLine(ref value) => {
                                text_decoration_line = Some(value)
                            },
                            PropertyDeclaration::TextDecorationStyle(ref value) => {
                                text_decoration_style = Some(value)
                            },
                            PropertyDeclaration::TextDecorationColor(ref value) => {
                                text_decoration_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        text_decoration_line,
                        text_decoration_style,
                        text_decoration_color,
                ) {

                    (
                        Some(text_decoration_line),
                        Some(text_decoration_style),
                        Some(text_decoration_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            text_decoration_line,
                            text_decoration_style,
                            text_decoration_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::TextDecorationLine(
                        longhands.text_decoration_line
                    ));
                    declarations.push(PropertyDeclaration::TextDecorationStyle(
                        longhands.text_decoration_style
                    ));
                    declarations.push(PropertyDeclaration::TextDecorationColor(
                        longhands.text_decoration_color
                    ));
            })
        }

        

        use values::specified;
        use properties::longhands::{text_decoration_line, text_decoration_style, text_decoration_color};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
            let (mut line, mut style, mut color, mut any) = (None, None, None, false);

        loop {
            macro_rules! parse_component {
                ($value:ident, $module:ident) => (
                    if $value.is_none() {
                        if let Ok(value) = input.try(|input| $module::parse(context, input)) {
                            $value = Some(value);
                            any = true;
                            continue;
                        }
                    }
                )
            }

            parse_component!(line, text_decoration_line);

                parse_component!(style, text_decoration_style);
                parse_component!(color, text_decoration_color);

            break;
        }

        if !any {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }

        Ok(expanded! {
            text_decoration_line: unwrap_or_initial!(text_decoration_line, line),

                text_decoration_style: unwrap_or_initial!(text_decoration_style, style),
                text_decoration_color: unwrap_or_initial!(text_decoration_color, color),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.text_decoration_line.to_css(dest)?;

                if *self.text_decoration_style != text_decoration_style::SpecifiedValue::Solid {
                    dest.write_str(" ")?;
                    self.text_decoration_style.to_css(dest)?;
                }

                if *self.text_decoration_color != specified::Color::CurrentColor {
                    dest.write_str(" ")?;
                    self.text_decoration_color.to_css(dest)?;
                }

            Ok(())
        }
    }

    }



    // We don't defined the 'all' shorthand using the regular helpers:shorthand
    // mechanism, since it causes some very large types to be generated.
    //
    // Also, make sure logical properties appear before its physical
    // counter-parts, in order to prevent bugs like:
    //
    //   https://bugzilla.mozilla.org/show_bug.cgi?id=1410028
    //
    // FIXME(emilio): Adopt the resolution from:
    //
    //   https://github.com/w3c/csswg-drafts/issues/1898
    //
    // when there is one, whatever that is.
    

    /// The max amount of longhands that the `all` shorthand will ever contain.
    pub const ALL_SHORTHAND_MAX_LEN: usize = 309;
}



// WARNING: It is *really* important for the variants of `LonghandId`
// and `PropertyDeclaration` to be defined in the exact same order,
// with the exception of `CSSWideKeyword`, `WithVariables` and `Custom`,
// which don't exist in `LonghandId`.



/// Servo's representation for a property declaration.
#[repr(u16)]
pub enum PropertyDeclaration {
    /// `align-content`
    AlignContent(::values::specified::AlignContent),
    /// `align-items`
    AlignItems(::values::specified::AlignItems),
    /// `align-self`
    AlignSelf(::values::specified::AlignSelf),
    /// `backface-visibility`
    BackfaceVisibility(longhands::backface_visibility::SpecifiedValue),
    /// `border-collapse`
    BorderCollapse(longhands::border_collapse::SpecifiedValue),
    /// `border-image-repeat`
    BorderImageRepeat(::values::specified::BorderImageRepeat),
    /// `box-decoration-break`
    BoxDecorationBreak(longhands::box_decoration_break::SpecifiedValue),
    /// `box-sizing`
    BoxSizing(longhands::box_sizing::SpecifiedValue),
    /// `caption-side`
    CaptionSide(longhands::caption_side::SpecifiedValue),
    /// `clear`
    Clear(longhands::clear::SpecifiedValue),
    /// `clip-rule`
    ClipRule(longhands::clip_rule::SpecifiedValue),
    /// `color-adjust`
    ColorAdjust(longhands::color_adjust::SpecifiedValue),
    /// `color-interpolation`
    ColorInterpolation(longhands::color_interpolation::SpecifiedValue),
    /// `color-interpolation-filters`
    ColorInterpolationFilters(longhands::color_interpolation_filters::SpecifiedValue),
    /// `column-count`
    ColumnCount(::values::specified::ColumnCount),
    /// `column-fill`
    ColumnFill(longhands::column_fill::SpecifiedValue),
    /// `column-rule-style`
    ColumnRuleStyle(longhands::column_rule_style::SpecifiedValue),
    /// `column-span`
    ColumnSpan(longhands::column_span::SpecifiedValue),
    /// `contain`
    Contain(::values::specified::Contain),
    /// `direction`
    Direction(longhands::direction::SpecifiedValue),
    /// `dominant-baseline`
    DominantBaseline(longhands::dominant_baseline::SpecifiedValue),
    /// `empty-cells`
    EmptyCells(longhands::empty_cells::SpecifiedValue),
    /// `fill-rule`
    FillRule(longhands::fill_rule::SpecifiedValue),
    /// `flex-direction`
    FlexDirection(longhands::flex_direction::SpecifiedValue),
    /// `flex-wrap`
    FlexWrap(longhands::flex_wrap::SpecifiedValue),
    /// `float`
    Float(longhands::float::SpecifiedValue),
    /// `font-kerning`
    FontKerning(longhands::font_kerning::SpecifiedValue),
    /// `font-optical-sizing`
    FontOpticalSizing(longhands::font_optical_sizing::SpecifiedValue),
    /// `font-stretch`
    FontStretch(longhands::font_stretch::SpecifiedValue),
    /// `font-style`
    FontStyle(longhands::font_style::SpecifiedValue),
    /// `font-synthesis`
    FontSynthesis(::values::specified::FontSynthesis),
    /// `font-variant-caps`
    FontVariantCaps(longhands::font_variant_caps::SpecifiedValue),
    /// `font-variant-position`
    FontVariantPosition(longhands::font_variant_position::SpecifiedValue),
    /// `font-weight`
    FontWeight(::values::specified::FontWeight),
    /// `grid-auto-flow`
    GridAutoFlow(::values::specified::GridAutoFlow),
    /// `hyphens`
    Hyphens(longhands::hyphens::SpecifiedValue),
    /// `image-orientation`
    ImageOrientation(::values::specified::ImageOrientation),
    /// `image-rendering`
    ImageRendering(longhands::image_rendering::SpecifiedValue),
    /// `ime-mode`
    ImeMode(longhands::ime_mode::SpecifiedValue),
    /// `initial-letter`
    InitialLetter(::values::specified::InitialLetter),
    /// `isolation`
    Isolation(longhands::isolation::SpecifiedValue),
    /// `justify-content`
    JustifyContent(::values::specified::JustifyContent),
    /// `justify-items`
    JustifyItems(::values::specified::JustifyItems),
    /// `justify-self`
    JustifySelf(::values::specified::JustifySelf),
    /// `list-style-position`
    ListStylePosition(longhands::list_style_position::SpecifiedValue),
    /// `mask-type`
    MaskType(longhands::mask_type::SpecifiedValue),
    /// `mix-blend-mode`
    MixBlendMode(longhands::mix_blend_mode::SpecifiedValue),
    /// `-moz-appearance`
    MozAppearance(longhands::_moz_appearance::SpecifiedValue),
    /// `-moz-box-align`
    MozBoxAlign(longhands::_moz_box_align::SpecifiedValue),
    /// `-moz-box-direction`
    MozBoxDirection(longhands::_moz_box_direction::SpecifiedValue),
    /// `-moz-box-orient`
    MozBoxOrient(longhands::_moz_box_orient::SpecifiedValue),
    /// `-moz-box-pack`
    MozBoxPack(longhands::_moz_box_pack::SpecifiedValue),
    /// `-moz-control-character-visibility`
    MozControlCharacterVisibility(longhands::_moz_control_character_visibility::SpecifiedValue),
    /// `-moz-float-edge`
    MozFloatEdge(longhands::_moz_float_edge::SpecifiedValue),
    /// `-moz-force-broken-image-icon`
    MozForceBrokenImageIcon(::values::specified::MozForceBrokenImageIcon),
    /// `-moz-math-display`
    MozMathDisplay(longhands::_moz_math_display::SpecifiedValue),
    /// `-moz-math-variant`
    MozMathVariant(longhands::_moz_math_variant::SpecifiedValue),
    /// `-moz-min-font-size-ratio`
    MozMinFontSizeRatio(::values::specified::Percentage),
    /// `-moz-orient`
    MozOrient(longhands::_moz_orient::SpecifiedValue),
    /// `-moz-osx-font-smoothing`
    MozOsxFontSmoothing(longhands::_moz_osx_font_smoothing::SpecifiedValue),
    /// `-moz-script-level`
    MozScriptLevel(::values::specified::MozScriptLevel),
    /// `-moz-script-min-size`
    MozScriptMinSize(::values::specified::MozScriptMinSize),
    /// `-moz-script-size-multiplier`
    MozScriptSizeMultiplier(::values::specified::MozScriptSizeMultiplier),
    /// `-moz-stack-sizing`
    MozStackSizing(longhands::_moz_stack_sizing::SpecifiedValue),
    /// `-moz-text-size-adjust`
    MozTextSizeAdjust(longhands::_moz_text_size_adjust::SpecifiedValue),
    /// `-moz-top-layer`
    MozTopLayer(longhands::_moz_top_layer::SpecifiedValue),
    /// `-moz-user-focus`
    MozUserFocus(longhands::_moz_user_focus::SpecifiedValue),
    /// `-moz-user-input`
    MozUserInput(longhands::_moz_user_input::SpecifiedValue),
    /// `-moz-user-modify`
    MozUserModify(longhands::_moz_user_modify::SpecifiedValue),
    /// `-moz-user-select`
    MozUserSelect(longhands::_moz_user_select::SpecifiedValue),
    /// `-moz-window-dragging`
    MozWindowDragging(longhands::_moz_window_dragging::SpecifiedValue),
    /// `-moz-window-shadow`
    MozWindowShadow(longhands::_moz_window_shadow::SpecifiedValue),
    /// `object-fit`
    ObjectFit(longhands::object_fit::SpecifiedValue),
    /// `outline-style`
    OutlineStyle(::values::specified::OutlineStyle),
    /// `overflow-wrap`
    OverflowWrap(longhands::overflow_wrap::SpecifiedValue),
    /// `overflow-x`
    OverflowX(longhands::overflow_x::SpecifiedValue),
    /// `page-break-after`
    PageBreakAfter(longhands::page_break_after::SpecifiedValue),
    /// `page-break-before`
    PageBreakBefore(longhands::page_break_before::SpecifiedValue),
    /// `page-break-inside`
    PageBreakInside(longhands::page_break_inside::SpecifiedValue),
    /// `paint-order`
    PaintOrder(::values::specified::SVGPaintOrder),
    /// `pointer-events`
    PointerEvents(longhands::pointer_events::SpecifiedValue),
    /// `position`
    Position(longhands::position::SpecifiedValue),
    /// `resize`
    Resize(longhands::resize::SpecifiedValue),
    /// `ruby-align`
    RubyAlign(longhands::ruby_align::SpecifiedValue),
    /// `ruby-position`
    RubyPosition(longhands::ruby_position::SpecifiedValue),
    /// `scroll-behavior`
    ScrollBehavior(longhands::scroll_behavior::SpecifiedValue),
    /// `shape-rendering`
    ShapeRendering(longhands::shape_rendering::SpecifiedValue),
    /// `stroke-linecap`
    StrokeLinecap(longhands::stroke_linecap::SpecifiedValue),
    /// `stroke-linejoin`
    StrokeLinejoin(longhands::stroke_linejoin::SpecifiedValue),
    /// `table-layout`
    TableLayout(longhands::table_layout::SpecifiedValue),
    /// `text-align-last`
    TextAlignLast(longhands::text_align_last::SpecifiedValue),
    /// `text-anchor`
    TextAnchor(longhands::text_anchor::SpecifiedValue),
    /// `text-combine-upright`
    TextCombineUpright(longhands::text_combine_upright::SpecifiedValue),
    /// `text-decoration-line`
    TextDecorationLine(::values::specified::TextDecorationLine),
    /// `text-decoration-style`
    TextDecorationStyle(longhands::text_decoration_style::SpecifiedValue),
    /// `text-justify`
    TextJustify(longhands::text_justify::SpecifiedValue),
    /// `text-orientation`
    TextOrientation(longhands::text_orientation::SpecifiedValue),
    /// `text-rendering`
    TextRendering(longhands::text_rendering::SpecifiedValue),
    /// `text-transform`
    TextTransform(longhands::text_transform::SpecifiedValue),
    /// `touch-action`
    TouchAction(::values::specified::TouchAction),
    /// `transform-box`
    TransformBox(longhands::transform_box::SpecifiedValue),
    /// `transform-style`
    TransformStyle(::values::specified::TransformStyle),
    /// `unicode-bidi`
    UnicodeBidi(longhands::unicode_bidi::SpecifiedValue),
    /// `vector-effect`
    VectorEffect(longhands::vector_effect::SpecifiedValue),
    /// `visibility`
    Visibility(longhands::visibility::SpecifiedValue),
    /// `white-space`
    WhiteSpace(longhands::white_space::SpecifiedValue),
    /// `word-break`
    WordBreak(longhands::word_break::SpecifiedValue),
    /// `writing-mode`
    WritingMode(longhands::writing_mode::SpecifiedValue),
    /// `-x-span`
    XSpan(::values::specified::XSpan),
    /// `-x-text-zoom`
    XTextZoom(::values::specified::XTextZoom),
    /// `z-index`
    ZIndex(::values::specified::ZIndex),
    /// `-moz-box-ordinal-group`
    MozBoxOrdinalGroup(::values::specified::Integer),
    /// `order`
    Order(::values::specified::Integer),
    /// `overscroll-behavior-x`
    OverscrollBehaviorX(::values::specified::OverscrollBehavior),
    /// `overscroll-behavior-y`
    OverscrollBehaviorY(::values::specified::OverscrollBehavior),
    /// `scroll-snap-type-x`
    ScrollSnapTypeX(::values::specified::ScrollSnapType),
    /// `scroll-snap-type-y`
    ScrollSnapTypeY(::values::specified::ScrollSnapType),
    /// `flex-grow`
    FlexGrow(::values::specified::NonNegativeNumber),
    /// `flex-shrink`
    FlexShrink(::values::specified::NonNegativeNumber),
    /// `-moz-box-flex`
    MozBoxFlex(::values::specified::NonNegativeNumber),
    /// `flood-opacity`
    FloodOpacity(::values::specified::Opacity),
    /// `-moz-window-opacity`
    MozWindowOpacity(::values::specified::Opacity),
    /// `opacity`
    Opacity(::values::specified::Opacity),
    /// `shape-image-threshold`
    ShapeImageThreshold(::values::specified::Opacity),
    /// `stop-opacity`
    StopOpacity(::values::specified::Opacity),
    /// `border-block-end-style`
    BorderBlockEndStyle(::values::specified::BorderStyle),
    /// `border-block-start-style`
    BorderBlockStartStyle(::values::specified::BorderStyle),
    /// `border-bottom-style`
    BorderBottomStyle(::values::specified::BorderStyle),
    /// `border-inline-end-style`
    BorderInlineEndStyle(::values::specified::BorderStyle),
    /// `border-inline-start-style`
    BorderInlineStartStyle(::values::specified::BorderStyle),
    /// `border-left-style`
    BorderLeftStyle(::values::specified::BorderStyle),
    /// `border-right-style`
    BorderRightStyle(::values::specified::BorderStyle),
    /// `border-top-style`
    BorderTopStyle(::values::specified::BorderStyle),
    /// `animation-delay`
    AnimationDelay(longhands::animation_delay::SpecifiedValue),
    /// `animation-direction`
    AnimationDirection(longhands::animation_direction::SpecifiedValue),
    /// `animation-duration`
    AnimationDuration(longhands::animation_duration::SpecifiedValue),
    /// `animation-fill-mode`
    AnimationFillMode(longhands::animation_fill_mode::SpecifiedValue),
    /// `animation-iteration-count`
    AnimationIterationCount(longhands::animation_iteration_count::SpecifiedValue),
    /// `animation-name`
    AnimationName(longhands::animation_name::SpecifiedValue),
    /// `animation-play-state`
    AnimationPlayState(longhands::animation_play_state::SpecifiedValue),
    /// `animation-timing-function`
    AnimationTimingFunction(longhands::animation_timing_function::SpecifiedValue),
    /// `background-attachment`
    BackgroundAttachment(longhands::background_attachment::SpecifiedValue),
    /// `background-blend-mode`
    BackgroundBlendMode(longhands::background_blend_mode::SpecifiedValue),
    /// `background-clip`
    BackgroundClip(longhands::background_clip::SpecifiedValue),
    /// `background-image`
    BackgroundImage(longhands::background_image::SpecifiedValue),
    /// `background-origin`
    BackgroundOrigin(longhands::background_origin::SpecifiedValue),
    /// `background-position-x`
    BackgroundPositionX(longhands::background_position_x::SpecifiedValue),
    /// `background-position-y`
    BackgroundPositionY(longhands::background_position_y::SpecifiedValue),
    /// `background-repeat`
    BackgroundRepeat(longhands::background_repeat::SpecifiedValue),
    /// `background-size`
    BackgroundSize(longhands::background_size::SpecifiedValue),
    /// `border-image-outset`
    BorderImageOutset(Box<::values::specified::LengthOrNumberRect>),
    /// `border-image-slice`
    BorderImageSlice(Box<::values::specified::BorderImageSlice>),
    /// `border-image-source`
    BorderImageSource(Box<::values::specified::ImageLayer>),
    /// `border-image-width`
    BorderImageWidth(Box<::values::specified::BorderImageWidth>),
    /// `border-spacing`
    BorderSpacing(Box<::values::specified::BorderSpacing>),
    /// `box-shadow`
    BoxShadow(longhands::box_shadow::SpecifiedValue),
    /// `caret-color`
    CaretColor(::values::specified::CaretColor),
    /// `clip-path`
    ClipPath(Box<::values::specified::basic_shape::ClippingShape>),
    /// `color`
    Color(::values::specified::ColorPropertyValue),
    /// `column-gap`
    ColumnGap(::values::specified::length::NonNegativeLengthOrNormal),
    /// `column-width`
    ColumnWidth(::values::specified::length::NonNegativeLengthOrAuto),
    /// `content`
    Content(::values::specified::Content),
    /// `counter-increment`
    CounterIncrement(::values::specified::CounterIncrement),
    /// `counter-reset`
    CounterReset(::values::specified::CounterReset),
    /// `cursor`
    Cursor(::values::specified::Cursor),
    /// `display`
    Display(::values::specified::Display),
    /// `filter`
    Filter(longhands::filter::SpecifiedValue),
    /// `font-family`
    FontFamily(::values::specified::FontFamily),
    /// `font-feature-settings`
    FontFeatureSettings(::values::specified::FontFeatureSettings),
    /// `font-language-override`
    FontLanguageOverride(::values::specified::FontLanguageOverride),
    /// `font-size`
    FontSize(::values::specified::FontSize),
    /// `font-size-adjust`
    FontSizeAdjust(::values::specified::FontSizeAdjust),
    /// `font-variant-alternates`
    FontVariantAlternates(::values::specified::FontVariantAlternates),
    /// `font-variant-east-asian`
    FontVariantEastAsian(::values::specified::FontVariantEastAsian),
    /// `font-variant-ligatures`
    FontVariantLigatures(::values::specified::FontVariantLigatures),
    /// `font-variant-numeric`
    FontVariantNumeric(::values::specified::FontVariantNumeric),
    /// `font-variation-settings`
    FontVariationSettings(::values::specified::FontVariationSettings),
    /// `grid-template-areas`
    GridTemplateAreas(::values::specified::GridTemplateAreas),
    /// `letter-spacing`
    LetterSpacing(::values::specified::LetterSpacing),
    /// `line-height`
    LineHeight(::values::specified::LineHeight),
    /// `list-style-image`
    ListStyleImage(::values::specified::ListStyleImage),
    /// `list-style-type`
    ListStyleType(Box<::values::specified::ListStyleType>),
    /// `mask-clip`
    MaskClip(longhands::mask_clip::SpecifiedValue),
    /// `mask-composite`
    MaskComposite(longhands::mask_composite::SpecifiedValue),
    /// `mask-image`
    MaskImage(longhands::mask_image::SpecifiedValue),
    /// `mask-mode`
    MaskMode(longhands::mask_mode::SpecifiedValue),
    /// `mask-origin`
    MaskOrigin(longhands::mask_origin::SpecifiedValue),
    /// `mask-position-x`
    MaskPositionX(longhands::mask_position_x::SpecifiedValue),
    /// `mask-position-y`
    MaskPositionY(longhands::mask_position_y::SpecifiedValue),
    /// `mask-repeat`
    MaskRepeat(longhands::mask_repeat::SpecifiedValue),
    /// `mask-size`
    MaskSize(longhands::mask_size::SpecifiedValue),
    /// `-moz-context-properties`
    MozContextProperties(longhands::_moz_context_properties::SpecifiedValue),
    /// `-moz-tab-size`
    MozTabSize(::values::specified::MozTabSize),
    /// `outline-offset`
    OutlineOffset(::values::specified::Length),
    /// `overflow-y`
    OverflowY(longhands::overflow_y::SpecifiedValue),
    /// `perspective`
    Perspective(::values::specified::Perspective),
    /// `perspective-origin`
    PerspectiveOrigin(Box<::values::specified::position::Position>),
    /// `quotes`
    Quotes(::values::specified::Quotes),
    /// `rotate`
    Rotate(Box<::values::specified::Rotate>),
    /// `scale`
    Scale(Box<::values::specified::Scale>),
    /// `scroll-snap-coordinate`
    ScrollSnapCoordinate(longhands::scroll_snap_coordinate::SpecifiedValue),
    /// `shape-outside`
    ShapeOutside(Box<::values::specified::basic_shape::FloatAreaShape>),
    /// `stroke-dasharray`
    StrokeDasharray(::values::specified::SVGStrokeDashArray),
    /// `stroke-dashoffset`
    StrokeDashoffset(::values::specified::SVGLength),
    /// `stroke-miterlimit`
    StrokeMiterlimit(::values::specified::GreaterThanOrEqualToOneNumber),
    /// `stroke-width`
    StrokeWidth(::values::specified::SVGWidth),
    /// `text-align`
    TextAlign(::values::specified::TextAlign),
    /// `text-emphasis-position`
    TextEmphasisPosition(longhands::text_emphasis_position::SpecifiedValue),
    /// `text-emphasis-style`
    TextEmphasisStyle(Box<::values::specified::TextEmphasisStyle>),
    /// `text-indent`
    TextIndent(::values::specified::LengthOrPercentage),
    /// `text-overflow`
    TextOverflow(Box<::values::specified::TextOverflow>),
    /// `text-shadow`
    TextShadow(longhands::text_shadow::SpecifiedValue),
    /// `transition-delay`
    TransitionDelay(longhands::transition_delay::SpecifiedValue),
    /// `transition-duration`
    TransitionDuration(longhands::transition_duration::SpecifiedValue),
    /// `transition-property`
    TransitionProperty(longhands::transition_property::SpecifiedValue),
    /// `transition-timing-function`
    TransitionTimingFunction(longhands::transition_timing_function::SpecifiedValue),
    /// `translate`
    Translate(Box<::values::specified::Translate>),
    /// `vertical-align`
    VerticalAlign(::values::specified::VerticalAlign),
    /// `will-change`
    WillChange(::values::specified::WillChange),
    /// `word-spacing`
    WordSpacing(::values::specified::WordSpacing),
    /// `-x-lang`
    XLang(::values::specified::XLang),
    /// `overflow-clip-box-block`
    OverflowClipBoxBlock(::values::specified::OverflowClipBox),
    /// `overflow-clip-box-inline`
    OverflowClipBoxInline(::values::specified::OverflowClipBox),
    /// `fill-opacity`
    FillOpacity(::values::specified::SVGOpacity),
    /// `stroke-opacity`
    StrokeOpacity(::values::specified::SVGOpacity),
    /// `scroll-snap-points-x`
    ScrollSnapPointsX(::values::specified::ScrollSnapPoint),
    /// `scroll-snap-points-y`
    ScrollSnapPointsY(::values::specified::ScrollSnapPoint),
    /// `-moz-window-transform`
    MozWindowTransform(::values::specified::Transform),
    /// `transform`
    Transform(::values::specified::Transform),
    /// `clip`
    Clip(Box<::values::specified::ClipRectOrAuto>),
    /// `-moz-image-region`
    MozImageRegion(Box<::values::specified::ClipRectOrAuto>),
    /// `grid-template-columns`
    GridTemplateColumns(Box<::values::specified::GridTemplateComponent>),
    /// `grid-template-rows`
    GridTemplateRows(Box<::values::specified::GridTemplateComponent>),
    /// `object-position`
    ObjectPosition(Box<::values::specified::Position>),
    /// `scroll-snap-destination`
    ScrollSnapDestination(Box<::values::specified::Position>),
    /// `fill`
    Fill(Box<::values::specified::SVGPaint>),
    /// `stroke`
    Stroke(Box<::values::specified::SVGPaint>),
    /// `grid-auto-columns`
    GridAutoColumns(Box<::values::specified::TrackSize>),
    /// `grid-auto-rows`
    GridAutoRows(Box<::values::specified::TrackSize>),
    /// `-moz-window-transform-origin`
    MozWindowTransformOrigin(Box<::values::specified::TransformOrigin>),
    /// `transform-origin`
    TransformOrigin(Box<::values::specified::TransformOrigin>),
    /// `max-block-size`
    MaxBlockSize(::values::specified::MaxLength),
    /// `max-height`
    MaxHeight(::values::specified::MaxLength),
    /// `max-inline-size`
    MaxInlineSize(::values::specified::MaxLength),
    /// `max-width`
    MaxWidth(::values::specified::MaxLength),
    /// `flood-color`
    FloodColor(::values::specified::RGBAColor),
    /// `lighting-color`
    LightingColor(::values::specified::RGBAColor),
    /// `-moz-font-smoothing-background-color`
    MozFontSmoothingBackgroundColor(::values::specified::RGBAColor),
    /// `stop-color`
    StopColor(::values::specified::RGBAColor),
    /// `marker-end`
    MarkerEnd(::values::specified::UrlOrNone),
    /// `marker-mid`
    MarkerMid(::values::specified::UrlOrNone),
    /// `marker-start`
    MarkerStart(::values::specified::UrlOrNone),
    /// `-moz-binding`
    MozBinding(::values::specified::UrlOrNone),
    /// `grid-column-end`
    GridColumnEnd(Box<::values::specified::GridLine>),
    /// `grid-column-start`
    GridColumnStart(Box<::values::specified::GridLine>),
    /// `grid-row-end`
    GridRowEnd(Box<::values::specified::GridLine>),
    /// `grid-row-start`
    GridRowStart(Box<::values::specified::GridLine>),
    /// `border-bottom-left-radius`
    BorderBottomLeftRadius(Box<::values::specified::BorderCornerRadius>),
    /// `border-bottom-right-radius`
    BorderBottomRightRadius(Box<::values::specified::BorderCornerRadius>),
    /// `border-top-left-radius`
    BorderTopLeftRadius(Box<::values::specified::BorderCornerRadius>),
    /// `border-top-right-radius`
    BorderTopRightRadius(Box<::values::specified::BorderCornerRadius>),
    /// `-moz-outline-radius-bottomleft`
    MozOutlineRadiusBottomleft(Box<::values::specified::BorderCornerRadius>),
    /// `-moz-outline-radius-bottomright`
    MozOutlineRadiusBottomright(Box<::values::specified::BorderCornerRadius>),
    /// `-moz-outline-radius-topleft`
    MozOutlineRadiusTopleft(Box<::values::specified::BorderCornerRadius>),
    /// `-moz-outline-radius-topright`
    MozOutlineRadiusTopright(Box<::values::specified::BorderCornerRadius>),
    /// `block-size`
    BlockSize(::values::specified::MozLength),
    /// `flex-basis`
    FlexBasis(::values::specified::MozLength),
    /// `height`
    Height(::values::specified::MozLength),
    /// `inline-size`
    InlineSize(::values::specified::MozLength),
    /// `min-block-size`
    MinBlockSize(::values::specified::MozLength),
    /// `min-height`
    MinHeight(::values::specified::MozLength),
    /// `min-inline-size`
    MinInlineSize(::values::specified::MozLength),
    /// `min-width`
    MinWidth(::values::specified::MozLength),
    /// `width`
    Width(::values::specified::MozLength),
    /// `grid-column-gap`
    GridColumnGap(::values::specified::NonNegativeLengthOrPercentage),
    /// `grid-row-gap`
    GridRowGap(::values::specified::NonNegativeLengthOrPercentage),
    /// `padding-block-end`
    PaddingBlockEnd(::values::specified::NonNegativeLengthOrPercentage),
    /// `padding-block-start`
    PaddingBlockStart(::values::specified::NonNegativeLengthOrPercentage),
    /// `padding-bottom`
    PaddingBottom(::values::specified::NonNegativeLengthOrPercentage),
    /// `padding-inline-end`
    PaddingInlineEnd(::values::specified::NonNegativeLengthOrPercentage),
    /// `padding-inline-start`
    PaddingInlineStart(::values::specified::NonNegativeLengthOrPercentage),
    /// `padding-left`
    PaddingLeft(::values::specified::NonNegativeLengthOrPercentage),
    /// `padding-right`
    PaddingRight(::values::specified::NonNegativeLengthOrPercentage),
    /// `padding-top`
    PaddingTop(::values::specified::NonNegativeLengthOrPercentage),
    /// `border-block-end-width`
    BorderBlockEndWidth(::values::specified::BorderSideWidth),
    /// `border-block-start-width`
    BorderBlockStartWidth(::values::specified::BorderSideWidth),
    /// `border-bottom-width`
    BorderBottomWidth(::values::specified::BorderSideWidth),
    /// `border-inline-end-width`
    BorderInlineEndWidth(::values::specified::BorderSideWidth),
    /// `border-inline-start-width`
    BorderInlineStartWidth(::values::specified::BorderSideWidth),
    /// `border-left-width`
    BorderLeftWidth(::values::specified::BorderSideWidth),
    /// `border-right-width`
    BorderRightWidth(::values::specified::BorderSideWidth),
    /// `border-top-width`
    BorderTopWidth(::values::specified::BorderSideWidth),
    /// `column-rule-width`
    ColumnRuleWidth(::values::specified::BorderSideWidth),
    /// `outline-width`
    OutlineWidth(::values::specified::BorderSideWidth),
    /// `-webkit-text-stroke-width`
    WebkitTextStrokeWidth(::values::specified::BorderSideWidth),
    /// `background-color`
    BackgroundColor(::values::specified::Color),
    /// `border-block-end-color`
    BorderBlockEndColor(::values::specified::Color),
    /// `border-block-start-color`
    BorderBlockStartColor(::values::specified::Color),
    /// `border-bottom-color`
    BorderBottomColor(::values::specified::Color),
    /// `border-inline-end-color`
    BorderInlineEndColor(::values::specified::Color),
    /// `border-inline-start-color`
    BorderInlineStartColor(::values::specified::Color),
    /// `border-left-color`
    BorderLeftColor(::values::specified::Color),
    /// `border-right-color`
    BorderRightColor(::values::specified::Color),
    /// `border-top-color`
    BorderTopColor(::values::specified::Color),
    /// `column-rule-color`
    ColumnRuleColor(::values::specified::Color),
    /// `outline-color`
    OutlineColor(::values::specified::Color),
    /// `text-decoration-color`
    TextDecorationColor(::values::specified::Color),
    /// `text-emphasis-color`
    TextEmphasisColor(::values::specified::Color),
    /// `-webkit-text-fill-color`
    WebkitTextFillColor(::values::specified::Color),
    /// `-webkit-text-stroke-color`
    WebkitTextStrokeColor(::values::specified::Color),
    /// `bottom`
    Bottom(::values::specified::LengthOrPercentageOrAuto),
    /// `left`
    Left(::values::specified::LengthOrPercentageOrAuto),
    /// `margin-block-end`
    MarginBlockEnd(::values::specified::LengthOrPercentageOrAuto),
    /// `margin-block-start`
    MarginBlockStart(::values::specified::LengthOrPercentageOrAuto),
    /// `margin-bottom`
    MarginBottom(::values::specified::LengthOrPercentageOrAuto),
    /// `margin-inline-end`
    MarginInlineEnd(::values::specified::LengthOrPercentageOrAuto),
    /// `margin-inline-start`
    MarginInlineStart(::values::specified::LengthOrPercentageOrAuto),
    /// `margin-left`
    MarginLeft(::values::specified::LengthOrPercentageOrAuto),
    /// `margin-right`
    MarginRight(::values::specified::LengthOrPercentageOrAuto),
    /// `margin-top`
    MarginTop(::values::specified::LengthOrPercentageOrAuto),
    /// `offset-block-end`
    OffsetBlockEnd(::values::specified::LengthOrPercentageOrAuto),
    /// `offset-block-start`
    OffsetBlockStart(::values::specified::LengthOrPercentageOrAuto),
    /// `offset-inline-end`
    OffsetInlineEnd(::values::specified::LengthOrPercentageOrAuto),
    /// `offset-inline-start`
    OffsetInlineStart(::values::specified::LengthOrPercentageOrAuto),
    /// `right`
    Right(::values::specified::LengthOrPercentageOrAuto),
    /// `top`
    Top(::values::specified::LengthOrPercentageOrAuto),
    /// A CSS-wide keyword.
    CSSWideKeyword(WideKeywordDeclaration),
    /// An unparsed declaration.
    WithVariables(VariableDeclaration),
    /// A custom property declaration.
    Custom(CustomDeclaration),
}

#[repr(C)]
struct PropertyDeclarationVariantRepr<T> {
    tag: u16,
    value: T
}

impl Clone for PropertyDeclaration {
    #[inline]
    fn clone(&self) -> Self {
        use self::PropertyDeclaration::*;

        

        let self_tag = unsafe {
            (*(self as *const _ as *const PropertyDeclarationVariantRepr<()>)).tag
        };
        if self_tag <= LonghandId::BorderTopStyle as u16 {
            #[derive(Clone, Copy)]
            #[repr(u16)]
            enum CopyVariants {
                _AlignContent(::values::specified::AlignContent),
                _AlignItems(::values::specified::AlignItems),
                _AlignSelf(::values::specified::AlignSelf),
                _BackfaceVisibility(longhands::backface_visibility::SpecifiedValue),
                _BorderCollapse(longhands::border_collapse::SpecifiedValue),
                _BorderImageRepeat(::values::specified::BorderImageRepeat),
                _BoxDecorationBreak(longhands::box_decoration_break::SpecifiedValue),
                _BoxSizing(longhands::box_sizing::SpecifiedValue),
                _CaptionSide(longhands::caption_side::SpecifiedValue),
                _Clear(longhands::clear::SpecifiedValue),
                _ClipRule(longhands::clip_rule::SpecifiedValue),
                _ColorAdjust(longhands::color_adjust::SpecifiedValue),
                _ColorInterpolation(longhands::color_interpolation::SpecifiedValue),
                _ColorInterpolationFilters(longhands::color_interpolation_filters::SpecifiedValue),
                _ColumnCount(::values::specified::ColumnCount),
                _ColumnFill(longhands::column_fill::SpecifiedValue),
                _ColumnRuleStyle(longhands::column_rule_style::SpecifiedValue),
                _ColumnSpan(longhands::column_span::SpecifiedValue),
                _Contain(::values::specified::Contain),
                _Direction(longhands::direction::SpecifiedValue),
                _DominantBaseline(longhands::dominant_baseline::SpecifiedValue),
                _EmptyCells(longhands::empty_cells::SpecifiedValue),
                _FillRule(longhands::fill_rule::SpecifiedValue),
                _FlexDirection(longhands::flex_direction::SpecifiedValue),
                _FlexWrap(longhands::flex_wrap::SpecifiedValue),
                _Float(longhands::float::SpecifiedValue),
                _FontKerning(longhands::font_kerning::SpecifiedValue),
                _FontOpticalSizing(longhands::font_optical_sizing::SpecifiedValue),
                _FontStretch(longhands::font_stretch::SpecifiedValue),
                _FontStyle(longhands::font_style::SpecifiedValue),
                _FontSynthesis(::values::specified::FontSynthesis),
                _FontVariantCaps(longhands::font_variant_caps::SpecifiedValue),
                _FontVariantPosition(longhands::font_variant_position::SpecifiedValue),
                _FontWeight(::values::specified::FontWeight),
                _GridAutoFlow(::values::specified::GridAutoFlow),
                _Hyphens(longhands::hyphens::SpecifiedValue),
                _ImageOrientation(::values::specified::ImageOrientation),
                _ImageRendering(longhands::image_rendering::SpecifiedValue),
                _ImeMode(longhands::ime_mode::SpecifiedValue),
                _InitialLetter(::values::specified::InitialLetter),
                _Isolation(longhands::isolation::SpecifiedValue),
                _JustifyContent(::values::specified::JustifyContent),
                _JustifyItems(::values::specified::JustifyItems),
                _JustifySelf(::values::specified::JustifySelf),
                _ListStylePosition(longhands::list_style_position::SpecifiedValue),
                _MaskType(longhands::mask_type::SpecifiedValue),
                _MixBlendMode(longhands::mix_blend_mode::SpecifiedValue),
                _MozAppearance(longhands::_moz_appearance::SpecifiedValue),
                _MozBoxAlign(longhands::_moz_box_align::SpecifiedValue),
                _MozBoxDirection(longhands::_moz_box_direction::SpecifiedValue),
                _MozBoxOrient(longhands::_moz_box_orient::SpecifiedValue),
                _MozBoxPack(longhands::_moz_box_pack::SpecifiedValue),
                _MozControlCharacterVisibility(longhands::_moz_control_character_visibility::SpecifiedValue),
                _MozFloatEdge(longhands::_moz_float_edge::SpecifiedValue),
                _MozForceBrokenImageIcon(::values::specified::MozForceBrokenImageIcon),
                _MozMathDisplay(longhands::_moz_math_display::SpecifiedValue),
                _MozMathVariant(longhands::_moz_math_variant::SpecifiedValue),
                _MozMinFontSizeRatio(::values::specified::Percentage),
                _MozOrient(longhands::_moz_orient::SpecifiedValue),
                _MozOsxFontSmoothing(longhands::_moz_osx_font_smoothing::SpecifiedValue),
                _MozScriptLevel(::values::specified::MozScriptLevel),
                _MozScriptMinSize(::values::specified::MozScriptMinSize),
                _MozScriptSizeMultiplier(::values::specified::MozScriptSizeMultiplier),
                _MozStackSizing(longhands::_moz_stack_sizing::SpecifiedValue),
                _MozTextSizeAdjust(longhands::_moz_text_size_adjust::SpecifiedValue),
                _MozTopLayer(longhands::_moz_top_layer::SpecifiedValue),
                _MozUserFocus(longhands::_moz_user_focus::SpecifiedValue),
                _MozUserInput(longhands::_moz_user_input::SpecifiedValue),
                _MozUserModify(longhands::_moz_user_modify::SpecifiedValue),
                _MozUserSelect(longhands::_moz_user_select::SpecifiedValue),
                _MozWindowDragging(longhands::_moz_window_dragging::SpecifiedValue),
                _MozWindowShadow(longhands::_moz_window_shadow::SpecifiedValue),
                _ObjectFit(longhands::object_fit::SpecifiedValue),
                _OutlineStyle(::values::specified::OutlineStyle),
                _OverflowWrap(longhands::overflow_wrap::SpecifiedValue),
                _OverflowX(longhands::overflow_x::SpecifiedValue),
                _PageBreakAfter(longhands::page_break_after::SpecifiedValue),
                _PageBreakBefore(longhands::page_break_before::SpecifiedValue),
                _PageBreakInside(longhands::page_break_inside::SpecifiedValue),
                _PaintOrder(::values::specified::SVGPaintOrder),
                _PointerEvents(longhands::pointer_events::SpecifiedValue),
                _Position(longhands::position::SpecifiedValue),
                _Resize(longhands::resize::SpecifiedValue),
                _RubyAlign(longhands::ruby_align::SpecifiedValue),
                _RubyPosition(longhands::ruby_position::SpecifiedValue),
                _ScrollBehavior(longhands::scroll_behavior::SpecifiedValue),
                _ShapeRendering(longhands::shape_rendering::SpecifiedValue),
                _StrokeLinecap(longhands::stroke_linecap::SpecifiedValue),
                _StrokeLinejoin(longhands::stroke_linejoin::SpecifiedValue),
                _TableLayout(longhands::table_layout::SpecifiedValue),
                _TextAlignLast(longhands::text_align_last::SpecifiedValue),
                _TextAnchor(longhands::text_anchor::SpecifiedValue),
                _TextCombineUpright(longhands::text_combine_upright::SpecifiedValue),
                _TextDecorationLine(::values::specified::TextDecorationLine),
                _TextDecorationStyle(longhands::text_decoration_style::SpecifiedValue),
                _TextJustify(longhands::text_justify::SpecifiedValue),
                _TextOrientation(longhands::text_orientation::SpecifiedValue),
                _TextRendering(longhands::text_rendering::SpecifiedValue),
                _TextTransform(longhands::text_transform::SpecifiedValue),
                _TouchAction(::values::specified::TouchAction),
                _TransformBox(longhands::transform_box::SpecifiedValue),
                _TransformStyle(::values::specified::TransformStyle),
                _UnicodeBidi(longhands::unicode_bidi::SpecifiedValue),
                _VectorEffect(longhands::vector_effect::SpecifiedValue),
                _Visibility(longhands::visibility::SpecifiedValue),
                _WhiteSpace(longhands::white_space::SpecifiedValue),
                _WordBreak(longhands::word_break::SpecifiedValue),
                _WritingMode(longhands::writing_mode::SpecifiedValue),
                _XSpan(::values::specified::XSpan),
                _XTextZoom(::values::specified::XTextZoom),
                _ZIndex(::values::specified::ZIndex),
                _MozBoxOrdinalGroup(::values::specified::Integer),
                _Order(::values::specified::Integer),
                _OverscrollBehaviorX(::values::specified::OverscrollBehavior),
                _OverscrollBehaviorY(::values::specified::OverscrollBehavior),
                _ScrollSnapTypeX(::values::specified::ScrollSnapType),
                _ScrollSnapTypeY(::values::specified::ScrollSnapType),
                _FlexGrow(::values::specified::NonNegativeNumber),
                _FlexShrink(::values::specified::NonNegativeNumber),
                _MozBoxFlex(::values::specified::NonNegativeNumber),
                _FloodOpacity(::values::specified::Opacity),
                _MozWindowOpacity(::values::specified::Opacity),
                _Opacity(::values::specified::Opacity),
                _ShapeImageThreshold(::values::specified::Opacity),
                _StopOpacity(::values::specified::Opacity),
                _BorderBlockEndStyle(::values::specified::BorderStyle),
                _BorderBlockStartStyle(::values::specified::BorderStyle),
                _BorderBottomStyle(::values::specified::BorderStyle),
                _BorderInlineEndStyle(::values::specified::BorderStyle),
                _BorderInlineStartStyle(::values::specified::BorderStyle),
                _BorderLeftStyle(::values::specified::BorderStyle),
                _BorderRightStyle(::values::specified::BorderStyle),
                _BorderTopStyle(::values::specified::BorderStyle),
            }

            unsafe {
                let mut out = mem::uninitialized();
                ptr::write(
                    &mut out as *mut _ as *mut CopyVariants,
                    *(self as *const _ as *const CopyVariants),
                );
                return out;
            }
        }

        match *self {
            AlignContent(..) |
AlignItems(..) |
AlignSelf(..) |
BackfaceVisibility(..) |
BorderCollapse(..) |
BorderImageRepeat(..) |
BoxDecorationBreak(..) |
BoxSizing(..) |
CaptionSide(..) |
Clear(..) |
ClipRule(..) |
ColorAdjust(..) |
ColorInterpolation(..) |
ColorInterpolationFilters(..) |
ColumnCount(..) |
ColumnFill(..) |
ColumnRuleStyle(..) |
ColumnSpan(..) |
Contain(..) |
Direction(..) |
DominantBaseline(..) |
EmptyCells(..) |
FillRule(..) |
FlexDirection(..) |
FlexWrap(..) |
Float(..) |
FontKerning(..) |
FontOpticalSizing(..) |
FontStretch(..) |
FontStyle(..) |
FontSynthesis(..) |
FontVariantCaps(..) |
FontVariantPosition(..) |
FontWeight(..) |
GridAutoFlow(..) |
Hyphens(..) |
ImageOrientation(..) |
ImageRendering(..) |
ImeMode(..) |
InitialLetter(..) |
Isolation(..) |
JustifyContent(..) |
JustifyItems(..) |
JustifySelf(..) |
ListStylePosition(..) |
MaskType(..) |
MixBlendMode(..) |
MozAppearance(..) |
MozBoxAlign(..) |
MozBoxDirection(..) |
MozBoxOrient(..) |
MozBoxPack(..) |
MozControlCharacterVisibility(..) |
MozFloatEdge(..) |
MozForceBrokenImageIcon(..) |
MozMathDisplay(..) |
MozMathVariant(..) |
MozMinFontSizeRatio(..) |
MozOrient(..) |
MozOsxFontSmoothing(..) |
MozScriptLevel(..) |
MozScriptMinSize(..) |
MozScriptSizeMultiplier(..) |
MozStackSizing(..) |
MozTextSizeAdjust(..) |
MozTopLayer(..) |
MozUserFocus(..) |
MozUserInput(..) |
MozUserModify(..) |
MozUserSelect(..) |
MozWindowDragging(..) |
MozWindowShadow(..) |
ObjectFit(..) |
OutlineStyle(..) |
OverflowWrap(..) |
OverflowX(..) |
PageBreakAfter(..) |
PageBreakBefore(..) |
PageBreakInside(..) |
PaintOrder(..) |
PointerEvents(..) |
Position(..) |
Resize(..) |
RubyAlign(..) |
RubyPosition(..) |
ScrollBehavior(..) |
ShapeRendering(..) |
StrokeLinecap(..) |
StrokeLinejoin(..) |
TableLayout(..) |
TextAlignLast(..) |
TextAnchor(..) |
TextCombineUpright(..) |
TextDecorationLine(..) |
TextDecorationStyle(..) |
TextJustify(..) |
TextOrientation(..) |
TextRendering(..) |
TextTransform(..) |
TouchAction(..) |
TransformBox(..) |
TransformStyle(..) |
UnicodeBidi(..) |
VectorEffect(..) |
Visibility(..) |
WhiteSpace(..) |
WordBreak(..) |
WritingMode(..) |
XSpan(..) |
XTextZoom(..) |
ZIndex(..) |
MozBoxOrdinalGroup(..) |
Order(..) |
OverscrollBehaviorX(..) |
OverscrollBehaviorY(..) |
ScrollSnapTypeX(..) |
ScrollSnapTypeY(..) |
FlexGrow(..) |
FlexShrink(..) |
MozBoxFlex(..) |
FloodOpacity(..) |
MozWindowOpacity(..) |
Opacity(..) |
ShapeImageThreshold(..) |
StopOpacity(..) |
BorderBlockEndStyle(..) |
BorderBlockStartStyle(..) |
BorderBottomStyle(..) |
BorderInlineEndStyle(..) |
BorderInlineStartStyle(..) |
BorderLeftStyle(..) |
BorderRightStyle(..) |
BorderTopStyle(..) => {
                unsafe { debug_unreachable!() }
            }
            
            AnimationDelay(ref value) => {
                AnimationDelay(value.clone())
            }
            
            AnimationDirection(ref value) => {
                AnimationDirection(value.clone())
            }
            
            AnimationDuration(ref value) => {
                AnimationDuration(value.clone())
            }
            
            AnimationFillMode(ref value) => {
                AnimationFillMode(value.clone())
            }
            
            AnimationIterationCount(ref value) => {
                AnimationIterationCount(value.clone())
            }
            
            AnimationName(ref value) => {
                AnimationName(value.clone())
            }
            
            AnimationPlayState(ref value) => {
                AnimationPlayState(value.clone())
            }
            
            AnimationTimingFunction(ref value) => {
                AnimationTimingFunction(value.clone())
            }
            
            BackgroundAttachment(ref value) => {
                BackgroundAttachment(value.clone())
            }
            
            BackgroundBlendMode(ref value) => {
                BackgroundBlendMode(value.clone())
            }
            
            BackgroundClip(ref value) => {
                BackgroundClip(value.clone())
            }
            
            BackgroundImage(ref value) => {
                BackgroundImage(value.clone())
            }
            
            BackgroundOrigin(ref value) => {
                BackgroundOrigin(value.clone())
            }
            
            BackgroundPositionX(ref value) => {
                BackgroundPositionX(value.clone())
            }
            
            BackgroundPositionY(ref value) => {
                BackgroundPositionY(value.clone())
            }
            
            BackgroundRepeat(ref value) => {
                BackgroundRepeat(value.clone())
            }
            
            BackgroundSize(ref value) => {
                BackgroundSize(value.clone())
            }
            
            BorderImageOutset(ref value) => {
                BorderImageOutset(value.clone())
            }
            
            BorderImageSlice(ref value) => {
                BorderImageSlice(value.clone())
            }
            
            BorderImageSource(ref value) => {
                BorderImageSource(value.clone())
            }
            
            BorderImageWidth(ref value) => {
                BorderImageWidth(value.clone())
            }
            
            BorderSpacing(ref value) => {
                BorderSpacing(value.clone())
            }
            
            BoxShadow(ref value) => {
                BoxShadow(value.clone())
            }
            
            CaretColor(ref value) => {
                CaretColor(value.clone())
            }
            
            ClipPath(ref value) => {
                ClipPath(value.clone())
            }
            
            Color(ref value) => {
                Color(value.clone())
            }
            
            ColumnGap(ref value) => {
                ColumnGap(value.clone())
            }
            
            ColumnWidth(ref value) => {
                ColumnWidth(value.clone())
            }
            
            Content(ref value) => {
                Content(value.clone())
            }
            
            CounterIncrement(ref value) => {
                CounterIncrement(value.clone())
            }
            
            CounterReset(ref value) => {
                CounterReset(value.clone())
            }
            
            Cursor(ref value) => {
                Cursor(value.clone())
            }
            
            Display(ref value) => {
                Display(value.clone())
            }
            
            Filter(ref value) => {
                Filter(value.clone())
            }
            
            FontFamily(ref value) => {
                FontFamily(value.clone())
            }
            
            FontFeatureSettings(ref value) => {
                FontFeatureSettings(value.clone())
            }
            
            FontLanguageOverride(ref value) => {
                FontLanguageOverride(value.clone())
            }
            
            FontSize(ref value) => {
                FontSize(value.clone())
            }
            
            FontSizeAdjust(ref value) => {
                FontSizeAdjust(value.clone())
            }
            
            FontVariantAlternates(ref value) => {
                FontVariantAlternates(value.clone())
            }
            
            FontVariantEastAsian(ref value) => {
                FontVariantEastAsian(value.clone())
            }
            
            FontVariantLigatures(ref value) => {
                FontVariantLigatures(value.clone())
            }
            
            FontVariantNumeric(ref value) => {
                FontVariantNumeric(value.clone())
            }
            
            FontVariationSettings(ref value) => {
                FontVariationSettings(value.clone())
            }
            
            GridTemplateAreas(ref value) => {
                GridTemplateAreas(value.clone())
            }
            
            LetterSpacing(ref value) => {
                LetterSpacing(value.clone())
            }
            
            LineHeight(ref value) => {
                LineHeight(value.clone())
            }
            
            ListStyleImage(ref value) => {
                ListStyleImage(value.clone())
            }
            
            ListStyleType(ref value) => {
                ListStyleType(value.clone())
            }
            
            MaskClip(ref value) => {
                MaskClip(value.clone())
            }
            
            MaskComposite(ref value) => {
                MaskComposite(value.clone())
            }
            
            MaskImage(ref value) => {
                MaskImage(value.clone())
            }
            
            MaskMode(ref value) => {
                MaskMode(value.clone())
            }
            
            MaskOrigin(ref value) => {
                MaskOrigin(value.clone())
            }
            
            MaskPositionX(ref value) => {
                MaskPositionX(value.clone())
            }
            
            MaskPositionY(ref value) => {
                MaskPositionY(value.clone())
            }
            
            MaskRepeat(ref value) => {
                MaskRepeat(value.clone())
            }
            
            MaskSize(ref value) => {
                MaskSize(value.clone())
            }
            
            MozContextProperties(ref value) => {
                MozContextProperties(value.clone())
            }
            
            MozTabSize(ref value) => {
                MozTabSize(value.clone())
            }
            
            OutlineOffset(ref value) => {
                OutlineOffset(value.clone())
            }
            
            OverflowY(ref value) => {
                OverflowY(value.clone())
            }
            
            Perspective(ref value) => {
                Perspective(value.clone())
            }
            
            PerspectiveOrigin(ref value) => {
                PerspectiveOrigin(value.clone())
            }
            
            Quotes(ref value) => {
                Quotes(value.clone())
            }
            
            Rotate(ref value) => {
                Rotate(value.clone())
            }
            
            Scale(ref value) => {
                Scale(value.clone())
            }
            
            ScrollSnapCoordinate(ref value) => {
                ScrollSnapCoordinate(value.clone())
            }
            
            ShapeOutside(ref value) => {
                ShapeOutside(value.clone())
            }
            
            StrokeDasharray(ref value) => {
                StrokeDasharray(value.clone())
            }
            
            StrokeDashoffset(ref value) => {
                StrokeDashoffset(value.clone())
            }
            
            StrokeMiterlimit(ref value) => {
                StrokeMiterlimit(value.clone())
            }
            
            StrokeWidth(ref value) => {
                StrokeWidth(value.clone())
            }
            
            TextAlign(ref value) => {
                TextAlign(value.clone())
            }
            
            TextEmphasisPosition(ref value) => {
                TextEmphasisPosition(value.clone())
            }
            
            TextEmphasisStyle(ref value) => {
                TextEmphasisStyle(value.clone())
            }
            
            TextIndent(ref value) => {
                TextIndent(value.clone())
            }
            
            TextOverflow(ref value) => {
                TextOverflow(value.clone())
            }
            
            TextShadow(ref value) => {
                TextShadow(value.clone())
            }
            
            TransitionDelay(ref value) => {
                TransitionDelay(value.clone())
            }
            
            TransitionDuration(ref value) => {
                TransitionDuration(value.clone())
            }
            
            TransitionProperty(ref value) => {
                TransitionProperty(value.clone())
            }
            
            TransitionTimingFunction(ref value) => {
                TransitionTimingFunction(value.clone())
            }
            
            Translate(ref value) => {
                Translate(value.clone())
            }
            
            VerticalAlign(ref value) => {
                VerticalAlign(value.clone())
            }
            
            WillChange(ref value) => {
                WillChange(value.clone())
            }
            
            WordSpacing(ref value) => {
                WordSpacing(value.clone())
            }
            
            XLang(ref value) => {
                XLang(value.clone())
            }
            
            OverflowClipBoxBlock(ref value) |
OverflowClipBoxInline(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::OverflowClipBox>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            FillOpacity(ref value) |
StrokeOpacity(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::SVGOpacity>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            ScrollSnapPointsX(ref value) |
ScrollSnapPointsY(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::ScrollSnapPoint>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            MozWindowTransform(ref value) |
Transform(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::Transform>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            Clip(ref value) |
MozImageRegion(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::ClipRectOrAuto>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            GridTemplateColumns(ref value) |
GridTemplateRows(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::GridTemplateComponent>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            ObjectPosition(ref value) |
ScrollSnapDestination(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::Position>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            Fill(ref value) |
Stroke(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::SVGPaint>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            GridAutoColumns(ref value) |
GridAutoRows(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::TrackSize>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            MozWindowTransformOrigin(ref value) |
TransformOrigin(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::TransformOrigin>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            MaxBlockSize(ref value) |
MaxHeight(ref value) |
MaxInlineSize(ref value) |
MaxWidth(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::MaxLength>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            FloodColor(ref value) |
LightingColor(ref value) |
MozFontSmoothingBackgroundColor(ref value) |
StopColor(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::RGBAColor>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            MarkerEnd(ref value) |
MarkerMid(ref value) |
MarkerStart(ref value) |
MozBinding(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::UrlOrNone>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            GridColumnEnd(ref value) |
GridColumnStart(ref value) |
GridRowEnd(ref value) |
GridRowStart(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::GridLine>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            BorderBottomLeftRadius(ref value) |
BorderBottomRightRadius(ref value) |
BorderTopLeftRadius(ref value) |
BorderTopRightRadius(ref value) |
MozOutlineRadiusBottomleft(ref value) |
MozOutlineRadiusBottomright(ref value) |
MozOutlineRadiusTopleft(ref value) |
MozOutlineRadiusTopright(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::BorderCornerRadius>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            BlockSize(ref value) |
FlexBasis(ref value) |
Height(ref value) |
InlineSize(ref value) |
MinBlockSize(ref value) |
MinHeight(ref value) |
MinInlineSize(ref value) |
MinWidth(ref value) |
Width(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::MozLength>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            GridColumnGap(ref value) |
GridRowGap(ref value) |
PaddingBlockEnd(ref value) |
PaddingBlockStart(ref value) |
PaddingBottom(ref value) |
PaddingInlineEnd(ref value) |
PaddingInlineStart(ref value) |
PaddingLeft(ref value) |
PaddingRight(ref value) |
PaddingTop(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::NonNegativeLengthOrPercentage>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            BorderBlockEndWidth(ref value) |
BorderBlockStartWidth(ref value) |
BorderBottomWidth(ref value) |
BorderInlineEndWidth(ref value) |
BorderInlineStartWidth(ref value) |
BorderLeftWidth(ref value) |
BorderRightWidth(ref value) |
BorderTopWidth(ref value) |
ColumnRuleWidth(ref value) |
OutlineWidth(ref value) |
WebkitTextStrokeWidth(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::BorderSideWidth>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            BackgroundColor(ref value) |
BorderBlockEndColor(ref value) |
BorderBlockStartColor(ref value) |
BorderBottomColor(ref value) |
BorderInlineEndColor(ref value) |
BorderInlineStartColor(ref value) |
BorderLeftColor(ref value) |
BorderRightColor(ref value) |
BorderTopColor(ref value) |
ColumnRuleColor(ref value) |
OutlineColor(ref value) |
TextDecorationColor(ref value) |
TextEmphasisColor(ref value) |
WebkitTextFillColor(ref value) |
WebkitTextStrokeColor(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::Color>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            Bottom(ref value) |
Left(ref value) |
MarginBlockEnd(ref value) |
MarginBlockStart(ref value) |
MarginBottom(ref value) |
MarginInlineEnd(ref value) |
MarginInlineStart(ref value) |
MarginLeft(ref value) |
MarginRight(ref value) |
MarginTop(ref value) |
OffsetBlockEnd(ref value) |
OffsetBlockStart(ref value) |
OffsetInlineEnd(ref value) |
OffsetInlineStart(ref value) |
Right(ref value) |
Top(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::LengthOrPercentageOrAuto>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            CSSWideKeyword(ref value) => {
                CSSWideKeyword(value.clone())
            }
            
            WithVariables(ref value) => {
                WithVariables(value.clone())
            }
            
            Custom(ref value) => {
                Custom(value.clone())
            }
        }
    }
}

impl PartialEq for PropertyDeclaration {
    #[inline]
    fn eq(&self, other: &Self) -> bool {
        use self::PropertyDeclaration::*;

        unsafe {
            let this_repr =
                &*(self as *const _ as *const PropertyDeclarationVariantRepr<()>);
            let other_repr =
                &*(other as *const _ as *const PropertyDeclarationVariantRepr<()>);
            if this_repr.tag != other_repr.tag {
                return false;
            }
            match *self {
                AlignContent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::AlignContent>);
                    *this == other_repr.value
                }
                AlignItems(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::AlignItems>);
                    *this == other_repr.value
                }
                AlignSelf(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::AlignSelf>);
                    *this == other_repr.value
                }
                BackfaceVisibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::backface_visibility::SpecifiedValue>);
                    *this == other_repr.value
                }
                BorderCollapse(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::border_collapse::SpecifiedValue>);
                    *this == other_repr.value
                }
                BorderImageRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::BorderImageRepeat>);
                    *this == other_repr.value
                }
                BoxDecorationBreak(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::box_decoration_break::SpecifiedValue>);
                    *this == other_repr.value
                }
                BoxSizing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::box_sizing::SpecifiedValue>);
                    *this == other_repr.value
                }
                CaptionSide(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::caption_side::SpecifiedValue>);
                    *this == other_repr.value
                }
                Clear(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::clear::SpecifiedValue>);
                    *this == other_repr.value
                }
                ClipRule(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::clip_rule::SpecifiedValue>);
                    *this == other_repr.value
                }
                ColorAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::color_adjust::SpecifiedValue>);
                    *this == other_repr.value
                }
                ColorInterpolation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::color_interpolation::SpecifiedValue>);
                    *this == other_repr.value
                }
                ColorInterpolationFilters(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::color_interpolation_filters::SpecifiedValue>);
                    *this == other_repr.value
                }
                ColumnCount(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::ColumnCount>);
                    *this == other_repr.value
                }
                ColumnFill(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::column_fill::SpecifiedValue>);
                    *this == other_repr.value
                }
                ColumnRuleStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::column_rule_style::SpecifiedValue>);
                    *this == other_repr.value
                }
                ColumnSpan(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::column_span::SpecifiedValue>);
                    *this == other_repr.value
                }
                Contain(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Contain>);
                    *this == other_repr.value
                }
                Direction(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::direction::SpecifiedValue>);
                    *this == other_repr.value
                }
                DominantBaseline(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::dominant_baseline::SpecifiedValue>);
                    *this == other_repr.value
                }
                EmptyCells(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::empty_cells::SpecifiedValue>);
                    *this == other_repr.value
                }
                FillRule(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::fill_rule::SpecifiedValue>);
                    *this == other_repr.value
                }
                FlexDirection(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::flex_direction::SpecifiedValue>);
                    *this == other_repr.value
                }
                FlexWrap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::flex_wrap::SpecifiedValue>);
                    *this == other_repr.value
                }
                Float(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::float::SpecifiedValue>);
                    *this == other_repr.value
                }
                FontKerning(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_kerning::SpecifiedValue>);
                    *this == other_repr.value
                }
                FontOpticalSizing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_optical_sizing::SpecifiedValue>);
                    *this == other_repr.value
                }
                FontStretch(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_stretch::SpecifiedValue>);
                    *this == other_repr.value
                }
                FontStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_style::SpecifiedValue>);
                    *this == other_repr.value
                }
                FontSynthesis(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontSynthesis>);
                    *this == other_repr.value
                }
                FontVariantCaps(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_variant_caps::SpecifiedValue>);
                    *this == other_repr.value
                }
                FontVariantPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_variant_position::SpecifiedValue>);
                    *this == other_repr.value
                }
                FontWeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontWeight>);
                    *this == other_repr.value
                }
                GridAutoFlow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::GridAutoFlow>);
                    *this == other_repr.value
                }
                Hyphens(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::hyphens::SpecifiedValue>);
                    *this == other_repr.value
                }
                ImageOrientation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::ImageOrientation>);
                    *this == other_repr.value
                }
                ImageRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::image_rendering::SpecifiedValue>);
                    *this == other_repr.value
                }
                ImeMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::ime_mode::SpecifiedValue>);
                    *this == other_repr.value
                }
                InitialLetter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::InitialLetter>);
                    *this == other_repr.value
                }
                Isolation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::isolation::SpecifiedValue>);
                    *this == other_repr.value
                }
                JustifyContent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::JustifyContent>);
                    *this == other_repr.value
                }
                JustifyItems(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::JustifyItems>);
                    *this == other_repr.value
                }
                JustifySelf(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::JustifySelf>);
                    *this == other_repr.value
                }
                ListStylePosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::list_style_position::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_type::SpecifiedValue>);
                    *this == other_repr.value
                }
                MixBlendMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mix_blend_mode::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozAppearance(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_appearance::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozBoxAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_align::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozBoxDirection(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_direction::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozBoxOrient(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_orient::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozBoxPack(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_pack::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozControlCharacterVisibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_control_character_visibility::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozFloatEdge(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_float_edge::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozForceBrokenImageIcon(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::MozForceBrokenImageIcon>);
                    *this == other_repr.value
                }
                MozMathDisplay(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_math_display::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozMathVariant(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_math_variant::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozMinFontSizeRatio(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Percentage>);
                    *this == other_repr.value
                }
                MozOrient(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_orient::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozOsxFontSmoothing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_osx_font_smoothing::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozScriptLevel(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::MozScriptLevel>);
                    *this == other_repr.value
                }
                MozScriptMinSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::MozScriptMinSize>);
                    *this == other_repr.value
                }
                MozScriptSizeMultiplier(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::MozScriptSizeMultiplier>);
                    *this == other_repr.value
                }
                MozStackSizing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_stack_sizing::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozTextSizeAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_text_size_adjust::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozTopLayer(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_top_layer::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozUserFocus(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_user_focus::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozUserInput(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_user_input::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozUserModify(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_user_modify::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozUserSelect(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_user_select::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozWindowDragging(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_window_dragging::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozWindowShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_window_shadow::SpecifiedValue>);
                    *this == other_repr.value
                }
                ObjectFit(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::object_fit::SpecifiedValue>);
                    *this == other_repr.value
                }
                OutlineStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::OutlineStyle>);
                    *this == other_repr.value
                }
                OverflowWrap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::overflow_wrap::SpecifiedValue>);
                    *this == other_repr.value
                }
                OverflowX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::overflow_x::SpecifiedValue>);
                    *this == other_repr.value
                }
                PageBreakAfter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::page_break_after::SpecifiedValue>);
                    *this == other_repr.value
                }
                PageBreakBefore(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::page_break_before::SpecifiedValue>);
                    *this == other_repr.value
                }
                PageBreakInside(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::page_break_inside::SpecifiedValue>);
                    *this == other_repr.value
                }
                PaintOrder(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::SVGPaintOrder>);
                    *this == other_repr.value
                }
                PointerEvents(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::pointer_events::SpecifiedValue>);
                    *this == other_repr.value
                }
                Position(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::position::SpecifiedValue>);
                    *this == other_repr.value
                }
                Resize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::resize::SpecifiedValue>);
                    *this == other_repr.value
                }
                RubyAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::ruby_align::SpecifiedValue>);
                    *this == other_repr.value
                }
                RubyPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::ruby_position::SpecifiedValue>);
                    *this == other_repr.value
                }
                ScrollBehavior(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::scroll_behavior::SpecifiedValue>);
                    *this == other_repr.value
                }
                ShapeRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::shape_rendering::SpecifiedValue>);
                    *this == other_repr.value
                }
                StrokeLinecap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::stroke_linecap::SpecifiedValue>);
                    *this == other_repr.value
                }
                StrokeLinejoin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::stroke_linejoin::SpecifiedValue>);
                    *this == other_repr.value
                }
                TableLayout(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::table_layout::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextAlignLast(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_align_last::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_anchor::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextCombineUpright(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_combine_upright::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextDecorationLine(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::TextDecorationLine>);
                    *this == other_repr.value
                }
                TextDecorationStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_decoration_style::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextJustify(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_justify::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextOrientation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_orientation::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_rendering::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextTransform(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_transform::SpecifiedValue>);
                    *this == other_repr.value
                }
                TouchAction(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::TouchAction>);
                    *this == other_repr.value
                }
                TransformBox(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::transform_box::SpecifiedValue>);
                    *this == other_repr.value
                }
                TransformStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::TransformStyle>);
                    *this == other_repr.value
                }
                UnicodeBidi(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::unicode_bidi::SpecifiedValue>);
                    *this == other_repr.value
                }
                VectorEffect(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::vector_effect::SpecifiedValue>);
                    *this == other_repr.value
                }
                Visibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::visibility::SpecifiedValue>);
                    *this == other_repr.value
                }
                WhiteSpace(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::white_space::SpecifiedValue>);
                    *this == other_repr.value
                }
                WordBreak(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::word_break::SpecifiedValue>);
                    *this == other_repr.value
                }
                WritingMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::writing_mode::SpecifiedValue>);
                    *this == other_repr.value
                }
                XSpan(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::XSpan>);
                    *this == other_repr.value
                }
                XTextZoom(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::XTextZoom>);
                    *this == other_repr.value
                }
                ZIndex(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::ZIndex>);
                    *this == other_repr.value
                }
                MozBoxOrdinalGroup(ref this) |
Order(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Integer>);
                    *this == other_repr.value
                }
                OverscrollBehaviorX(ref this) |
OverscrollBehaviorY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::OverscrollBehavior>);
                    *this == other_repr.value
                }
                ScrollSnapTypeX(ref this) |
ScrollSnapTypeY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::ScrollSnapType>);
                    *this == other_repr.value
                }
                FlexGrow(ref this) |
FlexShrink(ref this) |
MozBoxFlex(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::NonNegativeNumber>);
                    *this == other_repr.value
                }
                FloodOpacity(ref this) |
MozWindowOpacity(ref this) |
Opacity(ref this) |
ShapeImageThreshold(ref this) |
StopOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Opacity>);
                    *this == other_repr.value
                }
                BorderBlockEndStyle(ref this) |
BorderBlockStartStyle(ref this) |
BorderBottomStyle(ref this) |
BorderInlineEndStyle(ref this) |
BorderInlineStartStyle(ref this) |
BorderLeftStyle(ref this) |
BorderRightStyle(ref this) |
BorderTopStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::BorderStyle>);
                    *this == other_repr.value
                }
                AnimationDelay(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_delay::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationDirection(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_direction::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationDuration(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_duration::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationFillMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_fill_mode::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationIterationCount(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_iteration_count::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationName(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_name::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationPlayState(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_play_state::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationTimingFunction(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_timing_function::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundAttachment(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_attachment::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundBlendMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_blend_mode::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundClip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_clip::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_image::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_origin::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_position_x::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_position_y::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_repeat::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_size::SpecifiedValue>);
                    *this == other_repr.value
                }
                BorderImageOutset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::LengthOrNumberRect>>);
                    *this == other_repr.value
                }
                BorderImageSlice(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::BorderImageSlice>>);
                    *this == other_repr.value
                }
                BorderImageSource(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::ImageLayer>>);
                    *this == other_repr.value
                }
                BorderImageWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::BorderImageWidth>>);
                    *this == other_repr.value
                }
                BorderSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::BorderSpacing>>);
                    *this == other_repr.value
                }
                BoxShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::box_shadow::SpecifiedValue>);
                    *this == other_repr.value
                }
                CaretColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::CaretColor>);
                    *this == other_repr.value
                }
                ClipPath(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::basic_shape::ClippingShape>>);
                    *this == other_repr.value
                }
                Color(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::ColorPropertyValue>);
                    *this == other_repr.value
                }
                ColumnGap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::length::NonNegativeLengthOrNormal>);
                    *this == other_repr.value
                }
                ColumnWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::length::NonNegativeLengthOrAuto>);
                    *this == other_repr.value
                }
                Content(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Content>);
                    *this == other_repr.value
                }
                CounterIncrement(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::CounterIncrement>);
                    *this == other_repr.value
                }
                CounterReset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::CounterReset>);
                    *this == other_repr.value
                }
                Cursor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Cursor>);
                    *this == other_repr.value
                }
                Display(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Display>);
                    *this == other_repr.value
                }
                Filter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::filter::SpecifiedValue>);
                    *this == other_repr.value
                }
                FontFamily(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontFamily>);
                    *this == other_repr.value
                }
                FontFeatureSettings(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontFeatureSettings>);
                    *this == other_repr.value
                }
                FontLanguageOverride(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontLanguageOverride>);
                    *this == other_repr.value
                }
                FontSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontSize>);
                    *this == other_repr.value
                }
                FontSizeAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontSizeAdjust>);
                    *this == other_repr.value
                }
                FontVariantAlternates(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontVariantAlternates>);
                    *this == other_repr.value
                }
                FontVariantEastAsian(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontVariantEastAsian>);
                    *this == other_repr.value
                }
                FontVariantLigatures(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontVariantLigatures>);
                    *this == other_repr.value
                }
                FontVariantNumeric(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontVariantNumeric>);
                    *this == other_repr.value
                }
                FontVariationSettings(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontVariationSettings>);
                    *this == other_repr.value
                }
                GridTemplateAreas(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::GridTemplateAreas>);
                    *this == other_repr.value
                }
                LetterSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::LetterSpacing>);
                    *this == other_repr.value
                }
                LineHeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::LineHeight>);
                    *this == other_repr.value
                }
                ListStyleImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::ListStyleImage>);
                    *this == other_repr.value
                }
                ListStyleType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::ListStyleType>>);
                    *this == other_repr.value
                }
                MaskClip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_clip::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskComposite(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_composite::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_image::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_mode::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_origin::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_position_x::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_position_y::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_repeat::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_size::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozContextProperties(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_context_properties::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozTabSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::MozTabSize>);
                    *this == other_repr.value
                }
                OutlineOffset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Length>);
                    *this == other_repr.value
                }
                OverflowY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::overflow_y::SpecifiedValue>);
                    *this == other_repr.value
                }
                Perspective(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Perspective>);
                    *this == other_repr.value
                }
                PerspectiveOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::position::Position>>);
                    *this == other_repr.value
                }
                Quotes(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Quotes>);
                    *this == other_repr.value
                }
                Rotate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::Rotate>>);
                    *this == other_repr.value
                }
                Scale(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::Scale>>);
                    *this == other_repr.value
                }
                ScrollSnapCoordinate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::scroll_snap_coordinate::SpecifiedValue>);
                    *this == other_repr.value
                }
                ShapeOutside(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::basic_shape::FloatAreaShape>>);
                    *this == other_repr.value
                }
                StrokeDasharray(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::SVGStrokeDashArray>);
                    *this == other_repr.value
                }
                StrokeDashoffset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::SVGLength>);
                    *this == other_repr.value
                }
                StrokeMiterlimit(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::GreaterThanOrEqualToOneNumber>);
                    *this == other_repr.value
                }
                StrokeWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::SVGWidth>);
                    *this == other_repr.value
                }
                TextAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::TextAlign>);
                    *this == other_repr.value
                }
                TextEmphasisPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_emphasis_position::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextEmphasisStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::TextEmphasisStyle>>);
                    *this == other_repr.value
                }
                TextIndent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::LengthOrPercentage>);
                    *this == other_repr.value
                }
                TextOverflow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::TextOverflow>>);
                    *this == other_repr.value
                }
                TextShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_shadow::SpecifiedValue>);
                    *this == other_repr.value
                }
                TransitionDelay(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::transition_delay::SpecifiedValue>);
                    *this == other_repr.value
                }
                TransitionDuration(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::transition_duration::SpecifiedValue>);
                    *this == other_repr.value
                }
                TransitionProperty(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::transition_property::SpecifiedValue>);
                    *this == other_repr.value
                }
                TransitionTimingFunction(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::transition_timing_function::SpecifiedValue>);
                    *this == other_repr.value
                }
                Translate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::Translate>>);
                    *this == other_repr.value
                }
                VerticalAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::VerticalAlign>);
                    *this == other_repr.value
                }
                WillChange(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::WillChange>);
                    *this == other_repr.value
                }
                WordSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::WordSpacing>);
                    *this == other_repr.value
                }
                XLang(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::XLang>);
                    *this == other_repr.value
                }
                OverflowClipBoxBlock(ref this) |
OverflowClipBoxInline(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::OverflowClipBox>);
                    *this == other_repr.value
                }
                FillOpacity(ref this) |
StrokeOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::SVGOpacity>);
                    *this == other_repr.value
                }
                ScrollSnapPointsX(ref this) |
ScrollSnapPointsY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::ScrollSnapPoint>);
                    *this == other_repr.value
                }
                MozWindowTransform(ref this) |
Transform(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Transform>);
                    *this == other_repr.value
                }
                Clip(ref this) |
MozImageRegion(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::ClipRectOrAuto>>);
                    *this == other_repr.value
                }
                GridTemplateColumns(ref this) |
GridTemplateRows(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::GridTemplateComponent>>);
                    *this == other_repr.value
                }
                ObjectPosition(ref this) |
ScrollSnapDestination(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::Position>>);
                    *this == other_repr.value
                }
                Fill(ref this) |
Stroke(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::SVGPaint>>);
                    *this == other_repr.value
                }
                GridAutoColumns(ref this) |
GridAutoRows(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::TrackSize>>);
                    *this == other_repr.value
                }
                MozWindowTransformOrigin(ref this) |
TransformOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::TransformOrigin>>);
                    *this == other_repr.value
                }
                MaxBlockSize(ref this) |
MaxHeight(ref this) |
MaxInlineSize(ref this) |
MaxWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::MaxLength>);
                    *this == other_repr.value
                }
                FloodColor(ref this) |
LightingColor(ref this) |
MozFontSmoothingBackgroundColor(ref this) |
StopColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::RGBAColor>);
                    *this == other_repr.value
                }
                MarkerEnd(ref this) |
MarkerMid(ref this) |
MarkerStart(ref this) |
MozBinding(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::UrlOrNone>);
                    *this == other_repr.value
                }
                GridColumnEnd(ref this) |
GridColumnStart(ref this) |
GridRowEnd(ref this) |
GridRowStart(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::GridLine>>);
                    *this == other_repr.value
                }
                BorderBottomLeftRadius(ref this) |
BorderBottomRightRadius(ref this) |
BorderTopLeftRadius(ref this) |
BorderTopRightRadius(ref this) |
MozOutlineRadiusBottomleft(ref this) |
MozOutlineRadiusBottomright(ref this) |
MozOutlineRadiusTopleft(ref this) |
MozOutlineRadiusTopright(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::BorderCornerRadius>>);
                    *this == other_repr.value
                }
                BlockSize(ref this) |
FlexBasis(ref this) |
Height(ref this) |
InlineSize(ref this) |
MinBlockSize(ref this) |
MinHeight(ref this) |
MinInlineSize(ref this) |
MinWidth(ref this) |
Width(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::MozLength>);
                    *this == other_repr.value
                }
                GridColumnGap(ref this) |
GridRowGap(ref this) |
PaddingBlockEnd(ref this) |
PaddingBlockStart(ref this) |
PaddingBottom(ref this) |
PaddingInlineEnd(ref this) |
PaddingInlineStart(ref this) |
PaddingLeft(ref this) |
PaddingRight(ref this) |
PaddingTop(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::NonNegativeLengthOrPercentage>);
                    *this == other_repr.value
                }
                BorderBlockEndWidth(ref this) |
BorderBlockStartWidth(ref this) |
BorderBottomWidth(ref this) |
BorderInlineEndWidth(ref this) |
BorderInlineStartWidth(ref this) |
BorderLeftWidth(ref this) |
BorderRightWidth(ref this) |
BorderTopWidth(ref this) |
ColumnRuleWidth(ref this) |
OutlineWidth(ref this) |
WebkitTextStrokeWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::BorderSideWidth>);
                    *this == other_repr.value
                }
                BackgroundColor(ref this) |
BorderBlockEndColor(ref this) |
BorderBlockStartColor(ref this) |
BorderBottomColor(ref this) |
BorderInlineEndColor(ref this) |
BorderInlineStartColor(ref this) |
BorderLeftColor(ref this) |
BorderRightColor(ref this) |
BorderTopColor(ref this) |
ColumnRuleColor(ref this) |
OutlineColor(ref this) |
TextDecorationColor(ref this) |
TextEmphasisColor(ref this) |
WebkitTextFillColor(ref this) |
WebkitTextStrokeColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Color>);
                    *this == other_repr.value
                }
                Bottom(ref this) |
Left(ref this) |
MarginBlockEnd(ref this) |
MarginBlockStart(ref this) |
MarginBottom(ref this) |
MarginInlineEnd(ref this) |
MarginInlineStart(ref this) |
MarginLeft(ref this) |
MarginRight(ref this) |
MarginTop(ref this) |
OffsetBlockEnd(ref this) |
OffsetBlockStart(ref this) |
OffsetInlineEnd(ref this) |
OffsetInlineStart(ref this) |
Right(ref this) |
Top(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::LengthOrPercentageOrAuto>);
                    *this == other_repr.value
                }
                CSSWideKeyword(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<WideKeywordDeclaration>);
                    *this == other_repr.value
                }
                WithVariables(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<VariableDeclaration>);
                    *this == other_repr.value
                }
                Custom(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<CustomDeclaration>);
                    *this == other_repr.value
                }
            }
        }
    }
}

#[cfg(feature = "gecko")]
impl MallocSizeOf for PropertyDeclaration {
    #[inline]
    fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize {
        use self::PropertyDeclaration::*;

        match *self {
            AlignContent(ref value) => {
                value.size_of(ops)
            }
            AlignItems(ref value) => {
                value.size_of(ops)
            }
            AlignSelf(ref value) => {
                value.size_of(ops)
            }
            BackfaceVisibility(ref value) => {
                value.size_of(ops)
            }
            BorderCollapse(ref value) => {
                value.size_of(ops)
            }
            BorderImageRepeat(ref value) => {
                value.size_of(ops)
            }
            BoxDecorationBreak(ref value) => {
                value.size_of(ops)
            }
            BoxSizing(ref value) => {
                value.size_of(ops)
            }
            CaptionSide(ref value) => {
                value.size_of(ops)
            }
            Clear(ref value) => {
                value.size_of(ops)
            }
            ClipRule(ref value) => {
                value.size_of(ops)
            }
            ColorAdjust(ref value) => {
                value.size_of(ops)
            }
            ColorInterpolation(ref value) => {
                value.size_of(ops)
            }
            ColorInterpolationFilters(ref value) => {
                value.size_of(ops)
            }
            ColumnCount(ref value) => {
                value.size_of(ops)
            }
            ColumnFill(ref value) => {
                value.size_of(ops)
            }
            ColumnRuleStyle(ref value) => {
                value.size_of(ops)
            }
            ColumnSpan(ref value) => {
                value.size_of(ops)
            }
            Contain(ref value) => {
                value.size_of(ops)
            }
            Direction(ref value) => {
                value.size_of(ops)
            }
            DominantBaseline(ref value) => {
                value.size_of(ops)
            }
            EmptyCells(ref value) => {
                value.size_of(ops)
            }
            FillRule(ref value) => {
                value.size_of(ops)
            }
            FlexDirection(ref value) => {
                value.size_of(ops)
            }
            FlexWrap(ref value) => {
                value.size_of(ops)
            }
            Float(ref value) => {
                value.size_of(ops)
            }
            FontKerning(ref value) => {
                value.size_of(ops)
            }
            FontOpticalSizing(ref value) => {
                value.size_of(ops)
            }
            FontStretch(ref value) => {
                value.size_of(ops)
            }
            FontStyle(ref value) => {
                value.size_of(ops)
            }
            FontSynthesis(ref value) => {
                value.size_of(ops)
            }
            FontVariantCaps(ref value) => {
                value.size_of(ops)
            }
            FontVariantPosition(ref value) => {
                value.size_of(ops)
            }
            FontWeight(ref value) => {
                value.size_of(ops)
            }
            GridAutoFlow(ref value) => {
                value.size_of(ops)
            }
            Hyphens(ref value) => {
                value.size_of(ops)
            }
            ImageOrientation(ref value) => {
                value.size_of(ops)
            }
            ImageRendering(ref value) => {
                value.size_of(ops)
            }
            ImeMode(ref value) => {
                value.size_of(ops)
            }
            InitialLetter(ref value) => {
                value.size_of(ops)
            }
            Isolation(ref value) => {
                value.size_of(ops)
            }
            JustifyContent(ref value) => {
                value.size_of(ops)
            }
            JustifyItems(ref value) => {
                value.size_of(ops)
            }
            JustifySelf(ref value) => {
                value.size_of(ops)
            }
            ListStylePosition(ref value) => {
                value.size_of(ops)
            }
            MaskType(ref value) => {
                value.size_of(ops)
            }
            MixBlendMode(ref value) => {
                value.size_of(ops)
            }
            MozAppearance(ref value) => {
                value.size_of(ops)
            }
            MozBoxAlign(ref value) => {
                value.size_of(ops)
            }
            MozBoxDirection(ref value) => {
                value.size_of(ops)
            }
            MozBoxOrient(ref value) => {
                value.size_of(ops)
            }
            MozBoxPack(ref value) => {
                value.size_of(ops)
            }
            MozControlCharacterVisibility(ref value) => {
                value.size_of(ops)
            }
            MozFloatEdge(ref value) => {
                value.size_of(ops)
            }
            MozForceBrokenImageIcon(ref value) => {
                value.size_of(ops)
            }
            MozMathDisplay(ref value) => {
                value.size_of(ops)
            }
            MozMathVariant(ref value) => {
                value.size_of(ops)
            }
            MozMinFontSizeRatio(ref value) => {
                value.size_of(ops)
            }
            MozOrient(ref value) => {
                value.size_of(ops)
            }
            MozOsxFontSmoothing(ref value) => {
                value.size_of(ops)
            }
            MozScriptLevel(ref value) => {
                value.size_of(ops)
            }
            MozScriptMinSize(ref value) => {
                value.size_of(ops)
            }
            MozScriptSizeMultiplier(ref value) => {
                value.size_of(ops)
            }
            MozStackSizing(ref value) => {
                value.size_of(ops)
            }
            MozTextSizeAdjust(ref value) => {
                value.size_of(ops)
            }
            MozTopLayer(ref value) => {
                value.size_of(ops)
            }
            MozUserFocus(ref value) => {
                value.size_of(ops)
            }
            MozUserInput(ref value) => {
                value.size_of(ops)
            }
            MozUserModify(ref value) => {
                value.size_of(ops)
            }
            MozUserSelect(ref value) => {
                value.size_of(ops)
            }
            MozWindowDragging(ref value) => {
                value.size_of(ops)
            }
            MozWindowShadow(ref value) => {
                value.size_of(ops)
            }
            ObjectFit(ref value) => {
                value.size_of(ops)
            }
            OutlineStyle(ref value) => {
                value.size_of(ops)
            }
            OverflowWrap(ref value) => {
                value.size_of(ops)
            }
            OverflowX(ref value) => {
                value.size_of(ops)
            }
            PageBreakAfter(ref value) => {
                value.size_of(ops)
            }
            PageBreakBefore(ref value) => {
                value.size_of(ops)
            }
            PageBreakInside(ref value) => {
                value.size_of(ops)
            }
            PaintOrder(ref value) => {
                value.size_of(ops)
            }
            PointerEvents(ref value) => {
                value.size_of(ops)
            }
            Position(ref value) => {
                value.size_of(ops)
            }
            Resize(ref value) => {
                value.size_of(ops)
            }
            RubyAlign(ref value) => {
                value.size_of(ops)
            }
            RubyPosition(ref value) => {
                value.size_of(ops)
            }
            ScrollBehavior(ref value) => {
                value.size_of(ops)
            }
            ShapeRendering(ref value) => {
                value.size_of(ops)
            }
            StrokeLinecap(ref value) => {
                value.size_of(ops)
            }
            StrokeLinejoin(ref value) => {
                value.size_of(ops)
            }
            TableLayout(ref value) => {
                value.size_of(ops)
            }
            TextAlignLast(ref value) => {
                value.size_of(ops)
            }
            TextAnchor(ref value) => {
                value.size_of(ops)
            }
            TextCombineUpright(ref value) => {
                value.size_of(ops)
            }
            TextDecorationLine(ref value) => {
                value.size_of(ops)
            }
            TextDecorationStyle(ref value) => {
                value.size_of(ops)
            }
            TextJustify(ref value) => {
                value.size_of(ops)
            }
            TextOrientation(ref value) => {
                value.size_of(ops)
            }
            TextRendering(ref value) => {
                value.size_of(ops)
            }
            TextTransform(ref value) => {
                value.size_of(ops)
            }
            TouchAction(ref value) => {
                value.size_of(ops)
            }
            TransformBox(ref value) => {
                value.size_of(ops)
            }
            TransformStyle(ref value) => {
                value.size_of(ops)
            }
            UnicodeBidi(ref value) => {
                value.size_of(ops)
            }
            VectorEffect(ref value) => {
                value.size_of(ops)
            }
            Visibility(ref value) => {
                value.size_of(ops)
            }
            WhiteSpace(ref value) => {
                value.size_of(ops)
            }
            WordBreak(ref value) => {
                value.size_of(ops)
            }
            WritingMode(ref value) => {
                value.size_of(ops)
            }
            XSpan(ref value) => {
                value.size_of(ops)
            }
            XTextZoom(ref value) => {
                value.size_of(ops)
            }
            ZIndex(ref value) => {
                value.size_of(ops)
            }
            MozBoxOrdinalGroup(ref value) | Order(ref value) => {
                value.size_of(ops)
            }
            OverscrollBehaviorX(ref value) | OverscrollBehaviorY(ref value) => {
                value.size_of(ops)
            }
            ScrollSnapTypeX(ref value) | ScrollSnapTypeY(ref value) => {
                value.size_of(ops)
            }
            FlexGrow(ref value) | FlexShrink(ref value) | MozBoxFlex(ref value) => {
                value.size_of(ops)
            }
            FloodOpacity(ref value) | MozWindowOpacity(ref value) | Opacity(ref value) | ShapeImageThreshold(ref value) | StopOpacity(ref value) => {
                value.size_of(ops)
            }
            BorderBlockEndStyle(ref value) | BorderBlockStartStyle(ref value) | BorderBottomStyle(ref value) | BorderInlineEndStyle(ref value) | BorderInlineStartStyle(ref value) | BorderLeftStyle(ref value) | BorderRightStyle(ref value) | BorderTopStyle(ref value) => {
                value.size_of(ops)
            }
            AnimationDelay(ref value) => {
                value.size_of(ops)
            }
            AnimationDirection(ref value) => {
                value.size_of(ops)
            }
            AnimationDuration(ref value) => {
                value.size_of(ops)
            }
            AnimationFillMode(ref value) => {
                value.size_of(ops)
            }
            AnimationIterationCount(ref value) => {
                value.size_of(ops)
            }
            AnimationName(ref value) => {
                value.size_of(ops)
            }
            AnimationPlayState(ref value) => {
                value.size_of(ops)
            }
            AnimationTimingFunction(ref value) => {
                value.size_of(ops)
            }
            BackgroundAttachment(ref value) => {
                value.size_of(ops)
            }
            BackgroundBlendMode(ref value) => {
                value.size_of(ops)
            }
            BackgroundClip(ref value) => {
                value.size_of(ops)
            }
            BackgroundImage(ref value) => {
                value.size_of(ops)
            }
            BackgroundOrigin(ref value) => {
                value.size_of(ops)
            }
            BackgroundPositionX(ref value) => {
                value.size_of(ops)
            }
            BackgroundPositionY(ref value) => {
                value.size_of(ops)
            }
            BackgroundRepeat(ref value) => {
                value.size_of(ops)
            }
            BackgroundSize(ref value) => {
                value.size_of(ops)
            }
            BorderImageOutset(ref value) => {
                value.size_of(ops)
            }
            BorderImageSlice(ref value) => {
                value.size_of(ops)
            }
            BorderImageSource(ref value) => {
                value.size_of(ops)
            }
            BorderImageWidth(ref value) => {
                value.size_of(ops)
            }
            BorderSpacing(ref value) => {
                value.size_of(ops)
            }
            BoxShadow(ref value) => {
                value.size_of(ops)
            }
            CaretColor(ref value) => {
                value.size_of(ops)
            }
            ClipPath(ref value) => {
                value.size_of(ops)
            }
            Color(ref value) => {
                value.size_of(ops)
            }
            ColumnGap(ref value) => {
                value.size_of(ops)
            }
            ColumnWidth(ref value) => {
                value.size_of(ops)
            }
            Content(ref value) => {
                value.size_of(ops)
            }
            CounterIncrement(ref value) => {
                value.size_of(ops)
            }
            CounterReset(ref value) => {
                value.size_of(ops)
            }
            Cursor(ref value) => {
                value.size_of(ops)
            }
            Display(ref value) => {
                value.size_of(ops)
            }
            Filter(ref value) => {
                value.size_of(ops)
            }
            FontFamily(ref value) => {
                value.size_of(ops)
            }
            FontFeatureSettings(ref value) => {
                value.size_of(ops)
            }
            FontLanguageOverride(ref value) => {
                value.size_of(ops)
            }
            FontSize(ref value) => {
                value.size_of(ops)
            }
            FontSizeAdjust(ref value) => {
                value.size_of(ops)
            }
            FontVariantAlternates(ref value) => {
                value.size_of(ops)
            }
            FontVariantEastAsian(ref value) => {
                value.size_of(ops)
            }
            FontVariantLigatures(ref value) => {
                value.size_of(ops)
            }
            FontVariantNumeric(ref value) => {
                value.size_of(ops)
            }
            FontVariationSettings(ref value) => {
                value.size_of(ops)
            }
            GridTemplateAreas(ref value) => {
                value.size_of(ops)
            }
            LetterSpacing(ref value) => {
                value.size_of(ops)
            }
            LineHeight(ref value) => {
                value.size_of(ops)
            }
            ListStyleImage(ref value) => {
                value.size_of(ops)
            }
            ListStyleType(ref value) => {
                value.size_of(ops)
            }
            MaskClip(ref value) => {
                value.size_of(ops)
            }
            MaskComposite(ref value) => {
                value.size_of(ops)
            }
            MaskImage(ref value) => {
                value.size_of(ops)
            }
            MaskMode(ref value) => {
                value.size_of(ops)
            }
            MaskOrigin(ref value) => {
                value.size_of(ops)
            }
            MaskPositionX(ref value) => {
                value.size_of(ops)
            }
            MaskPositionY(ref value) => {
                value.size_of(ops)
            }
            MaskRepeat(ref value) => {
                value.size_of(ops)
            }
            MaskSize(ref value) => {
                value.size_of(ops)
            }
            MozContextProperties(ref value) => {
                value.size_of(ops)
            }
            MozTabSize(ref value) => {
                value.size_of(ops)
            }
            OutlineOffset(ref value) => {
                value.size_of(ops)
            }
            OverflowY(ref value) => {
                value.size_of(ops)
            }
            Perspective(ref value) => {
                value.size_of(ops)
            }
            PerspectiveOrigin(ref value) => {
                value.size_of(ops)
            }
            Quotes(ref value) => {
                value.size_of(ops)
            }
            Rotate(ref value) => {
                value.size_of(ops)
            }
            Scale(ref value) => {
                value.size_of(ops)
            }
            ScrollSnapCoordinate(ref value) => {
                value.size_of(ops)
            }
            ShapeOutside(ref value) => {
                value.size_of(ops)
            }
            StrokeDasharray(ref value) => {
                value.size_of(ops)
            }
            StrokeDashoffset(ref value) => {
                value.size_of(ops)
            }
            StrokeMiterlimit(ref value) => {
                value.size_of(ops)
            }
            StrokeWidth(ref value) => {
                value.size_of(ops)
            }
            TextAlign(ref value) => {
                value.size_of(ops)
            }
            TextEmphasisPosition(ref value) => {
                value.size_of(ops)
            }
            TextEmphasisStyle(ref value) => {
                value.size_of(ops)
            }
            TextIndent(ref value) => {
                value.size_of(ops)
            }
            TextOverflow(ref value) => {
                value.size_of(ops)
            }
            TextShadow(ref value) => {
                value.size_of(ops)
            }
            TransitionDelay(ref value) => {
                value.size_of(ops)
            }
            TransitionDuration(ref value) => {
                value.size_of(ops)
            }
            TransitionProperty(ref value) => {
                value.size_of(ops)
            }
            TransitionTimingFunction(ref value) => {
                value.size_of(ops)
            }
            Translate(ref value) => {
                value.size_of(ops)
            }
            VerticalAlign(ref value) => {
                value.size_of(ops)
            }
            WillChange(ref value) => {
                value.size_of(ops)
            }
            WordSpacing(ref value) => {
                value.size_of(ops)
            }
            XLang(ref value) => {
                value.size_of(ops)
            }
            OverflowClipBoxBlock(ref value) | OverflowClipBoxInline(ref value) => {
                value.size_of(ops)
            }
            FillOpacity(ref value) | StrokeOpacity(ref value) => {
                value.size_of(ops)
            }
            ScrollSnapPointsX(ref value) | ScrollSnapPointsY(ref value) => {
                value.size_of(ops)
            }
            MozWindowTransform(ref value) | Transform(ref value) => {
                value.size_of(ops)
            }
            Clip(ref value) | MozImageRegion(ref value) => {
                value.size_of(ops)
            }
            GridTemplateColumns(ref value) | GridTemplateRows(ref value) => {
                value.size_of(ops)
            }
            ObjectPosition(ref value) | ScrollSnapDestination(ref value) => {
                value.size_of(ops)
            }
            Fill(ref value) | Stroke(ref value) => {
                value.size_of(ops)
            }
            GridAutoColumns(ref value) | GridAutoRows(ref value) => {
                value.size_of(ops)
            }
            MozWindowTransformOrigin(ref value) | TransformOrigin(ref value) => {
                value.size_of(ops)
            }
            MaxBlockSize(ref value) | MaxHeight(ref value) | MaxInlineSize(ref value) | MaxWidth(ref value) => {
                value.size_of(ops)
            }
            FloodColor(ref value) | LightingColor(ref value) | MozFontSmoothingBackgroundColor(ref value) | StopColor(ref value) => {
                value.size_of(ops)
            }
            MarkerEnd(ref value) | MarkerMid(ref value) | MarkerStart(ref value) | MozBinding(ref value) => {
                value.size_of(ops)
            }
            GridColumnEnd(ref value) | GridColumnStart(ref value) | GridRowEnd(ref value) | GridRowStart(ref value) => {
                value.size_of(ops)
            }
            BorderBottomLeftRadius(ref value) | BorderBottomRightRadius(ref value) | BorderTopLeftRadius(ref value) | BorderTopRightRadius(ref value) | MozOutlineRadiusBottomleft(ref value) | MozOutlineRadiusBottomright(ref value) | MozOutlineRadiusTopleft(ref value) | MozOutlineRadiusTopright(ref value) => {
                value.size_of(ops)
            }
            BlockSize(ref value) | FlexBasis(ref value) | Height(ref value) | InlineSize(ref value) | MinBlockSize(ref value) | MinHeight(ref value) | MinInlineSize(ref value) | MinWidth(ref value) | Width(ref value) => {
                value.size_of(ops)
            }
            GridColumnGap(ref value) | GridRowGap(ref value) | PaddingBlockEnd(ref value) | PaddingBlockStart(ref value) | PaddingBottom(ref value) | PaddingInlineEnd(ref value) | PaddingInlineStart(ref value) | PaddingLeft(ref value) | PaddingRight(ref value) | PaddingTop(ref value) => {
                value.size_of(ops)
            }
            BorderBlockEndWidth(ref value) | BorderBlockStartWidth(ref value) | BorderBottomWidth(ref value) | BorderInlineEndWidth(ref value) | BorderInlineStartWidth(ref value) | BorderLeftWidth(ref value) | BorderRightWidth(ref value) | BorderTopWidth(ref value) | ColumnRuleWidth(ref value) | OutlineWidth(ref value) | WebkitTextStrokeWidth(ref value) => {
                value.size_of(ops)
            }
            BackgroundColor(ref value) | BorderBlockEndColor(ref value) | BorderBlockStartColor(ref value) | BorderBottomColor(ref value) | BorderInlineEndColor(ref value) | BorderInlineStartColor(ref value) | BorderLeftColor(ref value) | BorderRightColor(ref value) | BorderTopColor(ref value) | ColumnRuleColor(ref value) | OutlineColor(ref value) | TextDecorationColor(ref value) | TextEmphasisColor(ref value) | WebkitTextFillColor(ref value) | WebkitTextStrokeColor(ref value) => {
                value.size_of(ops)
            }
            Bottom(ref value) | Left(ref value) | MarginBlockEnd(ref value) | MarginBlockStart(ref value) | MarginBottom(ref value) | MarginInlineEnd(ref value) | MarginInlineStart(ref value) | MarginLeft(ref value) | MarginRight(ref value) | MarginTop(ref value) | OffsetBlockEnd(ref value) | OffsetBlockStart(ref value) | OffsetInlineEnd(ref value) | OffsetInlineStart(ref value) | Right(ref value) | Top(ref value) => {
                value.size_of(ops)
            }
            CSSWideKeyword(ref value) => {
                value.size_of(ops)
            }
            WithVariables(ref value) => {
                value.size_of(ops)
            }
            Custom(ref value) => {
                value.size_of(ops)
            }
        }
    }
}


impl PropertyDeclaration {
    /// Like the method on ToCss, but without the type parameter to avoid
    /// accidentally monomorphizing this large function multiple times for
    /// different writers.
    pub fn to_css(&self, dest: &mut CssStringWriter) -> fmt::Result {
        use self::PropertyDeclaration::*;

        let mut dest = CssWriter::new(dest);
        match *self {
            AlignContent(ref value) => {
                value.to_css(&mut dest)
            }
            AlignItems(ref value) => {
                value.to_css(&mut dest)
            }
            AlignSelf(ref value) => {
                value.to_css(&mut dest)
            }
            BackfaceVisibility(ref value) => {
                value.to_css(&mut dest)
            }
            BorderCollapse(ref value) => {
                value.to_css(&mut dest)
            }
            BorderImageRepeat(ref value) => {
                value.to_css(&mut dest)
            }
            BoxDecorationBreak(ref value) => {
                value.to_css(&mut dest)
            }
            BoxSizing(ref value) => {
                value.to_css(&mut dest)
            }
            CaptionSide(ref value) => {
                value.to_css(&mut dest)
            }
            Clear(ref value) => {
                value.to_css(&mut dest)
            }
            ClipRule(ref value) => {
                value.to_css(&mut dest)
            }
            ColorAdjust(ref value) => {
                value.to_css(&mut dest)
            }
            ColorInterpolation(ref value) => {
                value.to_css(&mut dest)
            }
            ColorInterpolationFilters(ref value) => {
                value.to_css(&mut dest)
            }
            ColumnCount(ref value) => {
                value.to_css(&mut dest)
            }
            ColumnFill(ref value) => {
                value.to_css(&mut dest)
            }
            ColumnRuleStyle(ref value) => {
                value.to_css(&mut dest)
            }
            ColumnSpan(ref value) => {
                value.to_css(&mut dest)
            }
            Contain(ref value) => {
                value.to_css(&mut dest)
            }
            Direction(ref value) => {
                value.to_css(&mut dest)
            }
            DominantBaseline(ref value) => {
                value.to_css(&mut dest)
            }
            EmptyCells(ref value) => {
                value.to_css(&mut dest)
            }
            FillRule(ref value) => {
                value.to_css(&mut dest)
            }
            FlexDirection(ref value) => {
                value.to_css(&mut dest)
            }
            FlexWrap(ref value) => {
                value.to_css(&mut dest)
            }
            Float(ref value) => {
                value.to_css(&mut dest)
            }
            FontKerning(ref value) => {
                value.to_css(&mut dest)
            }
            FontOpticalSizing(ref value) => {
                value.to_css(&mut dest)
            }
            FontStretch(ref value) => {
                value.to_css(&mut dest)
            }
            FontStyle(ref value) => {
                value.to_css(&mut dest)
            }
            FontSynthesis(ref value) => {
                value.to_css(&mut dest)
            }
            FontVariantCaps(ref value) => {
                value.to_css(&mut dest)
            }
            FontVariantPosition(ref value) => {
                value.to_css(&mut dest)
            }
            FontWeight(ref value) => {
                value.to_css(&mut dest)
            }
            GridAutoFlow(ref value) => {
                value.to_css(&mut dest)
            }
            Hyphens(ref value) => {
                value.to_css(&mut dest)
            }
            ImageOrientation(ref value) => {
                value.to_css(&mut dest)
            }
            ImageRendering(ref value) => {
                value.to_css(&mut dest)
            }
            ImeMode(ref value) => {
                value.to_css(&mut dest)
            }
            InitialLetter(ref value) => {
                value.to_css(&mut dest)
            }
            Isolation(ref value) => {
                value.to_css(&mut dest)
            }
            JustifyContent(ref value) => {
                value.to_css(&mut dest)
            }
            JustifyItems(ref value) => {
                value.to_css(&mut dest)
            }
            JustifySelf(ref value) => {
                value.to_css(&mut dest)
            }
            ListStylePosition(ref value) => {
                value.to_css(&mut dest)
            }
            MaskType(ref value) => {
                value.to_css(&mut dest)
            }
            MixBlendMode(ref value) => {
                value.to_css(&mut dest)
            }
            MozAppearance(ref value) => {
                value.to_css(&mut dest)
            }
            MozBoxAlign(ref value) => {
                value.to_css(&mut dest)
            }
            MozBoxDirection(ref value) => {
                value.to_css(&mut dest)
            }
            MozBoxOrient(ref value) => {
                value.to_css(&mut dest)
            }
            MozBoxPack(ref value) => {
                value.to_css(&mut dest)
            }
            MozControlCharacterVisibility(ref value) => {
                value.to_css(&mut dest)
            }
            MozFloatEdge(ref value) => {
                value.to_css(&mut dest)
            }
            MozForceBrokenImageIcon(ref value) => {
                value.to_css(&mut dest)
            }
            MozMathDisplay(ref value) => {
                value.to_css(&mut dest)
            }
            MozMathVariant(ref value) => {
                value.to_css(&mut dest)
            }
            MozMinFontSizeRatio(ref value) => {
                value.to_css(&mut dest)
            }
            MozOrient(ref value) => {
                value.to_css(&mut dest)
            }
            MozOsxFontSmoothing(ref value) => {
                value.to_css(&mut dest)
            }
            MozScriptLevel(ref value) => {
                value.to_css(&mut dest)
            }
            MozScriptMinSize(ref value) => {
                value.to_css(&mut dest)
            }
            MozScriptSizeMultiplier(ref value) => {
                value.to_css(&mut dest)
            }
            MozStackSizing(ref value) => {
                value.to_css(&mut dest)
            }
            MozTextSizeAdjust(ref value) => {
                value.to_css(&mut dest)
            }
            MozTopLayer(ref value) => {
                value.to_css(&mut dest)
            }
            MozUserFocus(ref value) => {
                value.to_css(&mut dest)
            }
            MozUserInput(ref value) => {
                value.to_css(&mut dest)
            }
            MozUserModify(ref value) => {
                value.to_css(&mut dest)
            }
            MozUserSelect(ref value) => {
                value.to_css(&mut dest)
            }
            MozWindowDragging(ref value) => {
                value.to_css(&mut dest)
            }
            MozWindowShadow(ref value) => {
                value.to_css(&mut dest)
            }
            ObjectFit(ref value) => {
                value.to_css(&mut dest)
            }
            OutlineStyle(ref value) => {
                value.to_css(&mut dest)
            }
            OverflowWrap(ref value) => {
                value.to_css(&mut dest)
            }
            OverflowX(ref value) => {
                value.to_css(&mut dest)
            }
            PageBreakAfter(ref value) => {
                value.to_css(&mut dest)
            }
            PageBreakBefore(ref value) => {
                value.to_css(&mut dest)
            }
            PageBreakInside(ref value) => {
                value.to_css(&mut dest)
            }
            PaintOrder(ref value) => {
                value.to_css(&mut dest)
            }
            PointerEvents(ref value) => {
                value.to_css(&mut dest)
            }
            Position(ref value) => {
                value.to_css(&mut dest)
            }
            Resize(ref value) => {
                value.to_css(&mut dest)
            }
            RubyAlign(ref value) => {
                value.to_css(&mut dest)
            }
            RubyPosition(ref value) => {
                value.to_css(&mut dest)
            }
            ScrollBehavior(ref value) => {
                value.to_css(&mut dest)
            }
            ShapeRendering(ref value) => {
                value.to_css(&mut dest)
            }
            StrokeLinecap(ref value) => {
                value.to_css(&mut dest)
            }
            StrokeLinejoin(ref value) => {
                value.to_css(&mut dest)
            }
            TableLayout(ref value) => {
                value.to_css(&mut dest)
            }
            TextAlignLast(ref value) => {
                value.to_css(&mut dest)
            }
            TextAnchor(ref value) => {
                value.to_css(&mut dest)
            }
            TextCombineUpright(ref value) => {
                value.to_css(&mut dest)
            }
            TextDecorationLine(ref value) => {
                value.to_css(&mut dest)
            }
            TextDecorationStyle(ref value) => {
                value.to_css(&mut dest)
            }
            TextJustify(ref value) => {
                value.to_css(&mut dest)
            }
            TextOrientation(ref value) => {
                value.to_css(&mut dest)
            }
            TextRendering(ref value) => {
                value.to_css(&mut dest)
            }
            TextTransform(ref value) => {
                value.to_css(&mut dest)
            }
            TouchAction(ref value) => {
                value.to_css(&mut dest)
            }
            TransformBox(ref value) => {
                value.to_css(&mut dest)
            }
            TransformStyle(ref value) => {
                value.to_css(&mut dest)
            }
            UnicodeBidi(ref value) => {
                value.to_css(&mut dest)
            }
            VectorEffect(ref value) => {
                value.to_css(&mut dest)
            }
            Visibility(ref value) => {
                value.to_css(&mut dest)
            }
            WhiteSpace(ref value) => {
                value.to_css(&mut dest)
            }
            WordBreak(ref value) => {
                value.to_css(&mut dest)
            }
            WritingMode(ref value) => {
                value.to_css(&mut dest)
            }
            XSpan(ref value) => {
                value.to_css(&mut dest)
            }
            XTextZoom(ref value) => {
                value.to_css(&mut dest)
            }
            ZIndex(ref value) => {
                value.to_css(&mut dest)
            }
            MozBoxOrdinalGroup(ref value) | Order(ref value) => {
                value.to_css(&mut dest)
            }
            OverscrollBehaviorX(ref value) | OverscrollBehaviorY(ref value) => {
                value.to_css(&mut dest)
            }
            ScrollSnapTypeX(ref value) | ScrollSnapTypeY(ref value) => {
                value.to_css(&mut dest)
            }
            FlexGrow(ref value) | FlexShrink(ref value) | MozBoxFlex(ref value) => {
                value.to_css(&mut dest)
            }
            FloodOpacity(ref value) | MozWindowOpacity(ref value) | Opacity(ref value) | ShapeImageThreshold(ref value) | StopOpacity(ref value) => {
                value.to_css(&mut dest)
            }
            BorderBlockEndStyle(ref value) | BorderBlockStartStyle(ref value) | BorderBottomStyle(ref value) | BorderInlineEndStyle(ref value) | BorderInlineStartStyle(ref value) | BorderLeftStyle(ref value) | BorderRightStyle(ref value) | BorderTopStyle(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationDelay(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationDirection(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationDuration(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationFillMode(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationIterationCount(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationName(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationPlayState(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationTimingFunction(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundAttachment(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundBlendMode(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundClip(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundImage(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundOrigin(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundPositionX(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundPositionY(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundRepeat(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundSize(ref value) => {
                value.to_css(&mut dest)
            }
            BorderImageOutset(ref value) => {
                value.to_css(&mut dest)
            }
            BorderImageSlice(ref value) => {
                value.to_css(&mut dest)
            }
            BorderImageSource(ref value) => {
                value.to_css(&mut dest)
            }
            BorderImageWidth(ref value) => {
                value.to_css(&mut dest)
            }
            BorderSpacing(ref value) => {
                value.to_css(&mut dest)
            }
            BoxShadow(ref value) => {
                value.to_css(&mut dest)
            }
            CaretColor(ref value) => {
                value.to_css(&mut dest)
            }
            ClipPath(ref value) => {
                value.to_css(&mut dest)
            }
            Color(ref value) => {
                value.to_css(&mut dest)
            }
            ColumnGap(ref value) => {
                value.to_css(&mut dest)
            }
            ColumnWidth(ref value) => {
                value.to_css(&mut dest)
            }
            Content(ref value) => {
                value.to_css(&mut dest)
            }
            CounterIncrement(ref value) => {
                value.to_css(&mut dest)
            }
            CounterReset(ref value) => {
                value.to_css(&mut dest)
            }
            Cursor(ref value) => {
                value.to_css(&mut dest)
            }
            Display(ref value) => {
                value.to_css(&mut dest)
            }
            Filter(ref value) => {
                value.to_css(&mut dest)
            }
            FontFamily(ref value) => {
                value.to_css(&mut dest)
            }
            FontFeatureSettings(ref value) => {
                value.to_css(&mut dest)
            }
            FontLanguageOverride(ref value) => {
                value.to_css(&mut dest)
            }
            FontSize(ref value) => {
                value.to_css(&mut dest)
            }
            FontSizeAdjust(ref value) => {
                value.to_css(&mut dest)
            }
            FontVariantAlternates(ref value) => {
                value.to_css(&mut dest)
            }
            FontVariantEastAsian(ref value) => {
                value.to_css(&mut dest)
            }
            FontVariantLigatures(ref value) => {
                value.to_css(&mut dest)
            }
            FontVariantNumeric(ref value) => {
                value.to_css(&mut dest)
            }
            FontVariationSettings(ref value) => {
                value.to_css(&mut dest)
            }
            GridTemplateAreas(ref value) => {
                value.to_css(&mut dest)
            }
            LetterSpacing(ref value) => {
                value.to_css(&mut dest)
            }
            LineHeight(ref value) => {
                value.to_css(&mut dest)
            }
            ListStyleImage(ref value) => {
                value.to_css(&mut dest)
            }
            ListStyleType(ref value) => {
                value.to_css(&mut dest)
            }
            MaskClip(ref value) => {
                value.to_css(&mut dest)
            }
            MaskComposite(ref value) => {
                value.to_css(&mut dest)
            }
            MaskImage(ref value) => {
                value.to_css(&mut dest)
            }
            MaskMode(ref value) => {
                value.to_css(&mut dest)
            }
            MaskOrigin(ref value) => {
                value.to_css(&mut dest)
            }
            MaskPositionX(ref value) => {
                value.to_css(&mut dest)
            }
            MaskPositionY(ref value) => {
                value.to_css(&mut dest)
            }
            MaskRepeat(ref value) => {
                value.to_css(&mut dest)
            }
            MaskSize(ref value) => {
                value.to_css(&mut dest)
            }
            MozContextProperties(ref value) => {
                value.to_css(&mut dest)
            }
            MozTabSize(ref value) => {
                value.to_css(&mut dest)
            }
            OutlineOffset(ref value) => {
                value.to_css(&mut dest)
            }
            OverflowY(ref value) => {
                value.to_css(&mut dest)
            }
            Perspective(ref value) => {
                value.to_css(&mut dest)
            }
            PerspectiveOrigin(ref value) => {
                value.to_css(&mut dest)
            }
            Quotes(ref value) => {
                value.to_css(&mut dest)
            }
            Rotate(ref value) => {
                value.to_css(&mut dest)
            }
            Scale(ref value) => {
                value.to_css(&mut dest)
            }
            ScrollSnapCoordinate(ref value) => {
                value.to_css(&mut dest)
            }
            ShapeOutside(ref value) => {
                value.to_css(&mut dest)
            }
            StrokeDasharray(ref value) => {
                value.to_css(&mut dest)
            }
            StrokeDashoffset(ref value) => {
                value.to_css(&mut dest)
            }
            StrokeMiterlimit(ref value) => {
                value.to_css(&mut dest)
            }
            StrokeWidth(ref value) => {
                value.to_css(&mut dest)
            }
            TextAlign(ref value) => {
                value.to_css(&mut dest)
            }
            TextEmphasisPosition(ref value) => {
                value.to_css(&mut dest)
            }
            TextEmphasisStyle(ref value) => {
                value.to_css(&mut dest)
            }
            TextIndent(ref value) => {
                value.to_css(&mut dest)
            }
            TextOverflow(ref value) => {
                value.to_css(&mut dest)
            }
            TextShadow(ref value) => {
                value.to_css(&mut dest)
            }
            TransitionDelay(ref value) => {
                value.to_css(&mut dest)
            }
            TransitionDuration(ref value) => {
                value.to_css(&mut dest)
            }
            TransitionProperty(ref value) => {
                value.to_css(&mut dest)
            }
            TransitionTimingFunction(ref value) => {
                value.to_css(&mut dest)
            }
            Translate(ref value) => {
                value.to_css(&mut dest)
            }
            VerticalAlign(ref value) => {
                value.to_css(&mut dest)
            }
            WillChange(ref value) => {
                value.to_css(&mut dest)
            }
            WordSpacing(ref value) => {
                value.to_css(&mut dest)
            }
            XLang(ref value) => {
                value.to_css(&mut dest)
            }
            OverflowClipBoxBlock(ref value) | OverflowClipBoxInline(ref value) => {
                value.to_css(&mut dest)
            }
            FillOpacity(ref value) | StrokeOpacity(ref value) => {
                value.to_css(&mut dest)
            }
            ScrollSnapPointsX(ref value) | ScrollSnapPointsY(ref value) => {
                value.to_css(&mut dest)
            }
            MozWindowTransform(ref value) | Transform(ref value) => {
                value.to_css(&mut dest)
            }
            Clip(ref value) | MozImageRegion(ref value) => {
                value.to_css(&mut dest)
            }
            GridTemplateColumns(ref value) | GridTemplateRows(ref value) => {
                value.to_css(&mut dest)
            }
            ObjectPosition(ref value) | ScrollSnapDestination(ref value) => {
                value.to_css(&mut dest)
            }
            Fill(ref value) | Stroke(ref value) => {
                value.to_css(&mut dest)
            }
            GridAutoColumns(ref value) | GridAutoRows(ref value) => {
                value.to_css(&mut dest)
            }
            MozWindowTransformOrigin(ref value) | TransformOrigin(ref value) => {
                value.to_css(&mut dest)
            }
            MaxBlockSize(ref value) | MaxHeight(ref value) | MaxInlineSize(ref value) | MaxWidth(ref value) => {
                value.to_css(&mut dest)
            }
            FloodColor(ref value) | LightingColor(ref value) | MozFontSmoothingBackgroundColor(ref value) | StopColor(ref value) => {
                value.to_css(&mut dest)
            }
            MarkerEnd(ref value) | MarkerMid(ref value) | MarkerStart(ref value) | MozBinding(ref value) => {
                value.to_css(&mut dest)
            }
            GridColumnEnd(ref value) | GridColumnStart(ref value) | GridRowEnd(ref value) | GridRowStart(ref value) => {
                value.to_css(&mut dest)
            }
            BorderBottomLeftRadius(ref value) | BorderBottomRightRadius(ref value) | BorderTopLeftRadius(ref value) | BorderTopRightRadius(ref value) | MozOutlineRadiusBottomleft(ref value) | MozOutlineRadiusBottomright(ref value) | MozOutlineRadiusTopleft(ref value) | MozOutlineRadiusTopright(ref value) => {
                value.to_css(&mut dest)
            }
            BlockSize(ref value) | FlexBasis(ref value) | Height(ref value) | InlineSize(ref value) | MinBlockSize(ref value) | MinHeight(ref value) | MinInlineSize(ref value) | MinWidth(ref value) | Width(ref value) => {
                value.to_css(&mut dest)
            }
            GridColumnGap(ref value) | GridRowGap(ref value) | PaddingBlockEnd(ref value) | PaddingBlockStart(ref value) | PaddingBottom(ref value) | PaddingInlineEnd(ref value) | PaddingInlineStart(ref value) | PaddingLeft(ref value) | PaddingRight(ref value) | PaddingTop(ref value) => {
                value.to_css(&mut dest)
            }
            BorderBlockEndWidth(ref value) | BorderBlockStartWidth(ref value) | BorderBottomWidth(ref value) | BorderInlineEndWidth(ref value) | BorderInlineStartWidth(ref value) | BorderLeftWidth(ref value) | BorderRightWidth(ref value) | BorderTopWidth(ref value) | ColumnRuleWidth(ref value) | OutlineWidth(ref value) | WebkitTextStrokeWidth(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundColor(ref value) | BorderBlockEndColor(ref value) | BorderBlockStartColor(ref value) | BorderBottomColor(ref value) | BorderInlineEndColor(ref value) | BorderInlineStartColor(ref value) | BorderLeftColor(ref value) | BorderRightColor(ref value) | BorderTopColor(ref value) | ColumnRuleColor(ref value) | OutlineColor(ref value) | TextDecorationColor(ref value) | TextEmphasisColor(ref value) | WebkitTextFillColor(ref value) | WebkitTextStrokeColor(ref value) => {
                value.to_css(&mut dest)
            }
            Bottom(ref value) | Left(ref value) | MarginBlockEnd(ref value) | MarginBlockStart(ref value) | MarginBottom(ref value) | MarginInlineEnd(ref value) | MarginInlineStart(ref value) | MarginLeft(ref value) | MarginRight(ref value) | MarginTop(ref value) | OffsetBlockEnd(ref value) | OffsetBlockStart(ref value) | OffsetInlineEnd(ref value) | OffsetInlineStart(ref value) | Right(ref value) | Top(ref value) => {
                value.to_css(&mut dest)
            }
            CSSWideKeyword(ref value) => {
                value.to_css(&mut dest)
            }
            WithVariables(ref value) => {
                value.to_css(&mut dest)
            }
            Custom(ref value) => {
                value.to_css(&mut dest)
            }
        }
    }
}

/// A module with all the code related to animated properties.
///
/// This needs to be "included" by mako at least after all longhand modules,
/// given they populate the global data.
pub mod animated_properties {
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





use cssparser::Parser;
#[cfg(feature = "gecko")] use gecko_bindings::bindings::RawServoAnimationValueMap;
#[cfg(feature = "gecko")] use gecko_bindings::structs::RawGeckoGfxMatrix4x4;
#[cfg(feature = "gecko")] use gecko_bindings::structs::nsCSSPropertyID;
#[cfg(feature = "gecko")] use gecko_bindings::sugar::ownership::{HasFFI, HasSimpleFFI};
use itertools::{EitherOrBoth, Itertools};
use num_traits::Zero;
use properties::{CSSWideKeyword, PropertyDeclaration};
use properties::longhands;
use properties::longhands::font_weight::computed_value::T as FontWeight;
use properties::longhands::font_stretch::computed_value::T as FontStretch;
use properties::longhands::visibility::computed_value::T as Visibility;
use properties::PropertyId;
use properties::{LonghandId, ShorthandId};
use servo_arc::Arc;
use smallvec::SmallVec;
use std::{cmp, ptr};
use std::mem::{self, ManuallyDrop};
#[cfg(feature = "gecko")] use hash::FnvHashMap;
use style_traits::ParseError;
use super::ComputedValues;
use values::{CSSFloat, CustomIdent, Either};
use values::animated::{Animate, Procedure, ToAnimatedValue, ToAnimatedZero};
use values::animated::color::RGBA as AnimatedRGBA;
use values::animated::effects::Filter as AnimatedFilter;
use values::animated::effects::FilterList as AnimatedFilterList;
use values::computed::{Angle, CalcLengthOrPercentage};
use values::computed::{ClipRect, Context, ComputedUrl};
use values::computed::{Length, LengthOrPercentage, LengthOrPercentageOrAuto};
use values::computed::{LengthOrPercentageOrNone, MaxLength};
use values::computed::{NonNegativeNumber, Number, NumberOrPercentage, Percentage};
use values::computed::length::NonNegativeLengthOrPercentage;
use values::computed::ToComputedValue;
use values::computed::transform::{DirectionVector, Matrix, Matrix3D};
use values::computed::transform::TransformOperation as ComputedTransformOperation;
use values::computed::transform::Transform as ComputedTransform;
use values::computed::transform::Rotate as ComputedRotate;
use values::computed::transform::Translate as ComputedTranslate;
use values::computed::transform::Scale as ComputedScale;
use values::generics::transform::{self, Rotate, Translate, Scale, Transform, TransformOperation};
use values::distance::{ComputeSquaredDistance, SquaredDistance};
use values::generics::font::{FontSettings as GenericFontSettings, FontTag, VariationValue};
use values::computed::font::FontVariationSettings;
use values::generics::effects::Filter;
use values::generics::position as generic_position;
use values::generics::svg::{SVGLength,  SvgLengthOrPercentageOrNumber, SVGPaint};
use values::generics::svg::{SVGPaintKind, SVGStrokeDashArray, SVGOpacity};
use void::{self, Void};

/// <https://drafts.csswg.org/css-transitions/#animtype-repeatable-list>
pub trait RepeatableListAnimatable: Animate {}

/// Returns true if this nsCSSPropertyID is one of the animatable properties.
#[cfg(feature = "gecko")]
pub fn nscsspropertyid_is_animatable(property: nsCSSPropertyID) -> bool {
    match property {
                
    nsCSSPropertyID::eCSSProperty_align_content => true,
                
    nsCSSPropertyID::eCSSProperty_align_items => true,
                
    nsCSSPropertyID::eCSSProperty_align_self => true,
                
    nsCSSPropertyID::eCSSProperty_backface_visibility => true,
                
    nsCSSPropertyID::eCSSProperty_border_collapse => true,
                
    nsCSSPropertyID::eCSSProperty_border_image_repeat => true,
                
    nsCSSPropertyID::eCSSProperty_box_decoration_break => true,
                
    nsCSSPropertyID::eCSSProperty_box_sizing => true,
                
    nsCSSPropertyID::eCSSProperty_caption_side => true,
                
    nsCSSPropertyID::eCSSProperty_clear => true,
                
    nsCSSPropertyID::eCSSProperty_clip_rule => true,
                
    nsCSSPropertyID::eCSSProperty_color_adjust => true,
                
    nsCSSPropertyID::eCSSProperty_color_interpolation => true,
                
    nsCSSPropertyID::eCSSProperty_color_interpolation_filters => true,
                
    nsCSSPropertyID::eCSSProperty_column_count => true,
                
    nsCSSPropertyID::eCSSProperty_column_fill => true,
                
    nsCSSPropertyID::eCSSProperty_column_rule_style => true,
                
    nsCSSPropertyID::eCSSProperty_column_span => true,
                
    nsCSSPropertyID::eCSSProperty_contain => true,
                
    nsCSSPropertyID::eCSSProperty_direction => true,
                
    nsCSSPropertyID::eCSSProperty_dominant_baseline => true,
                
    nsCSSPropertyID::eCSSProperty_empty_cells => true,
                
    nsCSSPropertyID::eCSSProperty_fill_rule => true,
                
    nsCSSPropertyID::eCSSProperty_flex_direction => true,
                
    nsCSSPropertyID::eCSSProperty_flex_wrap => true,
                
    nsCSSPropertyID::eCSSProperty_float_ => true,
                
    nsCSSPropertyID::eCSSProperty_font_kerning => true,
                
    nsCSSPropertyID::eCSSProperty_font_optical_sizing => true,
                
    nsCSSPropertyID::eCSSProperty_font_stretch => true,
                
    nsCSSPropertyID::eCSSProperty_font_style => true,
                
    nsCSSPropertyID::eCSSProperty_font_synthesis => true,
                
    nsCSSPropertyID::eCSSProperty_font_variant_caps => true,
                
    nsCSSPropertyID::eCSSProperty_font_variant_position => true,
                
    nsCSSPropertyID::eCSSProperty_font_weight => true,
                
    nsCSSPropertyID::eCSSProperty_grid_auto_flow => true,
                
    nsCSSPropertyID::eCSSProperty_hyphens => true,
                
    nsCSSPropertyID::eCSSProperty_image_orientation => true,
                
    nsCSSPropertyID::eCSSProperty_image_rendering => true,
                
    nsCSSPropertyID::eCSSProperty_ime_mode => true,
                
    nsCSSPropertyID::eCSSProperty_initial_letter => true,
                
    nsCSSPropertyID::eCSSProperty_isolation => true,
                
    nsCSSPropertyID::eCSSProperty_justify_content => true,
                
    nsCSSPropertyID::eCSSProperty_justify_items => true,
                
    nsCSSPropertyID::eCSSProperty_justify_self => true,
                
    nsCSSPropertyID::eCSSProperty_list_style_position => true,
                
    nsCSSPropertyID::eCSSProperty_mask_type => true,
                
    nsCSSPropertyID::eCSSProperty_mix_blend_mode => true,
                
    nsCSSPropertyID::eCSSProperty__moz_appearance => true,
                
    nsCSSPropertyID::eCSSProperty__moz_box_align => true,
                
    nsCSSPropertyID::eCSSProperty__moz_box_direction => true,
                
    nsCSSPropertyID::eCSSProperty__moz_box_orient => true,
                
    nsCSSPropertyID::eCSSProperty__moz_box_pack => true,
                
    nsCSSPropertyID::eCSSProperty__moz_float_edge => true,
                
    nsCSSPropertyID::eCSSProperty__moz_force_broken_image_icon => true,
                
    nsCSSPropertyID::eCSSProperty__moz_orient => true,
                
    nsCSSPropertyID::eCSSProperty__moz_osx_font_smoothing => true,
                
    nsCSSPropertyID::eCSSProperty__moz_stack_sizing => true,
                
    nsCSSPropertyID::eCSSProperty__moz_text_size_adjust => true,
                
    nsCSSPropertyID::eCSSProperty__moz_user_focus => true,
                
    nsCSSPropertyID::eCSSProperty__moz_user_input => true,
                
    nsCSSPropertyID::eCSSProperty__moz_user_modify => true,
                
    nsCSSPropertyID::eCSSProperty__moz_user_select => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_dragging => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_shadow => true,
                
    nsCSSPropertyID::eCSSProperty_object_fit => true,
                
    nsCSSPropertyID::eCSSProperty_outline_style => true,
                
    nsCSSPropertyID::eCSSProperty_overflow_wrap => true,
                
    nsCSSPropertyID::eCSSProperty_overflow_x => true,
                
    nsCSSPropertyID::eCSSProperty_page_break_after => true,
                
    nsCSSPropertyID::eCSSProperty_page_break_before => true,
                
    nsCSSPropertyID::eCSSProperty_page_break_inside => true,
                
    nsCSSPropertyID::eCSSProperty_paint_order => true,
                
    nsCSSPropertyID::eCSSProperty_pointer_events => true,
                
    nsCSSPropertyID::eCSSProperty_position => true,
                
    nsCSSPropertyID::eCSSProperty_resize => true,
                
    nsCSSPropertyID::eCSSProperty_ruby_align => true,
                
    nsCSSPropertyID::eCSSProperty_ruby_position => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_behavior => true,
                
    nsCSSPropertyID::eCSSProperty_shape_rendering => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_linecap => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_linejoin => true,
                
    nsCSSPropertyID::eCSSProperty_table_layout => true,
                
    nsCSSPropertyID::eCSSProperty_text_align_last => true,
                
    nsCSSPropertyID::eCSSProperty_text_anchor => true,
                
    nsCSSPropertyID::eCSSProperty_text_combine_upright => true,
                
    nsCSSPropertyID::eCSSProperty_text_decoration_line => true,
                
    nsCSSPropertyID::eCSSProperty_text_decoration_style => true,
                
    nsCSSPropertyID::eCSSProperty_text_justify => true,
                
    nsCSSPropertyID::eCSSProperty_text_orientation => true,
                
    nsCSSPropertyID::eCSSProperty_text_rendering => true,
                
    nsCSSPropertyID::eCSSProperty_text_transform => true,
                
    nsCSSPropertyID::eCSSProperty_touch_action => true,
                
    nsCSSPropertyID::eCSSProperty_transform_box => true,
                
    nsCSSPropertyID::eCSSProperty_transform_style => true,
                
    nsCSSPropertyID::eCSSProperty_unicode_bidi => true,
                
    nsCSSPropertyID::eCSSProperty_vector_effect => true,
                
    nsCSSPropertyID::eCSSProperty_visibility => true,
                
    nsCSSPropertyID::eCSSProperty_white_space => true,
                
    nsCSSPropertyID::eCSSProperty_word_break => true,
                
    nsCSSPropertyID::eCSSProperty_writing_mode => true,
                
    nsCSSPropertyID::eCSSProperty_z_index => true,
                
    nsCSSPropertyID::eCSSProperty__moz_box_ordinal_group => true,
                
    nsCSSPropertyID::eCSSProperty_order => true,
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_x => true,
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_y => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_x => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_y => true,
                
    nsCSSPropertyID::eCSSProperty_flex_grow => true,
                
    nsCSSPropertyID::eCSSProperty_flex_shrink => true,
                
    nsCSSPropertyID::eCSSProperty__moz_box_flex => true,
                
    nsCSSPropertyID::eCSSProperty_flood_opacity => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_shape_image_threshold => true,
                
    nsCSSPropertyID::eCSSProperty_stop_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_style => true,
                
    nsCSSPropertyID::eCSSProperty_border_left_style => true,
                
    nsCSSPropertyID::eCSSProperty_border_right_style => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_style => true,
                
    nsCSSPropertyID::eCSSProperty_background_attachment => true,
                
    nsCSSPropertyID::eCSSProperty_background_blend_mode => true,
                
    nsCSSPropertyID::eCSSProperty_background_clip => true,
                
    nsCSSPropertyID::eCSSProperty_background_image => true,
                
    nsCSSPropertyID::eCSSProperty_background_origin => true,
                
    nsCSSPropertyID::eCSSProperty_background_position_x => true,
                
    nsCSSPropertyID::eCSSProperty_background_position_y => true,
                
    nsCSSPropertyID::eCSSProperty_background_repeat => true,
                
    nsCSSPropertyID::eCSSProperty_background_size => true,
                
    nsCSSPropertyID::eCSSProperty_border_image_outset => true,
                
    nsCSSPropertyID::eCSSProperty_border_image_slice => true,
                
    nsCSSPropertyID::eCSSProperty_border_image_source => true,
                
    nsCSSPropertyID::eCSSProperty_border_image_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_spacing => true,
                
    nsCSSPropertyID::eCSSProperty_box_shadow => true,
                
    nsCSSPropertyID::eCSSProperty_caret_color => true,
                
    nsCSSPropertyID::eCSSProperty_clip_path => true,
                
    nsCSSPropertyID::eCSSProperty_color => true,
                
    nsCSSPropertyID::eCSSProperty_column_gap => true,
                
    nsCSSPropertyID::eCSSProperty_column_width => true,
                
    nsCSSPropertyID::eCSSProperty_content => true,
                
    nsCSSPropertyID::eCSSProperty_counter_increment => true,
                
    nsCSSPropertyID::eCSSProperty_counter_reset => true,
                
    nsCSSPropertyID::eCSSProperty_cursor => true,
                
    nsCSSPropertyID::eCSSProperty_display => true,
                
    nsCSSPropertyID::eCSSProperty_filter => true,
                
    nsCSSPropertyID::eCSSProperty_font_family => true,
                
    nsCSSPropertyID::eCSSProperty_font_feature_settings => true,
                
    nsCSSPropertyID::eCSSProperty_font_language_override => true,
                
    nsCSSPropertyID::eCSSProperty_font_size => true,
                
    nsCSSPropertyID::eCSSProperty_font_size_adjust => true,
                
    nsCSSPropertyID::eCSSProperty_font_variant_alternates => true,
                
    nsCSSPropertyID::eCSSProperty_font_variant_east_asian => true,
                
    nsCSSPropertyID::eCSSProperty_font_variant_ligatures => true,
                
    nsCSSPropertyID::eCSSProperty_font_variant_numeric => true,
                
    nsCSSPropertyID::eCSSProperty_font_variation_settings => true,
                
    nsCSSPropertyID::eCSSProperty_grid_template_areas => true,
                
    nsCSSPropertyID::eCSSProperty_letter_spacing => true,
                
    nsCSSPropertyID::eCSSProperty_line_height => true,
                
    nsCSSPropertyID::eCSSProperty_list_style_image => true,
                
    nsCSSPropertyID::eCSSProperty_list_style_type => true,
                
    nsCSSPropertyID::eCSSProperty_mask_clip => true,
                
    nsCSSPropertyID::eCSSProperty_mask_composite => true,
                
    nsCSSPropertyID::eCSSProperty_mask_image => true,
                
    nsCSSPropertyID::eCSSProperty_mask_mode => true,
                
    nsCSSPropertyID::eCSSProperty_mask_origin => true,
                
    nsCSSPropertyID::eCSSProperty_mask_position_x => true,
                
    nsCSSPropertyID::eCSSProperty_mask_position_y => true,
                
    nsCSSPropertyID::eCSSProperty_mask_repeat => true,
                
    nsCSSPropertyID::eCSSProperty_mask_size => true,
                
    nsCSSPropertyID::eCSSProperty__moz_tab_size => true,
                
    nsCSSPropertyID::eCSSProperty_outline_offset => true,
                
    nsCSSPropertyID::eCSSProperty_overflow_y => true,
                
    nsCSSPropertyID::eCSSProperty_perspective => true,
                
    nsCSSPropertyID::eCSSProperty_perspective_origin => true,
                
    nsCSSPropertyID::eCSSProperty_quotes => true,
                
    nsCSSPropertyID::eCSSProperty_rotate => true,
                
    nsCSSPropertyID::eCSSProperty_scale => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_coordinate => true,
                
    nsCSSPropertyID::eCSSProperty_shape_outside => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_dasharray => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_dashoffset => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_miterlimit => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_width => true,
                
    nsCSSPropertyID::eCSSProperty_text_align => true,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_position => true,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_style => true,
                
    nsCSSPropertyID::eCSSProperty_text_indent => true,
                
    nsCSSPropertyID::eCSSProperty_text_overflow => true,
                
    nsCSSPropertyID::eCSSProperty_text_shadow => true,
                
    nsCSSPropertyID::eCSSProperty_translate => true,
                
    nsCSSPropertyID::eCSSProperty_vertical_align => true,
                
    nsCSSPropertyID::eCSSProperty_will_change => true,
                
    nsCSSPropertyID::eCSSProperty_word_spacing => true,
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_block => true,
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_inline => true,
                
    nsCSSPropertyID::eCSSProperty_fill_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_x => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_y => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform => true,
                
    nsCSSPropertyID::eCSSProperty_transform => true,
                
    nsCSSPropertyID::eCSSProperty_clip => true,
                
    nsCSSPropertyID::eCSSProperty__moz_image_region => true,
                
    nsCSSPropertyID::eCSSProperty_grid_template_columns => true,
                
    nsCSSPropertyID::eCSSProperty_grid_template_rows => true,
                
    nsCSSPropertyID::eCSSProperty_object_position => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_destination => true,
                
    nsCSSPropertyID::eCSSProperty_fill => true,
                
    nsCSSPropertyID::eCSSProperty_stroke => true,
                
    nsCSSPropertyID::eCSSProperty_grid_auto_columns => true,
                
    nsCSSPropertyID::eCSSProperty_grid_auto_rows => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform_origin => true,
                
    nsCSSPropertyID::eCSSProperty_transform_origin => true,
                
    nsCSSPropertyID::eCSSProperty_max_height => true,
                
    nsCSSPropertyID::eCSSProperty_max_width => true,
                
    nsCSSPropertyID::eCSSProperty_flood_color => true,
                
    nsCSSPropertyID::eCSSProperty_lighting_color => true,
                
    nsCSSPropertyID::eCSSProperty__moz_font_smoothing_background_color => true,
                
    nsCSSPropertyID::eCSSProperty_stop_color => true,
                
    nsCSSPropertyID::eCSSProperty_marker_end => true,
                
    nsCSSPropertyID::eCSSProperty_marker_mid => true,
                
    nsCSSPropertyID::eCSSProperty_marker_start => true,
                
    nsCSSPropertyID::eCSSProperty_grid_column_end => true,
                
    nsCSSPropertyID::eCSSProperty_grid_column_start => true,
                
    nsCSSPropertyID::eCSSProperty_grid_row_end => true,
                
    nsCSSPropertyID::eCSSProperty_grid_row_start => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_left_radius => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_right_radius => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_left_radius => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_right_radius => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomleft => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomright => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topleft => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topright => true,
                
    nsCSSPropertyID::eCSSProperty_flex_basis => true,
                
    nsCSSPropertyID::eCSSProperty_height => true,
                
    nsCSSPropertyID::eCSSProperty_min_height => true,
                
    nsCSSPropertyID::eCSSProperty_min_width => true,
                
    nsCSSPropertyID::eCSSProperty_width => true,
                
    nsCSSPropertyID::eCSSProperty_grid_column_gap => true,
                
    nsCSSPropertyID::eCSSProperty_grid_row_gap => true,
                
    nsCSSPropertyID::eCSSProperty_padding_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_padding_left => true,
                
    nsCSSPropertyID::eCSSProperty_padding_right => true,
                
    nsCSSPropertyID::eCSSProperty_padding_top => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_left_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_right_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_width => true,
                
    nsCSSPropertyID::eCSSProperty_column_rule_width => true,
                
    nsCSSPropertyID::eCSSProperty_outline_width => true,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_width => true,
                
    nsCSSPropertyID::eCSSProperty_background_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_left_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_right_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_color => true,
                
    nsCSSPropertyID::eCSSProperty_column_rule_color => true,
                
    nsCSSPropertyID::eCSSProperty_outline_color => true,
                
    nsCSSPropertyID::eCSSProperty_text_decoration_color => true,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_color => true,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_fill_color => true,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_color => true,
                
    nsCSSPropertyID::eCSSProperty_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_left => true,
                
    nsCSSPropertyID::eCSSProperty_margin_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_margin_left => true,
                
    nsCSSPropertyID::eCSSProperty_margin_right => true,
                
    nsCSSPropertyID::eCSSProperty_margin_top => true,
                
    nsCSSPropertyID::eCSSProperty_right => true,
                
    nsCSSPropertyID::eCSSProperty_top => true,
                
    nsCSSPropertyID::eCSSProperty_background => true,
                
    nsCSSPropertyID::eCSSProperty_background_position => true,
                
    nsCSSPropertyID::eCSSProperty_border_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_style => true,
                
    nsCSSPropertyID::eCSSProperty_border_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_top => true,
                
    nsCSSPropertyID::eCSSProperty_border_left => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_border_right => true,
                
    nsCSSPropertyID::eCSSProperty_border => true,
                
    nsCSSPropertyID::eCSSProperty_border_radius => true,
                
    nsCSSPropertyID::eCSSProperty_border_image => true,
                
    nsCSSPropertyID::eCSSProperty_overflow => true,
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type => true,
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior => true,
                
    nsCSSPropertyID::eCSSProperty_columns => true,
                
    nsCSSPropertyID::eCSSProperty_column_rule => true,
                
    nsCSSPropertyID::eCSSProperty_font => true,
                
    nsCSSPropertyID::eCSSProperty_font_variant => true,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis => true,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke => true,
                
    nsCSSPropertyID::eCSSProperty_list_style => true,
                
    nsCSSPropertyID::eCSSProperty_margin => true,
                
    nsCSSPropertyID::eCSSProperty_mask => true,
                
    nsCSSPropertyID::eCSSProperty_mask_position => true,
                
    nsCSSPropertyID::eCSSProperty_outline => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius => true,
                
    nsCSSPropertyID::eCSSProperty_padding => true,
                
    nsCSSPropertyID::eCSSProperty_flex_flow => true,
                
    nsCSSPropertyID::eCSSProperty_flex => true,
                
    nsCSSPropertyID::eCSSProperty_grid_gap => true,
                
    nsCSSPropertyID::eCSSProperty_grid_row => true,
                
    nsCSSPropertyID::eCSSProperty_grid_column => true,
                
    nsCSSPropertyID::eCSSProperty_grid_area => true,
                
    nsCSSPropertyID::eCSSProperty_grid_template => true,
                
    nsCSSPropertyID::eCSSProperty_grid => true,
                
    nsCSSPropertyID::eCSSProperty_place_content => true,
                
    nsCSSPropertyID::eCSSProperty_place_self => true,
                
    nsCSSPropertyID::eCSSProperty_place_items => true,
                
    nsCSSPropertyID::eCSSProperty_marker => true,
                
    nsCSSPropertyID::eCSSProperty_text_decoration => true,
        _ => false
    }
}

/// A given transition property, that is either `All`, a transitionable longhand property,
/// a shorthand with at least one transitionable longhand component, or an unsupported property.
// NB: This needs to be here because it needs all the longhands generated
// beforehand.
#[derive(Clone, Debug, Eq, Hash, MallocSizeOf, PartialEq, ToComputedValue, ToCss)]
pub enum TransitionProperty {
    /// A shorthand.
    Shorthand(ShorthandId),
    /// A longhand transitionable property.
    Longhand(LonghandId),
    /// Unrecognized property which could be any non-transitionable, custom property, or
    /// unknown property.
    Unsupported(CustomIdent),
}

impl TransitionProperty {
    /// Returns `all`.
    #[inline]
    pub fn all() -> Self {
        TransitionProperty::Shorthand(ShorthandId::All)
    }

    /// Parse a transition-property value.
    pub fn parse<'i, 't>(input: &mut Parser<'i, 't>) -> Result<Self, ParseError<'i>> {
        // FIXME(https://github.com/rust-lang/rust/issues/33156): remove this
        // enum and use PropertyId when stable Rust allows destructors in
        // statics.
        //
        // FIXME: This should handle aliases too.
        pub enum StaticId {
            Longhand(LonghandId),
            Shorthand(ShorthandId),
        }
        ascii_case_insensitive_phf_map! {
            static_id -> StaticId = {
                "background" => StaticId::Shorthand(ShorthandId::Background),
                "background-position" => StaticId::Shorthand(ShorthandId::BackgroundPosition),
                "border-color" => StaticId::Shorthand(ShorthandId::BorderColor),
                "border-style" => StaticId::Shorthand(ShorthandId::BorderStyle),
                "border-width" => StaticId::Shorthand(ShorthandId::BorderWidth),
                "border-top" => StaticId::Shorthand(ShorthandId::BorderTop),
                "border-left" => StaticId::Shorthand(ShorthandId::BorderLeft),
                "border-bottom" => StaticId::Shorthand(ShorthandId::BorderBottom),
                "border-right" => StaticId::Shorthand(ShorthandId::BorderRight),
                "border-block-start" => StaticId::Shorthand(ShorthandId::BorderBlockStart),
                "border-block-end" => StaticId::Shorthand(ShorthandId::BorderBlockEnd),
                "border-inline-start" => StaticId::Shorthand(ShorthandId::BorderInlineStart),
                "border-inline-end" => StaticId::Shorthand(ShorthandId::BorderInlineEnd),
                "border" => StaticId::Shorthand(ShorthandId::Border),
                "border-radius" => StaticId::Shorthand(ShorthandId::BorderRadius),
                "border-image" => StaticId::Shorthand(ShorthandId::BorderImage),
                "overflow" => StaticId::Shorthand(ShorthandId::Overflow),
                "overflow-clip-box" => StaticId::Shorthand(ShorthandId::OverflowClipBox),
                "transition" => StaticId::Shorthand(ShorthandId::Transition),
                "animation" => StaticId::Shorthand(ShorthandId::Animation),
                "scroll-snap-type" => StaticId::Shorthand(ShorthandId::ScrollSnapType),
                "overscroll-behavior" => StaticId::Shorthand(ShorthandId::OverscrollBehavior),
                "columns" => StaticId::Shorthand(ShorthandId::Columns),
                "column-rule" => StaticId::Shorthand(ShorthandId::ColumnRule),
                "font" => StaticId::Shorthand(ShorthandId::Font),
                "font-variant" => StaticId::Shorthand(ShorthandId::FontVariant),
                "text-emphasis" => StaticId::Shorthand(ShorthandId::TextEmphasis),
                "-webkit-text-stroke" => StaticId::Shorthand(ShorthandId::WebkitTextStroke),
                "list-style" => StaticId::Shorthand(ShorthandId::ListStyle),
                "margin" => StaticId::Shorthand(ShorthandId::Margin),
                "mask" => StaticId::Shorthand(ShorthandId::Mask),
                "mask-position" => StaticId::Shorthand(ShorthandId::MaskPosition),
                "outline" => StaticId::Shorthand(ShorthandId::Outline),
                "-moz-outline-radius" => StaticId::Shorthand(ShorthandId::MozOutlineRadius),
                "padding" => StaticId::Shorthand(ShorthandId::Padding),
                "flex-flow" => StaticId::Shorthand(ShorthandId::FlexFlow),
                "flex" => StaticId::Shorthand(ShorthandId::Flex),
                "grid-gap" => StaticId::Shorthand(ShorthandId::GridGap),
                "grid-row" => StaticId::Shorthand(ShorthandId::GridRow),
                "grid-column" => StaticId::Shorthand(ShorthandId::GridColumn),
                "grid-area" => StaticId::Shorthand(ShorthandId::GridArea),
                "grid-template" => StaticId::Shorthand(ShorthandId::GridTemplate),
                "grid" => StaticId::Shorthand(ShorthandId::Grid),
                "place-content" => StaticId::Shorthand(ShorthandId::PlaceContent),
                "place-self" => StaticId::Shorthand(ShorthandId::PlaceSelf),
                "place-items" => StaticId::Shorthand(ShorthandId::PlaceItems),
                "marker" => StaticId::Shorthand(ShorthandId::Marker),
                "text-decoration" => StaticId::Shorthand(ShorthandId::TextDecoration),
                "all" => StaticId::Shorthand(ShorthandId::All),
                "align-content" => StaticId::Longhand(LonghandId::AlignContent),
                "align-items" => StaticId::Longhand(LonghandId::AlignItems),
                "align-self" => StaticId::Longhand(LonghandId::AlignSelf),
                "backface-visibility" => StaticId::Longhand(LonghandId::BackfaceVisibility),
                "border-collapse" => StaticId::Longhand(LonghandId::BorderCollapse),
                "border-image-repeat" => StaticId::Longhand(LonghandId::BorderImageRepeat),
                "box-decoration-break" => StaticId::Longhand(LonghandId::BoxDecorationBreak),
                "box-sizing" => StaticId::Longhand(LonghandId::BoxSizing),
                "caption-side" => StaticId::Longhand(LonghandId::CaptionSide),
                "clear" => StaticId::Longhand(LonghandId::Clear),
                "clip-rule" => StaticId::Longhand(LonghandId::ClipRule),
                "color-adjust" => StaticId::Longhand(LonghandId::ColorAdjust),
                "color-interpolation" => StaticId::Longhand(LonghandId::ColorInterpolation),
                "color-interpolation-filters" => StaticId::Longhand(LonghandId::ColorInterpolationFilters),
                "column-count" => StaticId::Longhand(LonghandId::ColumnCount),
                "column-fill" => StaticId::Longhand(LonghandId::ColumnFill),
                "column-rule-style" => StaticId::Longhand(LonghandId::ColumnRuleStyle),
                "column-span" => StaticId::Longhand(LonghandId::ColumnSpan),
                "contain" => StaticId::Longhand(LonghandId::Contain),
                "direction" => StaticId::Longhand(LonghandId::Direction),
                "dominant-baseline" => StaticId::Longhand(LonghandId::DominantBaseline),
                "empty-cells" => StaticId::Longhand(LonghandId::EmptyCells),
                "fill-rule" => StaticId::Longhand(LonghandId::FillRule),
                "flex-direction" => StaticId::Longhand(LonghandId::FlexDirection),
                "flex-wrap" => StaticId::Longhand(LonghandId::FlexWrap),
                "float" => StaticId::Longhand(LonghandId::Float),
                "font-kerning" => StaticId::Longhand(LonghandId::FontKerning),
                "font-optical-sizing" => StaticId::Longhand(LonghandId::FontOpticalSizing),
                "font-stretch" => StaticId::Longhand(LonghandId::FontStretch),
                "font-style" => StaticId::Longhand(LonghandId::FontStyle),
                "font-synthesis" => StaticId::Longhand(LonghandId::FontSynthesis),
                "font-variant-caps" => StaticId::Longhand(LonghandId::FontVariantCaps),
                "font-variant-position" => StaticId::Longhand(LonghandId::FontVariantPosition),
                "font-weight" => StaticId::Longhand(LonghandId::FontWeight),
                "grid-auto-flow" => StaticId::Longhand(LonghandId::GridAutoFlow),
                "hyphens" => StaticId::Longhand(LonghandId::Hyphens),
                "image-orientation" => StaticId::Longhand(LonghandId::ImageOrientation),
                "image-rendering" => StaticId::Longhand(LonghandId::ImageRendering),
                "ime-mode" => StaticId::Longhand(LonghandId::ImeMode),
                "initial-letter" => StaticId::Longhand(LonghandId::InitialLetter),
                "isolation" => StaticId::Longhand(LonghandId::Isolation),
                "justify-content" => StaticId::Longhand(LonghandId::JustifyContent),
                "justify-items" => StaticId::Longhand(LonghandId::JustifyItems),
                "justify-self" => StaticId::Longhand(LonghandId::JustifySelf),
                "list-style-position" => StaticId::Longhand(LonghandId::ListStylePosition),
                "mask-type" => StaticId::Longhand(LonghandId::MaskType),
                "mix-blend-mode" => StaticId::Longhand(LonghandId::MixBlendMode),
                "-moz-appearance" => StaticId::Longhand(LonghandId::MozAppearance),
                "-moz-box-align" => StaticId::Longhand(LonghandId::MozBoxAlign),
                "-moz-box-direction" => StaticId::Longhand(LonghandId::MozBoxDirection),
                "-moz-box-orient" => StaticId::Longhand(LonghandId::MozBoxOrient),
                "-moz-box-pack" => StaticId::Longhand(LonghandId::MozBoxPack),
                "-moz-control-character-visibility" => StaticId::Longhand(LonghandId::MozControlCharacterVisibility),
                "-moz-float-edge" => StaticId::Longhand(LonghandId::MozFloatEdge),
                "-moz-force-broken-image-icon" => StaticId::Longhand(LonghandId::MozForceBrokenImageIcon),
                "-moz-math-display" => StaticId::Longhand(LonghandId::MozMathDisplay),
                "-moz-math-variant" => StaticId::Longhand(LonghandId::MozMathVariant),
                "-moz-min-font-size-ratio" => StaticId::Longhand(LonghandId::MozMinFontSizeRatio),
                "-moz-orient" => StaticId::Longhand(LonghandId::MozOrient),
                "-moz-osx-font-smoothing" => StaticId::Longhand(LonghandId::MozOsxFontSmoothing),
                "-moz-script-level" => StaticId::Longhand(LonghandId::MozScriptLevel),
                "-moz-script-min-size" => StaticId::Longhand(LonghandId::MozScriptMinSize),
                "-moz-script-size-multiplier" => StaticId::Longhand(LonghandId::MozScriptSizeMultiplier),
                "-moz-stack-sizing" => StaticId::Longhand(LonghandId::MozStackSizing),
                "-moz-text-size-adjust" => StaticId::Longhand(LonghandId::MozTextSizeAdjust),
                "-moz-top-layer" => StaticId::Longhand(LonghandId::MozTopLayer),
                "-moz-user-focus" => StaticId::Longhand(LonghandId::MozUserFocus),
                "-moz-user-input" => StaticId::Longhand(LonghandId::MozUserInput),
                "-moz-user-modify" => StaticId::Longhand(LonghandId::MozUserModify),
                "-moz-user-select" => StaticId::Longhand(LonghandId::MozUserSelect),
                "-moz-window-dragging" => StaticId::Longhand(LonghandId::MozWindowDragging),
                "-moz-window-shadow" => StaticId::Longhand(LonghandId::MozWindowShadow),
                "object-fit" => StaticId::Longhand(LonghandId::ObjectFit),
                "outline-style" => StaticId::Longhand(LonghandId::OutlineStyle),
                "overflow-wrap" => StaticId::Longhand(LonghandId::OverflowWrap),
                "overflow-x" => StaticId::Longhand(LonghandId::OverflowX),
                "page-break-after" => StaticId::Longhand(LonghandId::PageBreakAfter),
                "page-break-before" => StaticId::Longhand(LonghandId::PageBreakBefore),
                "page-break-inside" => StaticId::Longhand(LonghandId::PageBreakInside),
                "paint-order" => StaticId::Longhand(LonghandId::PaintOrder),
                "pointer-events" => StaticId::Longhand(LonghandId::PointerEvents),
                "position" => StaticId::Longhand(LonghandId::Position),
                "resize" => StaticId::Longhand(LonghandId::Resize),
                "ruby-align" => StaticId::Longhand(LonghandId::RubyAlign),
                "ruby-position" => StaticId::Longhand(LonghandId::RubyPosition),
                "scroll-behavior" => StaticId::Longhand(LonghandId::ScrollBehavior),
                "shape-rendering" => StaticId::Longhand(LonghandId::ShapeRendering),
                "stroke-linecap" => StaticId::Longhand(LonghandId::StrokeLinecap),
                "stroke-linejoin" => StaticId::Longhand(LonghandId::StrokeLinejoin),
                "table-layout" => StaticId::Longhand(LonghandId::TableLayout),
                "text-align-last" => StaticId::Longhand(LonghandId::TextAlignLast),
                "text-anchor" => StaticId::Longhand(LonghandId::TextAnchor),
                "text-combine-upright" => StaticId::Longhand(LonghandId::TextCombineUpright),
                "text-decoration-line" => StaticId::Longhand(LonghandId::TextDecorationLine),
                "text-decoration-style" => StaticId::Longhand(LonghandId::TextDecorationStyle),
                "text-justify" => StaticId::Longhand(LonghandId::TextJustify),
                "text-orientation" => StaticId::Longhand(LonghandId::TextOrientation),
                "text-rendering" => StaticId::Longhand(LonghandId::TextRendering),
                "text-transform" => StaticId::Longhand(LonghandId::TextTransform),
                "touch-action" => StaticId::Longhand(LonghandId::TouchAction),
                "transform-box" => StaticId::Longhand(LonghandId::TransformBox),
                "transform-style" => StaticId::Longhand(LonghandId::TransformStyle),
                "unicode-bidi" => StaticId::Longhand(LonghandId::UnicodeBidi),
                "vector-effect" => StaticId::Longhand(LonghandId::VectorEffect),
                "visibility" => StaticId::Longhand(LonghandId::Visibility),
                "white-space" => StaticId::Longhand(LonghandId::WhiteSpace),
                "word-break" => StaticId::Longhand(LonghandId::WordBreak),
                "writing-mode" => StaticId::Longhand(LonghandId::WritingMode),
                "-x-span" => StaticId::Longhand(LonghandId::XSpan),
                "-x-text-zoom" => StaticId::Longhand(LonghandId::XTextZoom),
                "z-index" => StaticId::Longhand(LonghandId::ZIndex),
                "-moz-box-ordinal-group" => StaticId::Longhand(LonghandId::MozBoxOrdinalGroup),
                "order" => StaticId::Longhand(LonghandId::Order),
                "overscroll-behavior-x" => StaticId::Longhand(LonghandId::OverscrollBehaviorX),
                "overscroll-behavior-y" => StaticId::Longhand(LonghandId::OverscrollBehaviorY),
                "scroll-snap-type-x" => StaticId::Longhand(LonghandId::ScrollSnapTypeX),
                "scroll-snap-type-y" => StaticId::Longhand(LonghandId::ScrollSnapTypeY),
                "flex-grow" => StaticId::Longhand(LonghandId::FlexGrow),
                "flex-shrink" => StaticId::Longhand(LonghandId::FlexShrink),
                "-moz-box-flex" => StaticId::Longhand(LonghandId::MozBoxFlex),
                "flood-opacity" => StaticId::Longhand(LonghandId::FloodOpacity),
                "-moz-window-opacity" => StaticId::Longhand(LonghandId::MozWindowOpacity),
                "opacity" => StaticId::Longhand(LonghandId::Opacity),
                "shape-image-threshold" => StaticId::Longhand(LonghandId::ShapeImageThreshold),
                "stop-opacity" => StaticId::Longhand(LonghandId::StopOpacity),
                "border-block-end-style" => StaticId::Longhand(LonghandId::BorderBlockEndStyle),
                "border-block-start-style" => StaticId::Longhand(LonghandId::BorderBlockStartStyle),
                "border-bottom-style" => StaticId::Longhand(LonghandId::BorderBottomStyle),
                "border-inline-end-style" => StaticId::Longhand(LonghandId::BorderInlineEndStyle),
                "border-inline-start-style" => StaticId::Longhand(LonghandId::BorderInlineStartStyle),
                "border-left-style" => StaticId::Longhand(LonghandId::BorderLeftStyle),
                "border-right-style" => StaticId::Longhand(LonghandId::BorderRightStyle),
                "border-top-style" => StaticId::Longhand(LonghandId::BorderTopStyle),
                "animation-delay" => StaticId::Longhand(LonghandId::AnimationDelay),
                "animation-direction" => StaticId::Longhand(LonghandId::AnimationDirection),
                "animation-duration" => StaticId::Longhand(LonghandId::AnimationDuration),
                "animation-fill-mode" => StaticId::Longhand(LonghandId::AnimationFillMode),
                "animation-iteration-count" => StaticId::Longhand(LonghandId::AnimationIterationCount),
                "animation-name" => StaticId::Longhand(LonghandId::AnimationName),
                "animation-play-state" => StaticId::Longhand(LonghandId::AnimationPlayState),
                "animation-timing-function" => StaticId::Longhand(LonghandId::AnimationTimingFunction),
                "background-attachment" => StaticId::Longhand(LonghandId::BackgroundAttachment),
                "background-blend-mode" => StaticId::Longhand(LonghandId::BackgroundBlendMode),
                "background-clip" => StaticId::Longhand(LonghandId::BackgroundClip),
                "background-image" => StaticId::Longhand(LonghandId::BackgroundImage),
                "background-origin" => StaticId::Longhand(LonghandId::BackgroundOrigin),
                "background-position-x" => StaticId::Longhand(LonghandId::BackgroundPositionX),
                "background-position-y" => StaticId::Longhand(LonghandId::BackgroundPositionY),
                "background-repeat" => StaticId::Longhand(LonghandId::BackgroundRepeat),
                "background-size" => StaticId::Longhand(LonghandId::BackgroundSize),
                "border-image-outset" => StaticId::Longhand(LonghandId::BorderImageOutset),
                "border-image-slice" => StaticId::Longhand(LonghandId::BorderImageSlice),
                "border-image-source" => StaticId::Longhand(LonghandId::BorderImageSource),
                "border-image-width" => StaticId::Longhand(LonghandId::BorderImageWidth),
                "border-spacing" => StaticId::Longhand(LonghandId::BorderSpacing),
                "box-shadow" => StaticId::Longhand(LonghandId::BoxShadow),
                "caret-color" => StaticId::Longhand(LonghandId::CaretColor),
                "clip-path" => StaticId::Longhand(LonghandId::ClipPath),
                "color" => StaticId::Longhand(LonghandId::Color),
                "column-gap" => StaticId::Longhand(LonghandId::ColumnGap),
                "column-width" => StaticId::Longhand(LonghandId::ColumnWidth),
                "content" => StaticId::Longhand(LonghandId::Content),
                "counter-increment" => StaticId::Longhand(LonghandId::CounterIncrement),
                "counter-reset" => StaticId::Longhand(LonghandId::CounterReset),
                "cursor" => StaticId::Longhand(LonghandId::Cursor),
                "display" => StaticId::Longhand(LonghandId::Display),
                "filter" => StaticId::Longhand(LonghandId::Filter),
                "font-family" => StaticId::Longhand(LonghandId::FontFamily),
                "font-feature-settings" => StaticId::Longhand(LonghandId::FontFeatureSettings),
                "font-language-override" => StaticId::Longhand(LonghandId::FontLanguageOverride),
                "font-size" => StaticId::Longhand(LonghandId::FontSize),
                "font-size-adjust" => StaticId::Longhand(LonghandId::FontSizeAdjust),
                "font-variant-alternates" => StaticId::Longhand(LonghandId::FontVariantAlternates),
                "font-variant-east-asian" => StaticId::Longhand(LonghandId::FontVariantEastAsian),
                "font-variant-ligatures" => StaticId::Longhand(LonghandId::FontVariantLigatures),
                "font-variant-numeric" => StaticId::Longhand(LonghandId::FontVariantNumeric),
                "font-variation-settings" => StaticId::Longhand(LonghandId::FontVariationSettings),
                "grid-template-areas" => StaticId::Longhand(LonghandId::GridTemplateAreas),
                "letter-spacing" => StaticId::Longhand(LonghandId::LetterSpacing),
                "line-height" => StaticId::Longhand(LonghandId::LineHeight),
                "list-style-image" => StaticId::Longhand(LonghandId::ListStyleImage),
                "list-style-type" => StaticId::Longhand(LonghandId::ListStyleType),
                "mask-clip" => StaticId::Longhand(LonghandId::MaskClip),
                "mask-composite" => StaticId::Longhand(LonghandId::MaskComposite),
                "mask-image" => StaticId::Longhand(LonghandId::MaskImage),
                "mask-mode" => StaticId::Longhand(LonghandId::MaskMode),
                "mask-origin" => StaticId::Longhand(LonghandId::MaskOrigin),
                "mask-position-x" => StaticId::Longhand(LonghandId::MaskPositionX),
                "mask-position-y" => StaticId::Longhand(LonghandId::MaskPositionY),
                "mask-repeat" => StaticId::Longhand(LonghandId::MaskRepeat),
                "mask-size" => StaticId::Longhand(LonghandId::MaskSize),
                "-moz-context-properties" => StaticId::Longhand(LonghandId::MozContextProperties),
                "-moz-tab-size" => StaticId::Longhand(LonghandId::MozTabSize),
                "outline-offset" => StaticId::Longhand(LonghandId::OutlineOffset),
                "overflow-y" => StaticId::Longhand(LonghandId::OverflowY),
                "perspective" => StaticId::Longhand(LonghandId::Perspective),
                "perspective-origin" => StaticId::Longhand(LonghandId::PerspectiveOrigin),
                "quotes" => StaticId::Longhand(LonghandId::Quotes),
                "rotate" => StaticId::Longhand(LonghandId::Rotate),
                "scale" => StaticId::Longhand(LonghandId::Scale),
                "scroll-snap-coordinate" => StaticId::Longhand(LonghandId::ScrollSnapCoordinate),
                "shape-outside" => StaticId::Longhand(LonghandId::ShapeOutside),
                "stroke-dasharray" => StaticId::Longhand(LonghandId::StrokeDasharray),
                "stroke-dashoffset" => StaticId::Longhand(LonghandId::StrokeDashoffset),
                "stroke-miterlimit" => StaticId::Longhand(LonghandId::StrokeMiterlimit),
                "stroke-width" => StaticId::Longhand(LonghandId::StrokeWidth),
                "text-align" => StaticId::Longhand(LonghandId::TextAlign),
                "text-emphasis-position" => StaticId::Longhand(LonghandId::TextEmphasisPosition),
                "text-emphasis-style" => StaticId::Longhand(LonghandId::TextEmphasisStyle),
                "text-indent" => StaticId::Longhand(LonghandId::TextIndent),
                "text-overflow" => StaticId::Longhand(LonghandId::TextOverflow),
                "text-shadow" => StaticId::Longhand(LonghandId::TextShadow),
                "transition-delay" => StaticId::Longhand(LonghandId::TransitionDelay),
                "transition-duration" => StaticId::Longhand(LonghandId::TransitionDuration),
                "transition-property" => StaticId::Longhand(LonghandId::TransitionProperty),
                "transition-timing-function" => StaticId::Longhand(LonghandId::TransitionTimingFunction),
                "translate" => StaticId::Longhand(LonghandId::Translate),
                "vertical-align" => StaticId::Longhand(LonghandId::VerticalAlign),
                "will-change" => StaticId::Longhand(LonghandId::WillChange),
                "word-spacing" => StaticId::Longhand(LonghandId::WordSpacing),
                "-x-lang" => StaticId::Longhand(LonghandId::XLang),
                "overflow-clip-box-block" => StaticId::Longhand(LonghandId::OverflowClipBoxBlock),
                "overflow-clip-box-inline" => StaticId::Longhand(LonghandId::OverflowClipBoxInline),
                "fill-opacity" => StaticId::Longhand(LonghandId::FillOpacity),
                "stroke-opacity" => StaticId::Longhand(LonghandId::StrokeOpacity),
                "scroll-snap-points-x" => StaticId::Longhand(LonghandId::ScrollSnapPointsX),
                "scroll-snap-points-y" => StaticId::Longhand(LonghandId::ScrollSnapPointsY),
                "-moz-window-transform" => StaticId::Longhand(LonghandId::MozWindowTransform),
                "transform" => StaticId::Longhand(LonghandId::Transform),
                "clip" => StaticId::Longhand(LonghandId::Clip),
                "-moz-image-region" => StaticId::Longhand(LonghandId::MozImageRegion),
                "grid-template-columns" => StaticId::Longhand(LonghandId::GridTemplateColumns),
                "grid-template-rows" => StaticId::Longhand(LonghandId::GridTemplateRows),
                "object-position" => StaticId::Longhand(LonghandId::ObjectPosition),
                "scroll-snap-destination" => StaticId::Longhand(LonghandId::ScrollSnapDestination),
                "fill" => StaticId::Longhand(LonghandId::Fill),
                "stroke" => StaticId::Longhand(LonghandId::Stroke),
                "grid-auto-columns" => StaticId::Longhand(LonghandId::GridAutoColumns),
                "grid-auto-rows" => StaticId::Longhand(LonghandId::GridAutoRows),
                "-moz-window-transform-origin" => StaticId::Longhand(LonghandId::MozWindowTransformOrigin),
                "transform-origin" => StaticId::Longhand(LonghandId::TransformOrigin),
                "max-block-size" => StaticId::Longhand(LonghandId::MaxBlockSize),
                "max-height" => StaticId::Longhand(LonghandId::MaxHeight),
                "max-inline-size" => StaticId::Longhand(LonghandId::MaxInlineSize),
                "max-width" => StaticId::Longhand(LonghandId::MaxWidth),
                "flood-color" => StaticId::Longhand(LonghandId::FloodColor),
                "lighting-color" => StaticId::Longhand(LonghandId::LightingColor),
                "-moz-font-smoothing-background-color" => StaticId::Longhand(LonghandId::MozFontSmoothingBackgroundColor),
                "stop-color" => StaticId::Longhand(LonghandId::StopColor),
                "marker-end" => StaticId::Longhand(LonghandId::MarkerEnd),
                "marker-mid" => StaticId::Longhand(LonghandId::MarkerMid),
                "marker-start" => StaticId::Longhand(LonghandId::MarkerStart),
                "-moz-binding" => StaticId::Longhand(LonghandId::MozBinding),
                "grid-column-end" => StaticId::Longhand(LonghandId::GridColumnEnd),
                "grid-column-start" => StaticId::Longhand(LonghandId::GridColumnStart),
                "grid-row-end" => StaticId::Longhand(LonghandId::GridRowEnd),
                "grid-row-start" => StaticId::Longhand(LonghandId::GridRowStart),
                "border-bottom-left-radius" => StaticId::Longhand(LonghandId::BorderBottomLeftRadius),
                "border-bottom-right-radius" => StaticId::Longhand(LonghandId::BorderBottomRightRadius),
                "border-top-left-radius" => StaticId::Longhand(LonghandId::BorderTopLeftRadius),
                "border-top-right-radius" => StaticId::Longhand(LonghandId::BorderTopRightRadius),
                "-moz-outline-radius-bottomleft" => StaticId::Longhand(LonghandId::MozOutlineRadiusBottomleft),
                "-moz-outline-radius-bottomright" => StaticId::Longhand(LonghandId::MozOutlineRadiusBottomright),
                "-moz-outline-radius-topleft" => StaticId::Longhand(LonghandId::MozOutlineRadiusTopleft),
                "-moz-outline-radius-topright" => StaticId::Longhand(LonghandId::MozOutlineRadiusTopright),
                "block-size" => StaticId::Longhand(LonghandId::BlockSize),
                "flex-basis" => StaticId::Longhand(LonghandId::FlexBasis),
                "height" => StaticId::Longhand(LonghandId::Height),
                "inline-size" => StaticId::Longhand(LonghandId::InlineSize),
                "min-block-size" => StaticId::Longhand(LonghandId::MinBlockSize),
                "min-height" => StaticId::Longhand(LonghandId::MinHeight),
                "min-inline-size" => StaticId::Longhand(LonghandId::MinInlineSize),
                "min-width" => StaticId::Longhand(LonghandId::MinWidth),
                "width" => StaticId::Longhand(LonghandId::Width),
                "grid-column-gap" => StaticId::Longhand(LonghandId::GridColumnGap),
                "grid-row-gap" => StaticId::Longhand(LonghandId::GridRowGap),
                "padding-block-end" => StaticId::Longhand(LonghandId::PaddingBlockEnd),
                "padding-block-start" => StaticId::Longhand(LonghandId::PaddingBlockStart),
                "padding-bottom" => StaticId::Longhand(LonghandId::PaddingBottom),
                "padding-inline-end" => StaticId::Longhand(LonghandId::PaddingInlineEnd),
                "padding-inline-start" => StaticId::Longhand(LonghandId::PaddingInlineStart),
                "padding-left" => StaticId::Longhand(LonghandId::PaddingLeft),
                "padding-right" => StaticId::Longhand(LonghandId::PaddingRight),
                "padding-top" => StaticId::Longhand(LonghandId::PaddingTop),
                "border-block-end-width" => StaticId::Longhand(LonghandId::BorderBlockEndWidth),
                "border-block-start-width" => StaticId::Longhand(LonghandId::BorderBlockStartWidth),
                "border-bottom-width" => StaticId::Longhand(LonghandId::BorderBottomWidth),
                "border-inline-end-width" => StaticId::Longhand(LonghandId::BorderInlineEndWidth),
                "border-inline-start-width" => StaticId::Longhand(LonghandId::BorderInlineStartWidth),
                "border-left-width" => StaticId::Longhand(LonghandId::BorderLeftWidth),
                "border-right-width" => StaticId::Longhand(LonghandId::BorderRightWidth),
                "border-top-width" => StaticId::Longhand(LonghandId::BorderTopWidth),
                "column-rule-width" => StaticId::Longhand(LonghandId::ColumnRuleWidth),
                "outline-width" => StaticId::Longhand(LonghandId::OutlineWidth),
                "-webkit-text-stroke-width" => StaticId::Longhand(LonghandId::WebkitTextStrokeWidth),
                "background-color" => StaticId::Longhand(LonghandId::BackgroundColor),
                "border-block-end-color" => StaticId::Longhand(LonghandId::BorderBlockEndColor),
                "border-block-start-color" => StaticId::Longhand(LonghandId::BorderBlockStartColor),
                "border-bottom-color" => StaticId::Longhand(LonghandId::BorderBottomColor),
                "border-inline-end-color" => StaticId::Longhand(LonghandId::BorderInlineEndColor),
                "border-inline-start-color" => StaticId::Longhand(LonghandId::BorderInlineStartColor),
                "border-left-color" => StaticId::Longhand(LonghandId::BorderLeftColor),
                "border-right-color" => StaticId::Longhand(LonghandId::BorderRightColor),
                "border-top-color" => StaticId::Longhand(LonghandId::BorderTopColor),
                "column-rule-color" => StaticId::Longhand(LonghandId::ColumnRuleColor),
                "outline-color" => StaticId::Longhand(LonghandId::OutlineColor),
                "text-decoration-color" => StaticId::Longhand(LonghandId::TextDecorationColor),
                "text-emphasis-color" => StaticId::Longhand(LonghandId::TextEmphasisColor),
                "-webkit-text-fill-color" => StaticId::Longhand(LonghandId::WebkitTextFillColor),
                "-webkit-text-stroke-color" => StaticId::Longhand(LonghandId::WebkitTextStrokeColor),
                "bottom" => StaticId::Longhand(LonghandId::Bottom),
                "left" => StaticId::Longhand(LonghandId::Left),
                "margin-block-end" => StaticId::Longhand(LonghandId::MarginBlockEnd),
                "margin-block-start" => StaticId::Longhand(LonghandId::MarginBlockStart),
                "margin-bottom" => StaticId::Longhand(LonghandId::MarginBottom),
                "margin-inline-end" => StaticId::Longhand(LonghandId::MarginInlineEnd),
                "margin-inline-start" => StaticId::Longhand(LonghandId::MarginInlineStart),
                "margin-left" => StaticId::Longhand(LonghandId::MarginLeft),
                "margin-right" => StaticId::Longhand(LonghandId::MarginRight),
                "margin-top" => StaticId::Longhand(LonghandId::MarginTop),
                "offset-block-end" => StaticId::Longhand(LonghandId::OffsetBlockEnd),
                "offset-block-start" => StaticId::Longhand(LonghandId::OffsetBlockStart),
                "offset-inline-end" => StaticId::Longhand(LonghandId::OffsetInlineEnd),
                "offset-inline-start" => StaticId::Longhand(LonghandId::OffsetInlineStart),
                "right" => StaticId::Longhand(LonghandId::Right),
                "top" => StaticId::Longhand(LonghandId::Top),
            }
        }

        let location = input.current_source_location();
        let ident = input.expect_ident()?;

        Ok(match static_id(&ident) {
            Some(&StaticId::Longhand(id)) => TransitionProperty::Longhand(id),
            Some(&StaticId::Shorthand(id)) => TransitionProperty::Shorthand(id),
            None => {
                TransitionProperty::Unsupported(
                    CustomIdent::from_ident(location, ident, &["none"])?,
                )
            },
        })
    }

    /// Convert TransitionProperty to nsCSSPropertyID.
    #[cfg(feature = "gecko")]
    pub fn to_nscsspropertyid(&self) -> Result<nsCSSPropertyID, ()> {
        Ok(match *self {
            TransitionProperty::Shorthand(ShorthandId::All) => {
                nsCSSPropertyID::eCSSPropertyExtra_all_properties
            }
            TransitionProperty::Shorthand(ref id) => id.to_nscsspropertyid(),
            TransitionProperty::Longhand(ref id) => id.to_nscsspropertyid(),
            TransitionProperty::Unsupported(..) => return Err(()),
        })
    }
}

/// Convert nsCSSPropertyID to TransitionProperty
#[cfg(feature = "gecko")]
#[allow(non_upper_case_globals)]
impl From<nsCSSPropertyID> for TransitionProperty {
    fn from(property: nsCSSPropertyID) -> TransitionProperty {
        match property {
            
    nsCSSPropertyID::eCSSProperty_align_content => {
                TransitionProperty::Longhand(LonghandId::AlignContent)
            }
            
    nsCSSPropertyID::eCSSProperty_align_items => {
                TransitionProperty::Longhand(LonghandId::AlignItems)
            }
            
    nsCSSPropertyID::eCSSProperty_align_self => {
                TransitionProperty::Longhand(LonghandId::AlignSelf)
            }
            
    nsCSSPropertyID::eCSSProperty_backface_visibility => {
                TransitionProperty::Longhand(LonghandId::BackfaceVisibility)
            }
            
    nsCSSPropertyID::eCSSProperty_border_collapse => {
                TransitionProperty::Longhand(LonghandId::BorderCollapse)
            }
            
    nsCSSPropertyID::eCSSProperty_border_image_repeat => {
                TransitionProperty::Longhand(LonghandId::BorderImageRepeat)
            }
            
    nsCSSPropertyID::eCSSProperty_box_decoration_break => {
                TransitionProperty::Longhand(LonghandId::BoxDecorationBreak)
            }
            
    nsCSSPropertyID::eCSSProperty_box_sizing => {
                TransitionProperty::Longhand(LonghandId::BoxSizing)
            }
            
    nsCSSPropertyID::eCSSProperty_caption_side => {
                TransitionProperty::Longhand(LonghandId::CaptionSide)
            }
            
    nsCSSPropertyID::eCSSProperty_clear => {
                TransitionProperty::Longhand(LonghandId::Clear)
            }
            
    nsCSSPropertyID::eCSSProperty_clip_rule => {
                TransitionProperty::Longhand(LonghandId::ClipRule)
            }
            
    nsCSSPropertyID::eCSSProperty_color_adjust => {
                TransitionProperty::Longhand(LonghandId::ColorAdjust)
            }
            
    nsCSSPropertyID::eCSSProperty_color_interpolation => {
                TransitionProperty::Longhand(LonghandId::ColorInterpolation)
            }
            
    nsCSSPropertyID::eCSSProperty_color_interpolation_filters => {
                TransitionProperty::Longhand(LonghandId::ColorInterpolationFilters)
            }
            
    nsCSSPropertyID::eCSSProperty_column_count => {
                TransitionProperty::Longhand(LonghandId::ColumnCount)
            }
            
    nsCSSPropertyID::eCSSProperty_column_fill => {
                TransitionProperty::Longhand(LonghandId::ColumnFill)
            }
            
    nsCSSPropertyID::eCSSProperty_column_rule_style => {
                TransitionProperty::Longhand(LonghandId::ColumnRuleStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_column_span => {
                TransitionProperty::Longhand(LonghandId::ColumnSpan)
            }
            
    nsCSSPropertyID::eCSSProperty_contain => {
                TransitionProperty::Longhand(LonghandId::Contain)
            }
            
    nsCSSPropertyID::eCSSProperty_direction => {
                TransitionProperty::Longhand(LonghandId::Direction)
            }
            
    nsCSSPropertyID::eCSSProperty_dominant_baseline => {
                TransitionProperty::Longhand(LonghandId::DominantBaseline)
            }
            
    nsCSSPropertyID::eCSSProperty_empty_cells => {
                TransitionProperty::Longhand(LonghandId::EmptyCells)
            }
            
    nsCSSPropertyID::eCSSProperty_fill_rule => {
                TransitionProperty::Longhand(LonghandId::FillRule)
            }
            
    nsCSSPropertyID::eCSSProperty_flex_direction => {
                TransitionProperty::Longhand(LonghandId::FlexDirection)
            }
            
    nsCSSPropertyID::eCSSProperty_flex_wrap => {
                TransitionProperty::Longhand(LonghandId::FlexWrap)
            }
            
    nsCSSPropertyID::eCSSProperty_float_ => {
                TransitionProperty::Longhand(LonghandId::Float)
            }
            
    nsCSSPropertyID::eCSSProperty_font_kerning => {
                TransitionProperty::Longhand(LonghandId::FontKerning)
            }
            
    nsCSSPropertyID::eCSSProperty_font_optical_sizing => {
                TransitionProperty::Longhand(LonghandId::FontOpticalSizing)
            }
            
    nsCSSPropertyID::eCSSProperty_font_stretch => {
                TransitionProperty::Longhand(LonghandId::FontStretch)
            }
            
    nsCSSPropertyID::eCSSProperty_font_style => {
                TransitionProperty::Longhand(LonghandId::FontStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_font_synthesis => {
                TransitionProperty::Longhand(LonghandId::FontSynthesis)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variant_caps => {
                TransitionProperty::Longhand(LonghandId::FontVariantCaps)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variant_position => {
                TransitionProperty::Longhand(LonghandId::FontVariantPosition)
            }
            
    nsCSSPropertyID::eCSSProperty_font_weight => {
                TransitionProperty::Longhand(LonghandId::FontWeight)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_auto_flow => {
                TransitionProperty::Longhand(LonghandId::GridAutoFlow)
            }
            
    nsCSSPropertyID::eCSSProperty_hyphens => {
                TransitionProperty::Longhand(LonghandId::Hyphens)
            }
            
    nsCSSPropertyID::eCSSProperty_image_orientation => {
                TransitionProperty::Longhand(LonghandId::ImageOrientation)
            }
            
    nsCSSPropertyID::eCSSProperty_image_rendering => {
                TransitionProperty::Longhand(LonghandId::ImageRendering)
            }
            
    nsCSSPropertyID::eCSSProperty_ime_mode => {
                TransitionProperty::Longhand(LonghandId::ImeMode)
            }
            
    nsCSSPropertyID::eCSSProperty_initial_letter => {
                TransitionProperty::Longhand(LonghandId::InitialLetter)
            }
            
    nsCSSPropertyID::eCSSProperty_isolation => {
                TransitionProperty::Longhand(LonghandId::Isolation)
            }
            
    nsCSSPropertyID::eCSSProperty_justify_content => {
                TransitionProperty::Longhand(LonghandId::JustifyContent)
            }
            
    nsCSSPropertyID::eCSSProperty_justify_items => {
                TransitionProperty::Longhand(LonghandId::JustifyItems)
            }
            
    nsCSSPropertyID::eCSSProperty_justify_self => {
                TransitionProperty::Longhand(LonghandId::JustifySelf)
            }
            
    nsCSSPropertyID::eCSSProperty_list_style_position => {
                TransitionProperty::Longhand(LonghandId::ListStylePosition)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_type => {
                TransitionProperty::Longhand(LonghandId::MaskType)
            }
            
    nsCSSPropertyID::eCSSProperty_mix_blend_mode => {
                TransitionProperty::Longhand(LonghandId::MixBlendMode)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_appearance => {
                TransitionProperty::Longhand(LonghandId::MozAppearance)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_box_align => {
                TransitionProperty::Longhand(LonghandId::MozBoxAlign)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_box_direction => {
                TransitionProperty::Longhand(LonghandId::MozBoxDirection)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_box_orient => {
                TransitionProperty::Longhand(LonghandId::MozBoxOrient)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_box_pack => {
                TransitionProperty::Longhand(LonghandId::MozBoxPack)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_control_character_visibility => {
                TransitionProperty::Longhand(LonghandId::MozControlCharacterVisibility)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_float_edge => {
                TransitionProperty::Longhand(LonghandId::MozFloatEdge)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_force_broken_image_icon => {
                TransitionProperty::Longhand(LonghandId::MozForceBrokenImageIcon)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_math_display => {
                TransitionProperty::Longhand(LonghandId::MozMathDisplay)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_math_variant => {
                TransitionProperty::Longhand(LonghandId::MozMathVariant)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_min_font_size_ratio => {
                TransitionProperty::Longhand(LonghandId::MozMinFontSizeRatio)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_orient => {
                TransitionProperty::Longhand(LonghandId::MozOrient)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_osx_font_smoothing => {
                TransitionProperty::Longhand(LonghandId::MozOsxFontSmoothing)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_script_level => {
                TransitionProperty::Longhand(LonghandId::MozScriptLevel)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_script_min_size => {
                TransitionProperty::Longhand(LonghandId::MozScriptMinSize)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_script_size_multiplier => {
                TransitionProperty::Longhand(LonghandId::MozScriptSizeMultiplier)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_stack_sizing => {
                TransitionProperty::Longhand(LonghandId::MozStackSizing)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_text_size_adjust => {
                TransitionProperty::Longhand(LonghandId::MozTextSizeAdjust)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_top_layer => {
                TransitionProperty::Longhand(LonghandId::MozTopLayer)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_user_focus => {
                TransitionProperty::Longhand(LonghandId::MozUserFocus)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_user_input => {
                TransitionProperty::Longhand(LonghandId::MozUserInput)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_user_modify => {
                TransitionProperty::Longhand(LonghandId::MozUserModify)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_user_select => {
                TransitionProperty::Longhand(LonghandId::MozUserSelect)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_window_dragging => {
                TransitionProperty::Longhand(LonghandId::MozWindowDragging)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_window_shadow => {
                TransitionProperty::Longhand(LonghandId::MozWindowShadow)
            }
            
    nsCSSPropertyID::eCSSProperty_object_fit => {
                TransitionProperty::Longhand(LonghandId::ObjectFit)
            }
            
    nsCSSPropertyID::eCSSProperty_outline_style => {
                TransitionProperty::Longhand(LonghandId::OutlineStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_overflow_wrap => {
                TransitionProperty::Longhand(LonghandId::OverflowWrap)
            }
            
    nsCSSPropertyID::eCSSProperty_overflow_x => {
                TransitionProperty::Longhand(LonghandId::OverflowX)
            }
            
    nsCSSPropertyID::eCSSProperty_page_break_after => {
                TransitionProperty::Longhand(LonghandId::PageBreakAfter)
            }
            
    nsCSSPropertyID::eCSSProperty_page_break_before => {
                TransitionProperty::Longhand(LonghandId::PageBreakBefore)
            }
            
    nsCSSPropertyID::eCSSProperty_page_break_inside => {
                TransitionProperty::Longhand(LonghandId::PageBreakInside)
            }
            
    nsCSSPropertyID::eCSSProperty_paint_order => {
                TransitionProperty::Longhand(LonghandId::PaintOrder)
            }
            
    nsCSSPropertyID::eCSSProperty_pointer_events => {
                TransitionProperty::Longhand(LonghandId::PointerEvents)
            }
            
    nsCSSPropertyID::eCSSProperty_position => {
                TransitionProperty::Longhand(LonghandId::Position)
            }
            
    nsCSSPropertyID::eCSSProperty_resize => {
                TransitionProperty::Longhand(LonghandId::Resize)
            }
            
    nsCSSPropertyID::eCSSProperty_ruby_align => {
                TransitionProperty::Longhand(LonghandId::RubyAlign)
            }
            
    nsCSSPropertyID::eCSSProperty_ruby_position => {
                TransitionProperty::Longhand(LonghandId::RubyPosition)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_behavior => {
                TransitionProperty::Longhand(LonghandId::ScrollBehavior)
            }
            
    nsCSSPropertyID::eCSSProperty_shape_rendering => {
                TransitionProperty::Longhand(LonghandId::ShapeRendering)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke_linecap => {
                TransitionProperty::Longhand(LonghandId::StrokeLinecap)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke_linejoin => {
                TransitionProperty::Longhand(LonghandId::StrokeLinejoin)
            }
            
    nsCSSPropertyID::eCSSProperty_table_layout => {
                TransitionProperty::Longhand(LonghandId::TableLayout)
            }
            
    nsCSSPropertyID::eCSSProperty_text_align_last => {
                TransitionProperty::Longhand(LonghandId::TextAlignLast)
            }
            
    nsCSSPropertyID::eCSSProperty_text_anchor => {
                TransitionProperty::Longhand(LonghandId::TextAnchor)
            }
            
    nsCSSPropertyID::eCSSProperty_text_combine_upright => {
                TransitionProperty::Longhand(LonghandId::TextCombineUpright)
            }
            
    nsCSSPropertyID::eCSSProperty_text_decoration_line => {
                TransitionProperty::Longhand(LonghandId::TextDecorationLine)
            }
            
    nsCSSPropertyID::eCSSProperty_text_decoration_style => {
                TransitionProperty::Longhand(LonghandId::TextDecorationStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_text_justify => {
                TransitionProperty::Longhand(LonghandId::TextJustify)
            }
            
    nsCSSPropertyID::eCSSProperty_text_orientation => {
                TransitionProperty::Longhand(LonghandId::TextOrientation)
            }
            
    nsCSSPropertyID::eCSSProperty_text_rendering => {
                TransitionProperty::Longhand(LonghandId::TextRendering)
            }
            
    nsCSSPropertyID::eCSSProperty_text_transform => {
                TransitionProperty::Longhand(LonghandId::TextTransform)
            }
            
    nsCSSPropertyID::eCSSProperty_touch_action => {
                TransitionProperty::Longhand(LonghandId::TouchAction)
            }
            
    nsCSSPropertyID::eCSSProperty_transform_box => {
                TransitionProperty::Longhand(LonghandId::TransformBox)
            }
            
    nsCSSPropertyID::eCSSProperty_transform_style => {
                TransitionProperty::Longhand(LonghandId::TransformStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_unicode_bidi => {
                TransitionProperty::Longhand(LonghandId::UnicodeBidi)
            }
            
    nsCSSPropertyID::eCSSProperty_vector_effect => {
                TransitionProperty::Longhand(LonghandId::VectorEffect)
            }
            
    nsCSSPropertyID::eCSSProperty_visibility => {
                TransitionProperty::Longhand(LonghandId::Visibility)
            }
            
    nsCSSPropertyID::eCSSProperty_white_space => {
                TransitionProperty::Longhand(LonghandId::WhiteSpace)
            }
            
    nsCSSPropertyID::eCSSProperty_word_break => {
                TransitionProperty::Longhand(LonghandId::WordBreak)
            }
            
    nsCSSPropertyID::eCSSProperty_writing_mode => {
                TransitionProperty::Longhand(LonghandId::WritingMode)
            }
            
    nsCSSPropertyID::eCSSProperty__x_span => {
                TransitionProperty::Longhand(LonghandId::XSpan)
            }
            
    nsCSSPropertyID::eCSSProperty__x_text_zoom => {
                TransitionProperty::Longhand(LonghandId::XTextZoom)
            }
            
    nsCSSPropertyID::eCSSProperty_z_index => {
                TransitionProperty::Longhand(LonghandId::ZIndex)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_box_ordinal_group => {
                TransitionProperty::Longhand(LonghandId::MozBoxOrdinalGroup)
            }
            
    nsCSSPropertyID::eCSSProperty_order => {
                TransitionProperty::Longhand(LonghandId::Order)
            }
            
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_x => {
                TransitionProperty::Longhand(LonghandId::OverscrollBehaviorX)
            }
            
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_y => {
                TransitionProperty::Longhand(LonghandId::OverscrollBehaviorY)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_x => {
                TransitionProperty::Longhand(LonghandId::ScrollSnapTypeX)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_y => {
                TransitionProperty::Longhand(LonghandId::ScrollSnapTypeY)
            }
            
    nsCSSPropertyID::eCSSProperty_flex_grow => {
                TransitionProperty::Longhand(LonghandId::FlexGrow)
            }
            
    nsCSSPropertyID::eCSSProperty_flex_shrink => {
                TransitionProperty::Longhand(LonghandId::FlexShrink)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_box_flex => {
                TransitionProperty::Longhand(LonghandId::MozBoxFlex)
            }
            
    nsCSSPropertyID::eCSSProperty_flood_opacity => {
                TransitionProperty::Longhand(LonghandId::FloodOpacity)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_window_opacity => {
                TransitionProperty::Longhand(LonghandId::MozWindowOpacity)
            }
            
    nsCSSPropertyID::eCSSProperty_opacity => {
                TransitionProperty::Longhand(LonghandId::Opacity)
            }
            
    nsCSSPropertyID::eCSSProperty_shape_image_threshold => {
                TransitionProperty::Longhand(LonghandId::ShapeImageThreshold)
            }
            
    nsCSSPropertyID::eCSSProperty_stop_opacity => {
                TransitionProperty::Longhand(LonghandId::StopOpacity)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_end_style => {
                TransitionProperty::Longhand(LonghandId::BorderBlockEndStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_start_style => {
                TransitionProperty::Longhand(LonghandId::BorderBlockStartStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_bottom_style => {
                TransitionProperty::Longhand(LonghandId::BorderBottomStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_end_style => {
                TransitionProperty::Longhand(LonghandId::BorderInlineEndStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_start_style => {
                TransitionProperty::Longhand(LonghandId::BorderInlineStartStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_left_style => {
                TransitionProperty::Longhand(LonghandId::BorderLeftStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_right_style => {
                TransitionProperty::Longhand(LonghandId::BorderRightStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_top_style => {
                TransitionProperty::Longhand(LonghandId::BorderTopStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_delay => {
                TransitionProperty::Longhand(LonghandId::AnimationDelay)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_direction => {
                TransitionProperty::Longhand(LonghandId::AnimationDirection)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_duration => {
                TransitionProperty::Longhand(LonghandId::AnimationDuration)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_fill_mode => {
                TransitionProperty::Longhand(LonghandId::AnimationFillMode)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_iteration_count => {
                TransitionProperty::Longhand(LonghandId::AnimationIterationCount)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_name => {
                TransitionProperty::Longhand(LonghandId::AnimationName)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_play_state => {
                TransitionProperty::Longhand(LonghandId::AnimationPlayState)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_timing_function => {
                TransitionProperty::Longhand(LonghandId::AnimationTimingFunction)
            }
            
    nsCSSPropertyID::eCSSProperty_background_attachment => {
                TransitionProperty::Longhand(LonghandId::BackgroundAttachment)
            }
            
    nsCSSPropertyID::eCSSProperty_background_blend_mode => {
                TransitionProperty::Longhand(LonghandId::BackgroundBlendMode)
            }
            
    nsCSSPropertyID::eCSSProperty_background_clip => {
                TransitionProperty::Longhand(LonghandId::BackgroundClip)
            }
            
    nsCSSPropertyID::eCSSProperty_background_image => {
                TransitionProperty::Longhand(LonghandId::BackgroundImage)
            }
            
    nsCSSPropertyID::eCSSProperty_background_origin => {
                TransitionProperty::Longhand(LonghandId::BackgroundOrigin)
            }
            
    nsCSSPropertyID::eCSSProperty_background_position_x => {
                TransitionProperty::Longhand(LonghandId::BackgroundPositionX)
            }
            
    nsCSSPropertyID::eCSSProperty_background_position_y => {
                TransitionProperty::Longhand(LonghandId::BackgroundPositionY)
            }
            
    nsCSSPropertyID::eCSSProperty_background_repeat => {
                TransitionProperty::Longhand(LonghandId::BackgroundRepeat)
            }
            
    nsCSSPropertyID::eCSSProperty_background_size => {
                TransitionProperty::Longhand(LonghandId::BackgroundSize)
            }
            
    nsCSSPropertyID::eCSSProperty_border_image_outset => {
                TransitionProperty::Longhand(LonghandId::BorderImageOutset)
            }
            
    nsCSSPropertyID::eCSSProperty_border_image_slice => {
                TransitionProperty::Longhand(LonghandId::BorderImageSlice)
            }
            
    nsCSSPropertyID::eCSSProperty_border_image_source => {
                TransitionProperty::Longhand(LonghandId::BorderImageSource)
            }
            
    nsCSSPropertyID::eCSSProperty_border_image_width => {
                TransitionProperty::Longhand(LonghandId::BorderImageWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_spacing => {
                TransitionProperty::Longhand(LonghandId::BorderSpacing)
            }
            
    nsCSSPropertyID::eCSSProperty_box_shadow => {
                TransitionProperty::Longhand(LonghandId::BoxShadow)
            }
            
    nsCSSPropertyID::eCSSProperty_caret_color => {
                TransitionProperty::Longhand(LonghandId::CaretColor)
            }
            
    nsCSSPropertyID::eCSSProperty_clip_path => {
                TransitionProperty::Longhand(LonghandId::ClipPath)
            }
            
    nsCSSPropertyID::eCSSProperty_color => {
                TransitionProperty::Longhand(LonghandId::Color)
            }
            
    nsCSSPropertyID::eCSSProperty_column_gap => {
                TransitionProperty::Longhand(LonghandId::ColumnGap)
            }
            
    nsCSSPropertyID::eCSSProperty_column_width => {
                TransitionProperty::Longhand(LonghandId::ColumnWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_content => {
                TransitionProperty::Longhand(LonghandId::Content)
            }
            
    nsCSSPropertyID::eCSSProperty_counter_increment => {
                TransitionProperty::Longhand(LonghandId::CounterIncrement)
            }
            
    nsCSSPropertyID::eCSSProperty_counter_reset => {
                TransitionProperty::Longhand(LonghandId::CounterReset)
            }
            
    nsCSSPropertyID::eCSSProperty_cursor => {
                TransitionProperty::Longhand(LonghandId::Cursor)
            }
            
    nsCSSPropertyID::eCSSProperty_display => {
                TransitionProperty::Longhand(LonghandId::Display)
            }
            
    nsCSSPropertyID::eCSSProperty_filter => {
                TransitionProperty::Longhand(LonghandId::Filter)
            }
            
    nsCSSPropertyID::eCSSProperty_font_family => {
                TransitionProperty::Longhand(LonghandId::FontFamily)
            }
            
    nsCSSPropertyID::eCSSProperty_font_feature_settings => {
                TransitionProperty::Longhand(LonghandId::FontFeatureSettings)
            }
            
    nsCSSPropertyID::eCSSProperty_font_language_override => {
                TransitionProperty::Longhand(LonghandId::FontLanguageOverride)
            }
            
    nsCSSPropertyID::eCSSProperty_font_size => {
                TransitionProperty::Longhand(LonghandId::FontSize)
            }
            
    nsCSSPropertyID::eCSSProperty_font_size_adjust => {
                TransitionProperty::Longhand(LonghandId::FontSizeAdjust)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variant_alternates => {
                TransitionProperty::Longhand(LonghandId::FontVariantAlternates)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variant_east_asian => {
                TransitionProperty::Longhand(LonghandId::FontVariantEastAsian)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variant_ligatures => {
                TransitionProperty::Longhand(LonghandId::FontVariantLigatures)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variant_numeric => {
                TransitionProperty::Longhand(LonghandId::FontVariantNumeric)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variation_settings => {
                TransitionProperty::Longhand(LonghandId::FontVariationSettings)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_template_areas => {
                TransitionProperty::Longhand(LonghandId::GridTemplateAreas)
            }
            
    nsCSSPropertyID::eCSSProperty_letter_spacing => {
                TransitionProperty::Longhand(LonghandId::LetterSpacing)
            }
            
    nsCSSPropertyID::eCSSProperty_line_height => {
                TransitionProperty::Longhand(LonghandId::LineHeight)
            }
            
    nsCSSPropertyID::eCSSProperty_list_style_image => {
                TransitionProperty::Longhand(LonghandId::ListStyleImage)
            }
            
    nsCSSPropertyID::eCSSProperty_list_style_type => {
                TransitionProperty::Longhand(LonghandId::ListStyleType)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_clip => {
                TransitionProperty::Longhand(LonghandId::MaskClip)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_composite => {
                TransitionProperty::Longhand(LonghandId::MaskComposite)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_image => {
                TransitionProperty::Longhand(LonghandId::MaskImage)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_mode => {
                TransitionProperty::Longhand(LonghandId::MaskMode)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_origin => {
                TransitionProperty::Longhand(LonghandId::MaskOrigin)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_position_x => {
                TransitionProperty::Longhand(LonghandId::MaskPositionX)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_position_y => {
                TransitionProperty::Longhand(LonghandId::MaskPositionY)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_repeat => {
                TransitionProperty::Longhand(LonghandId::MaskRepeat)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_size => {
                TransitionProperty::Longhand(LonghandId::MaskSize)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_context_properties => {
                TransitionProperty::Longhand(LonghandId::MozContextProperties)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_tab_size => {
                TransitionProperty::Longhand(LonghandId::MozTabSize)
            }
            
    nsCSSPropertyID::eCSSProperty_outline_offset => {
                TransitionProperty::Longhand(LonghandId::OutlineOffset)
            }
            
    nsCSSPropertyID::eCSSProperty_overflow_y => {
                TransitionProperty::Longhand(LonghandId::OverflowY)
            }
            
    nsCSSPropertyID::eCSSProperty_perspective => {
                TransitionProperty::Longhand(LonghandId::Perspective)
            }
            
    nsCSSPropertyID::eCSSProperty_perspective_origin => {
                TransitionProperty::Longhand(LonghandId::PerspectiveOrigin)
            }
            
    nsCSSPropertyID::eCSSProperty_quotes => {
                TransitionProperty::Longhand(LonghandId::Quotes)
            }
            
    nsCSSPropertyID::eCSSProperty_rotate => {
                TransitionProperty::Longhand(LonghandId::Rotate)
            }
            
    nsCSSPropertyID::eCSSProperty_scale => {
                TransitionProperty::Longhand(LonghandId::Scale)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_snap_coordinate => {
                TransitionProperty::Longhand(LonghandId::ScrollSnapCoordinate)
            }
            
    nsCSSPropertyID::eCSSProperty_shape_outside => {
                TransitionProperty::Longhand(LonghandId::ShapeOutside)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke_dasharray => {
                TransitionProperty::Longhand(LonghandId::StrokeDasharray)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke_dashoffset => {
                TransitionProperty::Longhand(LonghandId::StrokeDashoffset)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke_miterlimit => {
                TransitionProperty::Longhand(LonghandId::StrokeMiterlimit)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke_width => {
                TransitionProperty::Longhand(LonghandId::StrokeWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_text_align => {
                TransitionProperty::Longhand(LonghandId::TextAlign)
            }
            
    nsCSSPropertyID::eCSSProperty_text_emphasis_position => {
                TransitionProperty::Longhand(LonghandId::TextEmphasisPosition)
            }
            
    nsCSSPropertyID::eCSSProperty_text_emphasis_style => {
                TransitionProperty::Longhand(LonghandId::TextEmphasisStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_text_indent => {
                TransitionProperty::Longhand(LonghandId::TextIndent)
            }
            
    nsCSSPropertyID::eCSSProperty_text_overflow => {
                TransitionProperty::Longhand(LonghandId::TextOverflow)
            }
            
    nsCSSPropertyID::eCSSProperty_text_shadow => {
                TransitionProperty::Longhand(LonghandId::TextShadow)
            }
            
    nsCSSPropertyID::eCSSProperty_transition_delay => {
                TransitionProperty::Longhand(LonghandId::TransitionDelay)
            }
            
    nsCSSPropertyID::eCSSProperty_transition_duration => {
                TransitionProperty::Longhand(LonghandId::TransitionDuration)
            }
            
    nsCSSPropertyID::eCSSProperty_transition_property => {
                TransitionProperty::Longhand(LonghandId::TransitionProperty)
            }
            
    nsCSSPropertyID::eCSSProperty_transition_timing_function => {
                TransitionProperty::Longhand(LonghandId::TransitionTimingFunction)
            }
            
    nsCSSPropertyID::eCSSProperty_translate => {
                TransitionProperty::Longhand(LonghandId::Translate)
            }
            
    nsCSSPropertyID::eCSSProperty_vertical_align => {
                TransitionProperty::Longhand(LonghandId::VerticalAlign)
            }
            
    nsCSSPropertyID::eCSSProperty_will_change => {
                TransitionProperty::Longhand(LonghandId::WillChange)
            }
            
    nsCSSPropertyID::eCSSProperty_word_spacing => {
                TransitionProperty::Longhand(LonghandId::WordSpacing)
            }
            
    nsCSSPropertyID::eCSSProperty__x_lang => {
                TransitionProperty::Longhand(LonghandId::XLang)
            }
            
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_block => {
                TransitionProperty::Longhand(LonghandId::OverflowClipBoxBlock)
            }
            
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_inline => {
                TransitionProperty::Longhand(LonghandId::OverflowClipBoxInline)
            }
            
    nsCSSPropertyID::eCSSProperty_fill_opacity => {
                TransitionProperty::Longhand(LonghandId::FillOpacity)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke_opacity => {
                TransitionProperty::Longhand(LonghandId::StrokeOpacity)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_x => {
                TransitionProperty::Longhand(LonghandId::ScrollSnapPointsX)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_y => {
                TransitionProperty::Longhand(LonghandId::ScrollSnapPointsY)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_window_transform => {
                TransitionProperty::Longhand(LonghandId::MozWindowTransform)
            }
            
    nsCSSPropertyID::eCSSProperty_transform => {
                TransitionProperty::Longhand(LonghandId::Transform)
            }
            
    nsCSSPropertyID::eCSSProperty_clip => {
                TransitionProperty::Longhand(LonghandId::Clip)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_image_region => {
                TransitionProperty::Longhand(LonghandId::MozImageRegion)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_template_columns => {
                TransitionProperty::Longhand(LonghandId::GridTemplateColumns)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_template_rows => {
                TransitionProperty::Longhand(LonghandId::GridTemplateRows)
            }
            
    nsCSSPropertyID::eCSSProperty_object_position => {
                TransitionProperty::Longhand(LonghandId::ObjectPosition)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_snap_destination => {
                TransitionProperty::Longhand(LonghandId::ScrollSnapDestination)
            }
            
    nsCSSPropertyID::eCSSProperty_fill => {
                TransitionProperty::Longhand(LonghandId::Fill)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke => {
                TransitionProperty::Longhand(LonghandId::Stroke)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_auto_columns => {
                TransitionProperty::Longhand(LonghandId::GridAutoColumns)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_auto_rows => {
                TransitionProperty::Longhand(LonghandId::GridAutoRows)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_window_transform_origin => {
                TransitionProperty::Longhand(LonghandId::MozWindowTransformOrigin)
            }
            
    nsCSSPropertyID::eCSSProperty_transform_origin => {
                TransitionProperty::Longhand(LonghandId::TransformOrigin)
            }
            
    nsCSSPropertyID::eCSSProperty_max_block_size => {
                TransitionProperty::Longhand(LonghandId::MaxBlockSize)
            }
            
    nsCSSPropertyID::eCSSProperty_max_height => {
                TransitionProperty::Longhand(LonghandId::MaxHeight)
            }
            
    nsCSSPropertyID::eCSSProperty_max_inline_size => {
                TransitionProperty::Longhand(LonghandId::MaxInlineSize)
            }
            
    nsCSSPropertyID::eCSSProperty_max_width => {
                TransitionProperty::Longhand(LonghandId::MaxWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_flood_color => {
                TransitionProperty::Longhand(LonghandId::FloodColor)
            }
            
    nsCSSPropertyID::eCSSProperty_lighting_color => {
                TransitionProperty::Longhand(LonghandId::LightingColor)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_font_smoothing_background_color => {
                TransitionProperty::Longhand(LonghandId::MozFontSmoothingBackgroundColor)
            }
            
    nsCSSPropertyID::eCSSProperty_stop_color => {
                TransitionProperty::Longhand(LonghandId::StopColor)
            }
            
    nsCSSPropertyID::eCSSProperty_marker_end => {
                TransitionProperty::Longhand(LonghandId::MarkerEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_marker_mid => {
                TransitionProperty::Longhand(LonghandId::MarkerMid)
            }
            
    nsCSSPropertyID::eCSSProperty_marker_start => {
                TransitionProperty::Longhand(LonghandId::MarkerStart)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_binding => {
                TransitionProperty::Longhand(LonghandId::MozBinding)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_column_end => {
                TransitionProperty::Longhand(LonghandId::GridColumnEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_column_start => {
                TransitionProperty::Longhand(LonghandId::GridColumnStart)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_row_end => {
                TransitionProperty::Longhand(LonghandId::GridRowEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_row_start => {
                TransitionProperty::Longhand(LonghandId::GridRowStart)
            }
            
    nsCSSPropertyID::eCSSProperty_border_bottom_left_radius => {
                TransitionProperty::Longhand(LonghandId::BorderBottomLeftRadius)
            }
            
    nsCSSPropertyID::eCSSProperty_border_bottom_right_radius => {
                TransitionProperty::Longhand(LonghandId::BorderBottomRightRadius)
            }
            
    nsCSSPropertyID::eCSSProperty_border_top_left_radius => {
                TransitionProperty::Longhand(LonghandId::BorderTopLeftRadius)
            }
            
    nsCSSPropertyID::eCSSProperty_border_top_right_radius => {
                TransitionProperty::Longhand(LonghandId::BorderTopRightRadius)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomleft => {
                TransitionProperty::Longhand(LonghandId::MozOutlineRadiusBottomleft)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomright => {
                TransitionProperty::Longhand(LonghandId::MozOutlineRadiusBottomright)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topleft => {
                TransitionProperty::Longhand(LonghandId::MozOutlineRadiusTopleft)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topright => {
                TransitionProperty::Longhand(LonghandId::MozOutlineRadiusTopright)
            }
            
    nsCSSPropertyID::eCSSProperty_block_size => {
                TransitionProperty::Longhand(LonghandId::BlockSize)
            }
            
    nsCSSPropertyID::eCSSProperty_flex_basis => {
                TransitionProperty::Longhand(LonghandId::FlexBasis)
            }
            
    nsCSSPropertyID::eCSSProperty_height => {
                TransitionProperty::Longhand(LonghandId::Height)
            }
            
    nsCSSPropertyID::eCSSProperty_inline_size => {
                TransitionProperty::Longhand(LonghandId::InlineSize)
            }
            
    nsCSSPropertyID::eCSSProperty_min_block_size => {
                TransitionProperty::Longhand(LonghandId::MinBlockSize)
            }
            
    nsCSSPropertyID::eCSSProperty_min_height => {
                TransitionProperty::Longhand(LonghandId::MinHeight)
            }
            
    nsCSSPropertyID::eCSSProperty_min_inline_size => {
                TransitionProperty::Longhand(LonghandId::MinInlineSize)
            }
            
    nsCSSPropertyID::eCSSProperty_min_width => {
                TransitionProperty::Longhand(LonghandId::MinWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_width => {
                TransitionProperty::Longhand(LonghandId::Width)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_column_gap => {
                TransitionProperty::Longhand(LonghandId::GridColumnGap)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_row_gap => {
                TransitionProperty::Longhand(LonghandId::GridRowGap)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_block_end => {
                TransitionProperty::Longhand(LonghandId::PaddingBlockEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_block_start => {
                TransitionProperty::Longhand(LonghandId::PaddingBlockStart)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_bottom => {
                TransitionProperty::Longhand(LonghandId::PaddingBottom)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_inline_end => {
                TransitionProperty::Longhand(LonghandId::PaddingInlineEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_inline_start => {
                TransitionProperty::Longhand(LonghandId::PaddingInlineStart)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_left => {
                TransitionProperty::Longhand(LonghandId::PaddingLeft)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_right => {
                TransitionProperty::Longhand(LonghandId::PaddingRight)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_top => {
                TransitionProperty::Longhand(LonghandId::PaddingTop)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_end_width => {
                TransitionProperty::Longhand(LonghandId::BorderBlockEndWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_start_width => {
                TransitionProperty::Longhand(LonghandId::BorderBlockStartWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_bottom_width => {
                TransitionProperty::Longhand(LonghandId::BorderBottomWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_end_width => {
                TransitionProperty::Longhand(LonghandId::BorderInlineEndWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_start_width => {
                TransitionProperty::Longhand(LonghandId::BorderInlineStartWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_left_width => {
                TransitionProperty::Longhand(LonghandId::BorderLeftWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_right_width => {
                TransitionProperty::Longhand(LonghandId::BorderRightWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_top_width => {
                TransitionProperty::Longhand(LonghandId::BorderTopWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_column_rule_width => {
                TransitionProperty::Longhand(LonghandId::ColumnRuleWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_outline_width => {
                TransitionProperty::Longhand(LonghandId::OutlineWidth)
            }
            
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_width => {
                TransitionProperty::Longhand(LonghandId::WebkitTextStrokeWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_background_color => {
                TransitionProperty::Longhand(LonghandId::BackgroundColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_end_color => {
                TransitionProperty::Longhand(LonghandId::BorderBlockEndColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_start_color => {
                TransitionProperty::Longhand(LonghandId::BorderBlockStartColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_bottom_color => {
                TransitionProperty::Longhand(LonghandId::BorderBottomColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_end_color => {
                TransitionProperty::Longhand(LonghandId::BorderInlineEndColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_start_color => {
                TransitionProperty::Longhand(LonghandId::BorderInlineStartColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_left_color => {
                TransitionProperty::Longhand(LonghandId::BorderLeftColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_right_color => {
                TransitionProperty::Longhand(LonghandId::BorderRightColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_top_color => {
                TransitionProperty::Longhand(LonghandId::BorderTopColor)
            }
            
    nsCSSPropertyID::eCSSProperty_column_rule_color => {
                TransitionProperty::Longhand(LonghandId::ColumnRuleColor)
            }
            
    nsCSSPropertyID::eCSSProperty_outline_color => {
                TransitionProperty::Longhand(LonghandId::OutlineColor)
            }
            
    nsCSSPropertyID::eCSSProperty_text_decoration_color => {
                TransitionProperty::Longhand(LonghandId::TextDecorationColor)
            }
            
    nsCSSPropertyID::eCSSProperty_text_emphasis_color => {
                TransitionProperty::Longhand(LonghandId::TextEmphasisColor)
            }
            
    nsCSSPropertyID::eCSSProperty__webkit_text_fill_color => {
                TransitionProperty::Longhand(LonghandId::WebkitTextFillColor)
            }
            
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_color => {
                TransitionProperty::Longhand(LonghandId::WebkitTextStrokeColor)
            }
            
    nsCSSPropertyID::eCSSProperty_bottom => {
                TransitionProperty::Longhand(LonghandId::Bottom)
            }
            
    nsCSSPropertyID::eCSSProperty_left => {
                TransitionProperty::Longhand(LonghandId::Left)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_block_end => {
                TransitionProperty::Longhand(LonghandId::MarginBlockEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_block_start => {
                TransitionProperty::Longhand(LonghandId::MarginBlockStart)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_bottom => {
                TransitionProperty::Longhand(LonghandId::MarginBottom)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_inline_end => {
                TransitionProperty::Longhand(LonghandId::MarginInlineEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_inline_start => {
                TransitionProperty::Longhand(LonghandId::MarginInlineStart)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_left => {
                TransitionProperty::Longhand(LonghandId::MarginLeft)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_right => {
                TransitionProperty::Longhand(LonghandId::MarginRight)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_top => {
                TransitionProperty::Longhand(LonghandId::MarginTop)
            }
            
    nsCSSPropertyID::eCSSProperty_offset_block_end => {
                TransitionProperty::Longhand(LonghandId::OffsetBlockEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_offset_block_start => {
                TransitionProperty::Longhand(LonghandId::OffsetBlockStart)
            }
            
    nsCSSPropertyID::eCSSProperty_offset_inline_end => {
                TransitionProperty::Longhand(LonghandId::OffsetInlineEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_offset_inline_start => {
                TransitionProperty::Longhand(LonghandId::OffsetInlineStart)
            }
            
    nsCSSPropertyID::eCSSProperty_right => {
                TransitionProperty::Longhand(LonghandId::Right)
            }
            
    nsCSSPropertyID::eCSSProperty_top => {
                TransitionProperty::Longhand(LonghandId::Top)
            }
            
    nsCSSPropertyID::eCSSProperty_background => {
                TransitionProperty::Shorthand(ShorthandId::Background)
            }
            
    nsCSSPropertyID::eCSSProperty_background_position => {
                TransitionProperty::Shorthand(ShorthandId::BackgroundPosition)
            }
            
    nsCSSPropertyID::eCSSProperty_border_color => {
                TransitionProperty::Shorthand(ShorthandId::BorderColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_style => {
                TransitionProperty::Shorthand(ShorthandId::BorderStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_width => {
                TransitionProperty::Shorthand(ShorthandId::BorderWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_top => {
                TransitionProperty::Shorthand(ShorthandId::BorderTop)
            }
            
    nsCSSPropertyID::eCSSProperty_border_left => {
                TransitionProperty::Shorthand(ShorthandId::BorderLeft)
            }
            
    nsCSSPropertyID::eCSSProperty_border_bottom => {
                TransitionProperty::Shorthand(ShorthandId::BorderBottom)
            }
            
    nsCSSPropertyID::eCSSProperty_border_right => {
                TransitionProperty::Shorthand(ShorthandId::BorderRight)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_start => {
                TransitionProperty::Shorthand(ShorthandId::BorderBlockStart)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_end => {
                TransitionProperty::Shorthand(ShorthandId::BorderBlockEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_start => {
                TransitionProperty::Shorthand(ShorthandId::BorderInlineStart)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_end => {
                TransitionProperty::Shorthand(ShorthandId::BorderInlineEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_border => {
                TransitionProperty::Shorthand(ShorthandId::Border)
            }
            
    nsCSSPropertyID::eCSSProperty_border_radius => {
                TransitionProperty::Shorthand(ShorthandId::BorderRadius)
            }
            
    nsCSSPropertyID::eCSSProperty_border_image => {
                TransitionProperty::Shorthand(ShorthandId::BorderImage)
            }
            
    nsCSSPropertyID::eCSSProperty_overflow => {
                TransitionProperty::Shorthand(ShorthandId::Overflow)
            }
            
    nsCSSPropertyID::eCSSProperty_overflow_clip_box => {
                TransitionProperty::Shorthand(ShorthandId::OverflowClipBox)
            }
            
    nsCSSPropertyID::eCSSProperty_transition => {
                TransitionProperty::Shorthand(ShorthandId::Transition)
            }
            
    nsCSSPropertyID::eCSSProperty_animation => {
                TransitionProperty::Shorthand(ShorthandId::Animation)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_snap_type => {
                TransitionProperty::Shorthand(ShorthandId::ScrollSnapType)
            }
            
    nsCSSPropertyID::eCSSProperty_overscroll_behavior => {
                TransitionProperty::Shorthand(ShorthandId::OverscrollBehavior)
            }
            
    nsCSSPropertyID::eCSSProperty_columns => {
                TransitionProperty::Shorthand(ShorthandId::Columns)
            }
            
    nsCSSPropertyID::eCSSProperty_column_rule => {
                TransitionProperty::Shorthand(ShorthandId::ColumnRule)
            }
            
    nsCSSPropertyID::eCSSProperty_font => {
                TransitionProperty::Shorthand(ShorthandId::Font)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variant => {
                TransitionProperty::Shorthand(ShorthandId::FontVariant)
            }
            
    nsCSSPropertyID::eCSSProperty_text_emphasis => {
                TransitionProperty::Shorthand(ShorthandId::TextEmphasis)
            }
            
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke => {
                TransitionProperty::Shorthand(ShorthandId::WebkitTextStroke)
            }
            
    nsCSSPropertyID::eCSSProperty_list_style => {
                TransitionProperty::Shorthand(ShorthandId::ListStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_margin => {
                TransitionProperty::Shorthand(ShorthandId::Margin)
            }
            
    nsCSSPropertyID::eCSSProperty_mask => {
                TransitionProperty::Shorthand(ShorthandId::Mask)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_position => {
                TransitionProperty::Shorthand(ShorthandId::MaskPosition)
            }
            
    nsCSSPropertyID::eCSSProperty_outline => {
                TransitionProperty::Shorthand(ShorthandId::Outline)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_outline_radius => {
                TransitionProperty::Shorthand(ShorthandId::MozOutlineRadius)
            }
            
    nsCSSPropertyID::eCSSProperty_padding => {
                TransitionProperty::Shorthand(ShorthandId::Padding)
            }
            
    nsCSSPropertyID::eCSSProperty_flex_flow => {
                TransitionProperty::Shorthand(ShorthandId::FlexFlow)
            }
            
    nsCSSPropertyID::eCSSProperty_flex => {
                TransitionProperty::Shorthand(ShorthandId::Flex)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_gap => {
                TransitionProperty::Shorthand(ShorthandId::GridGap)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_row => {
                TransitionProperty::Shorthand(ShorthandId::GridRow)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_column => {
                TransitionProperty::Shorthand(ShorthandId::GridColumn)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_area => {
                TransitionProperty::Shorthand(ShorthandId::GridArea)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_template => {
                TransitionProperty::Shorthand(ShorthandId::GridTemplate)
            }
            
    nsCSSPropertyID::eCSSProperty_grid => {
                TransitionProperty::Shorthand(ShorthandId::Grid)
            }
            
    nsCSSPropertyID::eCSSProperty_place_content => {
                TransitionProperty::Shorthand(ShorthandId::PlaceContent)
            }
            
    nsCSSPropertyID::eCSSProperty_place_self => {
                TransitionProperty::Shorthand(ShorthandId::PlaceSelf)
            }
            
    nsCSSPropertyID::eCSSProperty_place_items => {
                TransitionProperty::Shorthand(ShorthandId::PlaceItems)
            }
            
    nsCSSPropertyID::eCSSProperty_marker => {
                TransitionProperty::Shorthand(ShorthandId::Marker)
            }
            
    nsCSSPropertyID::eCSSProperty_text_decoration => {
                TransitionProperty::Shorthand(ShorthandId::TextDecoration)
            }
            nsCSSPropertyID::eCSSPropertyExtra_all_properties => {
                TransitionProperty::Shorthand(ShorthandId::All)
            }
            _ => {
                panic!("non-convertible nsCSSPropertyID")
            }
        }
    }
}

/// Returns true if this nsCSSPropertyID is one of the transitionable properties.
#[cfg(feature = "gecko")]
pub fn nscsspropertyid_is_transitionable(property: nsCSSPropertyID) -> bool {
    match property {
                
    nsCSSPropertyID::eCSSProperty_column_count => true,
                
    nsCSSPropertyID::eCSSProperty_font_stretch => true,
                
    nsCSSPropertyID::eCSSProperty_font_weight => true,
                
    nsCSSPropertyID::eCSSProperty_visibility => true,
                
    nsCSSPropertyID::eCSSProperty_z_index => true,
                
    nsCSSPropertyID::eCSSProperty_order => true,
                
    nsCSSPropertyID::eCSSProperty_flex_grow => true,
                
    nsCSSPropertyID::eCSSProperty_flex_shrink => true,
                
    nsCSSPropertyID::eCSSProperty__moz_box_flex => true,
                
    nsCSSPropertyID::eCSSProperty_flood_opacity => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_shape_image_threshold => true,
                
    nsCSSPropertyID::eCSSProperty_stop_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_background_position_x => true,
                
    nsCSSPropertyID::eCSSProperty_background_position_y => true,
                
    nsCSSPropertyID::eCSSProperty_background_size => true,
                
    nsCSSPropertyID::eCSSProperty_border_spacing => true,
                
    nsCSSPropertyID::eCSSProperty_box_shadow => true,
                
    nsCSSPropertyID::eCSSProperty_caret_color => true,
                
    nsCSSPropertyID::eCSSProperty_clip_path => true,
                
    nsCSSPropertyID::eCSSProperty_color => true,
                
    nsCSSPropertyID::eCSSProperty_column_gap => true,
                
    nsCSSPropertyID::eCSSProperty_column_width => true,
                
    nsCSSPropertyID::eCSSProperty_filter => true,
                
    nsCSSPropertyID::eCSSProperty_font_size => true,
                
    nsCSSPropertyID::eCSSProperty_font_size_adjust => true,
                
    nsCSSPropertyID::eCSSProperty_font_variation_settings => true,
                
    nsCSSPropertyID::eCSSProperty_letter_spacing => true,
                
    nsCSSPropertyID::eCSSProperty_line_height => true,
                
    nsCSSPropertyID::eCSSProperty_mask_position_x => true,
                
    nsCSSPropertyID::eCSSProperty_mask_position_y => true,
                
    nsCSSPropertyID::eCSSProperty_mask_size => true,
                
    nsCSSPropertyID::eCSSProperty__moz_tab_size => true,
                
    nsCSSPropertyID::eCSSProperty_outline_offset => true,
                
    nsCSSPropertyID::eCSSProperty_perspective => true,
                
    nsCSSPropertyID::eCSSProperty_perspective_origin => true,
                
    nsCSSPropertyID::eCSSProperty_rotate => true,
                
    nsCSSPropertyID::eCSSProperty_scale => true,
                
    nsCSSPropertyID::eCSSProperty_shape_outside => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_dasharray => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_dashoffset => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_miterlimit => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_width => true,
                
    nsCSSPropertyID::eCSSProperty_text_indent => true,
                
    nsCSSPropertyID::eCSSProperty_text_shadow => true,
                
    nsCSSPropertyID::eCSSProperty_translate => true,
                
    nsCSSPropertyID::eCSSProperty_vertical_align => true,
                
    nsCSSPropertyID::eCSSProperty_word_spacing => true,
                
    nsCSSPropertyID::eCSSProperty_fill_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_opacity => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform => true,
                
    nsCSSPropertyID::eCSSProperty_transform => true,
                
    nsCSSPropertyID::eCSSProperty_clip => true,
                
    nsCSSPropertyID::eCSSProperty__moz_image_region => true,
                
    nsCSSPropertyID::eCSSProperty_object_position => true,
                
    nsCSSPropertyID::eCSSProperty_fill => true,
                
    nsCSSPropertyID::eCSSProperty_stroke => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform_origin => true,
                
    nsCSSPropertyID::eCSSProperty_transform_origin => true,
                
    nsCSSPropertyID::eCSSProperty_max_height => true,
                
    nsCSSPropertyID::eCSSProperty_max_width => true,
                
    nsCSSPropertyID::eCSSProperty_flood_color => true,
                
    nsCSSPropertyID::eCSSProperty_lighting_color => true,
                
    nsCSSPropertyID::eCSSProperty__moz_font_smoothing_background_color => true,
                
    nsCSSPropertyID::eCSSProperty_stop_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_left_radius => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_right_radius => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_left_radius => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_right_radius => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomleft => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomright => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topleft => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topright => true,
                
    nsCSSPropertyID::eCSSProperty_flex_basis => true,
                
    nsCSSPropertyID::eCSSProperty_height => true,
                
    nsCSSPropertyID::eCSSProperty_min_height => true,
                
    nsCSSPropertyID::eCSSProperty_min_width => true,
                
    nsCSSPropertyID::eCSSProperty_width => true,
                
    nsCSSPropertyID::eCSSProperty_grid_column_gap => true,
                
    nsCSSPropertyID::eCSSProperty_grid_row_gap => true,
                
    nsCSSPropertyID::eCSSProperty_padding_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_padding_left => true,
                
    nsCSSPropertyID::eCSSProperty_padding_right => true,
                
    nsCSSPropertyID::eCSSProperty_padding_top => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_left_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_right_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_width => true,
                
    nsCSSPropertyID::eCSSProperty_column_rule_width => true,
                
    nsCSSPropertyID::eCSSProperty_outline_width => true,
                
    nsCSSPropertyID::eCSSProperty_background_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_left_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_right_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_color => true,
                
    nsCSSPropertyID::eCSSProperty_column_rule_color => true,
                
    nsCSSPropertyID::eCSSProperty_outline_color => true,
                
    nsCSSPropertyID::eCSSProperty_text_decoration_color => true,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_color => true,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_fill_color => true,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_color => true,
                
    nsCSSPropertyID::eCSSProperty_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_left => true,
                
    nsCSSPropertyID::eCSSProperty_margin_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_margin_left => true,
                
    nsCSSPropertyID::eCSSProperty_margin_right => true,
                
    nsCSSPropertyID::eCSSProperty_margin_top => true,
                
    nsCSSPropertyID::eCSSProperty_right => true,
                
    nsCSSPropertyID::eCSSProperty_top => true,
                
    nsCSSPropertyID::eCSSProperty_background => true,
                
    nsCSSPropertyID::eCSSProperty_background_position => true,
                
    nsCSSPropertyID::eCSSProperty_border_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_top => true,
                
    nsCSSPropertyID::eCSSProperty_border_left => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_border_right => true,
                
    nsCSSPropertyID::eCSSProperty_border => true,
                
    nsCSSPropertyID::eCSSProperty_border_radius => true,
                
    nsCSSPropertyID::eCSSProperty_columns => true,
                
    nsCSSPropertyID::eCSSProperty_column_rule => true,
                
    nsCSSPropertyID::eCSSProperty_font => true,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis => true,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke => true,
                
    nsCSSPropertyID::eCSSProperty_margin => true,
                
    nsCSSPropertyID::eCSSProperty_mask => true,
                
    nsCSSPropertyID::eCSSProperty_mask_position => true,
                
    nsCSSPropertyID::eCSSProperty_outline => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius => true,
                
    nsCSSPropertyID::eCSSProperty_padding => true,
                
    nsCSSPropertyID::eCSSProperty_flex => true,
                
    nsCSSPropertyID::eCSSProperty_grid_gap => true,
                
    nsCSSPropertyID::eCSSProperty_text_decoration => true,
        _ => false
    }
}

/// An animated property interpolation between two computed values for that
/// property.
#[cfg(feature = "servo")]
#[derive(Clone, Debug, PartialEq)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub enum AnimatedProperty {
            
            /// align-content
            AlignContent(longhands::align_content::computed_value::T, longhands::align_content::computed_value::T),
            
            /// align-items
            AlignItems(longhands::align_items::computed_value::T, longhands::align_items::computed_value::T),
            
            /// align-self
            AlignSelf(longhands::align_self::computed_value::T, longhands::align_self::computed_value::T),
            
            /// backface-visibility
            BackfaceVisibility(longhands::backface_visibility::computed_value::T, longhands::backface_visibility::computed_value::T),
            
            /// border-collapse
            BorderCollapse(longhands::border_collapse::computed_value::T, longhands::border_collapse::computed_value::T),
            
            /// border-image-repeat
            BorderImageRepeat(longhands::border_image_repeat::computed_value::T, longhands::border_image_repeat::computed_value::T),
            
            /// box-decoration-break
            BoxDecorationBreak(longhands::box_decoration_break::computed_value::T, longhands::box_decoration_break::computed_value::T),
            
            /// box-sizing
            BoxSizing(longhands::box_sizing::computed_value::T, longhands::box_sizing::computed_value::T),
            
            /// caption-side
            CaptionSide(longhands::caption_side::computed_value::T, longhands::caption_side::computed_value::T),
            
            /// clear
            Clear(longhands::clear::computed_value::T, longhands::clear::computed_value::T),
            
            /// clip-rule
            ClipRule(longhands::clip_rule::computed_value::T, longhands::clip_rule::computed_value::T),
            
            /// color-adjust
            ColorAdjust(longhands::color_adjust::computed_value::T, longhands::color_adjust::computed_value::T),
            
            /// color-interpolation
            ColorInterpolation(longhands::color_interpolation::computed_value::T, longhands::color_interpolation::computed_value::T),
            
            /// color-interpolation-filters
            ColorInterpolationFilters(longhands::color_interpolation_filters::computed_value::T, longhands::color_interpolation_filters::computed_value::T),
            
            /// column-count
            ColumnCount(<longhands::column_count::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::column_count::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// column-fill
            ColumnFill(longhands::column_fill::computed_value::T, longhands::column_fill::computed_value::T),
            
            /// column-rule-style
            ColumnRuleStyle(longhands::column_rule_style::computed_value::T, longhands::column_rule_style::computed_value::T),
            
            /// column-span
            ColumnSpan(longhands::column_span::computed_value::T, longhands::column_span::computed_value::T),
            
            /// contain
            Contain(longhands::contain::computed_value::T, longhands::contain::computed_value::T),
            
            /// direction
            Direction(longhands::direction::computed_value::T, longhands::direction::computed_value::T),
            
            /// dominant-baseline
            DominantBaseline(longhands::dominant_baseline::computed_value::T, longhands::dominant_baseline::computed_value::T),
            
            /// empty-cells
            EmptyCells(longhands::empty_cells::computed_value::T, longhands::empty_cells::computed_value::T),
            
            /// fill-rule
            FillRule(longhands::fill_rule::computed_value::T, longhands::fill_rule::computed_value::T),
            
            /// flex-direction
            FlexDirection(longhands::flex_direction::computed_value::T, longhands::flex_direction::computed_value::T),
            
            /// flex-wrap
            FlexWrap(longhands::flex_wrap::computed_value::T, longhands::flex_wrap::computed_value::T),
            
            /// float
            Float(longhands::float::computed_value::T, longhands::float::computed_value::T),
            
            /// font-kerning
            FontKerning(longhands::font_kerning::computed_value::T, longhands::font_kerning::computed_value::T),
            
            /// font-optical-sizing
            FontOpticalSizing(longhands::font_optical_sizing::computed_value::T, longhands::font_optical_sizing::computed_value::T),
            
            /// font-stretch
            FontStretch(longhands::font_stretch::computed_value::T, longhands::font_stretch::computed_value::T),
            
            /// font-style
            FontStyle(longhands::font_style::computed_value::T, longhands::font_style::computed_value::T),
            
            /// font-synthesis
            FontSynthesis(longhands::font_synthesis::computed_value::T, longhands::font_synthesis::computed_value::T),
            
            /// font-variant-caps
            FontVariantCaps(longhands::font_variant_caps::computed_value::T, longhands::font_variant_caps::computed_value::T),
            
            /// font-variant-position
            FontVariantPosition(longhands::font_variant_position::computed_value::T, longhands::font_variant_position::computed_value::T),
            
            /// font-weight
            FontWeight(longhands::font_weight::computed_value::T, longhands::font_weight::computed_value::T),
            
            /// grid-auto-flow
            GridAutoFlow(longhands::grid_auto_flow::computed_value::T, longhands::grid_auto_flow::computed_value::T),
            
            /// hyphens
            Hyphens(longhands::hyphens::computed_value::T, longhands::hyphens::computed_value::T),
            
            /// image-orientation
            ImageOrientation(longhands::image_orientation::computed_value::T, longhands::image_orientation::computed_value::T),
            
            /// image-rendering
            ImageRendering(longhands::image_rendering::computed_value::T, longhands::image_rendering::computed_value::T),
            
            /// ime-mode
            ImeMode(longhands::ime_mode::computed_value::T, longhands::ime_mode::computed_value::T),
            
            /// initial-letter
            InitialLetter(longhands::initial_letter::computed_value::T, longhands::initial_letter::computed_value::T),
            
            /// isolation
            Isolation(longhands::isolation::computed_value::T, longhands::isolation::computed_value::T),
            
            /// justify-content
            JustifyContent(longhands::justify_content::computed_value::T, longhands::justify_content::computed_value::T),
            
            /// justify-items
            JustifyItems(longhands::justify_items::computed_value::T, longhands::justify_items::computed_value::T),
            
            /// justify-self
            JustifySelf(longhands::justify_self::computed_value::T, longhands::justify_self::computed_value::T),
            
            /// list-style-position
            ListStylePosition(longhands::list_style_position::computed_value::T, longhands::list_style_position::computed_value::T),
            
            /// mask-type
            MaskType(longhands::mask_type::computed_value::T, longhands::mask_type::computed_value::T),
            
            /// mix-blend-mode
            MixBlendMode(longhands::mix_blend_mode::computed_value::T, longhands::mix_blend_mode::computed_value::T),
            
            /// -moz-appearance
            MozAppearance(longhands::_moz_appearance::computed_value::T, longhands::_moz_appearance::computed_value::T),
            
            /// -moz-box-align
            MozBoxAlign(longhands::_moz_box_align::computed_value::T, longhands::_moz_box_align::computed_value::T),
            
            /// -moz-box-direction
            MozBoxDirection(longhands::_moz_box_direction::computed_value::T, longhands::_moz_box_direction::computed_value::T),
            
            /// -moz-box-orient
            MozBoxOrient(longhands::_moz_box_orient::computed_value::T, longhands::_moz_box_orient::computed_value::T),
            
            /// -moz-box-pack
            MozBoxPack(longhands::_moz_box_pack::computed_value::T, longhands::_moz_box_pack::computed_value::T),
            
            /// -moz-float-edge
            MozFloatEdge(longhands::_moz_float_edge::computed_value::T, longhands::_moz_float_edge::computed_value::T),
            
            /// -moz-force-broken-image-icon
            MozForceBrokenImageIcon(longhands::_moz_force_broken_image_icon::computed_value::T, longhands::_moz_force_broken_image_icon::computed_value::T),
            
            /// -moz-orient
            MozOrient(longhands::_moz_orient::computed_value::T, longhands::_moz_orient::computed_value::T),
            
            /// -moz-osx-font-smoothing
            MozOsxFontSmoothing(longhands::_moz_osx_font_smoothing::computed_value::T, longhands::_moz_osx_font_smoothing::computed_value::T),
            
            /// -moz-stack-sizing
            MozStackSizing(longhands::_moz_stack_sizing::computed_value::T, longhands::_moz_stack_sizing::computed_value::T),
            
            /// -moz-text-size-adjust
            MozTextSizeAdjust(longhands::_moz_text_size_adjust::computed_value::T, longhands::_moz_text_size_adjust::computed_value::T),
            
            /// -moz-user-focus
            MozUserFocus(longhands::_moz_user_focus::computed_value::T, longhands::_moz_user_focus::computed_value::T),
            
            /// -moz-user-input
            MozUserInput(longhands::_moz_user_input::computed_value::T, longhands::_moz_user_input::computed_value::T),
            
            /// -moz-user-modify
            MozUserModify(longhands::_moz_user_modify::computed_value::T, longhands::_moz_user_modify::computed_value::T),
            
            /// -moz-user-select
            MozUserSelect(longhands::_moz_user_select::computed_value::T, longhands::_moz_user_select::computed_value::T),
            
            /// -moz-window-dragging
            MozWindowDragging(longhands::_moz_window_dragging::computed_value::T, longhands::_moz_window_dragging::computed_value::T),
            
            /// -moz-window-shadow
            MozWindowShadow(longhands::_moz_window_shadow::computed_value::T, longhands::_moz_window_shadow::computed_value::T),
            
            /// object-fit
            ObjectFit(longhands::object_fit::computed_value::T, longhands::object_fit::computed_value::T),
            
            /// outline-style
            OutlineStyle(longhands::outline_style::computed_value::T, longhands::outline_style::computed_value::T),
            
            /// overflow-wrap
            OverflowWrap(longhands::overflow_wrap::computed_value::T, longhands::overflow_wrap::computed_value::T),
            
            /// overflow-x
            OverflowX(longhands::overflow_x::computed_value::T, longhands::overflow_x::computed_value::T),
            
            /// page-break-after
            PageBreakAfter(longhands::page_break_after::computed_value::T, longhands::page_break_after::computed_value::T),
            
            /// page-break-before
            PageBreakBefore(longhands::page_break_before::computed_value::T, longhands::page_break_before::computed_value::T),
            
            /// page-break-inside
            PageBreakInside(longhands::page_break_inside::computed_value::T, longhands::page_break_inside::computed_value::T),
            
            /// paint-order
            PaintOrder(longhands::paint_order::computed_value::T, longhands::paint_order::computed_value::T),
            
            /// pointer-events
            PointerEvents(longhands::pointer_events::computed_value::T, longhands::pointer_events::computed_value::T),
            
            /// position
            Position(longhands::position::computed_value::T, longhands::position::computed_value::T),
            
            /// resize
            Resize(longhands::resize::computed_value::T, longhands::resize::computed_value::T),
            
            /// ruby-align
            RubyAlign(longhands::ruby_align::computed_value::T, longhands::ruby_align::computed_value::T),
            
            /// ruby-position
            RubyPosition(longhands::ruby_position::computed_value::T, longhands::ruby_position::computed_value::T),
            
            /// scroll-behavior
            ScrollBehavior(longhands::scroll_behavior::computed_value::T, longhands::scroll_behavior::computed_value::T),
            
            /// shape-rendering
            ShapeRendering(longhands::shape_rendering::computed_value::T, longhands::shape_rendering::computed_value::T),
            
            /// stroke-linecap
            StrokeLinecap(longhands::stroke_linecap::computed_value::T, longhands::stroke_linecap::computed_value::T),
            
            /// stroke-linejoin
            StrokeLinejoin(longhands::stroke_linejoin::computed_value::T, longhands::stroke_linejoin::computed_value::T),
            
            /// table-layout
            TableLayout(longhands::table_layout::computed_value::T, longhands::table_layout::computed_value::T),
            
            /// text-align-last
            TextAlignLast(longhands::text_align_last::computed_value::T, longhands::text_align_last::computed_value::T),
            
            /// text-anchor
            TextAnchor(longhands::text_anchor::computed_value::T, longhands::text_anchor::computed_value::T),
            
            /// text-combine-upright
            TextCombineUpright(longhands::text_combine_upright::computed_value::T, longhands::text_combine_upright::computed_value::T),
            
            /// text-decoration-line
            TextDecorationLine(longhands::text_decoration_line::computed_value::T, longhands::text_decoration_line::computed_value::T),
            
            /// text-decoration-style
            TextDecorationStyle(longhands::text_decoration_style::computed_value::T, longhands::text_decoration_style::computed_value::T),
            
            /// text-justify
            TextJustify(longhands::text_justify::computed_value::T, longhands::text_justify::computed_value::T),
            
            /// text-orientation
            TextOrientation(longhands::text_orientation::computed_value::T, longhands::text_orientation::computed_value::T),
            
            /// text-rendering
            TextRendering(longhands::text_rendering::computed_value::T, longhands::text_rendering::computed_value::T),
            
            /// text-transform
            TextTransform(longhands::text_transform::computed_value::T, longhands::text_transform::computed_value::T),
            
            /// touch-action
            TouchAction(longhands::touch_action::computed_value::T, longhands::touch_action::computed_value::T),
            
            /// transform-box
            TransformBox(longhands::transform_box::computed_value::T, longhands::transform_box::computed_value::T),
            
            /// transform-style
            TransformStyle(longhands::transform_style::computed_value::T, longhands::transform_style::computed_value::T),
            
            /// unicode-bidi
            UnicodeBidi(longhands::unicode_bidi::computed_value::T, longhands::unicode_bidi::computed_value::T),
            
            /// vector-effect
            VectorEffect(longhands::vector_effect::computed_value::T, longhands::vector_effect::computed_value::T),
            
            /// visibility
            Visibility(longhands::visibility::computed_value::T, longhands::visibility::computed_value::T),
            
            /// white-space
            WhiteSpace(longhands::white_space::computed_value::T, longhands::white_space::computed_value::T),
            
            /// word-break
            WordBreak(longhands::word_break::computed_value::T, longhands::word_break::computed_value::T),
            
            /// writing-mode
            WritingMode(longhands::writing_mode::computed_value::T, longhands::writing_mode::computed_value::T),
            
            /// z-index
            ZIndex(longhands::z_index::computed_value::T, longhands::z_index::computed_value::T),
            
            /// -moz-box-ordinal-group
            MozBoxOrdinalGroup(longhands::_moz_box_ordinal_group::computed_value::T, longhands::_moz_box_ordinal_group::computed_value::T),
            
            /// order
            Order(longhands::order::computed_value::T, longhands::order::computed_value::T),
            
            /// overscroll-behavior-x
            OverscrollBehaviorX(longhands::overscroll_behavior_x::computed_value::T, longhands::overscroll_behavior_x::computed_value::T),
            
            /// overscroll-behavior-y
            OverscrollBehaviorY(longhands::overscroll_behavior_y::computed_value::T, longhands::overscroll_behavior_y::computed_value::T),
            
            /// scroll-snap-type-x
            ScrollSnapTypeX(longhands::scroll_snap_type_x::computed_value::T, longhands::scroll_snap_type_x::computed_value::T),
            
            /// scroll-snap-type-y
            ScrollSnapTypeY(longhands::scroll_snap_type_y::computed_value::T, longhands::scroll_snap_type_y::computed_value::T),
            
            /// flex-grow
            FlexGrow(<longhands::flex_grow::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::flex_grow::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// flex-shrink
            FlexShrink(<longhands::flex_shrink::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::flex_shrink::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -moz-box-flex
            MozBoxFlex(<longhands::_moz_box_flex::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_moz_box_flex::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// flood-opacity
            FloodOpacity(longhands::flood_opacity::computed_value::T, longhands::flood_opacity::computed_value::T),
            
            /// -moz-window-opacity
            MozWindowOpacity(longhands::_moz_window_opacity::computed_value::T, longhands::_moz_window_opacity::computed_value::T),
            
            /// opacity
            Opacity(longhands::opacity::computed_value::T, longhands::opacity::computed_value::T),
            
            /// shape-image-threshold
            ShapeImageThreshold(longhands::shape_image_threshold::computed_value::T, longhands::shape_image_threshold::computed_value::T),
            
            /// stop-opacity
            StopOpacity(longhands::stop_opacity::computed_value::T, longhands::stop_opacity::computed_value::T),
            
            /// border-bottom-style
            BorderBottomStyle(longhands::border_bottom_style::computed_value::T, longhands::border_bottom_style::computed_value::T),
            
            /// border-left-style
            BorderLeftStyle(longhands::border_left_style::computed_value::T, longhands::border_left_style::computed_value::T),
            
            /// border-right-style
            BorderRightStyle(longhands::border_right_style::computed_value::T, longhands::border_right_style::computed_value::T),
            
            /// border-top-style
            BorderTopStyle(longhands::border_top_style::computed_value::T, longhands::border_top_style::computed_value::T),
            
            /// background-attachment
            BackgroundAttachment(longhands::background_attachment::computed_value::T, longhands::background_attachment::computed_value::T),
            
            /// background-blend-mode
            BackgroundBlendMode(longhands::background_blend_mode::computed_value::T, longhands::background_blend_mode::computed_value::T),
            
            /// background-clip
            BackgroundClip(longhands::background_clip::computed_value::T, longhands::background_clip::computed_value::T),
            
            /// background-image
            BackgroundImage(longhands::background_image::computed_value::T, longhands::background_image::computed_value::T),
            
            /// background-origin
            BackgroundOrigin(longhands::background_origin::computed_value::T, longhands::background_origin::computed_value::T),
            
            /// background-position-x
            BackgroundPositionX(longhands::background_position_x::computed_value::T, longhands::background_position_x::computed_value::T),
            
            /// background-position-y
            BackgroundPositionY(longhands::background_position_y::computed_value::T, longhands::background_position_y::computed_value::T),
            
            /// background-repeat
            BackgroundRepeat(longhands::background_repeat::computed_value::T, longhands::background_repeat::computed_value::T),
            
            /// background-size
            BackgroundSize(<longhands::background_size::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::background_size::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-image-outset
            BorderImageOutset(longhands::border_image_outset::computed_value::T, longhands::border_image_outset::computed_value::T),
            
            /// border-image-slice
            BorderImageSlice(longhands::border_image_slice::computed_value::T, longhands::border_image_slice::computed_value::T),
            
            /// border-image-source
            BorderImageSource(longhands::border_image_source::computed_value::T, longhands::border_image_source::computed_value::T),
            
            /// border-image-width
            BorderImageWidth(longhands::border_image_width::computed_value::T, longhands::border_image_width::computed_value::T),
            
            /// border-spacing
            BorderSpacing(<longhands::border_spacing::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_spacing::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// box-shadow
            BoxShadow(<longhands::box_shadow::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::box_shadow::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// caret-color
            CaretColor(<longhands::caret_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::caret_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// clip-path
            ClipPath(longhands::clip_path::computed_value::T, longhands::clip_path::computed_value::T),
            
            /// color
            Color(<longhands::color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// column-gap
            ColumnGap(<longhands::column_gap::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::column_gap::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// column-width
            ColumnWidth(<longhands::column_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::column_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// content
            Content(longhands::content::computed_value::T, longhands::content::computed_value::T),
            
            /// counter-increment
            CounterIncrement(longhands::counter_increment::computed_value::T, longhands::counter_increment::computed_value::T),
            
            /// counter-reset
            CounterReset(longhands::counter_reset::computed_value::T, longhands::counter_reset::computed_value::T),
            
            /// cursor
            Cursor(longhands::cursor::computed_value::T, longhands::cursor::computed_value::T),
            
            /// display
            Display(longhands::display::computed_value::T, longhands::display::computed_value::T),
            
            /// filter
            Filter(<longhands::filter::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::filter::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// font-family
            FontFamily(longhands::font_family::computed_value::T, longhands::font_family::computed_value::T),
            
            /// font-feature-settings
            FontFeatureSettings(longhands::font_feature_settings::computed_value::T, longhands::font_feature_settings::computed_value::T),
            
            /// font-language-override
            FontLanguageOverride(longhands::font_language_override::computed_value::T, longhands::font_language_override::computed_value::T),
            
            /// font-size
            FontSize(<longhands::font_size::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::font_size::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// font-size-adjust
            FontSizeAdjust(longhands::font_size_adjust::computed_value::T, longhands::font_size_adjust::computed_value::T),
            
            /// font-variant-alternates
            FontVariantAlternates(longhands::font_variant_alternates::computed_value::T, longhands::font_variant_alternates::computed_value::T),
            
            /// font-variant-east-asian
            FontVariantEastAsian(longhands::font_variant_east_asian::computed_value::T, longhands::font_variant_east_asian::computed_value::T),
            
            /// font-variant-ligatures
            FontVariantLigatures(longhands::font_variant_ligatures::computed_value::T, longhands::font_variant_ligatures::computed_value::T),
            
            /// font-variant-numeric
            FontVariantNumeric(longhands::font_variant_numeric::computed_value::T, longhands::font_variant_numeric::computed_value::T),
            
            /// font-variation-settings
            FontVariationSettings(longhands::font_variation_settings::computed_value::T, longhands::font_variation_settings::computed_value::T),
            
            /// grid-template-areas
            GridTemplateAreas(longhands::grid_template_areas::computed_value::T, longhands::grid_template_areas::computed_value::T),
            
            /// letter-spacing
            LetterSpacing(longhands::letter_spacing::computed_value::T, longhands::letter_spacing::computed_value::T),
            
            /// line-height
            LineHeight(<longhands::line_height::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::line_height::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// list-style-image
            ListStyleImage(longhands::list_style_image::computed_value::T, longhands::list_style_image::computed_value::T),
            
            /// list-style-type
            ListStyleType(longhands::list_style_type::computed_value::T, longhands::list_style_type::computed_value::T),
            
            /// mask-clip
            MaskClip(longhands::mask_clip::computed_value::T, longhands::mask_clip::computed_value::T),
            
            /// mask-composite
            MaskComposite(longhands::mask_composite::computed_value::T, longhands::mask_composite::computed_value::T),
            
            /// mask-image
            MaskImage(longhands::mask_image::computed_value::T, longhands::mask_image::computed_value::T),
            
            /// mask-mode
            MaskMode(longhands::mask_mode::computed_value::T, longhands::mask_mode::computed_value::T),
            
            /// mask-origin
            MaskOrigin(longhands::mask_origin::computed_value::T, longhands::mask_origin::computed_value::T),
            
            /// mask-position-x
            MaskPositionX(longhands::mask_position_x::computed_value::T, longhands::mask_position_x::computed_value::T),
            
            /// mask-position-y
            MaskPositionY(longhands::mask_position_y::computed_value::T, longhands::mask_position_y::computed_value::T),
            
            /// mask-repeat
            MaskRepeat(longhands::mask_repeat::computed_value::T, longhands::mask_repeat::computed_value::T),
            
            /// mask-size
            MaskSize(longhands::mask_size::computed_value::T, longhands::mask_size::computed_value::T),
            
            /// -moz-tab-size
            MozTabSize(<longhands::_moz_tab_size::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_moz_tab_size::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// outline-offset
            OutlineOffset(longhands::outline_offset::computed_value::T, longhands::outline_offset::computed_value::T),
            
            /// overflow-y
            OverflowY(longhands::overflow_y::computed_value::T, longhands::overflow_y::computed_value::T),
            
            /// perspective
            Perspective(<longhands::perspective::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::perspective::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// perspective-origin
            PerspectiveOrigin(longhands::perspective_origin::computed_value::T, longhands::perspective_origin::computed_value::T),
            
            /// quotes
            Quotes(longhands::quotes::computed_value::T, longhands::quotes::computed_value::T),
            
            /// rotate
            Rotate(longhands::rotate::computed_value::T, longhands::rotate::computed_value::T),
            
            /// scale
            Scale(longhands::scale::computed_value::T, longhands::scale::computed_value::T),
            
            /// scroll-snap-coordinate
            ScrollSnapCoordinate(longhands::scroll_snap_coordinate::computed_value::T, longhands::scroll_snap_coordinate::computed_value::T),
            
            /// shape-outside
            ShapeOutside(longhands::shape_outside::computed_value::T, longhands::shape_outside::computed_value::T),
            
            /// stroke-dasharray
            StrokeDasharray(<longhands::stroke_dasharray::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::stroke_dasharray::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// stroke-dashoffset
            StrokeDashoffset(longhands::stroke_dashoffset::computed_value::T, longhands::stroke_dashoffset::computed_value::T),
            
            /// stroke-miterlimit
            StrokeMiterlimit(<longhands::stroke_miterlimit::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::stroke_miterlimit::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// stroke-width
            StrokeWidth(<longhands::stroke_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::stroke_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// text-align
            TextAlign(longhands::text_align::computed_value::T, longhands::text_align::computed_value::T),
            
            /// text-emphasis-position
            TextEmphasisPosition(longhands::text_emphasis_position::computed_value::T, longhands::text_emphasis_position::computed_value::T),
            
            /// text-emphasis-style
            TextEmphasisStyle(longhands::text_emphasis_style::computed_value::T, longhands::text_emphasis_style::computed_value::T),
            
            /// text-indent
            TextIndent(longhands::text_indent::computed_value::T, longhands::text_indent::computed_value::T),
            
            /// text-overflow
            TextOverflow(longhands::text_overflow::computed_value::T, longhands::text_overflow::computed_value::T),
            
            /// text-shadow
            TextShadow(<longhands::text_shadow::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::text_shadow::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// translate
            Translate(longhands::translate::computed_value::T, longhands::translate::computed_value::T),
            
            /// vertical-align
            VerticalAlign(longhands::vertical_align::computed_value::T, longhands::vertical_align::computed_value::T),
            
            /// will-change
            WillChange(longhands::will_change::computed_value::T, longhands::will_change::computed_value::T),
            
            /// word-spacing
            WordSpacing(longhands::word_spacing::computed_value::T, longhands::word_spacing::computed_value::T),
            
            /// overflow-clip-box-block
            OverflowClipBoxBlock(longhands::overflow_clip_box_block::computed_value::T, longhands::overflow_clip_box_block::computed_value::T),
            
            /// overflow-clip-box-inline
            OverflowClipBoxInline(longhands::overflow_clip_box_inline::computed_value::T, longhands::overflow_clip_box_inline::computed_value::T),
            
            /// fill-opacity
            FillOpacity(longhands::fill_opacity::computed_value::T, longhands::fill_opacity::computed_value::T),
            
            /// stroke-opacity
            StrokeOpacity(longhands::stroke_opacity::computed_value::T, longhands::stroke_opacity::computed_value::T),
            
            /// scroll-snap-points-x
            ScrollSnapPointsX(longhands::scroll_snap_points_x::computed_value::T, longhands::scroll_snap_points_x::computed_value::T),
            
            /// scroll-snap-points-y
            ScrollSnapPointsY(longhands::scroll_snap_points_y::computed_value::T, longhands::scroll_snap_points_y::computed_value::T),
            
            /// -moz-window-transform
            MozWindowTransform(longhands::_moz_window_transform::computed_value::T, longhands::_moz_window_transform::computed_value::T),
            
            /// transform
            Transform(longhands::transform::computed_value::T, longhands::transform::computed_value::T),
            
            /// clip
            Clip(longhands::clip::computed_value::T, longhands::clip::computed_value::T),
            
            /// -moz-image-region
            MozImageRegion(longhands::_moz_image_region::computed_value::T, longhands::_moz_image_region::computed_value::T),
            
            /// grid-template-columns
            GridTemplateColumns(longhands::grid_template_columns::computed_value::T, longhands::grid_template_columns::computed_value::T),
            
            /// grid-template-rows
            GridTemplateRows(longhands::grid_template_rows::computed_value::T, longhands::grid_template_rows::computed_value::T),
            
            /// object-position
            ObjectPosition(longhands::object_position::computed_value::T, longhands::object_position::computed_value::T),
            
            /// scroll-snap-destination
            ScrollSnapDestination(longhands::scroll_snap_destination::computed_value::T, longhands::scroll_snap_destination::computed_value::T),
            
            /// fill
            Fill(<longhands::fill::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::fill::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// stroke
            Stroke(<longhands::stroke::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::stroke::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// grid-auto-columns
            GridAutoColumns(longhands::grid_auto_columns::computed_value::T, longhands::grid_auto_columns::computed_value::T),
            
            /// grid-auto-rows
            GridAutoRows(longhands::grid_auto_rows::computed_value::T, longhands::grid_auto_rows::computed_value::T),
            
            /// -moz-window-transform-origin
            MozWindowTransformOrigin(longhands::_moz_window_transform_origin::computed_value::T, longhands::_moz_window_transform_origin::computed_value::T),
            
            /// transform-origin
            TransformOrigin(longhands::transform_origin::computed_value::T, longhands::transform_origin::computed_value::T),
            
            /// max-height
            MaxHeight(<longhands::max_height::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::max_height::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// max-width
            MaxWidth(<longhands::max_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::max_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// flood-color
            FloodColor(<longhands::flood_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::flood_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// lighting-color
            LightingColor(<longhands::lighting_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::lighting_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -moz-font-smoothing-background-color
            MozFontSmoothingBackgroundColor(<longhands::_moz_font_smoothing_background_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_moz_font_smoothing_background_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// stop-color
            StopColor(<longhands::stop_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::stop_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// marker-end
            MarkerEnd(longhands::marker_end::computed_value::T, longhands::marker_end::computed_value::T),
            
            /// marker-mid
            MarkerMid(longhands::marker_mid::computed_value::T, longhands::marker_mid::computed_value::T),
            
            /// marker-start
            MarkerStart(longhands::marker_start::computed_value::T, longhands::marker_start::computed_value::T),
            
            /// grid-column-end
            GridColumnEnd(longhands::grid_column_end::computed_value::T, longhands::grid_column_end::computed_value::T),
            
            /// grid-column-start
            GridColumnStart(longhands::grid_column_start::computed_value::T, longhands::grid_column_start::computed_value::T),
            
            /// grid-row-end
            GridRowEnd(longhands::grid_row_end::computed_value::T, longhands::grid_row_end::computed_value::T),
            
            /// grid-row-start
            GridRowStart(longhands::grid_row_start::computed_value::T, longhands::grid_row_start::computed_value::T),
            
            /// border-bottom-left-radius
            BorderBottomLeftRadius(<longhands::border_bottom_left_radius::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_bottom_left_radius::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-bottom-right-radius
            BorderBottomRightRadius(<longhands::border_bottom_right_radius::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_bottom_right_radius::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-top-left-radius
            BorderTopLeftRadius(<longhands::border_top_left_radius::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_top_left_radius::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-top-right-radius
            BorderTopRightRadius(<longhands::border_top_right_radius::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_top_right_radius::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -moz-outline-radius-bottomleft
            MozOutlineRadiusBottomleft(<longhands::_moz_outline_radius_bottomleft::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_moz_outline_radius_bottomleft::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -moz-outline-radius-bottomright
            MozOutlineRadiusBottomright(<longhands::_moz_outline_radius_bottomright::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_moz_outline_radius_bottomright::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -moz-outline-radius-topleft
            MozOutlineRadiusTopleft(<longhands::_moz_outline_radius_topleft::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_moz_outline_radius_topleft::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -moz-outline-radius-topright
            MozOutlineRadiusTopright(<longhands::_moz_outline_radius_topright::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_moz_outline_radius_topright::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// flex-basis
            FlexBasis(<longhands::flex_basis::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::flex_basis::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// height
            Height(<longhands::height::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::height::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// min-height
            MinHeight(<longhands::min_height::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::min_height::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// min-width
            MinWidth(<longhands::min_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::min_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// width
            Width(<longhands::width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// grid-column-gap
            GridColumnGap(<longhands::grid_column_gap::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::grid_column_gap::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// grid-row-gap
            GridRowGap(<longhands::grid_row_gap::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::grid_row_gap::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// padding-bottom
            PaddingBottom(<longhands::padding_bottom::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::padding_bottom::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// padding-left
            PaddingLeft(<longhands::padding_left::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::padding_left::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// padding-right
            PaddingRight(<longhands::padding_right::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::padding_right::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// padding-top
            PaddingTop(<longhands::padding_top::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::padding_top::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-bottom-width
            BorderBottomWidth(<longhands::border_bottom_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_bottom_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-left-width
            BorderLeftWidth(<longhands::border_left_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_left_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-right-width
            BorderRightWidth(<longhands::border_right_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_right_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-top-width
            BorderTopWidth(<longhands::border_top_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_top_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// column-rule-width
            ColumnRuleWidth(<longhands::column_rule_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::column_rule_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// outline-width
            OutlineWidth(<longhands::outline_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::outline_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -webkit-text-stroke-width
            WebkitTextStrokeWidth(longhands::_webkit_text_stroke_width::computed_value::T, longhands::_webkit_text_stroke_width::computed_value::T),
            
            /// background-color
            BackgroundColor(<longhands::background_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::background_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-bottom-color
            BorderBottomColor(<longhands::border_bottom_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_bottom_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-left-color
            BorderLeftColor(<longhands::border_left_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_left_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-right-color
            BorderRightColor(<longhands::border_right_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_right_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-top-color
            BorderTopColor(<longhands::border_top_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_top_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// column-rule-color
            ColumnRuleColor(<longhands::column_rule_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::column_rule_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// outline-color
            OutlineColor(<longhands::outline_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::outline_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// text-decoration-color
            TextDecorationColor(<longhands::text_decoration_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::text_decoration_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// text-emphasis-color
            TextEmphasisColor(<longhands::text_emphasis_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::text_emphasis_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -webkit-text-fill-color
            WebkitTextFillColor(<longhands::_webkit_text_fill_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_webkit_text_fill_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -webkit-text-stroke-color
            WebkitTextStrokeColor(<longhands::_webkit_text_stroke_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_webkit_text_stroke_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// bottom
            Bottom(longhands::bottom::computed_value::T, longhands::bottom::computed_value::T),
            
            /// left
            Left(longhands::left::computed_value::T, longhands::left::computed_value::T),
            
            /// margin-bottom
            MarginBottom(longhands::margin_bottom::computed_value::T, longhands::margin_bottom::computed_value::T),
            
            /// margin-left
            MarginLeft(longhands::margin_left::computed_value::T, longhands::margin_left::computed_value::T),
            
            /// margin-right
            MarginRight(longhands::margin_right::computed_value::T, longhands::margin_right::computed_value::T),
            
            /// margin-top
            MarginTop(longhands::margin_top::computed_value::T, longhands::margin_top::computed_value::T),
            
            /// right
            Right(longhands::right::computed_value::T, longhands::right::computed_value::T),
            
            /// top
            Top(longhands::top::computed_value::T, longhands::top::computed_value::T),
}

#[cfg(feature = "servo")]
impl AnimatedProperty {
    /// Get the name of this property.
    pub fn name(&self) -> &'static str {
        match *self {
                    AnimatedProperty::AlignContent(..) => "align-content",
                    AnimatedProperty::AlignItems(..) => "align-items",
                    AnimatedProperty::AlignSelf(..) => "align-self",
                    AnimatedProperty::BackfaceVisibility(..) => "backface-visibility",
                    AnimatedProperty::BorderCollapse(..) => "border-collapse",
                    AnimatedProperty::BorderImageRepeat(..) => "border-image-repeat",
                    AnimatedProperty::BoxDecorationBreak(..) => "box-decoration-break",
                    AnimatedProperty::BoxSizing(..) => "box-sizing",
                    AnimatedProperty::CaptionSide(..) => "caption-side",
                    AnimatedProperty::Clear(..) => "clear",
                    AnimatedProperty::ClipRule(..) => "clip-rule",
                    AnimatedProperty::ColorAdjust(..) => "color-adjust",
                    AnimatedProperty::ColorInterpolation(..) => "color-interpolation",
                    AnimatedProperty::ColorInterpolationFilters(..) => "color-interpolation-filters",
                    AnimatedProperty::ColumnCount(..) => "column-count",
                    AnimatedProperty::ColumnFill(..) => "column-fill",
                    AnimatedProperty::ColumnRuleStyle(..) => "column-rule-style",
                    AnimatedProperty::ColumnSpan(..) => "column-span",
                    AnimatedProperty::Contain(..) => "contain",
                    AnimatedProperty::Direction(..) => "direction",
                    AnimatedProperty::DominantBaseline(..) => "dominant-baseline",
                    AnimatedProperty::EmptyCells(..) => "empty-cells",
                    AnimatedProperty::FillRule(..) => "fill-rule",
                    AnimatedProperty::FlexDirection(..) => "flex-direction",
                    AnimatedProperty::FlexWrap(..) => "flex-wrap",
                    AnimatedProperty::Float(..) => "float",
                    AnimatedProperty::FontKerning(..) => "font-kerning",
                    AnimatedProperty::FontOpticalSizing(..) => "font-optical-sizing",
                    AnimatedProperty::FontStretch(..) => "font-stretch",
                    AnimatedProperty::FontStyle(..) => "font-style",
                    AnimatedProperty::FontSynthesis(..) => "font-synthesis",
                    AnimatedProperty::FontVariantCaps(..) => "font-variant-caps",
                    AnimatedProperty::FontVariantPosition(..) => "font-variant-position",
                    AnimatedProperty::FontWeight(..) => "font-weight",
                    AnimatedProperty::GridAutoFlow(..) => "grid-auto-flow",
                    AnimatedProperty::Hyphens(..) => "hyphens",
                    AnimatedProperty::ImageOrientation(..) => "image-orientation",
                    AnimatedProperty::ImageRendering(..) => "image-rendering",
                    AnimatedProperty::ImeMode(..) => "ime-mode",
                    AnimatedProperty::InitialLetter(..) => "initial-letter",
                    AnimatedProperty::Isolation(..) => "isolation",
                    AnimatedProperty::JustifyContent(..) => "justify-content",
                    AnimatedProperty::JustifyItems(..) => "justify-items",
                    AnimatedProperty::JustifySelf(..) => "justify-self",
                    AnimatedProperty::ListStylePosition(..) => "list-style-position",
                    AnimatedProperty::MaskType(..) => "mask-type",
                    AnimatedProperty::MixBlendMode(..) => "mix-blend-mode",
                    AnimatedProperty::MozAppearance(..) => "-moz-appearance",
                    AnimatedProperty::MozBoxAlign(..) => "-moz-box-align",
                    AnimatedProperty::MozBoxDirection(..) => "-moz-box-direction",
                    AnimatedProperty::MozBoxOrient(..) => "-moz-box-orient",
                    AnimatedProperty::MozBoxPack(..) => "-moz-box-pack",
                    AnimatedProperty::MozFloatEdge(..) => "-moz-float-edge",
                    AnimatedProperty::MozForceBrokenImageIcon(..) => "-moz-force-broken-image-icon",
                    AnimatedProperty::MozOrient(..) => "-moz-orient",
                    AnimatedProperty::MozOsxFontSmoothing(..) => "-moz-osx-font-smoothing",
                    AnimatedProperty::MozStackSizing(..) => "-moz-stack-sizing",
                    AnimatedProperty::MozTextSizeAdjust(..) => "-moz-text-size-adjust",
                    AnimatedProperty::MozUserFocus(..) => "-moz-user-focus",
                    AnimatedProperty::MozUserInput(..) => "-moz-user-input",
                    AnimatedProperty::MozUserModify(..) => "-moz-user-modify",
                    AnimatedProperty::MozUserSelect(..) => "-moz-user-select",
                    AnimatedProperty::MozWindowDragging(..) => "-moz-window-dragging",
                    AnimatedProperty::MozWindowShadow(..) => "-moz-window-shadow",
                    AnimatedProperty::ObjectFit(..) => "object-fit",
                    AnimatedProperty::OutlineStyle(..) => "outline-style",
                    AnimatedProperty::OverflowWrap(..) => "overflow-wrap",
                    AnimatedProperty::OverflowX(..) => "overflow-x",
                    AnimatedProperty::PageBreakAfter(..) => "page-break-after",
                    AnimatedProperty::PageBreakBefore(..) => "page-break-before",
                    AnimatedProperty::PageBreakInside(..) => "page-break-inside",
                    AnimatedProperty::PaintOrder(..) => "paint-order",
                    AnimatedProperty::PointerEvents(..) => "pointer-events",
                    AnimatedProperty::Position(..) => "position",
                    AnimatedProperty::Resize(..) => "resize",
                    AnimatedProperty::RubyAlign(..) => "ruby-align",
                    AnimatedProperty::RubyPosition(..) => "ruby-position",
                    AnimatedProperty::ScrollBehavior(..) => "scroll-behavior",
                    AnimatedProperty::ShapeRendering(..) => "shape-rendering",
                    AnimatedProperty::StrokeLinecap(..) => "stroke-linecap",
                    AnimatedProperty::StrokeLinejoin(..) => "stroke-linejoin",
                    AnimatedProperty::TableLayout(..) => "table-layout",
                    AnimatedProperty::TextAlignLast(..) => "text-align-last",
                    AnimatedProperty::TextAnchor(..) => "text-anchor",
                    AnimatedProperty::TextCombineUpright(..) => "text-combine-upright",
                    AnimatedProperty::TextDecorationLine(..) => "text-decoration-line",
                    AnimatedProperty::TextDecorationStyle(..) => "text-decoration-style",
                    AnimatedProperty::TextJustify(..) => "text-justify",
                    AnimatedProperty::TextOrientation(..) => "text-orientation",
                    AnimatedProperty::TextRendering(..) => "text-rendering",
                    AnimatedProperty::TextTransform(..) => "text-transform",
                    AnimatedProperty::TouchAction(..) => "touch-action",
                    AnimatedProperty::TransformBox(..) => "transform-box",
                    AnimatedProperty::TransformStyle(..) => "transform-style",
                    AnimatedProperty::UnicodeBidi(..) => "unicode-bidi",
                    AnimatedProperty::VectorEffect(..) => "vector-effect",
                    AnimatedProperty::Visibility(..) => "visibility",
                    AnimatedProperty::WhiteSpace(..) => "white-space",
                    AnimatedProperty::WordBreak(..) => "word-break",
                    AnimatedProperty::WritingMode(..) => "writing-mode",
                    AnimatedProperty::ZIndex(..) => "z-index",
                    AnimatedProperty::MozBoxOrdinalGroup(..) => "-moz-box-ordinal-group",
                    AnimatedProperty::Order(..) => "order",
                    AnimatedProperty::OverscrollBehaviorX(..) => "overscroll-behavior-x",
                    AnimatedProperty::OverscrollBehaviorY(..) => "overscroll-behavior-y",
                    AnimatedProperty::ScrollSnapTypeX(..) => "scroll-snap-type-x",
                    AnimatedProperty::ScrollSnapTypeY(..) => "scroll-snap-type-y",
                    AnimatedProperty::FlexGrow(..) => "flex-grow",
                    AnimatedProperty::FlexShrink(..) => "flex-shrink",
                    AnimatedProperty::MozBoxFlex(..) => "-moz-box-flex",
                    AnimatedProperty::FloodOpacity(..) => "flood-opacity",
                    AnimatedProperty::MozWindowOpacity(..) => "-moz-window-opacity",
                    AnimatedProperty::Opacity(..) => "opacity",
                    AnimatedProperty::ShapeImageThreshold(..) => "shape-image-threshold",
                    AnimatedProperty::StopOpacity(..) => "stop-opacity",
                    AnimatedProperty::BorderBottomStyle(..) => "border-bottom-style",
                    AnimatedProperty::BorderLeftStyle(..) => "border-left-style",
                    AnimatedProperty::BorderRightStyle(..) => "border-right-style",
                    AnimatedProperty::BorderTopStyle(..) => "border-top-style",
                    AnimatedProperty::BackgroundAttachment(..) => "background-attachment",
                    AnimatedProperty::BackgroundBlendMode(..) => "background-blend-mode",
                    AnimatedProperty::BackgroundClip(..) => "background-clip",
                    AnimatedProperty::BackgroundImage(..) => "background-image",
                    AnimatedProperty::BackgroundOrigin(..) => "background-origin",
                    AnimatedProperty::BackgroundPositionX(..) => "background-position-x",
                    AnimatedProperty::BackgroundPositionY(..) => "background-position-y",
                    AnimatedProperty::BackgroundRepeat(..) => "background-repeat",
                    AnimatedProperty::BackgroundSize(..) => "background-size",
                    AnimatedProperty::BorderImageOutset(..) => "border-image-outset",
                    AnimatedProperty::BorderImageSlice(..) => "border-image-slice",
                    AnimatedProperty::BorderImageSource(..) => "border-image-source",
                    AnimatedProperty::BorderImageWidth(..) => "border-image-width",
                    AnimatedProperty::BorderSpacing(..) => "border-spacing",
                    AnimatedProperty::BoxShadow(..) => "box-shadow",
                    AnimatedProperty::CaretColor(..) => "caret-color",
                    AnimatedProperty::ClipPath(..) => "clip-path",
                    AnimatedProperty::Color(..) => "color",
                    AnimatedProperty::ColumnGap(..) => "column-gap",
                    AnimatedProperty::ColumnWidth(..) => "column-width",
                    AnimatedProperty::Content(..) => "content",
                    AnimatedProperty::CounterIncrement(..) => "counter-increment",
                    AnimatedProperty::CounterReset(..) => "counter-reset",
                    AnimatedProperty::Cursor(..) => "cursor",
                    AnimatedProperty::Display(..) => "display",
                    AnimatedProperty::Filter(..) => "filter",
                    AnimatedProperty::FontFamily(..) => "font-family",
                    AnimatedProperty::FontFeatureSettings(..) => "font-feature-settings",
                    AnimatedProperty::FontLanguageOverride(..) => "font-language-override",
                    AnimatedProperty::FontSize(..) => "font-size",
                    AnimatedProperty::FontSizeAdjust(..) => "font-size-adjust",
                    AnimatedProperty::FontVariantAlternates(..) => "font-variant-alternates",
                    AnimatedProperty::FontVariantEastAsian(..) => "font-variant-east-asian",
                    AnimatedProperty::FontVariantLigatures(..) => "font-variant-ligatures",
                    AnimatedProperty::FontVariantNumeric(..) => "font-variant-numeric",
                    AnimatedProperty::FontVariationSettings(..) => "font-variation-settings",
                    AnimatedProperty::GridTemplateAreas(..) => "grid-template-areas",
                    AnimatedProperty::LetterSpacing(..) => "letter-spacing",
                    AnimatedProperty::LineHeight(..) => "line-height",
                    AnimatedProperty::ListStyleImage(..) => "list-style-image",
                    AnimatedProperty::ListStyleType(..) => "list-style-type",
                    AnimatedProperty::MaskClip(..) => "mask-clip",
                    AnimatedProperty::MaskComposite(..) => "mask-composite",
                    AnimatedProperty::MaskImage(..) => "mask-image",
                    AnimatedProperty::MaskMode(..) => "mask-mode",
                    AnimatedProperty::MaskOrigin(..) => "mask-origin",
                    AnimatedProperty::MaskPositionX(..) => "mask-position-x",
                    AnimatedProperty::MaskPositionY(..) => "mask-position-y",
                    AnimatedProperty::MaskRepeat(..) => "mask-repeat",
                    AnimatedProperty::MaskSize(..) => "mask-size",
                    AnimatedProperty::MozTabSize(..) => "-moz-tab-size",
                    AnimatedProperty::OutlineOffset(..) => "outline-offset",
                    AnimatedProperty::OverflowY(..) => "overflow-y",
                    AnimatedProperty::Perspective(..) => "perspective",
                    AnimatedProperty::PerspectiveOrigin(..) => "perspective-origin",
                    AnimatedProperty::Quotes(..) => "quotes",
                    AnimatedProperty::Rotate(..) => "rotate",
                    AnimatedProperty::Scale(..) => "scale",
                    AnimatedProperty::ScrollSnapCoordinate(..) => "scroll-snap-coordinate",
                    AnimatedProperty::ShapeOutside(..) => "shape-outside",
                    AnimatedProperty::StrokeDasharray(..) => "stroke-dasharray",
                    AnimatedProperty::StrokeDashoffset(..) => "stroke-dashoffset",
                    AnimatedProperty::StrokeMiterlimit(..) => "stroke-miterlimit",
                    AnimatedProperty::StrokeWidth(..) => "stroke-width",
                    AnimatedProperty::TextAlign(..) => "text-align",
                    AnimatedProperty::TextEmphasisPosition(..) => "text-emphasis-position",
                    AnimatedProperty::TextEmphasisStyle(..) => "text-emphasis-style",
                    AnimatedProperty::TextIndent(..) => "text-indent",
                    AnimatedProperty::TextOverflow(..) => "text-overflow",
                    AnimatedProperty::TextShadow(..) => "text-shadow",
                    AnimatedProperty::Translate(..) => "translate",
                    AnimatedProperty::VerticalAlign(..) => "vertical-align",
                    AnimatedProperty::WillChange(..) => "will-change",
                    AnimatedProperty::WordSpacing(..) => "word-spacing",
                    AnimatedProperty::OverflowClipBoxBlock(..) => "overflow-clip-box-block",
                    AnimatedProperty::OverflowClipBoxInline(..) => "overflow-clip-box-inline",
                    AnimatedProperty::FillOpacity(..) => "fill-opacity",
                    AnimatedProperty::StrokeOpacity(..) => "stroke-opacity",
                    AnimatedProperty::ScrollSnapPointsX(..) => "scroll-snap-points-x",
                    AnimatedProperty::ScrollSnapPointsY(..) => "scroll-snap-points-y",
                    AnimatedProperty::MozWindowTransform(..) => "-moz-window-transform",
                    AnimatedProperty::Transform(..) => "transform",
                    AnimatedProperty::Clip(..) => "clip",
                    AnimatedProperty::MozImageRegion(..) => "-moz-image-region",
                    AnimatedProperty::GridTemplateColumns(..) => "grid-template-columns",
                    AnimatedProperty::GridTemplateRows(..) => "grid-template-rows",
                    AnimatedProperty::ObjectPosition(..) => "object-position",
                    AnimatedProperty::ScrollSnapDestination(..) => "scroll-snap-destination",
                    AnimatedProperty::Fill(..) => "fill",
                    AnimatedProperty::Stroke(..) => "stroke",
                    AnimatedProperty::GridAutoColumns(..) => "grid-auto-columns",
                    AnimatedProperty::GridAutoRows(..) => "grid-auto-rows",
                    AnimatedProperty::MozWindowTransformOrigin(..) => "-moz-window-transform-origin",
                    AnimatedProperty::TransformOrigin(..) => "transform-origin",
                    AnimatedProperty::MaxHeight(..) => "max-height",
                    AnimatedProperty::MaxWidth(..) => "max-width",
                    AnimatedProperty::FloodColor(..) => "flood-color",
                    AnimatedProperty::LightingColor(..) => "lighting-color",
                    AnimatedProperty::MozFontSmoothingBackgroundColor(..) => "-moz-font-smoothing-background-color",
                    AnimatedProperty::StopColor(..) => "stop-color",
                    AnimatedProperty::MarkerEnd(..) => "marker-end",
                    AnimatedProperty::MarkerMid(..) => "marker-mid",
                    AnimatedProperty::MarkerStart(..) => "marker-start",
                    AnimatedProperty::GridColumnEnd(..) => "grid-column-end",
                    AnimatedProperty::GridColumnStart(..) => "grid-column-start",
                    AnimatedProperty::GridRowEnd(..) => "grid-row-end",
                    AnimatedProperty::GridRowStart(..) => "grid-row-start",
                    AnimatedProperty::BorderBottomLeftRadius(..) => "border-bottom-left-radius",
                    AnimatedProperty::BorderBottomRightRadius(..) => "border-bottom-right-radius",
                    AnimatedProperty::BorderTopLeftRadius(..) => "border-top-left-radius",
                    AnimatedProperty::BorderTopRightRadius(..) => "border-top-right-radius",
                    AnimatedProperty::MozOutlineRadiusBottomleft(..) => "-moz-outline-radius-bottomleft",
                    AnimatedProperty::MozOutlineRadiusBottomright(..) => "-moz-outline-radius-bottomright",
                    AnimatedProperty::MozOutlineRadiusTopleft(..) => "-moz-outline-radius-topleft",
                    AnimatedProperty::MozOutlineRadiusTopright(..) => "-moz-outline-radius-topright",
                    AnimatedProperty::FlexBasis(..) => "flex-basis",
                    AnimatedProperty::Height(..) => "height",
                    AnimatedProperty::MinHeight(..) => "min-height",
                    AnimatedProperty::MinWidth(..) => "min-width",
                    AnimatedProperty::Width(..) => "width",
                    AnimatedProperty::GridColumnGap(..) => "grid-column-gap",
                    AnimatedProperty::GridRowGap(..) => "grid-row-gap",
                    AnimatedProperty::PaddingBottom(..) => "padding-bottom",
                    AnimatedProperty::PaddingLeft(..) => "padding-left",
                    AnimatedProperty::PaddingRight(..) => "padding-right",
                    AnimatedProperty::PaddingTop(..) => "padding-top",
                    AnimatedProperty::BorderBottomWidth(..) => "border-bottom-width",
                    AnimatedProperty::BorderLeftWidth(..) => "border-left-width",
                    AnimatedProperty::BorderRightWidth(..) => "border-right-width",
                    AnimatedProperty::BorderTopWidth(..) => "border-top-width",
                    AnimatedProperty::ColumnRuleWidth(..) => "column-rule-width",
                    AnimatedProperty::OutlineWidth(..) => "outline-width",
                    AnimatedProperty::WebkitTextStrokeWidth(..) => "-webkit-text-stroke-width",
                    AnimatedProperty::BackgroundColor(..) => "background-color",
                    AnimatedProperty::BorderBottomColor(..) => "border-bottom-color",
                    AnimatedProperty::BorderLeftColor(..) => "border-left-color",
                    AnimatedProperty::BorderRightColor(..) => "border-right-color",
                    AnimatedProperty::BorderTopColor(..) => "border-top-color",
                    AnimatedProperty::ColumnRuleColor(..) => "column-rule-color",
                    AnimatedProperty::OutlineColor(..) => "outline-color",
                    AnimatedProperty::TextDecorationColor(..) => "text-decoration-color",
                    AnimatedProperty::TextEmphasisColor(..) => "text-emphasis-color",
                    AnimatedProperty::WebkitTextFillColor(..) => "-webkit-text-fill-color",
                    AnimatedProperty::WebkitTextStrokeColor(..) => "-webkit-text-stroke-color",
                    AnimatedProperty::Bottom(..) => "bottom",
                    AnimatedProperty::Left(..) => "left",
                    AnimatedProperty::MarginBottom(..) => "margin-bottom",
                    AnimatedProperty::MarginLeft(..) => "margin-left",
                    AnimatedProperty::MarginRight(..) => "margin-right",
                    AnimatedProperty::MarginTop(..) => "margin-top",
                    AnimatedProperty::Right(..) => "right",
                    AnimatedProperty::Top(..) => "top",
        }
    }

    /// Whether this interpolation does animate, that is, whether the start and
    /// end values are different.
    pub fn does_animate(&self) -> bool {
        match *self {
                    AnimatedProperty::AlignContent(ref from, ref to) => from != to,
                    AnimatedProperty::AlignItems(ref from, ref to) => from != to,
                    AnimatedProperty::AlignSelf(ref from, ref to) => from != to,
                    AnimatedProperty::BackfaceVisibility(ref from, ref to) => from != to,
                    AnimatedProperty::BorderCollapse(ref from, ref to) => from != to,
                    AnimatedProperty::BorderImageRepeat(ref from, ref to) => from != to,
                    AnimatedProperty::BoxDecorationBreak(ref from, ref to) => from != to,
                    AnimatedProperty::BoxSizing(ref from, ref to) => from != to,
                    AnimatedProperty::CaptionSide(ref from, ref to) => from != to,
                    AnimatedProperty::Clear(ref from, ref to) => from != to,
                    AnimatedProperty::ClipRule(ref from, ref to) => from != to,
                    AnimatedProperty::ColorAdjust(ref from, ref to) => from != to,
                    AnimatedProperty::ColorInterpolation(ref from, ref to) => from != to,
                    AnimatedProperty::ColorInterpolationFilters(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnCount(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnFill(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnRuleStyle(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnSpan(ref from, ref to) => from != to,
                    AnimatedProperty::Contain(ref from, ref to) => from != to,
                    AnimatedProperty::Direction(ref from, ref to) => from != to,
                    AnimatedProperty::DominantBaseline(ref from, ref to) => from != to,
                    AnimatedProperty::EmptyCells(ref from, ref to) => from != to,
                    AnimatedProperty::FillRule(ref from, ref to) => from != to,
                    AnimatedProperty::FlexDirection(ref from, ref to) => from != to,
                    AnimatedProperty::FlexWrap(ref from, ref to) => from != to,
                    AnimatedProperty::Float(ref from, ref to) => from != to,
                    AnimatedProperty::FontKerning(ref from, ref to) => from != to,
                    AnimatedProperty::FontOpticalSizing(ref from, ref to) => from != to,
                    AnimatedProperty::FontStretch(ref from, ref to) => from != to,
                    AnimatedProperty::FontStyle(ref from, ref to) => from != to,
                    AnimatedProperty::FontSynthesis(ref from, ref to) => from != to,
                    AnimatedProperty::FontVariantCaps(ref from, ref to) => from != to,
                    AnimatedProperty::FontVariantPosition(ref from, ref to) => from != to,
                    AnimatedProperty::FontWeight(ref from, ref to) => from != to,
                    AnimatedProperty::GridAutoFlow(ref from, ref to) => from != to,
                    AnimatedProperty::Hyphens(ref from, ref to) => from != to,
                    AnimatedProperty::ImageOrientation(ref from, ref to) => from != to,
                    AnimatedProperty::ImageRendering(ref from, ref to) => from != to,
                    AnimatedProperty::ImeMode(ref from, ref to) => from != to,
                    AnimatedProperty::InitialLetter(ref from, ref to) => from != to,
                    AnimatedProperty::Isolation(ref from, ref to) => from != to,
                    AnimatedProperty::JustifyContent(ref from, ref to) => from != to,
                    AnimatedProperty::JustifyItems(ref from, ref to) => from != to,
                    AnimatedProperty::JustifySelf(ref from, ref to) => from != to,
                    AnimatedProperty::ListStylePosition(ref from, ref to) => from != to,
                    AnimatedProperty::MaskType(ref from, ref to) => from != to,
                    AnimatedProperty::MixBlendMode(ref from, ref to) => from != to,
                    AnimatedProperty::MozAppearance(ref from, ref to) => from != to,
                    AnimatedProperty::MozBoxAlign(ref from, ref to) => from != to,
                    AnimatedProperty::MozBoxDirection(ref from, ref to) => from != to,
                    AnimatedProperty::MozBoxOrient(ref from, ref to) => from != to,
                    AnimatedProperty::MozBoxPack(ref from, ref to) => from != to,
                    AnimatedProperty::MozFloatEdge(ref from, ref to) => from != to,
                    AnimatedProperty::MozForceBrokenImageIcon(ref from, ref to) => from != to,
                    AnimatedProperty::MozOrient(ref from, ref to) => from != to,
                    AnimatedProperty::MozOsxFontSmoothing(ref from, ref to) => from != to,
                    AnimatedProperty::MozStackSizing(ref from, ref to) => from != to,
                    AnimatedProperty::MozTextSizeAdjust(ref from, ref to) => from != to,
                    AnimatedProperty::MozUserFocus(ref from, ref to) => from != to,
                    AnimatedProperty::MozUserInput(ref from, ref to) => from != to,
                    AnimatedProperty::MozUserModify(ref from, ref to) => from != to,
                    AnimatedProperty::MozUserSelect(ref from, ref to) => from != to,
                    AnimatedProperty::MozWindowDragging(ref from, ref to) => from != to,
                    AnimatedProperty::MozWindowShadow(ref from, ref to) => from != to,
                    AnimatedProperty::ObjectFit(ref from, ref to) => from != to,
                    AnimatedProperty::OutlineStyle(ref from, ref to) => from != to,
                    AnimatedProperty::OverflowWrap(ref from, ref to) => from != to,
                    AnimatedProperty::OverflowX(ref from, ref to) => from != to,
                    AnimatedProperty::PageBreakAfter(ref from, ref to) => from != to,
                    AnimatedProperty::PageBreakBefore(ref from, ref to) => from != to,
                    AnimatedProperty::PageBreakInside(ref from, ref to) => from != to,
                    AnimatedProperty::PaintOrder(ref from, ref to) => from != to,
                    AnimatedProperty::PointerEvents(ref from, ref to) => from != to,
                    AnimatedProperty::Position(ref from, ref to) => from != to,
                    AnimatedProperty::Resize(ref from, ref to) => from != to,
                    AnimatedProperty::RubyAlign(ref from, ref to) => from != to,
                    AnimatedProperty::RubyPosition(ref from, ref to) => from != to,
                    AnimatedProperty::ScrollBehavior(ref from, ref to) => from != to,
                    AnimatedProperty::ShapeRendering(ref from, ref to) => from != to,
                    AnimatedProperty::StrokeLinecap(ref from, ref to) => from != to,
                    AnimatedProperty::StrokeLinejoin(ref from, ref to) => from != to,
                    AnimatedProperty::TableLayout(ref from, ref to) => from != to,
                    AnimatedProperty::TextAlignLast(ref from, ref to) => from != to,
                    AnimatedProperty::TextAnchor(ref from, ref to) => from != to,
                    AnimatedProperty::TextCombineUpright(ref from, ref to) => from != to,
                    AnimatedProperty::TextDecorationLine(ref from, ref to) => from != to,
                    AnimatedProperty::TextDecorationStyle(ref from, ref to) => from != to,
                    AnimatedProperty::TextJustify(ref from, ref to) => from != to,
                    AnimatedProperty::TextOrientation(ref from, ref to) => from != to,
                    AnimatedProperty::TextRendering(ref from, ref to) => from != to,
                    AnimatedProperty::TextTransform(ref from, ref to) => from != to,
                    AnimatedProperty::TouchAction(ref from, ref to) => from != to,
                    AnimatedProperty::TransformBox(ref from, ref to) => from != to,
                    AnimatedProperty::TransformStyle(ref from, ref to) => from != to,
                    AnimatedProperty::UnicodeBidi(ref from, ref to) => from != to,
                    AnimatedProperty::VectorEffect(ref from, ref to) => from != to,
                    AnimatedProperty::Visibility(ref from, ref to) => from != to,
                    AnimatedProperty::WhiteSpace(ref from, ref to) => from != to,
                    AnimatedProperty::WordBreak(ref from, ref to) => from != to,
                    AnimatedProperty::WritingMode(ref from, ref to) => from != to,
                    AnimatedProperty::ZIndex(ref from, ref to) => from != to,
                    AnimatedProperty::MozBoxOrdinalGroup(ref from, ref to) => from != to,
                    AnimatedProperty::Order(ref from, ref to) => from != to,
                    AnimatedProperty::OverscrollBehaviorX(ref from, ref to) => from != to,
                    AnimatedProperty::OverscrollBehaviorY(ref from, ref to) => from != to,
                    AnimatedProperty::ScrollSnapTypeX(ref from, ref to) => from != to,
                    AnimatedProperty::ScrollSnapTypeY(ref from, ref to) => from != to,
                    AnimatedProperty::FlexGrow(ref from, ref to) => from != to,
                    AnimatedProperty::FlexShrink(ref from, ref to) => from != to,
                    AnimatedProperty::MozBoxFlex(ref from, ref to) => from != to,
                    AnimatedProperty::FloodOpacity(ref from, ref to) => from != to,
                    AnimatedProperty::MozWindowOpacity(ref from, ref to) => from != to,
                    AnimatedProperty::Opacity(ref from, ref to) => from != to,
                    AnimatedProperty::ShapeImageThreshold(ref from, ref to) => from != to,
                    AnimatedProperty::StopOpacity(ref from, ref to) => from != to,
                    AnimatedProperty::BorderBottomStyle(ref from, ref to) => from != to,
                    AnimatedProperty::BorderLeftStyle(ref from, ref to) => from != to,
                    AnimatedProperty::BorderRightStyle(ref from, ref to) => from != to,
                    AnimatedProperty::BorderTopStyle(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundAttachment(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundBlendMode(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundClip(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundImage(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundOrigin(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundPositionX(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundPositionY(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundRepeat(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundSize(ref from, ref to) => from != to,
                    AnimatedProperty::BorderImageOutset(ref from, ref to) => from != to,
                    AnimatedProperty::BorderImageSlice(ref from, ref to) => from != to,
                    AnimatedProperty::BorderImageSource(ref from, ref to) => from != to,
                    AnimatedProperty::BorderImageWidth(ref from, ref to) => from != to,
                    AnimatedProperty::BorderSpacing(ref from, ref to) => from != to,
                    AnimatedProperty::BoxShadow(ref from, ref to) => from != to,
                    AnimatedProperty::CaretColor(ref from, ref to) => from != to,
                    AnimatedProperty::ClipPath(ref from, ref to) => from != to,
                    AnimatedProperty::Color(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnGap(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnWidth(ref from, ref to) => from != to,
                    AnimatedProperty::Content(ref from, ref to) => from != to,
                    AnimatedProperty::CounterIncrement(ref from, ref to) => from != to,
                    AnimatedProperty::CounterReset(ref from, ref to) => from != to,
                    AnimatedProperty::Cursor(ref from, ref to) => from != to,
                    AnimatedProperty::Display(ref from, ref to) => from != to,
                    AnimatedProperty::Filter(ref from, ref to) => from != to,
                    AnimatedProperty::FontFamily(ref from, ref to) => from != to,
                    AnimatedProperty::FontFeatureSettings(ref from, ref to) => from != to,
                    AnimatedProperty::FontLanguageOverride(ref from, ref to) => from != to,
                    AnimatedProperty::FontSize(ref from, ref to) => from != to,
                    AnimatedProperty::FontSizeAdjust(ref from, ref to) => from != to,
                    AnimatedProperty::FontVariantAlternates(ref from, ref to) => from != to,
                    AnimatedProperty::FontVariantEastAsian(ref from, ref to) => from != to,
                    AnimatedProperty::FontVariantLigatures(ref from, ref to) => from != to,
                    AnimatedProperty::FontVariantNumeric(ref from, ref to) => from != to,
                    AnimatedProperty::FontVariationSettings(ref from, ref to) => from != to,
                    AnimatedProperty::GridTemplateAreas(ref from, ref to) => from != to,
                    AnimatedProperty::LetterSpacing(ref from, ref to) => from != to,
                    AnimatedProperty::LineHeight(ref from, ref to) => from != to,
                    AnimatedProperty::ListStyleImage(ref from, ref to) => from != to,
                    AnimatedProperty::ListStyleType(ref from, ref to) => from != to,
                    AnimatedProperty::MaskClip(ref from, ref to) => from != to,
                    AnimatedProperty::MaskComposite(ref from, ref to) => from != to,
                    AnimatedProperty::MaskImage(ref from, ref to) => from != to,
                    AnimatedProperty::MaskMode(ref from, ref to) => from != to,
                    AnimatedProperty::MaskOrigin(ref from, ref to) => from != to,
                    AnimatedProperty::MaskPositionX(ref from, ref to) => from != to,
                    AnimatedProperty::MaskPositionY(ref from, ref to) => from != to,
                    AnimatedProperty::MaskRepeat(ref from, ref to) => from != to,
                    AnimatedProperty::MaskSize(ref from, ref to) => from != to,
                    AnimatedProperty::MozTabSize(ref from, ref to) => from != to,
                    AnimatedProperty::OutlineOffset(ref from, ref to) => from != to,
                    AnimatedProperty::OverflowY(ref from, ref to) => from != to,
                    AnimatedProperty::Perspective(ref from, ref to) => from != to,
                    AnimatedProperty::PerspectiveOrigin(ref from, ref to) => from != to,
                    AnimatedProperty::Quotes(ref from, ref to) => from != to,
                    AnimatedProperty::Rotate(ref from, ref to) => from != to,
                    AnimatedProperty::Scale(ref from, ref to) => from != to,
                    AnimatedProperty::ScrollSnapCoordinate(ref from, ref to) => from != to,
                    AnimatedProperty::ShapeOutside(ref from, ref to) => from != to,
                    AnimatedProperty::StrokeDasharray(ref from, ref to) => from != to,
                    AnimatedProperty::StrokeDashoffset(ref from, ref to) => from != to,
                    AnimatedProperty::StrokeMiterlimit(ref from, ref to) => from != to,
                    AnimatedProperty::StrokeWidth(ref from, ref to) => from != to,
                    AnimatedProperty::TextAlign(ref from, ref to) => from != to,
                    AnimatedProperty::TextEmphasisPosition(ref from, ref to) => from != to,
                    AnimatedProperty::TextEmphasisStyle(ref from, ref to) => from != to,
                    AnimatedProperty::TextIndent(ref from, ref to) => from != to,
                    AnimatedProperty::TextOverflow(ref from, ref to) => from != to,
                    AnimatedProperty::TextShadow(ref from, ref to) => from != to,
                    AnimatedProperty::Translate(ref from, ref to) => from != to,
                    AnimatedProperty::VerticalAlign(ref from, ref to) => from != to,
                    AnimatedProperty::WillChange(ref from, ref to) => from != to,
                    AnimatedProperty::WordSpacing(ref from, ref to) => from != to,
                    AnimatedProperty::OverflowClipBoxBlock(ref from, ref to) => from != to,
                    AnimatedProperty::OverflowClipBoxInline(ref from, ref to) => from != to,
                    AnimatedProperty::FillOpacity(ref from, ref to) => from != to,
                    AnimatedProperty::StrokeOpacity(ref from, ref to) => from != to,
                    AnimatedProperty::ScrollSnapPointsX(ref from, ref to) => from != to,
                    AnimatedProperty::ScrollSnapPointsY(ref from, ref to) => from != to,
                    AnimatedProperty::MozWindowTransform(ref from, ref to) => from != to,
                    AnimatedProperty::Transform(ref from, ref to) => from != to,
                    AnimatedProperty::Clip(ref from, ref to) => from != to,
                    AnimatedProperty::MozImageRegion(ref from, ref to) => from != to,
                    AnimatedProperty::GridTemplateColumns(ref from, ref to) => from != to,
                    AnimatedProperty::GridTemplateRows(ref from, ref to) => from != to,
                    AnimatedProperty::ObjectPosition(ref from, ref to) => from != to,
                    AnimatedProperty::ScrollSnapDestination(ref from, ref to) => from != to,
                    AnimatedProperty::Fill(ref from, ref to) => from != to,
                    AnimatedProperty::Stroke(ref from, ref to) => from != to,
                    AnimatedProperty::GridAutoColumns(ref from, ref to) => from != to,
                    AnimatedProperty::GridAutoRows(ref from, ref to) => from != to,
                    AnimatedProperty::MozWindowTransformOrigin(ref from, ref to) => from != to,
                    AnimatedProperty::TransformOrigin(ref from, ref to) => from != to,
                    AnimatedProperty::MaxHeight(ref from, ref to) => from != to,
                    AnimatedProperty::MaxWidth(ref from, ref to) => from != to,
                    AnimatedProperty::FloodColor(ref from, ref to) => from != to,
                    AnimatedProperty::LightingColor(ref from, ref to) => from != to,
                    AnimatedProperty::MozFontSmoothingBackgroundColor(ref from, ref to) => from != to,
                    AnimatedProperty::StopColor(ref from, ref to) => from != to,
                    AnimatedProperty::MarkerEnd(ref from, ref to) => from != to,
                    AnimatedProperty::MarkerMid(ref from, ref to) => from != to,
                    AnimatedProperty::MarkerStart(ref from, ref to) => from != to,
                    AnimatedProperty::GridColumnEnd(ref from, ref to) => from != to,
                    AnimatedProperty::GridColumnStart(ref from, ref to) => from != to,
                    AnimatedProperty::GridRowEnd(ref from, ref to) => from != to,
                    AnimatedProperty::GridRowStart(ref from, ref to) => from != to,
                    AnimatedProperty::BorderBottomLeftRadius(ref from, ref to) => from != to,
                    AnimatedProperty::BorderBottomRightRadius(ref from, ref to) => from != to,
                    AnimatedProperty::BorderTopLeftRadius(ref from, ref to) => from != to,
                    AnimatedProperty::BorderTopRightRadius(ref from, ref to) => from != to,
                    AnimatedProperty::MozOutlineRadiusBottomleft(ref from, ref to) => from != to,
                    AnimatedProperty::MozOutlineRadiusBottomright(ref from, ref to) => from != to,
                    AnimatedProperty::MozOutlineRadiusTopleft(ref from, ref to) => from != to,
                    AnimatedProperty::MozOutlineRadiusTopright(ref from, ref to) => from != to,
                    AnimatedProperty::FlexBasis(ref from, ref to) => from != to,
                    AnimatedProperty::Height(ref from, ref to) => from != to,
                    AnimatedProperty::MinHeight(ref from, ref to) => from != to,
                    AnimatedProperty::MinWidth(ref from, ref to) => from != to,
                    AnimatedProperty::Width(ref from, ref to) => from != to,
                    AnimatedProperty::GridColumnGap(ref from, ref to) => from != to,
                    AnimatedProperty::GridRowGap(ref from, ref to) => from != to,
                    AnimatedProperty::PaddingBottom(ref from, ref to) => from != to,
                    AnimatedProperty::PaddingLeft(ref from, ref to) => from != to,
                    AnimatedProperty::PaddingRight(ref from, ref to) => from != to,
                    AnimatedProperty::PaddingTop(ref from, ref to) => from != to,
                    AnimatedProperty::BorderBottomWidth(ref from, ref to) => from != to,
                    AnimatedProperty::BorderLeftWidth(ref from, ref to) => from != to,
                    AnimatedProperty::BorderRightWidth(ref from, ref to) => from != to,
                    AnimatedProperty::BorderTopWidth(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnRuleWidth(ref from, ref to) => from != to,
                    AnimatedProperty::OutlineWidth(ref from, ref to) => from != to,
                    AnimatedProperty::WebkitTextStrokeWidth(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundColor(ref from, ref to) => from != to,
                    AnimatedProperty::BorderBottomColor(ref from, ref to) => from != to,
                    AnimatedProperty::BorderLeftColor(ref from, ref to) => from != to,
                    AnimatedProperty::BorderRightColor(ref from, ref to) => from != to,
                    AnimatedProperty::BorderTopColor(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnRuleColor(ref from, ref to) => from != to,
                    AnimatedProperty::OutlineColor(ref from, ref to) => from != to,
                    AnimatedProperty::TextDecorationColor(ref from, ref to) => from != to,
                    AnimatedProperty::TextEmphasisColor(ref from, ref to) => from != to,
                    AnimatedProperty::WebkitTextFillColor(ref from, ref to) => from != to,
                    AnimatedProperty::WebkitTextStrokeColor(ref from, ref to) => from != to,
                    AnimatedProperty::Bottom(ref from, ref to) => from != to,
                    AnimatedProperty::Left(ref from, ref to) => from != to,
                    AnimatedProperty::MarginBottom(ref from, ref to) => from != to,
                    AnimatedProperty::MarginLeft(ref from, ref to) => from != to,
                    AnimatedProperty::MarginRight(ref from, ref to) => from != to,
                    AnimatedProperty::MarginTop(ref from, ref to) => from != to,
                    AnimatedProperty::Right(ref from, ref to) => from != to,
                    AnimatedProperty::Top(ref from, ref to) => from != to,
        }
    }

    /// Whether an animated property has the same end value as another.
    pub fn has_the_same_end_value_as(&self, other: &Self) -> bool {
        match (self, other) {
                    (&AnimatedProperty::AlignContent(_, ref this_end_value),
                     &AnimatedProperty::AlignContent(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::AlignItems(_, ref this_end_value),
                     &AnimatedProperty::AlignItems(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::AlignSelf(_, ref this_end_value),
                     &AnimatedProperty::AlignSelf(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackfaceVisibility(_, ref this_end_value),
                     &AnimatedProperty::BackfaceVisibility(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderCollapse(_, ref this_end_value),
                     &AnimatedProperty::BorderCollapse(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderImageRepeat(_, ref this_end_value),
                     &AnimatedProperty::BorderImageRepeat(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BoxDecorationBreak(_, ref this_end_value),
                     &AnimatedProperty::BoxDecorationBreak(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BoxSizing(_, ref this_end_value),
                     &AnimatedProperty::BoxSizing(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::CaptionSide(_, ref this_end_value),
                     &AnimatedProperty::CaptionSide(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Clear(_, ref this_end_value),
                     &AnimatedProperty::Clear(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ClipRule(_, ref this_end_value),
                     &AnimatedProperty::ClipRule(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColorAdjust(_, ref this_end_value),
                     &AnimatedProperty::ColorAdjust(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColorInterpolation(_, ref this_end_value),
                     &AnimatedProperty::ColorInterpolation(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColorInterpolationFilters(_, ref this_end_value),
                     &AnimatedProperty::ColorInterpolationFilters(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnCount(_, ref this_end_value),
                     &AnimatedProperty::ColumnCount(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnFill(_, ref this_end_value),
                     &AnimatedProperty::ColumnFill(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnRuleStyle(_, ref this_end_value),
                     &AnimatedProperty::ColumnRuleStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnSpan(_, ref this_end_value),
                     &AnimatedProperty::ColumnSpan(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Contain(_, ref this_end_value),
                     &AnimatedProperty::Contain(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Direction(_, ref this_end_value),
                     &AnimatedProperty::Direction(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::DominantBaseline(_, ref this_end_value),
                     &AnimatedProperty::DominantBaseline(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::EmptyCells(_, ref this_end_value),
                     &AnimatedProperty::EmptyCells(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FillRule(_, ref this_end_value),
                     &AnimatedProperty::FillRule(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FlexDirection(_, ref this_end_value),
                     &AnimatedProperty::FlexDirection(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FlexWrap(_, ref this_end_value),
                     &AnimatedProperty::FlexWrap(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Float(_, ref this_end_value),
                     &AnimatedProperty::Float(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontKerning(_, ref this_end_value),
                     &AnimatedProperty::FontKerning(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontOpticalSizing(_, ref this_end_value),
                     &AnimatedProperty::FontOpticalSizing(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontStretch(_, ref this_end_value),
                     &AnimatedProperty::FontStretch(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontStyle(_, ref this_end_value),
                     &AnimatedProperty::FontStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontSynthesis(_, ref this_end_value),
                     &AnimatedProperty::FontSynthesis(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontVariantCaps(_, ref this_end_value),
                     &AnimatedProperty::FontVariantCaps(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontVariantPosition(_, ref this_end_value),
                     &AnimatedProperty::FontVariantPosition(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontWeight(_, ref this_end_value),
                     &AnimatedProperty::FontWeight(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridAutoFlow(_, ref this_end_value),
                     &AnimatedProperty::GridAutoFlow(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Hyphens(_, ref this_end_value),
                     &AnimatedProperty::Hyphens(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ImageOrientation(_, ref this_end_value),
                     &AnimatedProperty::ImageOrientation(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ImageRendering(_, ref this_end_value),
                     &AnimatedProperty::ImageRendering(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ImeMode(_, ref this_end_value),
                     &AnimatedProperty::ImeMode(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::InitialLetter(_, ref this_end_value),
                     &AnimatedProperty::InitialLetter(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Isolation(_, ref this_end_value),
                     &AnimatedProperty::Isolation(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::JustifyContent(_, ref this_end_value),
                     &AnimatedProperty::JustifyContent(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::JustifyItems(_, ref this_end_value),
                     &AnimatedProperty::JustifyItems(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::JustifySelf(_, ref this_end_value),
                     &AnimatedProperty::JustifySelf(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ListStylePosition(_, ref this_end_value),
                     &AnimatedProperty::ListStylePosition(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskType(_, ref this_end_value),
                     &AnimatedProperty::MaskType(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MixBlendMode(_, ref this_end_value),
                     &AnimatedProperty::MixBlendMode(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozAppearance(_, ref this_end_value),
                     &AnimatedProperty::MozAppearance(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBoxAlign(_, ref this_end_value),
                     &AnimatedProperty::MozBoxAlign(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBoxDirection(_, ref this_end_value),
                     &AnimatedProperty::MozBoxDirection(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBoxOrient(_, ref this_end_value),
                     &AnimatedProperty::MozBoxOrient(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBoxPack(_, ref this_end_value),
                     &AnimatedProperty::MozBoxPack(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozFloatEdge(_, ref this_end_value),
                     &AnimatedProperty::MozFloatEdge(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozForceBrokenImageIcon(_, ref this_end_value),
                     &AnimatedProperty::MozForceBrokenImageIcon(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozOrient(_, ref this_end_value),
                     &AnimatedProperty::MozOrient(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozOsxFontSmoothing(_, ref this_end_value),
                     &AnimatedProperty::MozOsxFontSmoothing(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozStackSizing(_, ref this_end_value),
                     &AnimatedProperty::MozStackSizing(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozTextSizeAdjust(_, ref this_end_value),
                     &AnimatedProperty::MozTextSizeAdjust(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozUserFocus(_, ref this_end_value),
                     &AnimatedProperty::MozUserFocus(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozUserInput(_, ref this_end_value),
                     &AnimatedProperty::MozUserInput(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozUserModify(_, ref this_end_value),
                     &AnimatedProperty::MozUserModify(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozUserSelect(_, ref this_end_value),
                     &AnimatedProperty::MozUserSelect(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozWindowDragging(_, ref this_end_value),
                     &AnimatedProperty::MozWindowDragging(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozWindowShadow(_, ref this_end_value),
                     &AnimatedProperty::MozWindowShadow(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ObjectFit(_, ref this_end_value),
                     &AnimatedProperty::ObjectFit(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OutlineStyle(_, ref this_end_value),
                     &AnimatedProperty::OutlineStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OverflowWrap(_, ref this_end_value),
                     &AnimatedProperty::OverflowWrap(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OverflowX(_, ref this_end_value),
                     &AnimatedProperty::OverflowX(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PageBreakAfter(_, ref this_end_value),
                     &AnimatedProperty::PageBreakAfter(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PageBreakBefore(_, ref this_end_value),
                     &AnimatedProperty::PageBreakBefore(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PageBreakInside(_, ref this_end_value),
                     &AnimatedProperty::PageBreakInside(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PaintOrder(_, ref this_end_value),
                     &AnimatedProperty::PaintOrder(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PointerEvents(_, ref this_end_value),
                     &AnimatedProperty::PointerEvents(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Position(_, ref this_end_value),
                     &AnimatedProperty::Position(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Resize(_, ref this_end_value),
                     &AnimatedProperty::Resize(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::RubyAlign(_, ref this_end_value),
                     &AnimatedProperty::RubyAlign(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::RubyPosition(_, ref this_end_value),
                     &AnimatedProperty::RubyPosition(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ScrollBehavior(_, ref this_end_value),
                     &AnimatedProperty::ScrollBehavior(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ShapeRendering(_, ref this_end_value),
                     &AnimatedProperty::ShapeRendering(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StrokeLinecap(_, ref this_end_value),
                     &AnimatedProperty::StrokeLinecap(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StrokeLinejoin(_, ref this_end_value),
                     &AnimatedProperty::StrokeLinejoin(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TableLayout(_, ref this_end_value),
                     &AnimatedProperty::TableLayout(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextAlignLast(_, ref this_end_value),
                     &AnimatedProperty::TextAlignLast(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextAnchor(_, ref this_end_value),
                     &AnimatedProperty::TextAnchor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextCombineUpright(_, ref this_end_value),
                     &AnimatedProperty::TextCombineUpright(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextDecorationLine(_, ref this_end_value),
                     &AnimatedProperty::TextDecorationLine(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextDecorationStyle(_, ref this_end_value),
                     &AnimatedProperty::TextDecorationStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextJustify(_, ref this_end_value),
                     &AnimatedProperty::TextJustify(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextOrientation(_, ref this_end_value),
                     &AnimatedProperty::TextOrientation(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextRendering(_, ref this_end_value),
                     &AnimatedProperty::TextRendering(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextTransform(_, ref this_end_value),
                     &AnimatedProperty::TextTransform(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TouchAction(_, ref this_end_value),
                     &AnimatedProperty::TouchAction(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TransformBox(_, ref this_end_value),
                     &AnimatedProperty::TransformBox(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TransformStyle(_, ref this_end_value),
                     &AnimatedProperty::TransformStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::UnicodeBidi(_, ref this_end_value),
                     &AnimatedProperty::UnicodeBidi(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::VectorEffect(_, ref this_end_value),
                     &AnimatedProperty::VectorEffect(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Visibility(_, ref this_end_value),
                     &AnimatedProperty::Visibility(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WhiteSpace(_, ref this_end_value),
                     &AnimatedProperty::WhiteSpace(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WordBreak(_, ref this_end_value),
                     &AnimatedProperty::WordBreak(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WritingMode(_, ref this_end_value),
                     &AnimatedProperty::WritingMode(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ZIndex(_, ref this_end_value),
                     &AnimatedProperty::ZIndex(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBoxOrdinalGroup(_, ref this_end_value),
                     &AnimatedProperty::MozBoxOrdinalGroup(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Order(_, ref this_end_value),
                     &AnimatedProperty::Order(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OverscrollBehaviorX(_, ref this_end_value),
                     &AnimatedProperty::OverscrollBehaviorX(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OverscrollBehaviorY(_, ref this_end_value),
                     &AnimatedProperty::OverscrollBehaviorY(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ScrollSnapTypeX(_, ref this_end_value),
                     &AnimatedProperty::ScrollSnapTypeX(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ScrollSnapTypeY(_, ref this_end_value),
                     &AnimatedProperty::ScrollSnapTypeY(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FlexGrow(_, ref this_end_value),
                     &AnimatedProperty::FlexGrow(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FlexShrink(_, ref this_end_value),
                     &AnimatedProperty::FlexShrink(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBoxFlex(_, ref this_end_value),
                     &AnimatedProperty::MozBoxFlex(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FloodOpacity(_, ref this_end_value),
                     &AnimatedProperty::FloodOpacity(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozWindowOpacity(_, ref this_end_value),
                     &AnimatedProperty::MozWindowOpacity(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Opacity(_, ref this_end_value),
                     &AnimatedProperty::Opacity(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ShapeImageThreshold(_, ref this_end_value),
                     &AnimatedProperty::ShapeImageThreshold(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StopOpacity(_, ref this_end_value),
                     &AnimatedProperty::StopOpacity(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderBottomStyle(_, ref this_end_value),
                     &AnimatedProperty::BorderBottomStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderLeftStyle(_, ref this_end_value),
                     &AnimatedProperty::BorderLeftStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderRightStyle(_, ref this_end_value),
                     &AnimatedProperty::BorderRightStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderTopStyle(_, ref this_end_value),
                     &AnimatedProperty::BorderTopStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundAttachment(_, ref this_end_value),
                     &AnimatedProperty::BackgroundAttachment(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundBlendMode(_, ref this_end_value),
                     &AnimatedProperty::BackgroundBlendMode(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundClip(_, ref this_end_value),
                     &AnimatedProperty::BackgroundClip(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundImage(_, ref this_end_value),
                     &AnimatedProperty::BackgroundImage(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundOrigin(_, ref this_end_value),
                     &AnimatedProperty::BackgroundOrigin(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundPositionX(_, ref this_end_value),
                     &AnimatedProperty::BackgroundPositionX(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundPositionY(_, ref this_end_value),
                     &AnimatedProperty::BackgroundPositionY(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundRepeat(_, ref this_end_value),
                     &AnimatedProperty::BackgroundRepeat(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundSize(_, ref this_end_value),
                     &AnimatedProperty::BackgroundSize(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderImageOutset(_, ref this_end_value),
                     &AnimatedProperty::BorderImageOutset(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderImageSlice(_, ref this_end_value),
                     &AnimatedProperty::BorderImageSlice(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderImageSource(_, ref this_end_value),
                     &AnimatedProperty::BorderImageSource(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderImageWidth(_, ref this_end_value),
                     &AnimatedProperty::BorderImageWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderSpacing(_, ref this_end_value),
                     &AnimatedProperty::BorderSpacing(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BoxShadow(_, ref this_end_value),
                     &AnimatedProperty::BoxShadow(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::CaretColor(_, ref this_end_value),
                     &AnimatedProperty::CaretColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ClipPath(_, ref this_end_value),
                     &AnimatedProperty::ClipPath(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Color(_, ref this_end_value),
                     &AnimatedProperty::Color(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnGap(_, ref this_end_value),
                     &AnimatedProperty::ColumnGap(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnWidth(_, ref this_end_value),
                     &AnimatedProperty::ColumnWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Content(_, ref this_end_value),
                     &AnimatedProperty::Content(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::CounterIncrement(_, ref this_end_value),
                     &AnimatedProperty::CounterIncrement(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::CounterReset(_, ref this_end_value),
                     &AnimatedProperty::CounterReset(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Cursor(_, ref this_end_value),
                     &AnimatedProperty::Cursor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Display(_, ref this_end_value),
                     &AnimatedProperty::Display(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Filter(_, ref this_end_value),
                     &AnimatedProperty::Filter(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontFamily(_, ref this_end_value),
                     &AnimatedProperty::FontFamily(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontFeatureSettings(_, ref this_end_value),
                     &AnimatedProperty::FontFeatureSettings(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontLanguageOverride(_, ref this_end_value),
                     &AnimatedProperty::FontLanguageOverride(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontSize(_, ref this_end_value),
                     &AnimatedProperty::FontSize(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontSizeAdjust(_, ref this_end_value),
                     &AnimatedProperty::FontSizeAdjust(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontVariantAlternates(_, ref this_end_value),
                     &AnimatedProperty::FontVariantAlternates(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontVariantEastAsian(_, ref this_end_value),
                     &AnimatedProperty::FontVariantEastAsian(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontVariantLigatures(_, ref this_end_value),
                     &AnimatedProperty::FontVariantLigatures(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontVariantNumeric(_, ref this_end_value),
                     &AnimatedProperty::FontVariantNumeric(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontVariationSettings(_, ref this_end_value),
                     &AnimatedProperty::FontVariationSettings(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridTemplateAreas(_, ref this_end_value),
                     &AnimatedProperty::GridTemplateAreas(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::LetterSpacing(_, ref this_end_value),
                     &AnimatedProperty::LetterSpacing(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::LineHeight(_, ref this_end_value),
                     &AnimatedProperty::LineHeight(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ListStyleImage(_, ref this_end_value),
                     &AnimatedProperty::ListStyleImage(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ListStyleType(_, ref this_end_value),
                     &AnimatedProperty::ListStyleType(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskClip(_, ref this_end_value),
                     &AnimatedProperty::MaskClip(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskComposite(_, ref this_end_value),
                     &AnimatedProperty::MaskComposite(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskImage(_, ref this_end_value),
                     &AnimatedProperty::MaskImage(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskMode(_, ref this_end_value),
                     &AnimatedProperty::MaskMode(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskOrigin(_, ref this_end_value),
                     &AnimatedProperty::MaskOrigin(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskPositionX(_, ref this_end_value),
                     &AnimatedProperty::MaskPositionX(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskPositionY(_, ref this_end_value),
                     &AnimatedProperty::MaskPositionY(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskRepeat(_, ref this_end_value),
                     &AnimatedProperty::MaskRepeat(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskSize(_, ref this_end_value),
                     &AnimatedProperty::MaskSize(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozTabSize(_, ref this_end_value),
                     &AnimatedProperty::MozTabSize(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OutlineOffset(_, ref this_end_value),
                     &AnimatedProperty::OutlineOffset(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OverflowY(_, ref this_end_value),
                     &AnimatedProperty::OverflowY(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Perspective(_, ref this_end_value),
                     &AnimatedProperty::Perspective(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PerspectiveOrigin(_, ref this_end_value),
                     &AnimatedProperty::PerspectiveOrigin(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Quotes(_, ref this_end_value),
                     &AnimatedProperty::Quotes(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Rotate(_, ref this_end_value),
                     &AnimatedProperty::Rotate(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Scale(_, ref this_end_value),
                     &AnimatedProperty::Scale(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ScrollSnapCoordinate(_, ref this_end_value),
                     &AnimatedProperty::ScrollSnapCoordinate(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ShapeOutside(_, ref this_end_value),
                     &AnimatedProperty::ShapeOutside(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StrokeDasharray(_, ref this_end_value),
                     &AnimatedProperty::StrokeDasharray(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StrokeDashoffset(_, ref this_end_value),
                     &AnimatedProperty::StrokeDashoffset(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StrokeMiterlimit(_, ref this_end_value),
                     &AnimatedProperty::StrokeMiterlimit(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StrokeWidth(_, ref this_end_value),
                     &AnimatedProperty::StrokeWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextAlign(_, ref this_end_value),
                     &AnimatedProperty::TextAlign(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextEmphasisPosition(_, ref this_end_value),
                     &AnimatedProperty::TextEmphasisPosition(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextEmphasisStyle(_, ref this_end_value),
                     &AnimatedProperty::TextEmphasisStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextIndent(_, ref this_end_value),
                     &AnimatedProperty::TextIndent(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextOverflow(_, ref this_end_value),
                     &AnimatedProperty::TextOverflow(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextShadow(_, ref this_end_value),
                     &AnimatedProperty::TextShadow(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Translate(_, ref this_end_value),
                     &AnimatedProperty::Translate(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::VerticalAlign(_, ref this_end_value),
                     &AnimatedProperty::VerticalAlign(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WillChange(_, ref this_end_value),
                     &AnimatedProperty::WillChange(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WordSpacing(_, ref this_end_value),
                     &AnimatedProperty::WordSpacing(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OverflowClipBoxBlock(_, ref this_end_value),
                     &AnimatedProperty::OverflowClipBoxBlock(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OverflowClipBoxInline(_, ref this_end_value),
                     &AnimatedProperty::OverflowClipBoxInline(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FillOpacity(_, ref this_end_value),
                     &AnimatedProperty::FillOpacity(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StrokeOpacity(_, ref this_end_value),
                     &AnimatedProperty::StrokeOpacity(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ScrollSnapPointsX(_, ref this_end_value),
                     &AnimatedProperty::ScrollSnapPointsX(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ScrollSnapPointsY(_, ref this_end_value),
                     &AnimatedProperty::ScrollSnapPointsY(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozWindowTransform(_, ref this_end_value),
                     &AnimatedProperty::MozWindowTransform(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Transform(_, ref this_end_value),
                     &AnimatedProperty::Transform(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Clip(_, ref this_end_value),
                     &AnimatedProperty::Clip(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozImageRegion(_, ref this_end_value),
                     &AnimatedProperty::MozImageRegion(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridTemplateColumns(_, ref this_end_value),
                     &AnimatedProperty::GridTemplateColumns(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridTemplateRows(_, ref this_end_value),
                     &AnimatedProperty::GridTemplateRows(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ObjectPosition(_, ref this_end_value),
                     &AnimatedProperty::ObjectPosition(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ScrollSnapDestination(_, ref this_end_value),
                     &AnimatedProperty::ScrollSnapDestination(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Fill(_, ref this_end_value),
                     &AnimatedProperty::Fill(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Stroke(_, ref this_end_value),
                     &AnimatedProperty::Stroke(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridAutoColumns(_, ref this_end_value),
                     &AnimatedProperty::GridAutoColumns(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridAutoRows(_, ref this_end_value),
                     &AnimatedProperty::GridAutoRows(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozWindowTransformOrigin(_, ref this_end_value),
                     &AnimatedProperty::MozWindowTransformOrigin(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TransformOrigin(_, ref this_end_value),
                     &AnimatedProperty::TransformOrigin(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaxHeight(_, ref this_end_value),
                     &AnimatedProperty::MaxHeight(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaxWidth(_, ref this_end_value),
                     &AnimatedProperty::MaxWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FloodColor(_, ref this_end_value),
                     &AnimatedProperty::FloodColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::LightingColor(_, ref this_end_value),
                     &AnimatedProperty::LightingColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozFontSmoothingBackgroundColor(_, ref this_end_value),
                     &AnimatedProperty::MozFontSmoothingBackgroundColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StopColor(_, ref this_end_value),
                     &AnimatedProperty::StopColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MarkerEnd(_, ref this_end_value),
                     &AnimatedProperty::MarkerEnd(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MarkerMid(_, ref this_end_value),
                     &AnimatedProperty::MarkerMid(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MarkerStart(_, ref this_end_value),
                     &AnimatedProperty::MarkerStart(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridColumnEnd(_, ref this_end_value),
                     &AnimatedProperty::GridColumnEnd(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridColumnStart(_, ref this_end_value),
                     &AnimatedProperty::GridColumnStart(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridRowEnd(_, ref this_end_value),
                     &AnimatedProperty::GridRowEnd(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridRowStart(_, ref this_end_value),
                     &AnimatedProperty::GridRowStart(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderBottomLeftRadius(_, ref this_end_value),
                     &AnimatedProperty::BorderBottomLeftRadius(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderBottomRightRadius(_, ref this_end_value),
                     &AnimatedProperty::BorderBottomRightRadius(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderTopLeftRadius(_, ref this_end_value),
                     &AnimatedProperty::BorderTopLeftRadius(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderTopRightRadius(_, ref this_end_value),
                     &AnimatedProperty::BorderTopRightRadius(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozOutlineRadiusBottomleft(_, ref this_end_value),
                     &AnimatedProperty::MozOutlineRadiusBottomleft(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozOutlineRadiusBottomright(_, ref this_end_value),
                     &AnimatedProperty::MozOutlineRadiusBottomright(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozOutlineRadiusTopleft(_, ref this_end_value),
                     &AnimatedProperty::MozOutlineRadiusTopleft(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozOutlineRadiusTopright(_, ref this_end_value),
                     &AnimatedProperty::MozOutlineRadiusTopright(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FlexBasis(_, ref this_end_value),
                     &AnimatedProperty::FlexBasis(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Height(_, ref this_end_value),
                     &AnimatedProperty::Height(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MinHeight(_, ref this_end_value),
                     &AnimatedProperty::MinHeight(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MinWidth(_, ref this_end_value),
                     &AnimatedProperty::MinWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Width(_, ref this_end_value),
                     &AnimatedProperty::Width(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridColumnGap(_, ref this_end_value),
                     &AnimatedProperty::GridColumnGap(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridRowGap(_, ref this_end_value),
                     &AnimatedProperty::GridRowGap(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PaddingBottom(_, ref this_end_value),
                     &AnimatedProperty::PaddingBottom(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PaddingLeft(_, ref this_end_value),
                     &AnimatedProperty::PaddingLeft(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PaddingRight(_, ref this_end_value),
                     &AnimatedProperty::PaddingRight(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PaddingTop(_, ref this_end_value),
                     &AnimatedProperty::PaddingTop(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderBottomWidth(_, ref this_end_value),
                     &AnimatedProperty::BorderBottomWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderLeftWidth(_, ref this_end_value),
                     &AnimatedProperty::BorderLeftWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderRightWidth(_, ref this_end_value),
                     &AnimatedProperty::BorderRightWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderTopWidth(_, ref this_end_value),
                     &AnimatedProperty::BorderTopWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnRuleWidth(_, ref this_end_value),
                     &AnimatedProperty::ColumnRuleWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OutlineWidth(_, ref this_end_value),
                     &AnimatedProperty::OutlineWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WebkitTextStrokeWidth(_, ref this_end_value),
                     &AnimatedProperty::WebkitTextStrokeWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundColor(_, ref this_end_value),
                     &AnimatedProperty::BackgroundColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderBottomColor(_, ref this_end_value),
                     &AnimatedProperty::BorderBottomColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderLeftColor(_, ref this_end_value),
                     &AnimatedProperty::BorderLeftColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderRightColor(_, ref this_end_value),
                     &AnimatedProperty::BorderRightColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderTopColor(_, ref this_end_value),
                     &AnimatedProperty::BorderTopColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnRuleColor(_, ref this_end_value),
                     &AnimatedProperty::ColumnRuleColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OutlineColor(_, ref this_end_value),
                     &AnimatedProperty::OutlineColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextDecorationColor(_, ref this_end_value),
                     &AnimatedProperty::TextDecorationColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextEmphasisColor(_, ref this_end_value),
                     &AnimatedProperty::TextEmphasisColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WebkitTextFillColor(_, ref this_end_value),
                     &AnimatedProperty::WebkitTextFillColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WebkitTextStrokeColor(_, ref this_end_value),
                     &AnimatedProperty::WebkitTextStrokeColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Bottom(_, ref this_end_value),
                     &AnimatedProperty::Bottom(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Left(_, ref this_end_value),
                     &AnimatedProperty::Left(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MarginBottom(_, ref this_end_value),
                     &AnimatedProperty::MarginBottom(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MarginLeft(_, ref this_end_value),
                     &AnimatedProperty::MarginLeft(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MarginRight(_, ref this_end_value),
                     &AnimatedProperty::MarginRight(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MarginTop(_, ref this_end_value),
                     &AnimatedProperty::MarginTop(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Right(_, ref this_end_value),
                     &AnimatedProperty::Right(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Top(_, ref this_end_value),
                     &AnimatedProperty::Top(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
            _ => false,
        }
    }

    /// Update `style` with the proper computed style corresponding to this
    /// animation at `progress`.
    pub fn update(&self, style: &mut ComputedValues, progress: f64) {
        match *self {
                    AnimatedProperty::AlignContent(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_align_content(value);
                    }
                    AnimatedProperty::AlignItems(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_align_items(value);
                    }
                    AnimatedProperty::AlignSelf(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_align_self(value);
                    }
                    AnimatedProperty::BackfaceVisibility(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_backface_visibility(value);
                    }
                    AnimatedProperty::BorderCollapse(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtable().set_border_collapse(value);
                    }
                    AnimatedProperty::BorderImageRepeat(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_image_repeat(value);
                    }
                    AnimatedProperty::BoxDecorationBreak(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_box_decoration_break(value);
                    }
                    AnimatedProperty::BoxSizing(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_box_sizing(value);
                    }
                    AnimatedProperty::CaptionSide(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtable().set_caption_side(value);
                    }
                    AnimatedProperty::Clear(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_clear(value);
                    }
                    AnimatedProperty::ClipRule(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_clip_rule(value);
                    }
                    AnimatedProperty::ColorAdjust(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedbox().set_color_adjust(value);
                    }
                    AnimatedProperty::ColorInterpolation(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_color_interpolation(value);
                    }
                    AnimatedProperty::ColorInterpolationFilters(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_color_interpolation_filters(value);
                    }
                    AnimatedProperty::ColumnCount(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::column_count::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_column().set_column_count(value);
                    }
                    AnimatedProperty::ColumnFill(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_column().set_column_fill(value);
                    }
                    AnimatedProperty::ColumnRuleStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_column().set_column_rule_style(value);
                    }
                    AnimatedProperty::ColumnSpan(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_column().set_column_span(value);
                    }
                    AnimatedProperty::Contain(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_contain(value);
                    }
                    AnimatedProperty::Direction(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedbox().set_direction(value);
                    }
                    AnimatedProperty::DominantBaseline(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_dominant_baseline(value);
                    }
                    AnimatedProperty::EmptyCells(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtable().set_empty_cells(value);
                    }
                    AnimatedProperty::FillRule(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_fill_rule(value);
                    }
                    AnimatedProperty::FlexDirection(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_flex_direction(value);
                    }
                    AnimatedProperty::FlexWrap(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_flex_wrap(value);
                    }
                    AnimatedProperty::Float(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_float(value);
                    }
                    AnimatedProperty::FontKerning(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_kerning(value);
                    }
                    AnimatedProperty::FontOpticalSizing(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_optical_sizing(value);
                    }
                    AnimatedProperty::FontStretch(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_font().set_font_stretch(value);
                    }
                    AnimatedProperty::FontStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_style(value);
                    }
                    AnimatedProperty::FontSynthesis(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_synthesis(value);
                    }
                    AnimatedProperty::FontVariantCaps(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_variant_caps(value);
                    }
                    AnimatedProperty::FontVariantPosition(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_variant_position(value);
                    }
                    AnimatedProperty::FontWeight(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_font().set_font_weight(value);
                    }
                    AnimatedProperty::GridAutoFlow(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_auto_flow(value);
                    }
                    AnimatedProperty::Hyphens(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_hyphens(value);
                    }
                    AnimatedProperty::ImageOrientation(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedbox().set_image_orientation(value);
                    }
                    AnimatedProperty::ImageRendering(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedbox().set_image_rendering(value);
                    }
                    AnimatedProperty::ImeMode(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_ui().set_ime_mode(value);
                    }
                    AnimatedProperty::InitialLetter(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_text().set_initial_letter(value);
                    }
                    AnimatedProperty::Isolation(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_isolation(value);
                    }
                    AnimatedProperty::JustifyContent(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_justify_content(value);
                    }
                    AnimatedProperty::JustifyItems(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_justify_items(value);
                    }
                    AnimatedProperty::JustifySelf(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_justify_self(value);
                    }
                    AnimatedProperty::ListStylePosition(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_list().set_list_style_position(value);
                    }
                    AnimatedProperty::MaskType(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_mask_type(value);
                    }
                    AnimatedProperty::MixBlendMode(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_effects().set_mix_blend_mode(value);
                    }
                    AnimatedProperty::MozAppearance(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set__moz_appearance(value);
                    }
                    AnimatedProperty::MozBoxAlign(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_xul().set__moz_box_align(value);
                    }
                    AnimatedProperty::MozBoxDirection(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_xul().set__moz_box_direction(value);
                    }
                    AnimatedProperty::MozBoxOrient(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_xul().set__moz_box_orient(value);
                    }
                    AnimatedProperty::MozBoxPack(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_xul().set__moz_box_pack(value);
                    }
                    AnimatedProperty::MozFloatEdge(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set__moz_float_edge(value);
                    }
                    AnimatedProperty::MozForceBrokenImageIcon(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_ui().set__moz_force_broken_image_icon(value);
                    }
                    AnimatedProperty::MozOrient(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set__moz_orient(value);
                    }
                    AnimatedProperty::MozOsxFontSmoothing(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set__moz_osx_font_smoothing(value);
                    }
                    AnimatedProperty::MozStackSizing(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_xul().set__moz_stack_sizing(value);
                    }
                    AnimatedProperty::MozTextSizeAdjust(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set__moz_text_size_adjust(value);
                    }
                    AnimatedProperty::MozUserFocus(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_pointing().set__moz_user_focus(value);
                    }
                    AnimatedProperty::MozUserInput(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_pointing().set__moz_user_input(value);
                    }
                    AnimatedProperty::MozUserModify(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_pointing().set__moz_user_modify(value);
                    }
                    AnimatedProperty::MozUserSelect(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_ui().set__moz_user_select(value);
                    }
                    AnimatedProperty::MozWindowDragging(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_ui().set__moz_window_dragging(value);
                    }
                    AnimatedProperty::MozWindowShadow(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_ui().set__moz_window_shadow(value);
                    }
                    AnimatedProperty::ObjectFit(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_object_fit(value);
                    }
                    AnimatedProperty::OutlineStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_outline().set_outline_style(value);
                    }
                    AnimatedProperty::OverflowWrap(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_overflow_wrap(value);
                    }
                    AnimatedProperty::OverflowX(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_overflow_x(value);
                    }
                    AnimatedProperty::PageBreakAfter(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_page_break_after(value);
                    }
                    AnimatedProperty::PageBreakBefore(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_page_break_before(value);
                    }
                    AnimatedProperty::PageBreakInside(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_page_break_inside(value);
                    }
                    AnimatedProperty::PaintOrder(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_paint_order(value);
                    }
                    AnimatedProperty::PointerEvents(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_pointing().set_pointer_events(value);
                    }
                    AnimatedProperty::Position(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_position(value);
                    }
                    AnimatedProperty::Resize(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_resize(value);
                    }
                    AnimatedProperty::RubyAlign(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_ruby_align(value);
                    }
                    AnimatedProperty::RubyPosition(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_ruby_position(value);
                    }
                    AnimatedProperty::ScrollBehavior(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_scroll_behavior(value);
                    }
                    AnimatedProperty::ShapeRendering(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_shape_rendering(value);
                    }
                    AnimatedProperty::StrokeLinecap(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_stroke_linecap(value);
                    }
                    AnimatedProperty::StrokeLinejoin(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_stroke_linejoin(value);
                    }
                    AnimatedProperty::TableLayout(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_table().set_table_layout(value);
                    }
                    AnimatedProperty::TextAlignLast(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_align_last(value);
                    }
                    AnimatedProperty::TextAnchor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_text_anchor(value);
                    }
                    AnimatedProperty::TextCombineUpright(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_combine_upright(value);
                    }
                    AnimatedProperty::TextDecorationLine(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_text().set_text_decoration_line(value);
                    }
                    AnimatedProperty::TextDecorationStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_text().set_text_decoration_style(value);
                    }
                    AnimatedProperty::TextJustify(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_justify(value);
                    }
                    AnimatedProperty::TextOrientation(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedbox().set_text_orientation(value);
                    }
                    AnimatedProperty::TextRendering(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_rendering(value);
                    }
                    AnimatedProperty::TextTransform(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_transform(value);
                    }
                    AnimatedProperty::TouchAction(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_touch_action(value);
                    }
                    AnimatedProperty::TransformBox(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_transform_box(value);
                    }
                    AnimatedProperty::TransformStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_transform_style(value);
                    }
                    AnimatedProperty::UnicodeBidi(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_text().set_unicode_bidi(value);
                    }
                    AnimatedProperty::VectorEffect(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_vector_effect(value);
                    }
                    AnimatedProperty::Visibility(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_inheritedbox().set_visibility(value);
                    }
                    AnimatedProperty::WhiteSpace(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_white_space(value);
                    }
                    AnimatedProperty::WordBreak(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_word_break(value);
                    }
                    AnimatedProperty::WritingMode(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedbox().set_writing_mode(value);
                    }
                    AnimatedProperty::ZIndex(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_position().set_z_index(value);
                    }
                    AnimatedProperty::MozBoxOrdinalGroup(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_xul().set__moz_box_ordinal_group(value);
                    }
                    AnimatedProperty::Order(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_position().set_order(value);
                    }
                    AnimatedProperty::OverscrollBehaviorX(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_overscroll_behavior_x(value);
                    }
                    AnimatedProperty::OverscrollBehaviorY(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_overscroll_behavior_y(value);
                    }
                    AnimatedProperty::ScrollSnapTypeX(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_scroll_snap_type_x(value);
                    }
                    AnimatedProperty::ScrollSnapTypeY(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_scroll_snap_type_y(value);
                    }
                    AnimatedProperty::FlexGrow(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::flex_grow::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_flex_grow(value);
                    }
                    AnimatedProperty::FlexShrink(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::flex_shrink::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_flex_shrink(value);
                    }
                    AnimatedProperty::MozBoxFlex(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_moz_box_flex::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_xul().set__moz_box_flex(value);
                    }
                    AnimatedProperty::FloodOpacity(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_svg().set_flood_opacity(value);
                    }
                    AnimatedProperty::MozWindowOpacity(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_ui().set__moz_window_opacity(value);
                    }
                    AnimatedProperty::Opacity(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_effects().set_opacity(value);
                    }
                    AnimatedProperty::ShapeImageThreshold(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_shape_image_threshold(value);
                    }
                    AnimatedProperty::StopOpacity(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_svg().set_stop_opacity(value);
                    }
                    AnimatedProperty::BorderBottomStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_bottom_style(value);
                    }
                    AnimatedProperty::BorderLeftStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_left_style(value);
                    }
                    AnimatedProperty::BorderRightStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_right_style(value);
                    }
                    AnimatedProperty::BorderTopStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_top_style(value);
                    }
                    AnimatedProperty::BackgroundAttachment(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_background().set_background_attachment(value);
                    }
                    AnimatedProperty::BackgroundBlendMode(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_background().set_background_blend_mode(value);
                    }
                    AnimatedProperty::BackgroundClip(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_background().set_background_clip(value);
                    }
                    AnimatedProperty::BackgroundImage(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_background().set_background_image(value);
                    }
                    AnimatedProperty::BackgroundOrigin(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_background().set_background_origin(value);
                    }
                    AnimatedProperty::BackgroundPositionX(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_background().set_background_position_x(value);
                    }
                    AnimatedProperty::BackgroundPositionY(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_background().set_background_position_y(value);
                    }
                    AnimatedProperty::BackgroundRepeat(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_background().set_background_repeat(value);
                    }
                    AnimatedProperty::BackgroundSize(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::background_size::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_background().set_background_size(value);
                    }
                    AnimatedProperty::BorderImageOutset(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_image_outset(value);
                    }
                    AnimatedProperty::BorderImageSlice(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_image_slice(value);
                    }
                    AnimatedProperty::BorderImageSource(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_image_source(value);
                    }
                    AnimatedProperty::BorderImageWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_image_width(value);
                    }
                    AnimatedProperty::BorderSpacing(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_spacing::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedtable().set_border_spacing(value);
                    }
                    AnimatedProperty::BoxShadow(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::box_shadow::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_effects().set_box_shadow(value);
                    }
                    AnimatedProperty::CaretColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::caret_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_pointing().set_caret_color(value);
                    }
                    AnimatedProperty::ClipPath(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_svg().set_clip_path(value);
                    }
                    AnimatedProperty::Color(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_color().set_color(value);
                    }
                    AnimatedProperty::ColumnGap(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::column_gap::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_column().set_column_gap(value);
                    }
                    AnimatedProperty::ColumnWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::column_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_column().set_column_width(value);
                    }
                    AnimatedProperty::Content(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_counters().set_content(value);
                    }
                    AnimatedProperty::CounterIncrement(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_counters().set_counter_increment(value);
                    }
                    AnimatedProperty::CounterReset(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_counters().set_counter_reset(value);
                    }
                    AnimatedProperty::Cursor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_pointing().set_cursor(value);
                    }
                    AnimatedProperty::Display(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_display(value);
                    }
                    AnimatedProperty::Filter(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::filter::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_effects().set_filter(value);
                    }
                    AnimatedProperty::FontFamily(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_family(value);
                    }
                    AnimatedProperty::FontFeatureSettings(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_feature_settings(value);
                    }
                    AnimatedProperty::FontLanguageOverride(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_language_override(value);
                    }
                    AnimatedProperty::FontSize(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::font_size::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_font().set_font_size(value);
                    }
                    AnimatedProperty::FontSizeAdjust(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_font().set_font_size_adjust(value);
                    }
                    AnimatedProperty::FontVariantAlternates(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_variant_alternates(value);
                    }
                    AnimatedProperty::FontVariantEastAsian(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_variant_east_asian(value);
                    }
                    AnimatedProperty::FontVariantLigatures(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_variant_ligatures(value);
                    }
                    AnimatedProperty::FontVariantNumeric(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_variant_numeric(value);
                    }
                    AnimatedProperty::FontVariationSettings(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_font().set_font_variation_settings(value);
                    }
                    AnimatedProperty::GridTemplateAreas(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_template_areas(value);
                    }
                    AnimatedProperty::LetterSpacing(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_inheritedtext().set_letter_spacing(value);
                    }
                    AnimatedProperty::LineHeight(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::line_height::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedtext().set_line_height(value);
                    }
                    AnimatedProperty::ListStyleImage(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_list().set_list_style_image(value);
                    }
                    AnimatedProperty::ListStyleType(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_list().set_list_style_type(value);
                    }
                    AnimatedProperty::MaskClip(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_mask_clip(value);
                    }
                    AnimatedProperty::MaskComposite(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_mask_composite(value);
                    }
                    AnimatedProperty::MaskImage(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_mask_image(value);
                    }
                    AnimatedProperty::MaskMode(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_mask_mode(value);
                    }
                    AnimatedProperty::MaskOrigin(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_mask_origin(value);
                    }
                    AnimatedProperty::MaskPositionX(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_svg().set_mask_position_x(value);
                    }
                    AnimatedProperty::MaskPositionY(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_svg().set_mask_position_y(value);
                    }
                    AnimatedProperty::MaskRepeat(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_mask_repeat(value);
                    }
                    AnimatedProperty::MaskSize(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_svg().set_mask_size(value);
                    }
                    AnimatedProperty::MozTabSize(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_moz_tab_size::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedtext().set__moz_tab_size(value);
                    }
                    AnimatedProperty::OutlineOffset(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_outline().set_outline_offset(value);
                    }
                    AnimatedProperty::OverflowY(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_overflow_y(value);
                    }
                    AnimatedProperty::Perspective(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::perspective::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_box().set_perspective(value);
                    }
                    AnimatedProperty::PerspectiveOrigin(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_perspective_origin(value);
                    }
                    AnimatedProperty::Quotes(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_list().set_quotes(value);
                    }
                    AnimatedProperty::Rotate(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_rotate(value);
                    }
                    AnimatedProperty::Scale(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_scale(value);
                    }
                    AnimatedProperty::ScrollSnapCoordinate(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_scroll_snap_coordinate(value);
                    }
                    AnimatedProperty::ShapeOutside(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_shape_outside(value);
                    }
                    AnimatedProperty::StrokeDasharray(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::stroke_dasharray::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedsvg().set_stroke_dasharray(value);
                    }
                    AnimatedProperty::StrokeDashoffset(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_inheritedsvg().set_stroke_dashoffset(value);
                    }
                    AnimatedProperty::StrokeMiterlimit(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::stroke_miterlimit::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedsvg().set_stroke_miterlimit(value);
                    }
                    AnimatedProperty::StrokeWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::stroke_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedsvg().set_stroke_width(value);
                    }
                    AnimatedProperty::TextAlign(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_align(value);
                    }
                    AnimatedProperty::TextEmphasisPosition(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_emphasis_position(value);
                    }
                    AnimatedProperty::TextEmphasisStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_emphasis_style(value);
                    }
                    AnimatedProperty::TextIndent(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_inheritedtext().set_text_indent(value);
                    }
                    AnimatedProperty::TextOverflow(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_text().set_text_overflow(value);
                    }
                    AnimatedProperty::TextShadow(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::text_shadow::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedtext().set_text_shadow(value);
                    }
                    AnimatedProperty::Translate(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_translate(value);
                    }
                    AnimatedProperty::VerticalAlign(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_vertical_align(value);
                    }
                    AnimatedProperty::WillChange(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_will_change(value);
                    }
                    AnimatedProperty::WordSpacing(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_inheritedtext().set_word_spacing(value);
                    }
                    AnimatedProperty::OverflowClipBoxBlock(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_overflow_clip_box_block(value);
                    }
                    AnimatedProperty::OverflowClipBoxInline(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_overflow_clip_box_inline(value);
                    }
                    AnimatedProperty::FillOpacity(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_inheritedsvg().set_fill_opacity(value);
                    }
                    AnimatedProperty::StrokeOpacity(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_inheritedsvg().set_stroke_opacity(value);
                    }
                    AnimatedProperty::ScrollSnapPointsX(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_scroll_snap_points_x(value);
                    }
                    AnimatedProperty::ScrollSnapPointsY(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_scroll_snap_points_y(value);
                    }
                    AnimatedProperty::MozWindowTransform(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_ui().set__moz_window_transform(value);
                    }
                    AnimatedProperty::Transform(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_transform(value);
                    }
                    AnimatedProperty::Clip(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_effects().set_clip(value);
                    }
                    AnimatedProperty::MozImageRegion(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_list().set__moz_image_region(value);
                    }
                    AnimatedProperty::GridTemplateColumns(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_template_columns(value);
                    }
                    AnimatedProperty::GridTemplateRows(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_template_rows(value);
                    }
                    AnimatedProperty::ObjectPosition(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_position().set_object_position(value);
                    }
                    AnimatedProperty::ScrollSnapDestination(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_scroll_snap_destination(value);
                    }
                    AnimatedProperty::Fill(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::fill::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedsvg().set_fill(value);
                    }
                    AnimatedProperty::Stroke(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::stroke::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedsvg().set_stroke(value);
                    }
                    AnimatedProperty::GridAutoColumns(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_auto_columns(value);
                    }
                    AnimatedProperty::GridAutoRows(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_auto_rows(value);
                    }
                    AnimatedProperty::MozWindowTransformOrigin(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_ui().set__moz_window_transform_origin(value);
                    }
                    AnimatedProperty::TransformOrigin(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_transform_origin(value);
                    }
                    AnimatedProperty::MaxHeight(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::max_height::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_max_height(value);
                    }
                    AnimatedProperty::MaxWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::max_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_max_width(value);
                    }
                    AnimatedProperty::FloodColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::flood_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_svg().set_flood_color(value);
                    }
                    AnimatedProperty::LightingColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::lighting_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_svg().set_lighting_color(value);
                    }
                    AnimatedProperty::MozFontSmoothingBackgroundColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_moz_font_smoothing_background_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_font().set__moz_font_smoothing_background_color(value);
                    }
                    AnimatedProperty::StopColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::stop_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_svg().set_stop_color(value);
                    }
                    AnimatedProperty::MarkerEnd(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_marker_end(value);
                    }
                    AnimatedProperty::MarkerMid(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_marker_mid(value);
                    }
                    AnimatedProperty::MarkerStart(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_marker_start(value);
                    }
                    AnimatedProperty::GridColumnEnd(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_column_end(value);
                    }
                    AnimatedProperty::GridColumnStart(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_column_start(value);
                    }
                    AnimatedProperty::GridRowEnd(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_row_end(value);
                    }
                    AnimatedProperty::GridRowStart(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_row_start(value);
                    }
                    AnimatedProperty::BorderBottomLeftRadius(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_bottom_left_radius::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_bottom_left_radius(value);
                    }
                    AnimatedProperty::BorderBottomRightRadius(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_bottom_right_radius::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_bottom_right_radius(value);
                    }
                    AnimatedProperty::BorderTopLeftRadius(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_top_left_radius::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_top_left_radius(value);
                    }
                    AnimatedProperty::BorderTopRightRadius(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_top_right_radius::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_top_right_radius(value);
                    }
                    AnimatedProperty::MozOutlineRadiusBottomleft(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_moz_outline_radius_bottomleft::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_outline().set__moz_outline_radius_bottomleft(value);
                    }
                    AnimatedProperty::MozOutlineRadiusBottomright(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_moz_outline_radius_bottomright::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_outline().set__moz_outline_radius_bottomright(value);
                    }
                    AnimatedProperty::MozOutlineRadiusTopleft(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_moz_outline_radius_topleft::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_outline().set__moz_outline_radius_topleft(value);
                    }
                    AnimatedProperty::MozOutlineRadiusTopright(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_moz_outline_radius_topright::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_outline().set__moz_outline_radius_topright(value);
                    }
                    AnimatedProperty::FlexBasis(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::flex_basis::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_flex_basis(value);
                    }
                    AnimatedProperty::Height(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::height::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_height(value);
                    }
                    AnimatedProperty::MinHeight(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::min_height::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_min_height(value);
                    }
                    AnimatedProperty::MinWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::min_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_min_width(value);
                    }
                    AnimatedProperty::Width(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_width(value);
                    }
                    AnimatedProperty::GridColumnGap(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::grid_column_gap::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_grid_column_gap(value);
                    }
                    AnimatedProperty::GridRowGap(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::grid_row_gap::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_grid_row_gap(value);
                    }
                    AnimatedProperty::PaddingBottom(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::padding_bottom::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_padding().set_padding_bottom(value);
                    }
                    AnimatedProperty::PaddingLeft(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::padding_left::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_padding().set_padding_left(value);
                    }
                    AnimatedProperty::PaddingRight(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::padding_right::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_padding().set_padding_right(value);
                    }
                    AnimatedProperty::PaddingTop(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::padding_top::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_padding().set_padding_top(value);
                    }
                    AnimatedProperty::BorderBottomWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_bottom_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_bottom_width(value);
                    }
                    AnimatedProperty::BorderLeftWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_left_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_left_width(value);
                    }
                    AnimatedProperty::BorderRightWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_right_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_right_width(value);
                    }
                    AnimatedProperty::BorderTopWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_top_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_top_width(value);
                    }
                    AnimatedProperty::ColumnRuleWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::column_rule_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_column().set_column_rule_width(value);
                    }
                    AnimatedProperty::OutlineWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::outline_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_outline().set_outline_width(value);
                    }
                    AnimatedProperty::WebkitTextStrokeWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set__webkit_text_stroke_width(value);
                    }
                    AnimatedProperty::BackgroundColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::background_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_background().set_background_color(value);
                    }
                    AnimatedProperty::BorderBottomColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_bottom_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_bottom_color(value);
                    }
                    AnimatedProperty::BorderLeftColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_left_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_left_color(value);
                    }
                    AnimatedProperty::BorderRightColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_right_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_right_color(value);
                    }
                    AnimatedProperty::BorderTopColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_top_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_top_color(value);
                    }
                    AnimatedProperty::ColumnRuleColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::column_rule_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_column().set_column_rule_color(value);
                    }
                    AnimatedProperty::OutlineColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::outline_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_outline().set_outline_color(value);
                    }
                    AnimatedProperty::TextDecorationColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::text_decoration_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_text().set_text_decoration_color(value);
                    }
                    AnimatedProperty::TextEmphasisColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::text_emphasis_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedtext().set_text_emphasis_color(value);
                    }
                    AnimatedProperty::WebkitTextFillColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_webkit_text_fill_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedtext().set__webkit_text_fill_color(value);
                    }
                    AnimatedProperty::WebkitTextStrokeColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_webkit_text_stroke_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedtext().set__webkit_text_stroke_color(value);
                    }
                    AnimatedProperty::Bottom(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_position().set_bottom(value);
                    }
                    AnimatedProperty::Left(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_position().set_left(value);
                    }
                    AnimatedProperty::MarginBottom(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_margin().set_margin_bottom(value);
                    }
                    AnimatedProperty::MarginLeft(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_margin().set_margin_left(value);
                    }
                    AnimatedProperty::MarginRight(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_margin().set_margin_right(value);
                    }
                    AnimatedProperty::MarginTop(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_margin().set_margin_top(value);
                    }
                    AnimatedProperty::Right(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_position().set_right(value);
                    }
                    AnimatedProperty::Top(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_position().set_top(value);
                    }
        }
    }

    /// Get an animatable value from a transition-property, an old style, and a
    /// new style.
    pub fn from_longhand(
        property: LonghandId,
        old_style: &ComputedValues,
        new_style: &ComputedValues,
    ) -> Option<AnimatedProperty> {
        Some(match property {
                LonghandId::AlignContent => {
                    let old_computed = old_style.get_position().clone_align_content();
                    let new_computed = new_style.get_position().clone_align_content();
                    AnimatedProperty::AlignContent(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::AlignItems => {
                    let old_computed = old_style.get_position().clone_align_items();
                    let new_computed = new_style.get_position().clone_align_items();
                    AnimatedProperty::AlignItems(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::AlignSelf => {
                    let old_computed = old_style.get_position().clone_align_self();
                    let new_computed = new_style.get_position().clone_align_self();
                    AnimatedProperty::AlignSelf(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackfaceVisibility => {
                    let old_computed = old_style.get_box().clone_backface_visibility();
                    let new_computed = new_style.get_box().clone_backface_visibility();
                    AnimatedProperty::BackfaceVisibility(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderCollapse => {
                    let old_computed = old_style.get_inheritedtable().clone_border_collapse();
                    let new_computed = new_style.get_inheritedtable().clone_border_collapse();
                    AnimatedProperty::BorderCollapse(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderImageRepeat => {
                    let old_computed = old_style.get_border().clone_border_image_repeat();
                    let new_computed = new_style.get_border().clone_border_image_repeat();
                    AnimatedProperty::BorderImageRepeat(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BoxDecorationBreak => {
                    let old_computed = old_style.get_border().clone_box_decoration_break();
                    let new_computed = new_style.get_border().clone_box_decoration_break();
                    AnimatedProperty::BoxDecorationBreak(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BoxSizing => {
                    let old_computed = old_style.get_position().clone_box_sizing();
                    let new_computed = new_style.get_position().clone_box_sizing();
                    AnimatedProperty::BoxSizing(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::CaptionSide => {
                    let old_computed = old_style.get_inheritedtable().clone_caption_side();
                    let new_computed = new_style.get_inheritedtable().clone_caption_side();
                    AnimatedProperty::CaptionSide(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Clear => {
                    let old_computed = old_style.get_box().clone_clear();
                    let new_computed = new_style.get_box().clone_clear();
                    AnimatedProperty::Clear(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ClipRule => {
                    let old_computed = old_style.get_inheritedsvg().clone_clip_rule();
                    let new_computed = new_style.get_inheritedsvg().clone_clip_rule();
                    AnimatedProperty::ClipRule(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ColorAdjust => {
                    let old_computed = old_style.get_inheritedbox().clone_color_adjust();
                    let new_computed = new_style.get_inheritedbox().clone_color_adjust();
                    AnimatedProperty::ColorAdjust(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ColorInterpolation => {
                    let old_computed = old_style.get_inheritedsvg().clone_color_interpolation();
                    let new_computed = new_style.get_inheritedsvg().clone_color_interpolation();
                    AnimatedProperty::ColorInterpolation(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ColorInterpolationFilters => {
                    let old_computed = old_style.get_inheritedsvg().clone_color_interpolation_filters();
                    let new_computed = new_style.get_inheritedsvg().clone_color_interpolation_filters();
                    AnimatedProperty::ColorInterpolationFilters(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ColumnCount => {
                    let old_computed = old_style.get_column().clone_column_count();
                    let new_computed = new_style.get_column().clone_column_count();
                    AnimatedProperty::ColumnCount(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::ColumnFill => {
                    let old_computed = old_style.get_column().clone_column_fill();
                    let new_computed = new_style.get_column().clone_column_fill();
                    AnimatedProperty::ColumnFill(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ColumnRuleStyle => {
                    let old_computed = old_style.get_column().clone_column_rule_style();
                    let new_computed = new_style.get_column().clone_column_rule_style();
                    AnimatedProperty::ColumnRuleStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ColumnSpan => {
                    let old_computed = old_style.get_column().clone_column_span();
                    let new_computed = new_style.get_column().clone_column_span();
                    AnimatedProperty::ColumnSpan(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Contain => {
                    let old_computed = old_style.get_box().clone_contain();
                    let new_computed = new_style.get_box().clone_contain();
                    AnimatedProperty::Contain(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Direction => {
                    let old_computed = old_style.get_inheritedbox().clone_direction();
                    let new_computed = new_style.get_inheritedbox().clone_direction();
                    AnimatedProperty::Direction(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::DominantBaseline => {
                    let old_computed = old_style.get_svg().clone_dominant_baseline();
                    let new_computed = new_style.get_svg().clone_dominant_baseline();
                    AnimatedProperty::DominantBaseline(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::EmptyCells => {
                    let old_computed = old_style.get_inheritedtable().clone_empty_cells();
                    let new_computed = new_style.get_inheritedtable().clone_empty_cells();
                    AnimatedProperty::EmptyCells(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FillRule => {
                    let old_computed = old_style.get_inheritedsvg().clone_fill_rule();
                    let new_computed = new_style.get_inheritedsvg().clone_fill_rule();
                    AnimatedProperty::FillRule(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FlexDirection => {
                    let old_computed = old_style.get_position().clone_flex_direction();
                    let new_computed = new_style.get_position().clone_flex_direction();
                    AnimatedProperty::FlexDirection(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FlexWrap => {
                    let old_computed = old_style.get_position().clone_flex_wrap();
                    let new_computed = new_style.get_position().clone_flex_wrap();
                    AnimatedProperty::FlexWrap(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Float => {
                    let old_computed = old_style.get_box().clone_float();
                    let new_computed = new_style.get_box().clone_float();
                    AnimatedProperty::Float(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontKerning => {
                    let old_computed = old_style.get_font().clone_font_kerning();
                    let new_computed = new_style.get_font().clone_font_kerning();
                    AnimatedProperty::FontKerning(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontOpticalSizing => {
                    let old_computed = old_style.get_font().clone_font_optical_sizing();
                    let new_computed = new_style.get_font().clone_font_optical_sizing();
                    AnimatedProperty::FontOpticalSizing(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontStretch => {
                    let old_computed = old_style.get_font().clone_font_stretch();
                    let new_computed = new_style.get_font().clone_font_stretch();
                    AnimatedProperty::FontStretch(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontStyle => {
                    let old_computed = old_style.get_font().clone_font_style();
                    let new_computed = new_style.get_font().clone_font_style();
                    AnimatedProperty::FontStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontSynthesis => {
                    let old_computed = old_style.get_font().clone_font_synthesis();
                    let new_computed = new_style.get_font().clone_font_synthesis();
                    AnimatedProperty::FontSynthesis(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontVariantCaps => {
                    let old_computed = old_style.get_font().clone_font_variant_caps();
                    let new_computed = new_style.get_font().clone_font_variant_caps();
                    AnimatedProperty::FontVariantCaps(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontVariantPosition => {
                    let old_computed = old_style.get_font().clone_font_variant_position();
                    let new_computed = new_style.get_font().clone_font_variant_position();
                    AnimatedProperty::FontVariantPosition(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontWeight => {
                    let old_computed = old_style.get_font().clone_font_weight();
                    let new_computed = new_style.get_font().clone_font_weight();
                    AnimatedProperty::FontWeight(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridAutoFlow => {
                    let old_computed = old_style.get_position().clone_grid_auto_flow();
                    let new_computed = new_style.get_position().clone_grid_auto_flow();
                    AnimatedProperty::GridAutoFlow(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Hyphens => {
                    let old_computed = old_style.get_inheritedtext().clone_hyphens();
                    let new_computed = new_style.get_inheritedtext().clone_hyphens();
                    AnimatedProperty::Hyphens(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ImageOrientation => {
                    let old_computed = old_style.get_inheritedbox().clone_image_orientation();
                    let new_computed = new_style.get_inheritedbox().clone_image_orientation();
                    AnimatedProperty::ImageOrientation(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ImageRendering => {
                    let old_computed = old_style.get_inheritedbox().clone_image_rendering();
                    let new_computed = new_style.get_inheritedbox().clone_image_rendering();
                    AnimatedProperty::ImageRendering(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ImeMode => {
                    let old_computed = old_style.get_ui().clone_ime_mode();
                    let new_computed = new_style.get_ui().clone_ime_mode();
                    AnimatedProperty::ImeMode(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::InitialLetter => {
                    let old_computed = old_style.get_text().clone_initial_letter();
                    let new_computed = new_style.get_text().clone_initial_letter();
                    AnimatedProperty::InitialLetter(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Isolation => {
                    let old_computed = old_style.get_box().clone_isolation();
                    let new_computed = new_style.get_box().clone_isolation();
                    AnimatedProperty::Isolation(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::JustifyContent => {
                    let old_computed = old_style.get_position().clone_justify_content();
                    let new_computed = new_style.get_position().clone_justify_content();
                    AnimatedProperty::JustifyContent(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::JustifyItems => {
                    let old_computed = old_style.get_position().clone_justify_items();
                    let new_computed = new_style.get_position().clone_justify_items();
                    AnimatedProperty::JustifyItems(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::JustifySelf => {
                    let old_computed = old_style.get_position().clone_justify_self();
                    let new_computed = new_style.get_position().clone_justify_self();
                    AnimatedProperty::JustifySelf(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ListStylePosition => {
                    let old_computed = old_style.get_list().clone_list_style_position();
                    let new_computed = new_style.get_list().clone_list_style_position();
                    AnimatedProperty::ListStylePosition(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskType => {
                    let old_computed = old_style.get_svg().clone_mask_type();
                    let new_computed = new_style.get_svg().clone_mask_type();
                    AnimatedProperty::MaskType(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MixBlendMode => {
                    let old_computed = old_style.get_effects().clone_mix_blend_mode();
                    let new_computed = new_style.get_effects().clone_mix_blend_mode();
                    AnimatedProperty::MixBlendMode(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozAppearance => {
                    let old_computed = old_style.get_box().clone__moz_appearance();
                    let new_computed = new_style.get_box().clone__moz_appearance();
                    AnimatedProperty::MozAppearance(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozBoxAlign => {
                    let old_computed = old_style.get_xul().clone__moz_box_align();
                    let new_computed = new_style.get_xul().clone__moz_box_align();
                    AnimatedProperty::MozBoxAlign(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozBoxDirection => {
                    let old_computed = old_style.get_xul().clone__moz_box_direction();
                    let new_computed = new_style.get_xul().clone__moz_box_direction();
                    AnimatedProperty::MozBoxDirection(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozBoxOrient => {
                    let old_computed = old_style.get_xul().clone__moz_box_orient();
                    let new_computed = new_style.get_xul().clone__moz_box_orient();
                    AnimatedProperty::MozBoxOrient(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozBoxPack => {
                    let old_computed = old_style.get_xul().clone__moz_box_pack();
                    let new_computed = new_style.get_xul().clone__moz_box_pack();
                    AnimatedProperty::MozBoxPack(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozFloatEdge => {
                    let old_computed = old_style.get_border().clone__moz_float_edge();
                    let new_computed = new_style.get_border().clone__moz_float_edge();
                    AnimatedProperty::MozFloatEdge(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozForceBrokenImageIcon => {
                    let old_computed = old_style.get_ui().clone__moz_force_broken_image_icon();
                    let new_computed = new_style.get_ui().clone__moz_force_broken_image_icon();
                    AnimatedProperty::MozForceBrokenImageIcon(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozOrient => {
                    let old_computed = old_style.get_box().clone__moz_orient();
                    let new_computed = new_style.get_box().clone__moz_orient();
                    AnimatedProperty::MozOrient(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozOsxFontSmoothing => {
                    let old_computed = old_style.get_font().clone__moz_osx_font_smoothing();
                    let new_computed = new_style.get_font().clone__moz_osx_font_smoothing();
                    AnimatedProperty::MozOsxFontSmoothing(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozStackSizing => {
                    let old_computed = old_style.get_xul().clone__moz_stack_sizing();
                    let new_computed = new_style.get_xul().clone__moz_stack_sizing();
                    AnimatedProperty::MozStackSizing(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozTextSizeAdjust => {
                    let old_computed = old_style.get_inheritedtext().clone__moz_text_size_adjust();
                    let new_computed = new_style.get_inheritedtext().clone__moz_text_size_adjust();
                    AnimatedProperty::MozTextSizeAdjust(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozUserFocus => {
                    let old_computed = old_style.get_pointing().clone__moz_user_focus();
                    let new_computed = new_style.get_pointing().clone__moz_user_focus();
                    AnimatedProperty::MozUserFocus(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozUserInput => {
                    let old_computed = old_style.get_pointing().clone__moz_user_input();
                    let new_computed = new_style.get_pointing().clone__moz_user_input();
                    AnimatedProperty::MozUserInput(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozUserModify => {
                    let old_computed = old_style.get_pointing().clone__moz_user_modify();
                    let new_computed = new_style.get_pointing().clone__moz_user_modify();
                    AnimatedProperty::MozUserModify(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozUserSelect => {
                    let old_computed = old_style.get_ui().clone__moz_user_select();
                    let new_computed = new_style.get_ui().clone__moz_user_select();
                    AnimatedProperty::MozUserSelect(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozWindowDragging => {
                    let old_computed = old_style.get_ui().clone__moz_window_dragging();
                    let new_computed = new_style.get_ui().clone__moz_window_dragging();
                    AnimatedProperty::MozWindowDragging(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozWindowShadow => {
                    let old_computed = old_style.get_ui().clone__moz_window_shadow();
                    let new_computed = new_style.get_ui().clone__moz_window_shadow();
                    AnimatedProperty::MozWindowShadow(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ObjectFit => {
                    let old_computed = old_style.get_position().clone_object_fit();
                    let new_computed = new_style.get_position().clone_object_fit();
                    AnimatedProperty::ObjectFit(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OutlineStyle => {
                    let old_computed = old_style.get_outline().clone_outline_style();
                    let new_computed = new_style.get_outline().clone_outline_style();
                    AnimatedProperty::OutlineStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OverflowWrap => {
                    let old_computed = old_style.get_inheritedtext().clone_overflow_wrap();
                    let new_computed = new_style.get_inheritedtext().clone_overflow_wrap();
                    AnimatedProperty::OverflowWrap(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OverflowX => {
                    let old_computed = old_style.get_box().clone_overflow_x();
                    let new_computed = new_style.get_box().clone_overflow_x();
                    AnimatedProperty::OverflowX(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::PageBreakAfter => {
                    let old_computed = old_style.get_box().clone_page_break_after();
                    let new_computed = new_style.get_box().clone_page_break_after();
                    AnimatedProperty::PageBreakAfter(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::PageBreakBefore => {
                    let old_computed = old_style.get_box().clone_page_break_before();
                    let new_computed = new_style.get_box().clone_page_break_before();
                    AnimatedProperty::PageBreakBefore(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::PageBreakInside => {
                    let old_computed = old_style.get_box().clone_page_break_inside();
                    let new_computed = new_style.get_box().clone_page_break_inside();
                    AnimatedProperty::PageBreakInside(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::PaintOrder => {
                    let old_computed = old_style.get_inheritedsvg().clone_paint_order();
                    let new_computed = new_style.get_inheritedsvg().clone_paint_order();
                    AnimatedProperty::PaintOrder(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::PointerEvents => {
                    let old_computed = old_style.get_pointing().clone_pointer_events();
                    let new_computed = new_style.get_pointing().clone_pointer_events();
                    AnimatedProperty::PointerEvents(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Position => {
                    let old_computed = old_style.get_box().clone_position();
                    let new_computed = new_style.get_box().clone_position();
                    AnimatedProperty::Position(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Resize => {
                    let old_computed = old_style.get_box().clone_resize();
                    let new_computed = new_style.get_box().clone_resize();
                    AnimatedProperty::Resize(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::RubyAlign => {
                    let old_computed = old_style.get_inheritedtext().clone_ruby_align();
                    let new_computed = new_style.get_inheritedtext().clone_ruby_align();
                    AnimatedProperty::RubyAlign(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::RubyPosition => {
                    let old_computed = old_style.get_inheritedtext().clone_ruby_position();
                    let new_computed = new_style.get_inheritedtext().clone_ruby_position();
                    AnimatedProperty::RubyPosition(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ScrollBehavior => {
                    let old_computed = old_style.get_box().clone_scroll_behavior();
                    let new_computed = new_style.get_box().clone_scroll_behavior();
                    AnimatedProperty::ScrollBehavior(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ShapeRendering => {
                    let old_computed = old_style.get_inheritedsvg().clone_shape_rendering();
                    let new_computed = new_style.get_inheritedsvg().clone_shape_rendering();
                    AnimatedProperty::ShapeRendering(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::StrokeLinecap => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke_linecap();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke_linecap();
                    AnimatedProperty::StrokeLinecap(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::StrokeLinejoin => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke_linejoin();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke_linejoin();
                    AnimatedProperty::StrokeLinejoin(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TableLayout => {
                    let old_computed = old_style.get_table().clone_table_layout();
                    let new_computed = new_style.get_table().clone_table_layout();
                    AnimatedProperty::TableLayout(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextAlignLast => {
                    let old_computed = old_style.get_inheritedtext().clone_text_align_last();
                    let new_computed = new_style.get_inheritedtext().clone_text_align_last();
                    AnimatedProperty::TextAlignLast(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextAnchor => {
                    let old_computed = old_style.get_inheritedsvg().clone_text_anchor();
                    let new_computed = new_style.get_inheritedsvg().clone_text_anchor();
                    AnimatedProperty::TextAnchor(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextCombineUpright => {
                    let old_computed = old_style.get_inheritedtext().clone_text_combine_upright();
                    let new_computed = new_style.get_inheritedtext().clone_text_combine_upright();
                    AnimatedProperty::TextCombineUpright(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextDecorationLine => {
                    let old_computed = old_style.get_text().clone_text_decoration_line();
                    let new_computed = new_style.get_text().clone_text_decoration_line();
                    AnimatedProperty::TextDecorationLine(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextDecorationStyle => {
                    let old_computed = old_style.get_text().clone_text_decoration_style();
                    let new_computed = new_style.get_text().clone_text_decoration_style();
                    AnimatedProperty::TextDecorationStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextJustify => {
                    let old_computed = old_style.get_inheritedtext().clone_text_justify();
                    let new_computed = new_style.get_inheritedtext().clone_text_justify();
                    AnimatedProperty::TextJustify(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextOrientation => {
                    let old_computed = old_style.get_inheritedbox().clone_text_orientation();
                    let new_computed = new_style.get_inheritedbox().clone_text_orientation();
                    AnimatedProperty::TextOrientation(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextRendering => {
                    let old_computed = old_style.get_inheritedtext().clone_text_rendering();
                    let new_computed = new_style.get_inheritedtext().clone_text_rendering();
                    AnimatedProperty::TextRendering(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextTransform => {
                    let old_computed = old_style.get_inheritedtext().clone_text_transform();
                    let new_computed = new_style.get_inheritedtext().clone_text_transform();
                    AnimatedProperty::TextTransform(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TouchAction => {
                    let old_computed = old_style.get_box().clone_touch_action();
                    let new_computed = new_style.get_box().clone_touch_action();
                    AnimatedProperty::TouchAction(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TransformBox => {
                    let old_computed = old_style.get_box().clone_transform_box();
                    let new_computed = new_style.get_box().clone_transform_box();
                    AnimatedProperty::TransformBox(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TransformStyle => {
                    let old_computed = old_style.get_box().clone_transform_style();
                    let new_computed = new_style.get_box().clone_transform_style();
                    AnimatedProperty::TransformStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::UnicodeBidi => {
                    let old_computed = old_style.get_text().clone_unicode_bidi();
                    let new_computed = new_style.get_text().clone_unicode_bidi();
                    AnimatedProperty::UnicodeBidi(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::VectorEffect => {
                    let old_computed = old_style.get_svg().clone_vector_effect();
                    let new_computed = new_style.get_svg().clone_vector_effect();
                    AnimatedProperty::VectorEffect(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Visibility => {
                    let old_computed = old_style.get_inheritedbox().clone_visibility();
                    let new_computed = new_style.get_inheritedbox().clone_visibility();
                    AnimatedProperty::Visibility(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::WhiteSpace => {
                    let old_computed = old_style.get_inheritedtext().clone_white_space();
                    let new_computed = new_style.get_inheritedtext().clone_white_space();
                    AnimatedProperty::WhiteSpace(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::WordBreak => {
                    let old_computed = old_style.get_inheritedtext().clone_word_break();
                    let new_computed = new_style.get_inheritedtext().clone_word_break();
                    AnimatedProperty::WordBreak(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::WritingMode => {
                    let old_computed = old_style.get_inheritedbox().clone_writing_mode();
                    let new_computed = new_style.get_inheritedbox().clone_writing_mode();
                    AnimatedProperty::WritingMode(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ZIndex => {
                    let old_computed = old_style.get_position().clone_z_index();
                    let new_computed = new_style.get_position().clone_z_index();
                    AnimatedProperty::ZIndex(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozBoxOrdinalGroup => {
                    let old_computed = old_style.get_xul().clone__moz_box_ordinal_group();
                    let new_computed = new_style.get_xul().clone__moz_box_ordinal_group();
                    AnimatedProperty::MozBoxOrdinalGroup(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Order => {
                    let old_computed = old_style.get_position().clone_order();
                    let new_computed = new_style.get_position().clone_order();
                    AnimatedProperty::Order(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OverscrollBehaviorX => {
                    let old_computed = old_style.get_box().clone_overscroll_behavior_x();
                    let new_computed = new_style.get_box().clone_overscroll_behavior_x();
                    AnimatedProperty::OverscrollBehaviorX(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OverscrollBehaviorY => {
                    let old_computed = old_style.get_box().clone_overscroll_behavior_y();
                    let new_computed = new_style.get_box().clone_overscroll_behavior_y();
                    AnimatedProperty::OverscrollBehaviorY(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ScrollSnapTypeX => {
                    let old_computed = old_style.get_box().clone_scroll_snap_type_x();
                    let new_computed = new_style.get_box().clone_scroll_snap_type_x();
                    AnimatedProperty::ScrollSnapTypeX(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ScrollSnapTypeY => {
                    let old_computed = old_style.get_box().clone_scroll_snap_type_y();
                    let new_computed = new_style.get_box().clone_scroll_snap_type_y();
                    AnimatedProperty::ScrollSnapTypeY(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FlexGrow => {
                    let old_computed = old_style.get_position().clone_flex_grow();
                    let new_computed = new_style.get_position().clone_flex_grow();
                    AnimatedProperty::FlexGrow(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::FlexShrink => {
                    let old_computed = old_style.get_position().clone_flex_shrink();
                    let new_computed = new_style.get_position().clone_flex_shrink();
                    AnimatedProperty::FlexShrink(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MozBoxFlex => {
                    let old_computed = old_style.get_xul().clone__moz_box_flex();
                    let new_computed = new_style.get_xul().clone__moz_box_flex();
                    AnimatedProperty::MozBoxFlex(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::FloodOpacity => {
                    let old_computed = old_style.get_svg().clone_flood_opacity();
                    let new_computed = new_style.get_svg().clone_flood_opacity();
                    AnimatedProperty::FloodOpacity(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozWindowOpacity => {
                    let old_computed = old_style.get_ui().clone__moz_window_opacity();
                    let new_computed = new_style.get_ui().clone__moz_window_opacity();
                    AnimatedProperty::MozWindowOpacity(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Opacity => {
                    let old_computed = old_style.get_effects().clone_opacity();
                    let new_computed = new_style.get_effects().clone_opacity();
                    AnimatedProperty::Opacity(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ShapeImageThreshold => {
                    let old_computed = old_style.get_box().clone_shape_image_threshold();
                    let new_computed = new_style.get_box().clone_shape_image_threshold();
                    AnimatedProperty::ShapeImageThreshold(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::StopOpacity => {
                    let old_computed = old_style.get_svg().clone_stop_opacity();
                    let new_computed = new_style.get_svg().clone_stop_opacity();
                    AnimatedProperty::StopOpacity(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderBottomStyle => {
                    let old_computed = old_style.get_border().clone_border_bottom_style();
                    let new_computed = new_style.get_border().clone_border_bottom_style();
                    AnimatedProperty::BorderBottomStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderLeftStyle => {
                    let old_computed = old_style.get_border().clone_border_left_style();
                    let new_computed = new_style.get_border().clone_border_left_style();
                    AnimatedProperty::BorderLeftStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderRightStyle => {
                    let old_computed = old_style.get_border().clone_border_right_style();
                    let new_computed = new_style.get_border().clone_border_right_style();
                    AnimatedProperty::BorderRightStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderTopStyle => {
                    let old_computed = old_style.get_border().clone_border_top_style();
                    let new_computed = new_style.get_border().clone_border_top_style();
                    AnimatedProperty::BorderTopStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundAttachment => {
                    let old_computed = old_style.get_background().clone_background_attachment();
                    let new_computed = new_style.get_background().clone_background_attachment();
                    AnimatedProperty::BackgroundAttachment(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundBlendMode => {
                    let old_computed = old_style.get_background().clone_background_blend_mode();
                    let new_computed = new_style.get_background().clone_background_blend_mode();
                    AnimatedProperty::BackgroundBlendMode(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundClip => {
                    let old_computed = old_style.get_background().clone_background_clip();
                    let new_computed = new_style.get_background().clone_background_clip();
                    AnimatedProperty::BackgroundClip(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundImage => {
                    let old_computed = old_style.get_background().clone_background_image();
                    let new_computed = new_style.get_background().clone_background_image();
                    AnimatedProperty::BackgroundImage(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundOrigin => {
                    let old_computed = old_style.get_background().clone_background_origin();
                    let new_computed = new_style.get_background().clone_background_origin();
                    AnimatedProperty::BackgroundOrigin(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundPositionX => {
                    let old_computed = old_style.get_background().clone_background_position_x();
                    let new_computed = new_style.get_background().clone_background_position_x();
                    AnimatedProperty::BackgroundPositionX(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundPositionY => {
                    let old_computed = old_style.get_background().clone_background_position_y();
                    let new_computed = new_style.get_background().clone_background_position_y();
                    AnimatedProperty::BackgroundPositionY(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundRepeat => {
                    let old_computed = old_style.get_background().clone_background_repeat();
                    let new_computed = new_style.get_background().clone_background_repeat();
                    AnimatedProperty::BackgroundRepeat(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundSize => {
                    let old_computed = old_style.get_background().clone_background_size();
                    let new_computed = new_style.get_background().clone_background_size();
                    AnimatedProperty::BackgroundSize(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderImageOutset => {
                    let old_computed = old_style.get_border().clone_border_image_outset();
                    let new_computed = new_style.get_border().clone_border_image_outset();
                    AnimatedProperty::BorderImageOutset(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderImageSlice => {
                    let old_computed = old_style.get_border().clone_border_image_slice();
                    let new_computed = new_style.get_border().clone_border_image_slice();
                    AnimatedProperty::BorderImageSlice(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderImageSource => {
                    let old_computed = old_style.get_border().clone_border_image_source();
                    let new_computed = new_style.get_border().clone_border_image_source();
                    AnimatedProperty::BorderImageSource(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderImageWidth => {
                    let old_computed = old_style.get_border().clone_border_image_width();
                    let new_computed = new_style.get_border().clone_border_image_width();
                    AnimatedProperty::BorderImageWidth(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderSpacing => {
                    let old_computed = old_style.get_inheritedtable().clone_border_spacing();
                    let new_computed = new_style.get_inheritedtable().clone_border_spacing();
                    AnimatedProperty::BorderSpacing(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BoxShadow => {
                    let old_computed = old_style.get_effects().clone_box_shadow();
                    let new_computed = new_style.get_effects().clone_box_shadow();
                    AnimatedProperty::BoxShadow(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::CaretColor => {
                    let old_computed = old_style.get_pointing().clone_caret_color();
                    let new_computed = new_style.get_pointing().clone_caret_color();
                    AnimatedProperty::CaretColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::ClipPath => {
                    let old_computed = old_style.get_svg().clone_clip_path();
                    let new_computed = new_style.get_svg().clone_clip_path();
                    AnimatedProperty::ClipPath(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Color => {
                    let old_computed = old_style.get_color().clone_color();
                    let new_computed = new_style.get_color().clone_color();
                    AnimatedProperty::Color(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::ColumnGap => {
                    let old_computed = old_style.get_column().clone_column_gap();
                    let new_computed = new_style.get_column().clone_column_gap();
                    AnimatedProperty::ColumnGap(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::ColumnWidth => {
                    let old_computed = old_style.get_column().clone_column_width();
                    let new_computed = new_style.get_column().clone_column_width();
                    AnimatedProperty::ColumnWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::Content => {
                    let old_computed = old_style.get_counters().clone_content();
                    let new_computed = new_style.get_counters().clone_content();
                    AnimatedProperty::Content(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::CounterIncrement => {
                    let old_computed = old_style.get_counters().clone_counter_increment();
                    let new_computed = new_style.get_counters().clone_counter_increment();
                    AnimatedProperty::CounterIncrement(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::CounterReset => {
                    let old_computed = old_style.get_counters().clone_counter_reset();
                    let new_computed = new_style.get_counters().clone_counter_reset();
                    AnimatedProperty::CounterReset(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Cursor => {
                    let old_computed = old_style.get_pointing().clone_cursor();
                    let new_computed = new_style.get_pointing().clone_cursor();
                    AnimatedProperty::Cursor(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Display => {
                    let old_computed = old_style.get_box().clone_display();
                    let new_computed = new_style.get_box().clone_display();
                    AnimatedProperty::Display(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Filter => {
                    let old_computed = old_style.get_effects().clone_filter();
                    let new_computed = new_style.get_effects().clone_filter();
                    AnimatedProperty::Filter(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::FontFamily => {
                    let old_computed = old_style.get_font().clone_font_family();
                    let new_computed = new_style.get_font().clone_font_family();
                    AnimatedProperty::FontFamily(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontFeatureSettings => {
                    let old_computed = old_style.get_font().clone_font_feature_settings();
                    let new_computed = new_style.get_font().clone_font_feature_settings();
                    AnimatedProperty::FontFeatureSettings(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontLanguageOverride => {
                    let old_computed = old_style.get_font().clone_font_language_override();
                    let new_computed = new_style.get_font().clone_font_language_override();
                    AnimatedProperty::FontLanguageOverride(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontSize => {
                    let old_computed = old_style.get_font().clone_font_size();
                    let new_computed = new_style.get_font().clone_font_size();
                    AnimatedProperty::FontSize(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::FontSizeAdjust => {
                    let old_computed = old_style.get_font().clone_font_size_adjust();
                    let new_computed = new_style.get_font().clone_font_size_adjust();
                    AnimatedProperty::FontSizeAdjust(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontVariantAlternates => {
                    let old_computed = old_style.get_font().clone_font_variant_alternates();
                    let new_computed = new_style.get_font().clone_font_variant_alternates();
                    AnimatedProperty::FontVariantAlternates(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontVariantEastAsian => {
                    let old_computed = old_style.get_font().clone_font_variant_east_asian();
                    let new_computed = new_style.get_font().clone_font_variant_east_asian();
                    AnimatedProperty::FontVariantEastAsian(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontVariantLigatures => {
                    let old_computed = old_style.get_font().clone_font_variant_ligatures();
                    let new_computed = new_style.get_font().clone_font_variant_ligatures();
                    AnimatedProperty::FontVariantLigatures(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontVariantNumeric => {
                    let old_computed = old_style.get_font().clone_font_variant_numeric();
                    let new_computed = new_style.get_font().clone_font_variant_numeric();
                    AnimatedProperty::FontVariantNumeric(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontVariationSettings => {
                    let old_computed = old_style.get_font().clone_font_variation_settings();
                    let new_computed = new_style.get_font().clone_font_variation_settings();
                    AnimatedProperty::FontVariationSettings(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridTemplateAreas => {
                    let old_computed = old_style.get_position().clone_grid_template_areas();
                    let new_computed = new_style.get_position().clone_grid_template_areas();
                    AnimatedProperty::GridTemplateAreas(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::LetterSpacing => {
                    let old_computed = old_style.get_inheritedtext().clone_letter_spacing();
                    let new_computed = new_style.get_inheritedtext().clone_letter_spacing();
                    AnimatedProperty::LetterSpacing(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::LineHeight => {
                    let old_computed = old_style.get_inheritedtext().clone_line_height();
                    let new_computed = new_style.get_inheritedtext().clone_line_height();
                    AnimatedProperty::LineHeight(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::ListStyleImage => {
                    let old_computed = old_style.get_list().clone_list_style_image();
                    let new_computed = new_style.get_list().clone_list_style_image();
                    AnimatedProperty::ListStyleImage(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ListStyleType => {
                    let old_computed = old_style.get_list().clone_list_style_type();
                    let new_computed = new_style.get_list().clone_list_style_type();
                    AnimatedProperty::ListStyleType(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskClip => {
                    let old_computed = old_style.get_svg().clone_mask_clip();
                    let new_computed = new_style.get_svg().clone_mask_clip();
                    AnimatedProperty::MaskClip(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskComposite => {
                    let old_computed = old_style.get_svg().clone_mask_composite();
                    let new_computed = new_style.get_svg().clone_mask_composite();
                    AnimatedProperty::MaskComposite(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskImage => {
                    let old_computed = old_style.get_svg().clone_mask_image();
                    let new_computed = new_style.get_svg().clone_mask_image();
                    AnimatedProperty::MaskImage(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskMode => {
                    let old_computed = old_style.get_svg().clone_mask_mode();
                    let new_computed = new_style.get_svg().clone_mask_mode();
                    AnimatedProperty::MaskMode(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskOrigin => {
                    let old_computed = old_style.get_svg().clone_mask_origin();
                    let new_computed = new_style.get_svg().clone_mask_origin();
                    AnimatedProperty::MaskOrigin(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskPositionX => {
                    let old_computed = old_style.get_svg().clone_mask_position_x();
                    let new_computed = new_style.get_svg().clone_mask_position_x();
                    AnimatedProperty::MaskPositionX(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskPositionY => {
                    let old_computed = old_style.get_svg().clone_mask_position_y();
                    let new_computed = new_style.get_svg().clone_mask_position_y();
                    AnimatedProperty::MaskPositionY(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskRepeat => {
                    let old_computed = old_style.get_svg().clone_mask_repeat();
                    let new_computed = new_style.get_svg().clone_mask_repeat();
                    AnimatedProperty::MaskRepeat(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskSize => {
                    let old_computed = old_style.get_svg().clone_mask_size();
                    let new_computed = new_style.get_svg().clone_mask_size();
                    AnimatedProperty::MaskSize(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozTabSize => {
                    let old_computed = old_style.get_inheritedtext().clone__moz_tab_size();
                    let new_computed = new_style.get_inheritedtext().clone__moz_tab_size();
                    AnimatedProperty::MozTabSize(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::OutlineOffset => {
                    let old_computed = old_style.get_outline().clone_outline_offset();
                    let new_computed = new_style.get_outline().clone_outline_offset();
                    AnimatedProperty::OutlineOffset(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OverflowY => {
                    let old_computed = old_style.get_box().clone_overflow_y();
                    let new_computed = new_style.get_box().clone_overflow_y();
                    AnimatedProperty::OverflowY(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Perspective => {
                    let old_computed = old_style.get_box().clone_perspective();
                    let new_computed = new_style.get_box().clone_perspective();
                    AnimatedProperty::Perspective(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::PerspectiveOrigin => {
                    let old_computed = old_style.get_box().clone_perspective_origin();
                    let new_computed = new_style.get_box().clone_perspective_origin();
                    AnimatedProperty::PerspectiveOrigin(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Quotes => {
                    let old_computed = old_style.get_list().clone_quotes();
                    let new_computed = new_style.get_list().clone_quotes();
                    AnimatedProperty::Quotes(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Rotate => {
                    let old_computed = old_style.get_box().clone_rotate();
                    let new_computed = new_style.get_box().clone_rotate();
                    AnimatedProperty::Rotate(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Scale => {
                    let old_computed = old_style.get_box().clone_scale();
                    let new_computed = new_style.get_box().clone_scale();
                    AnimatedProperty::Scale(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ScrollSnapCoordinate => {
                    let old_computed = old_style.get_box().clone_scroll_snap_coordinate();
                    let new_computed = new_style.get_box().clone_scroll_snap_coordinate();
                    AnimatedProperty::ScrollSnapCoordinate(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ShapeOutside => {
                    let old_computed = old_style.get_box().clone_shape_outside();
                    let new_computed = new_style.get_box().clone_shape_outside();
                    AnimatedProperty::ShapeOutside(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::StrokeDasharray => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke_dasharray();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke_dasharray();
                    AnimatedProperty::StrokeDasharray(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::StrokeDashoffset => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke_dashoffset();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke_dashoffset();
                    AnimatedProperty::StrokeDashoffset(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::StrokeMiterlimit => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke_miterlimit();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke_miterlimit();
                    AnimatedProperty::StrokeMiterlimit(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::StrokeWidth => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke_width();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke_width();
                    AnimatedProperty::StrokeWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::TextAlign => {
                    let old_computed = old_style.get_inheritedtext().clone_text_align();
                    let new_computed = new_style.get_inheritedtext().clone_text_align();
                    AnimatedProperty::TextAlign(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextEmphasisPosition => {
                    let old_computed = old_style.get_inheritedtext().clone_text_emphasis_position();
                    let new_computed = new_style.get_inheritedtext().clone_text_emphasis_position();
                    AnimatedProperty::TextEmphasisPosition(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextEmphasisStyle => {
                    let old_computed = old_style.get_inheritedtext().clone_text_emphasis_style();
                    let new_computed = new_style.get_inheritedtext().clone_text_emphasis_style();
                    AnimatedProperty::TextEmphasisStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextIndent => {
                    let old_computed = old_style.get_inheritedtext().clone_text_indent();
                    let new_computed = new_style.get_inheritedtext().clone_text_indent();
                    AnimatedProperty::TextIndent(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextOverflow => {
                    let old_computed = old_style.get_text().clone_text_overflow();
                    let new_computed = new_style.get_text().clone_text_overflow();
                    AnimatedProperty::TextOverflow(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextShadow => {
                    let old_computed = old_style.get_inheritedtext().clone_text_shadow();
                    let new_computed = new_style.get_inheritedtext().clone_text_shadow();
                    AnimatedProperty::TextShadow(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::Translate => {
                    let old_computed = old_style.get_box().clone_translate();
                    let new_computed = new_style.get_box().clone_translate();
                    AnimatedProperty::Translate(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::VerticalAlign => {
                    let old_computed = old_style.get_box().clone_vertical_align();
                    let new_computed = new_style.get_box().clone_vertical_align();
                    AnimatedProperty::VerticalAlign(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::WillChange => {
                    let old_computed = old_style.get_box().clone_will_change();
                    let new_computed = new_style.get_box().clone_will_change();
                    AnimatedProperty::WillChange(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::WordSpacing => {
                    let old_computed = old_style.get_inheritedtext().clone_word_spacing();
                    let new_computed = new_style.get_inheritedtext().clone_word_spacing();
                    AnimatedProperty::WordSpacing(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OverflowClipBoxBlock => {
                    let old_computed = old_style.get_box().clone_overflow_clip_box_block();
                    let new_computed = new_style.get_box().clone_overflow_clip_box_block();
                    AnimatedProperty::OverflowClipBoxBlock(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OverflowClipBoxInline => {
                    let old_computed = old_style.get_box().clone_overflow_clip_box_inline();
                    let new_computed = new_style.get_box().clone_overflow_clip_box_inline();
                    AnimatedProperty::OverflowClipBoxInline(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FillOpacity => {
                    let old_computed = old_style.get_inheritedsvg().clone_fill_opacity();
                    let new_computed = new_style.get_inheritedsvg().clone_fill_opacity();
                    AnimatedProperty::FillOpacity(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::StrokeOpacity => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke_opacity();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke_opacity();
                    AnimatedProperty::StrokeOpacity(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ScrollSnapPointsX => {
                    let old_computed = old_style.get_box().clone_scroll_snap_points_x();
                    let new_computed = new_style.get_box().clone_scroll_snap_points_x();
                    AnimatedProperty::ScrollSnapPointsX(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ScrollSnapPointsY => {
                    let old_computed = old_style.get_box().clone_scroll_snap_points_y();
                    let new_computed = new_style.get_box().clone_scroll_snap_points_y();
                    AnimatedProperty::ScrollSnapPointsY(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozWindowTransform => {
                    let old_computed = old_style.get_ui().clone__moz_window_transform();
                    let new_computed = new_style.get_ui().clone__moz_window_transform();
                    AnimatedProperty::MozWindowTransform(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Transform => {
                    let old_computed = old_style.get_box().clone_transform();
                    let new_computed = new_style.get_box().clone_transform();
                    AnimatedProperty::Transform(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Clip => {
                    let old_computed = old_style.get_effects().clone_clip();
                    let new_computed = new_style.get_effects().clone_clip();
                    AnimatedProperty::Clip(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozImageRegion => {
                    let old_computed = old_style.get_list().clone__moz_image_region();
                    let new_computed = new_style.get_list().clone__moz_image_region();
                    AnimatedProperty::MozImageRegion(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridTemplateColumns => {
                    let old_computed = old_style.get_position().clone_grid_template_columns();
                    let new_computed = new_style.get_position().clone_grid_template_columns();
                    AnimatedProperty::GridTemplateColumns(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridTemplateRows => {
                    let old_computed = old_style.get_position().clone_grid_template_rows();
                    let new_computed = new_style.get_position().clone_grid_template_rows();
                    AnimatedProperty::GridTemplateRows(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ObjectPosition => {
                    let old_computed = old_style.get_position().clone_object_position();
                    let new_computed = new_style.get_position().clone_object_position();
                    AnimatedProperty::ObjectPosition(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ScrollSnapDestination => {
                    let old_computed = old_style.get_box().clone_scroll_snap_destination();
                    let new_computed = new_style.get_box().clone_scroll_snap_destination();
                    AnimatedProperty::ScrollSnapDestination(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Fill => {
                    let old_computed = old_style.get_inheritedsvg().clone_fill();
                    let new_computed = new_style.get_inheritedsvg().clone_fill();
                    AnimatedProperty::Fill(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::Stroke => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke();
                    AnimatedProperty::Stroke(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::GridAutoColumns => {
                    let old_computed = old_style.get_position().clone_grid_auto_columns();
                    let new_computed = new_style.get_position().clone_grid_auto_columns();
                    AnimatedProperty::GridAutoColumns(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridAutoRows => {
                    let old_computed = old_style.get_position().clone_grid_auto_rows();
                    let new_computed = new_style.get_position().clone_grid_auto_rows();
                    AnimatedProperty::GridAutoRows(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozWindowTransformOrigin => {
                    let old_computed = old_style.get_ui().clone__moz_window_transform_origin();
                    let new_computed = new_style.get_ui().clone__moz_window_transform_origin();
                    AnimatedProperty::MozWindowTransformOrigin(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TransformOrigin => {
                    let old_computed = old_style.get_box().clone_transform_origin();
                    let new_computed = new_style.get_box().clone_transform_origin();
                    AnimatedProperty::TransformOrigin(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaxHeight => {
                    let old_computed = old_style.get_position().clone_max_height();
                    let new_computed = new_style.get_position().clone_max_height();
                    AnimatedProperty::MaxHeight(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MaxWidth => {
                    let old_computed = old_style.get_position().clone_max_width();
                    let new_computed = new_style.get_position().clone_max_width();
                    AnimatedProperty::MaxWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::FloodColor => {
                    let old_computed = old_style.get_svg().clone_flood_color();
                    let new_computed = new_style.get_svg().clone_flood_color();
                    AnimatedProperty::FloodColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::LightingColor => {
                    let old_computed = old_style.get_svg().clone_lighting_color();
                    let new_computed = new_style.get_svg().clone_lighting_color();
                    AnimatedProperty::LightingColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MozFontSmoothingBackgroundColor => {
                    let old_computed = old_style.get_font().clone__moz_font_smoothing_background_color();
                    let new_computed = new_style.get_font().clone__moz_font_smoothing_background_color();
                    AnimatedProperty::MozFontSmoothingBackgroundColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::StopColor => {
                    let old_computed = old_style.get_svg().clone_stop_color();
                    let new_computed = new_style.get_svg().clone_stop_color();
                    AnimatedProperty::StopColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MarkerEnd => {
                    let old_computed = old_style.get_inheritedsvg().clone_marker_end();
                    let new_computed = new_style.get_inheritedsvg().clone_marker_end();
                    AnimatedProperty::MarkerEnd(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MarkerMid => {
                    let old_computed = old_style.get_inheritedsvg().clone_marker_mid();
                    let new_computed = new_style.get_inheritedsvg().clone_marker_mid();
                    AnimatedProperty::MarkerMid(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MarkerStart => {
                    let old_computed = old_style.get_inheritedsvg().clone_marker_start();
                    let new_computed = new_style.get_inheritedsvg().clone_marker_start();
                    AnimatedProperty::MarkerStart(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridColumnEnd => {
                    let old_computed = old_style.get_position().clone_grid_column_end();
                    let new_computed = new_style.get_position().clone_grid_column_end();
                    AnimatedProperty::GridColumnEnd(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridColumnStart => {
                    let old_computed = old_style.get_position().clone_grid_column_start();
                    let new_computed = new_style.get_position().clone_grid_column_start();
                    AnimatedProperty::GridColumnStart(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridRowEnd => {
                    let old_computed = old_style.get_position().clone_grid_row_end();
                    let new_computed = new_style.get_position().clone_grid_row_end();
                    AnimatedProperty::GridRowEnd(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridRowStart => {
                    let old_computed = old_style.get_position().clone_grid_row_start();
                    let new_computed = new_style.get_position().clone_grid_row_start();
                    AnimatedProperty::GridRowStart(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderBottomLeftRadius => {
                    let old_computed = old_style.get_border().clone_border_bottom_left_radius();
                    let new_computed = new_style.get_border().clone_border_bottom_left_radius();
                    AnimatedProperty::BorderBottomLeftRadius(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderBottomRightRadius => {
                    let old_computed = old_style.get_border().clone_border_bottom_right_radius();
                    let new_computed = new_style.get_border().clone_border_bottom_right_radius();
                    AnimatedProperty::BorderBottomRightRadius(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderTopLeftRadius => {
                    let old_computed = old_style.get_border().clone_border_top_left_radius();
                    let new_computed = new_style.get_border().clone_border_top_left_radius();
                    AnimatedProperty::BorderTopLeftRadius(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderTopRightRadius => {
                    let old_computed = old_style.get_border().clone_border_top_right_radius();
                    let new_computed = new_style.get_border().clone_border_top_right_radius();
                    AnimatedProperty::BorderTopRightRadius(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MozOutlineRadiusBottomleft => {
                    let old_computed = old_style.get_outline().clone__moz_outline_radius_bottomleft();
                    let new_computed = new_style.get_outline().clone__moz_outline_radius_bottomleft();
                    AnimatedProperty::MozOutlineRadiusBottomleft(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MozOutlineRadiusBottomright => {
                    let old_computed = old_style.get_outline().clone__moz_outline_radius_bottomright();
                    let new_computed = new_style.get_outline().clone__moz_outline_radius_bottomright();
                    AnimatedProperty::MozOutlineRadiusBottomright(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MozOutlineRadiusTopleft => {
                    let old_computed = old_style.get_outline().clone__moz_outline_radius_topleft();
                    let new_computed = new_style.get_outline().clone__moz_outline_radius_topleft();
                    AnimatedProperty::MozOutlineRadiusTopleft(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MozOutlineRadiusTopright => {
                    let old_computed = old_style.get_outline().clone__moz_outline_radius_topright();
                    let new_computed = new_style.get_outline().clone__moz_outline_radius_topright();
                    AnimatedProperty::MozOutlineRadiusTopright(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::FlexBasis => {
                    let old_computed = old_style.get_position().clone_flex_basis();
                    let new_computed = new_style.get_position().clone_flex_basis();
                    AnimatedProperty::FlexBasis(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::Height => {
                    let old_computed = old_style.get_position().clone_height();
                    let new_computed = new_style.get_position().clone_height();
                    AnimatedProperty::Height(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MinHeight => {
                    let old_computed = old_style.get_position().clone_min_height();
                    let new_computed = new_style.get_position().clone_min_height();
                    AnimatedProperty::MinHeight(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MinWidth => {
                    let old_computed = old_style.get_position().clone_min_width();
                    let new_computed = new_style.get_position().clone_min_width();
                    AnimatedProperty::MinWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::Width => {
                    let old_computed = old_style.get_position().clone_width();
                    let new_computed = new_style.get_position().clone_width();
                    AnimatedProperty::Width(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::GridColumnGap => {
                    let old_computed = old_style.get_position().clone_grid_column_gap();
                    let new_computed = new_style.get_position().clone_grid_column_gap();
                    AnimatedProperty::GridColumnGap(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::GridRowGap => {
                    let old_computed = old_style.get_position().clone_grid_row_gap();
                    let new_computed = new_style.get_position().clone_grid_row_gap();
                    AnimatedProperty::GridRowGap(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::PaddingBottom => {
                    let old_computed = old_style.get_padding().clone_padding_bottom();
                    let new_computed = new_style.get_padding().clone_padding_bottom();
                    AnimatedProperty::PaddingBottom(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::PaddingLeft => {
                    let old_computed = old_style.get_padding().clone_padding_left();
                    let new_computed = new_style.get_padding().clone_padding_left();
                    AnimatedProperty::PaddingLeft(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::PaddingRight => {
                    let old_computed = old_style.get_padding().clone_padding_right();
                    let new_computed = new_style.get_padding().clone_padding_right();
                    AnimatedProperty::PaddingRight(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::PaddingTop => {
                    let old_computed = old_style.get_padding().clone_padding_top();
                    let new_computed = new_style.get_padding().clone_padding_top();
                    AnimatedProperty::PaddingTop(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderBottomWidth => {
                    let old_computed = old_style.get_border().clone_border_bottom_width();
                    let new_computed = new_style.get_border().clone_border_bottom_width();
                    AnimatedProperty::BorderBottomWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderLeftWidth => {
                    let old_computed = old_style.get_border().clone_border_left_width();
                    let new_computed = new_style.get_border().clone_border_left_width();
                    AnimatedProperty::BorderLeftWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderRightWidth => {
                    let old_computed = old_style.get_border().clone_border_right_width();
                    let new_computed = new_style.get_border().clone_border_right_width();
                    AnimatedProperty::BorderRightWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderTopWidth => {
                    let old_computed = old_style.get_border().clone_border_top_width();
                    let new_computed = new_style.get_border().clone_border_top_width();
                    AnimatedProperty::BorderTopWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::ColumnRuleWidth => {
                    let old_computed = old_style.get_column().clone_column_rule_width();
                    let new_computed = new_style.get_column().clone_column_rule_width();
                    AnimatedProperty::ColumnRuleWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::OutlineWidth => {
                    let old_computed = old_style.get_outline().clone_outline_width();
                    let new_computed = new_style.get_outline().clone_outline_width();
                    AnimatedProperty::OutlineWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::WebkitTextStrokeWidth => {
                    let old_computed = old_style.get_inheritedtext().clone__webkit_text_stroke_width();
                    let new_computed = new_style.get_inheritedtext().clone__webkit_text_stroke_width();
                    AnimatedProperty::WebkitTextStrokeWidth(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundColor => {
                    let old_computed = old_style.get_background().clone_background_color();
                    let new_computed = new_style.get_background().clone_background_color();
                    AnimatedProperty::BackgroundColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderBottomColor => {
                    let old_computed = old_style.get_border().clone_border_bottom_color();
                    let new_computed = new_style.get_border().clone_border_bottom_color();
                    AnimatedProperty::BorderBottomColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderLeftColor => {
                    let old_computed = old_style.get_border().clone_border_left_color();
                    let new_computed = new_style.get_border().clone_border_left_color();
                    AnimatedProperty::BorderLeftColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderRightColor => {
                    let old_computed = old_style.get_border().clone_border_right_color();
                    let new_computed = new_style.get_border().clone_border_right_color();
                    AnimatedProperty::BorderRightColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderTopColor => {
                    let old_computed = old_style.get_border().clone_border_top_color();
                    let new_computed = new_style.get_border().clone_border_top_color();
                    AnimatedProperty::BorderTopColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::ColumnRuleColor => {
                    let old_computed = old_style.get_column().clone_column_rule_color();
                    let new_computed = new_style.get_column().clone_column_rule_color();
                    AnimatedProperty::ColumnRuleColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::OutlineColor => {
                    let old_computed = old_style.get_outline().clone_outline_color();
                    let new_computed = new_style.get_outline().clone_outline_color();
                    AnimatedProperty::OutlineColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::TextDecorationColor => {
                    let old_computed = old_style.get_text().clone_text_decoration_color();
                    let new_computed = new_style.get_text().clone_text_decoration_color();
                    AnimatedProperty::TextDecorationColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::TextEmphasisColor => {
                    let old_computed = old_style.get_inheritedtext().clone_text_emphasis_color();
                    let new_computed = new_style.get_inheritedtext().clone_text_emphasis_color();
                    AnimatedProperty::TextEmphasisColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::WebkitTextFillColor => {
                    let old_computed = old_style.get_inheritedtext().clone__webkit_text_fill_color();
                    let new_computed = new_style.get_inheritedtext().clone__webkit_text_fill_color();
                    AnimatedProperty::WebkitTextFillColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::WebkitTextStrokeColor => {
                    let old_computed = old_style.get_inheritedtext().clone__webkit_text_stroke_color();
                    let new_computed = new_style.get_inheritedtext().clone__webkit_text_stroke_color();
                    AnimatedProperty::WebkitTextStrokeColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::Bottom => {
                    let old_computed = old_style.get_position().clone_bottom();
                    let new_computed = new_style.get_position().clone_bottom();
                    AnimatedProperty::Bottom(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Left => {
                    let old_computed = old_style.get_position().clone_left();
                    let new_computed = new_style.get_position().clone_left();
                    AnimatedProperty::Left(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MarginBottom => {
                    let old_computed = old_style.get_margin().clone_margin_bottom();
                    let new_computed = new_style.get_margin().clone_margin_bottom();
                    AnimatedProperty::MarginBottom(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MarginLeft => {
                    let old_computed = old_style.get_margin().clone_margin_left();
                    let new_computed = new_style.get_margin().clone_margin_left();
                    AnimatedProperty::MarginLeft(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MarginRight => {
                    let old_computed = old_style.get_margin().clone_margin_right();
                    let new_computed = new_style.get_margin().clone_margin_right();
                    AnimatedProperty::MarginRight(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MarginTop => {
                    let old_computed = old_style.get_margin().clone_margin_top();
                    let new_computed = new_style.get_margin().clone_margin_top();
                    AnimatedProperty::MarginTop(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Right => {
                    let old_computed = old_style.get_position().clone_right();
                    let new_computed = new_style.get_position().clone_right();
                    AnimatedProperty::Right(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Top => {
                    let old_computed = old_style.get_position().clone_top();
                    let new_computed = new_style.get_position().clone_top();
                    AnimatedProperty::Top(
                        old_computed,
                        new_computed,
                    )
                }
            _ => return None,
        })
    }
}

/// A collection of AnimationValue that were composed on an element.
/// This HashMap stores the values that are the last AnimationValue to be
/// composed for each TransitionProperty.
#[cfg(feature = "gecko")]
pub type AnimationValueMap = FnvHashMap<LonghandId, AnimationValue>;
#[cfg(feature = "gecko")]
unsafe impl HasFFI for AnimationValueMap {
    type FFIType = RawServoAnimationValueMap;
}
#[cfg(feature = "gecko")]
unsafe impl HasSimpleFFI for AnimationValueMap {}

/// An enum to represent a single computed value belonging to an animated
/// property in order to be interpolated with another one. When interpolating,
/// both values need to belong to the same property.
///
/// This is different to AnimatedProperty in the sense that AnimatedProperty
/// also knows the final value to be used during the animation.
///
/// This is to be used in Gecko integration code.
///
/// FIXME: We need to add a path for custom properties, but that's trivial after
/// this (is a similar path to that of PropertyDeclaration).
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
#[derive(Debug)]
#[repr(u16)]
pub enum AnimationValue {
    /// `align-content`
    AlignContent(<::values::specified::AlignContent as ToComputedValue>::ComputedValue),
    /// `align-items`
    AlignItems(<::values::specified::AlignItems as ToComputedValue>::ComputedValue),
    /// `align-self`
    AlignSelf(<::values::specified::AlignSelf as ToComputedValue>::ComputedValue),
    /// `backface-visibility`
    BackfaceVisibility(<longhands::backface_visibility::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `border-collapse`
    BorderCollapse(<longhands::border_collapse::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `border-image-repeat`
    BorderImageRepeat(<::values::specified::BorderImageRepeat as ToComputedValue>::ComputedValue),
    /// `box-decoration-break`
    BoxDecorationBreak(<longhands::box_decoration_break::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `box-sizing`
    BoxSizing(<longhands::box_sizing::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `caption-side`
    CaptionSide(<longhands::caption_side::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `clear`
    Clear(<longhands::clear::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `clip-rule`
    ClipRule(<longhands::clip_rule::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `color-adjust`
    ColorAdjust(<longhands::color_adjust::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `color-interpolation`
    ColorInterpolation(<longhands::color_interpolation::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `color-interpolation-filters`
    ColorInterpolationFilters(<longhands::color_interpolation_filters::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `column-count`
    ColumnCount(<<::values::specified::ColumnCount as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `column-fill`
    ColumnFill(<longhands::column_fill::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `column-rule-style`
    ColumnRuleStyle(<longhands::column_rule_style::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `column-span`
    ColumnSpan(<longhands::column_span::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `contain`
    Contain(<::values::specified::Contain as ToComputedValue>::ComputedValue),
    /// `direction`
    Direction(<longhands::direction::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `dominant-baseline`
    DominantBaseline(<longhands::dominant_baseline::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `empty-cells`
    EmptyCells(<longhands::empty_cells::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `fill-rule`
    FillRule(<longhands::fill_rule::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `flex-direction`
    FlexDirection(<longhands::flex_direction::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `flex-wrap`
    FlexWrap(<longhands::flex_wrap::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `float`
    Float(<longhands::float::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `font-kerning`
    FontKerning(<longhands::font_kerning::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `font-optical-sizing`
    FontOpticalSizing(<longhands::font_optical_sizing::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `font-stretch`
    FontStretch(<longhands::font_stretch::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `font-style`
    FontStyle(<longhands::font_style::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `font-synthesis`
    FontSynthesis(<::values::specified::FontSynthesis as ToComputedValue>::ComputedValue),
    /// `font-variant-caps`
    FontVariantCaps(<longhands::font_variant_caps::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `font-variant-position`
    FontVariantPosition(<longhands::font_variant_position::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `font-weight`
    FontWeight(<::values::specified::FontWeight as ToComputedValue>::ComputedValue),
    /// `grid-auto-flow`
    GridAutoFlow(<::values::specified::GridAutoFlow as ToComputedValue>::ComputedValue),
    /// `hyphens`
    Hyphens(<longhands::hyphens::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `image-orientation`
    ImageOrientation(<::values::specified::ImageOrientation as ToComputedValue>::ComputedValue),
    /// `image-rendering`
    ImageRendering(<longhands::image_rendering::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `ime-mode`
    ImeMode(<longhands::ime_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `initial-letter`
    InitialLetter(<::values::specified::InitialLetter as ToComputedValue>::ComputedValue),
    /// `isolation`
    Isolation(<longhands::isolation::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `justify-content`
    JustifyContent(<::values::specified::JustifyContent as ToComputedValue>::ComputedValue),
    /// `justify-items`
    JustifyItems(<::values::specified::JustifyItems as ToComputedValue>::ComputedValue),
    /// `justify-self`
    JustifySelf(<::values::specified::JustifySelf as ToComputedValue>::ComputedValue),
    /// `list-style-position`
    ListStylePosition(<longhands::list_style_position::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-type`
    MaskType(<longhands::mask_type::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mix-blend-mode`
    MixBlendMode(<longhands::mix_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-appearance`
    MozAppearance(<longhands::_moz_appearance::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-box-align`
    MozBoxAlign(<longhands::_moz_box_align::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-box-direction`
    MozBoxDirection(<longhands::_moz_box_direction::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-box-orient`
    MozBoxOrient(<longhands::_moz_box_orient::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-box-pack`
    MozBoxPack(<longhands::_moz_box_pack::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-control-character-visibility` (not animatable)
    MozControlCharacterVisibility(Void),
    /// `-moz-float-edge`
    MozFloatEdge(<longhands::_moz_float_edge::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-force-broken-image-icon`
    MozForceBrokenImageIcon(<::values::specified::MozForceBrokenImageIcon as ToComputedValue>::ComputedValue),
    /// `-moz-math-display` (not animatable)
    MozMathDisplay(Void),
    /// `-moz-math-variant` (not animatable)
    MozMathVariant(Void),
    /// `-moz-min-font-size-ratio` (not animatable)
    MozMinFontSizeRatio(Void),
    /// `-moz-orient`
    MozOrient(<longhands::_moz_orient::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-osx-font-smoothing`
    MozOsxFontSmoothing(<longhands::_moz_osx_font_smoothing::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-script-level` (not animatable)
    MozScriptLevel(Void),
    /// `-moz-script-min-size` (not animatable)
    MozScriptMinSize(Void),
    /// `-moz-script-size-multiplier` (not animatable)
    MozScriptSizeMultiplier(Void),
    /// `-moz-stack-sizing`
    MozStackSizing(<longhands::_moz_stack_sizing::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-text-size-adjust`
    MozTextSizeAdjust(<longhands::_moz_text_size_adjust::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-top-layer` (not animatable)
    MozTopLayer(Void),
    /// `-moz-user-focus`
    MozUserFocus(<longhands::_moz_user_focus::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-user-input`
    MozUserInput(<longhands::_moz_user_input::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-user-modify`
    MozUserModify(<longhands::_moz_user_modify::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-user-select`
    MozUserSelect(<longhands::_moz_user_select::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-window-dragging`
    MozWindowDragging(<longhands::_moz_window_dragging::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-window-shadow`
    MozWindowShadow(<longhands::_moz_window_shadow::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `object-fit`
    ObjectFit(<longhands::object_fit::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `outline-style`
    OutlineStyle(<::values::specified::OutlineStyle as ToComputedValue>::ComputedValue),
    /// `overflow-wrap`
    OverflowWrap(<longhands::overflow_wrap::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `overflow-x`
    OverflowX(<longhands::overflow_x::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `page-break-after`
    PageBreakAfter(<longhands::page_break_after::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `page-break-before`
    PageBreakBefore(<longhands::page_break_before::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `page-break-inside`
    PageBreakInside(<longhands::page_break_inside::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `paint-order`
    PaintOrder(<::values::specified::SVGPaintOrder as ToComputedValue>::ComputedValue),
    /// `pointer-events`
    PointerEvents(<longhands::pointer_events::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `position`
    Position(<longhands::position::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `resize`
    Resize(<longhands::resize::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `ruby-align`
    RubyAlign(<longhands::ruby_align::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `ruby-position`
    RubyPosition(<longhands::ruby_position::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `scroll-behavior`
    ScrollBehavior(<longhands::scroll_behavior::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `shape-rendering`
    ShapeRendering(<longhands::shape_rendering::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `stroke-linecap`
    StrokeLinecap(<longhands::stroke_linecap::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `stroke-linejoin`
    StrokeLinejoin(<longhands::stroke_linejoin::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `table-layout`
    TableLayout(<longhands::table_layout::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `text-align-last`
    TextAlignLast(<longhands::text_align_last::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `text-anchor`
    TextAnchor(<longhands::text_anchor::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `text-combine-upright`
    TextCombineUpright(<longhands::text_combine_upright::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `text-decoration-line`
    TextDecorationLine(<::values::specified::TextDecorationLine as ToComputedValue>::ComputedValue),
    /// `text-decoration-style`
    TextDecorationStyle(<longhands::text_decoration_style::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `text-justify`
    TextJustify(<longhands::text_justify::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `text-orientation`
    TextOrientation(<longhands::text_orientation::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `text-rendering`
    TextRendering(<longhands::text_rendering::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `text-transform`
    TextTransform(<longhands::text_transform::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `touch-action`
    TouchAction(<::values::specified::TouchAction as ToComputedValue>::ComputedValue),
    /// `transform-box`
    TransformBox(<longhands::transform_box::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `transform-style`
    TransformStyle(<::values::specified::TransformStyle as ToComputedValue>::ComputedValue),
    /// `unicode-bidi`
    UnicodeBidi(<longhands::unicode_bidi::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `vector-effect`
    VectorEffect(<longhands::vector_effect::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `visibility`
    Visibility(<longhands::visibility::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `white-space`
    WhiteSpace(<longhands::white_space::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `word-break`
    WordBreak(<longhands::word_break::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `writing-mode`
    WritingMode(<longhands::writing_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-x-span` (not animatable)
    XSpan(Void),
    /// `-x-text-zoom` (not animatable)
    XTextZoom(Void),
    /// `z-index`
    ZIndex(<::values::specified::ZIndex as ToComputedValue>::ComputedValue),
    /// `-moz-box-ordinal-group`
    MozBoxOrdinalGroup(<::values::specified::Integer as ToComputedValue>::ComputedValue),
    /// `order`
    Order(<::values::specified::Integer as ToComputedValue>::ComputedValue),
    /// `overscroll-behavior-x`
    OverscrollBehaviorX(<::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue),
    /// `overscroll-behavior-y`
    OverscrollBehaviorY(<::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue),
    /// `scroll-snap-type-x`
    ScrollSnapTypeX(<::values::specified::ScrollSnapType as ToComputedValue>::ComputedValue),
    /// `scroll-snap-type-y`
    ScrollSnapTypeY(<::values::specified::ScrollSnapType as ToComputedValue>::ComputedValue),
    /// `flex-grow`
    FlexGrow(<<::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `flex-shrink`
    FlexShrink(<<::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `-moz-box-flex`
    MozBoxFlex(<<::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `flood-opacity`
    FloodOpacity(<::values::specified::Opacity as ToComputedValue>::ComputedValue),
    /// `-moz-window-opacity`
    MozWindowOpacity(<::values::specified::Opacity as ToComputedValue>::ComputedValue),
    /// `opacity`
    Opacity(<::values::specified::Opacity as ToComputedValue>::ComputedValue),
    /// `shape-image-threshold`
    ShapeImageThreshold(<::values::specified::Opacity as ToComputedValue>::ComputedValue),
    /// `stop-opacity`
    StopOpacity(<::values::specified::Opacity as ToComputedValue>::ComputedValue),
    /// `border-block-end-style` (not animatable)
    BorderBlockEndStyle(Void),
    /// `border-block-start-style` (not animatable)
    BorderBlockStartStyle(Void),
    /// `border-bottom-style`
    BorderBottomStyle(<::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
    /// `border-inline-end-style` (not animatable)
    BorderInlineEndStyle(Void),
    /// `border-inline-start-style` (not animatable)
    BorderInlineStartStyle(Void),
    /// `border-left-style`
    BorderLeftStyle(<::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
    /// `border-right-style`
    BorderRightStyle(<::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
    /// `border-top-style`
    BorderTopStyle(<::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
    /// `animation-delay` (not animatable)
    AnimationDelay(Void),
    /// `animation-direction` (not animatable)
    AnimationDirection(Void),
    /// `animation-duration` (not animatable)
    AnimationDuration(Void),
    /// `animation-fill-mode` (not animatable)
    AnimationFillMode(Void),
    /// `animation-iteration-count` (not animatable)
    AnimationIterationCount(Void),
    /// `animation-name` (not animatable)
    AnimationName(Void),
    /// `animation-play-state` (not animatable)
    AnimationPlayState(Void),
    /// `animation-timing-function` (not animatable)
    AnimationTimingFunction(Void),
    /// `background-attachment`
    BackgroundAttachment(<longhands::background_attachment::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-blend-mode`
    BackgroundBlendMode(<longhands::background_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-clip`
    BackgroundClip(<longhands::background_clip::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-image`
    BackgroundImage(<longhands::background_image::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-origin`
    BackgroundOrigin(<longhands::background_origin::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-position-x`
    BackgroundPositionX(<longhands::background_position_x::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-position-y`
    BackgroundPositionY(<longhands::background_position_y::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-repeat`
    BackgroundRepeat(<longhands::background_repeat::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-size`
    BackgroundSize(<<longhands::background_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-image-outset`
    BorderImageOutset(<::values::specified::LengthOrNumberRect as ToComputedValue>::ComputedValue),
    /// `border-image-slice`
    BorderImageSlice(<::values::specified::BorderImageSlice as ToComputedValue>::ComputedValue),
    /// `border-image-source`
    BorderImageSource(<::values::specified::ImageLayer as ToComputedValue>::ComputedValue),
    /// `border-image-width`
    BorderImageWidth(<::values::specified::BorderImageWidth as ToComputedValue>::ComputedValue),
    /// `border-spacing`
    BorderSpacing(<<::values::specified::BorderSpacing as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `box-shadow`
    BoxShadow(<<longhands::box_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `caret-color`
    CaretColor(<<::values::specified::CaretColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `clip-path`
    ClipPath(<::values::specified::basic_shape::ClippingShape as ToComputedValue>::ComputedValue),
    /// `color`
    Color(<<::values::specified::ColorPropertyValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `column-gap`
    ColumnGap(<<::values::specified::length::NonNegativeLengthOrNormal as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `column-width`
    ColumnWidth(<<::values::specified::length::NonNegativeLengthOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `content`
    Content(<::values::specified::Content as ToComputedValue>::ComputedValue),
    /// `counter-increment`
    CounterIncrement(<::values::specified::CounterIncrement as ToComputedValue>::ComputedValue),
    /// `counter-reset`
    CounterReset(<::values::specified::CounterReset as ToComputedValue>::ComputedValue),
    /// `cursor`
    Cursor(<::values::specified::Cursor as ToComputedValue>::ComputedValue),
    /// `display`
    Display(<::values::specified::Display as ToComputedValue>::ComputedValue),
    /// `filter`
    Filter(<<longhands::filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `font-family`
    FontFamily(<::values::specified::FontFamily as ToComputedValue>::ComputedValue),
    /// `font-feature-settings`
    FontFeatureSettings(<::values::specified::FontFeatureSettings as ToComputedValue>::ComputedValue),
    /// `font-language-override`
    FontLanguageOverride(<::values::specified::FontLanguageOverride as ToComputedValue>::ComputedValue),
    /// `font-size`
    FontSize(<<::values::specified::FontSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `font-size-adjust`
    FontSizeAdjust(<::values::specified::FontSizeAdjust as ToComputedValue>::ComputedValue),
    /// `font-variant-alternates`
    FontVariantAlternates(<::values::specified::FontVariantAlternates as ToComputedValue>::ComputedValue),
    /// `font-variant-east-asian`
    FontVariantEastAsian(<::values::specified::FontVariantEastAsian as ToComputedValue>::ComputedValue),
    /// `font-variant-ligatures`
    FontVariantLigatures(<::values::specified::FontVariantLigatures as ToComputedValue>::ComputedValue),
    /// `font-variant-numeric`
    FontVariantNumeric(<::values::specified::FontVariantNumeric as ToComputedValue>::ComputedValue),
    /// `font-variation-settings`
    FontVariationSettings(<::values::specified::FontVariationSettings as ToComputedValue>::ComputedValue),
    /// `grid-template-areas`
    GridTemplateAreas(<::values::specified::GridTemplateAreas as ToComputedValue>::ComputedValue),
    /// `letter-spacing`
    LetterSpacing(<::values::specified::LetterSpacing as ToComputedValue>::ComputedValue),
    /// `line-height`
    LineHeight(<<::values::specified::LineHeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `list-style-image`
    ListStyleImage(<::values::specified::ListStyleImage as ToComputedValue>::ComputedValue),
    /// `list-style-type`
    ListStyleType(<::values::specified::ListStyleType as ToComputedValue>::ComputedValue),
    /// `mask-clip`
    MaskClip(<longhands::mask_clip::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-composite`
    MaskComposite(<longhands::mask_composite::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-image`
    MaskImage(<longhands::mask_image::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-mode`
    MaskMode(<longhands::mask_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-origin`
    MaskOrigin(<longhands::mask_origin::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-position-x`
    MaskPositionX(<longhands::mask_position_x::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-position-y`
    MaskPositionY(<longhands::mask_position_y::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-repeat`
    MaskRepeat(<longhands::mask_repeat::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-size`
    MaskSize(<longhands::mask_size::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-context-properties` (not animatable)
    MozContextProperties(Void),
    /// `-moz-tab-size`
    MozTabSize(<<::values::specified::MozTabSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `outline-offset`
    OutlineOffset(<::values::specified::Length as ToComputedValue>::ComputedValue),
    /// `overflow-y`
    OverflowY(<longhands::overflow_y::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `perspective`
    Perspective(<<::values::specified::Perspective as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `perspective-origin`
    PerspectiveOrigin(<::values::specified::position::Position as ToComputedValue>::ComputedValue),
    /// `quotes`
    Quotes(<::values::specified::Quotes as ToComputedValue>::ComputedValue),
    /// `rotate`
    Rotate(<::values::specified::Rotate as ToComputedValue>::ComputedValue),
    /// `scale`
    Scale(<::values::specified::Scale as ToComputedValue>::ComputedValue),
    /// `scroll-snap-coordinate`
    ScrollSnapCoordinate(<longhands::scroll_snap_coordinate::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `shape-outside`
    ShapeOutside(<::values::specified::basic_shape::FloatAreaShape as ToComputedValue>::ComputedValue),
    /// `stroke-dasharray`
    StrokeDasharray(<<::values::specified::SVGStrokeDashArray as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `stroke-dashoffset`
    StrokeDashoffset(<::values::specified::SVGLength as ToComputedValue>::ComputedValue),
    /// `stroke-miterlimit`
    StrokeMiterlimit(<<::values::specified::GreaterThanOrEqualToOneNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `stroke-width`
    StrokeWidth(<<::values::specified::SVGWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `text-align`
    TextAlign(<::values::specified::TextAlign as ToComputedValue>::ComputedValue),
    /// `text-emphasis-position`
    TextEmphasisPosition(<longhands::text_emphasis_position::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `text-emphasis-style`
    TextEmphasisStyle(<::values::specified::TextEmphasisStyle as ToComputedValue>::ComputedValue),
    /// `text-indent`
    TextIndent(<::values::specified::LengthOrPercentage as ToComputedValue>::ComputedValue),
    /// `text-overflow`
    TextOverflow(<::values::specified::TextOverflow as ToComputedValue>::ComputedValue),
    /// `text-shadow`
    TextShadow(<<longhands::text_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `transition-delay` (not animatable)
    TransitionDelay(Void),
    /// `transition-duration` (not animatable)
    TransitionDuration(Void),
    /// `transition-property` (not animatable)
    TransitionProperty(Void),
    /// `transition-timing-function` (not animatable)
    TransitionTimingFunction(Void),
    /// `translate`
    Translate(<::values::specified::Translate as ToComputedValue>::ComputedValue),
    /// `vertical-align`
    VerticalAlign(<::values::specified::VerticalAlign as ToComputedValue>::ComputedValue),
    /// `will-change`
    WillChange(<::values::specified::WillChange as ToComputedValue>::ComputedValue),
    /// `word-spacing`
    WordSpacing(<::values::specified::WordSpacing as ToComputedValue>::ComputedValue),
    /// `-x-lang` (not animatable)
    XLang(Void),
    /// `overflow-clip-box-block`
    OverflowClipBoxBlock(<::values::specified::OverflowClipBox as ToComputedValue>::ComputedValue),
    /// `overflow-clip-box-inline`
    OverflowClipBoxInline(<::values::specified::OverflowClipBox as ToComputedValue>::ComputedValue),
    /// `fill-opacity`
    FillOpacity(<::values::specified::SVGOpacity as ToComputedValue>::ComputedValue),
    /// `stroke-opacity`
    StrokeOpacity(<::values::specified::SVGOpacity as ToComputedValue>::ComputedValue),
    /// `scroll-snap-points-x`
    ScrollSnapPointsX(<::values::specified::ScrollSnapPoint as ToComputedValue>::ComputedValue),
    /// `scroll-snap-points-y`
    ScrollSnapPointsY(<::values::specified::ScrollSnapPoint as ToComputedValue>::ComputedValue),
    /// `-moz-window-transform`
    MozWindowTransform(<::values::specified::Transform as ToComputedValue>::ComputedValue),
    /// `transform`
    Transform(<::values::specified::Transform as ToComputedValue>::ComputedValue),
    /// `clip`
    Clip(<::values::specified::ClipRectOrAuto as ToComputedValue>::ComputedValue),
    /// `-moz-image-region`
    MozImageRegion(<::values::specified::ClipRectOrAuto as ToComputedValue>::ComputedValue),
    /// `grid-template-columns`
    GridTemplateColumns(<::values::specified::GridTemplateComponent as ToComputedValue>::ComputedValue),
    /// `grid-template-rows`
    GridTemplateRows(<::values::specified::GridTemplateComponent as ToComputedValue>::ComputedValue),
    /// `object-position`
    ObjectPosition(<::values::specified::Position as ToComputedValue>::ComputedValue),
    /// `scroll-snap-destination`
    ScrollSnapDestination(<::values::specified::Position as ToComputedValue>::ComputedValue),
    /// `fill`
    Fill(<<::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `stroke`
    Stroke(<<::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `grid-auto-columns`
    GridAutoColumns(<::values::specified::TrackSize as ToComputedValue>::ComputedValue),
    /// `grid-auto-rows`
    GridAutoRows(<::values::specified::TrackSize as ToComputedValue>::ComputedValue),
    /// `-moz-window-transform-origin`
    MozWindowTransformOrigin(<::values::specified::TransformOrigin as ToComputedValue>::ComputedValue),
    /// `transform-origin`
    TransformOrigin(<::values::specified::TransformOrigin as ToComputedValue>::ComputedValue),
    /// `max-block-size` (not animatable)
    MaxBlockSize(Void),
    /// `max-height`
    MaxHeight(<<::values::specified::MaxLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `max-inline-size` (not animatable)
    MaxInlineSize(Void),
    /// `max-width`
    MaxWidth(<<::values::specified::MaxLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `flood-color`
    FloodColor(<<::values::specified::RGBAColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `lighting-color`
    LightingColor(<<::values::specified::RGBAColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `-moz-font-smoothing-background-color`
    MozFontSmoothingBackgroundColor(<<::values::specified::RGBAColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `stop-color`
    StopColor(<<::values::specified::RGBAColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `marker-end`
    MarkerEnd(<::values::specified::UrlOrNone as ToComputedValue>::ComputedValue),
    /// `marker-mid`
    MarkerMid(<::values::specified::UrlOrNone as ToComputedValue>::ComputedValue),
    /// `marker-start`
    MarkerStart(<::values::specified::UrlOrNone as ToComputedValue>::ComputedValue),
    /// `-moz-binding` (not animatable)
    MozBinding(Void),
    /// `grid-column-end`
    GridColumnEnd(<::values::specified::GridLine as ToComputedValue>::ComputedValue),
    /// `grid-column-start`
    GridColumnStart(<::values::specified::GridLine as ToComputedValue>::ComputedValue),
    /// `grid-row-end`
    GridRowEnd(<::values::specified::GridLine as ToComputedValue>::ComputedValue),
    /// `grid-row-start`
    GridRowStart(<::values::specified::GridLine as ToComputedValue>::ComputedValue),
    /// `border-bottom-left-radius`
    BorderBottomLeftRadius(<<::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-bottom-right-radius`
    BorderBottomRightRadius(<<::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-top-left-radius`
    BorderTopLeftRadius(<<::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-top-right-radius`
    BorderTopRightRadius(<<::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `-moz-outline-radius-bottomleft`
    MozOutlineRadiusBottomleft(<<::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `-moz-outline-radius-bottomright`
    MozOutlineRadiusBottomright(<<::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `-moz-outline-radius-topleft`
    MozOutlineRadiusTopleft(<<::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `-moz-outline-radius-topright`
    MozOutlineRadiusTopright(<<::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `block-size` (not animatable)
    BlockSize(Void),
    /// `flex-basis`
    FlexBasis(<<::values::specified::MozLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `height`
    Height(<<::values::specified::MozLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `inline-size` (not animatable)
    InlineSize(Void),
    /// `min-block-size` (not animatable)
    MinBlockSize(Void),
    /// `min-height`
    MinHeight(<<::values::specified::MozLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `min-inline-size` (not animatable)
    MinInlineSize(Void),
    /// `min-width`
    MinWidth(<<::values::specified::MozLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `width`
    Width(<<::values::specified::MozLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `grid-column-gap`
    GridColumnGap(<<::values::specified::NonNegativeLengthOrPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `grid-row-gap`
    GridRowGap(<<::values::specified::NonNegativeLengthOrPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `padding-block-end` (not animatable)
    PaddingBlockEnd(Void),
    /// `padding-block-start` (not animatable)
    PaddingBlockStart(Void),
    /// `padding-bottom`
    PaddingBottom(<<::values::specified::NonNegativeLengthOrPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `padding-inline-end` (not animatable)
    PaddingInlineEnd(Void),
    /// `padding-inline-start` (not animatable)
    PaddingInlineStart(Void),
    /// `padding-left`
    PaddingLeft(<<::values::specified::NonNegativeLengthOrPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `padding-right`
    PaddingRight(<<::values::specified::NonNegativeLengthOrPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `padding-top`
    PaddingTop(<<::values::specified::NonNegativeLengthOrPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-block-end-width` (not animatable)
    BorderBlockEndWidth(Void),
    /// `border-block-start-width` (not animatable)
    BorderBlockStartWidth(Void),
    /// `border-bottom-width`
    BorderBottomWidth(<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-inline-end-width` (not animatable)
    BorderInlineEndWidth(Void),
    /// `border-inline-start-width` (not animatable)
    BorderInlineStartWidth(Void),
    /// `border-left-width`
    BorderLeftWidth(<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-right-width`
    BorderRightWidth(<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-top-width`
    BorderTopWidth(<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `column-rule-width`
    ColumnRuleWidth(<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `outline-width`
    OutlineWidth(<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `-webkit-text-stroke-width`
    WebkitTextStrokeWidth(<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue),
    /// `background-color`
    BackgroundColor(<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-block-end-color` (not animatable)
    BorderBlockEndColor(Void),
    /// `border-block-start-color` (not animatable)
    BorderBlockStartColor(Void),
    /// `border-bottom-color`
    BorderBottomColor(<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-inline-end-color` (not animatable)
    BorderInlineEndColor(Void),
    /// `border-inline-start-color` (not animatable)
    BorderInlineStartColor(Void),
    /// `border-left-color`
    BorderLeftColor(<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-right-color`
    BorderRightColor(<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-top-color`
    BorderTopColor(<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `column-rule-color`
    ColumnRuleColor(<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `outline-color`
    OutlineColor(<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `text-decoration-color`
    TextDecorationColor(<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `text-emphasis-color`
    TextEmphasisColor(<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `-webkit-text-fill-color`
    WebkitTextFillColor(<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `-webkit-text-stroke-color`
    WebkitTextStrokeColor(<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `bottom`
    Bottom(<::values::specified::LengthOrPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `left`
    Left(<::values::specified::LengthOrPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `margin-block-end` (not animatable)
    MarginBlockEnd(Void),
    /// `margin-block-start` (not animatable)
    MarginBlockStart(Void),
    /// `margin-bottom`
    MarginBottom(<::values::specified::LengthOrPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `margin-inline-end` (not animatable)
    MarginInlineEnd(Void),
    /// `margin-inline-start` (not animatable)
    MarginInlineStart(Void),
    /// `margin-left`
    MarginLeft(<::values::specified::LengthOrPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `margin-right`
    MarginRight(<::values::specified::LengthOrPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `margin-top`
    MarginTop(<::values::specified::LengthOrPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `offset-block-end` (not animatable)
    OffsetBlockEnd(Void),
    /// `offset-block-start` (not animatable)
    OffsetBlockStart(Void),
    /// `offset-inline-end` (not animatable)
    OffsetInlineEnd(Void),
    /// `offset-inline-start` (not animatable)
    OffsetInlineStart(Void),
    /// `right`
    Right(<::values::specified::LengthOrPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `top`
    Top(<::values::specified::LengthOrPercentageOrAuto as ToComputedValue>::ComputedValue),
}



#[repr(C)]
struct AnimationValueVariantRepr<T> {
    tag: u16,
    value: T
}

impl Clone for AnimationValue {
    #[inline]
    fn clone(&self) -> Self {
        use self::AnimationValue::*;

        

        let self_tag = unsafe { *(self as *const _ as *const u16) };
        if self_tag <= LonghandId::BorderTopStyle as u16 {
            #[derive(Clone, Copy)]
            #[repr(u16)]
            enum CopyVariants {
                _AlignContent(<::values::specified::AlignContent as ToComputedValue>::ComputedValue),
                _AlignItems(<::values::specified::AlignItems as ToComputedValue>::ComputedValue),
                _AlignSelf(<::values::specified::AlignSelf as ToComputedValue>::ComputedValue),
                _BackfaceVisibility(<longhands::backface_visibility::SpecifiedValue as ToComputedValue>::ComputedValue),
                _BorderCollapse(<longhands::border_collapse::SpecifiedValue as ToComputedValue>::ComputedValue),
                _BorderImageRepeat(<::values::specified::BorderImageRepeat as ToComputedValue>::ComputedValue),
                _BoxDecorationBreak(<longhands::box_decoration_break::SpecifiedValue as ToComputedValue>::ComputedValue),
                _BoxSizing(<longhands::box_sizing::SpecifiedValue as ToComputedValue>::ComputedValue),
                _CaptionSide(<longhands::caption_side::SpecifiedValue as ToComputedValue>::ComputedValue),
                _Clear(<longhands::clear::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ClipRule(<longhands::clip_rule::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ColorAdjust(<longhands::color_adjust::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ColorInterpolation(<longhands::color_interpolation::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ColorInterpolationFilters(<longhands::color_interpolation_filters::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ColumnCount(<<::values::specified::ColumnCount as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
                _ColumnFill(<longhands::column_fill::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ColumnRuleStyle(<longhands::column_rule_style::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ColumnSpan(<longhands::column_span::SpecifiedValue as ToComputedValue>::ComputedValue),
                _Contain(<::values::specified::Contain as ToComputedValue>::ComputedValue),
                _Direction(<longhands::direction::SpecifiedValue as ToComputedValue>::ComputedValue),
                _DominantBaseline(<longhands::dominant_baseline::SpecifiedValue as ToComputedValue>::ComputedValue),
                _EmptyCells(<longhands::empty_cells::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FillRule(<longhands::fill_rule::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FlexDirection(<longhands::flex_direction::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FlexWrap(<longhands::flex_wrap::SpecifiedValue as ToComputedValue>::ComputedValue),
                _Float(<longhands::float::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FontKerning(<longhands::font_kerning::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FontOpticalSizing(<longhands::font_optical_sizing::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FontStretch(<longhands::font_stretch::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FontStyle(<longhands::font_style::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FontSynthesis(<::values::specified::FontSynthesis as ToComputedValue>::ComputedValue),
                _FontVariantCaps(<longhands::font_variant_caps::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FontVariantPosition(<longhands::font_variant_position::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FontWeight(<::values::specified::FontWeight as ToComputedValue>::ComputedValue),
                _GridAutoFlow(<::values::specified::GridAutoFlow as ToComputedValue>::ComputedValue),
                _Hyphens(<longhands::hyphens::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ImageOrientation(<::values::specified::ImageOrientation as ToComputedValue>::ComputedValue),
                _ImageRendering(<longhands::image_rendering::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ImeMode(<longhands::ime_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
                _InitialLetter(<::values::specified::InitialLetter as ToComputedValue>::ComputedValue),
                _Isolation(<longhands::isolation::SpecifiedValue as ToComputedValue>::ComputedValue),
                _JustifyContent(<::values::specified::JustifyContent as ToComputedValue>::ComputedValue),
                _JustifyItems(<::values::specified::JustifyItems as ToComputedValue>::ComputedValue),
                _JustifySelf(<::values::specified::JustifySelf as ToComputedValue>::ComputedValue),
                _ListStylePosition(<longhands::list_style_position::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MaskType(<longhands::mask_type::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MixBlendMode(<longhands::mix_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozAppearance(<longhands::_moz_appearance::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozBoxAlign(<longhands::_moz_box_align::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozBoxDirection(<longhands::_moz_box_direction::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozBoxOrient(<longhands::_moz_box_orient::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozBoxPack(<longhands::_moz_box_pack::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozFloatEdge(<longhands::_moz_float_edge::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozForceBrokenImageIcon(<::values::specified::MozForceBrokenImageIcon as ToComputedValue>::ComputedValue),
                _MozOrient(<longhands::_moz_orient::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozOsxFontSmoothing(<longhands::_moz_osx_font_smoothing::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozStackSizing(<longhands::_moz_stack_sizing::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozTextSizeAdjust(<longhands::_moz_text_size_adjust::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozUserFocus(<longhands::_moz_user_focus::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozUserInput(<longhands::_moz_user_input::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozUserModify(<longhands::_moz_user_modify::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozUserSelect(<longhands::_moz_user_select::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozWindowDragging(<longhands::_moz_window_dragging::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozWindowShadow(<longhands::_moz_window_shadow::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ObjectFit(<longhands::object_fit::SpecifiedValue as ToComputedValue>::ComputedValue),
                _OutlineStyle(<::values::specified::OutlineStyle as ToComputedValue>::ComputedValue),
                _OverflowWrap(<longhands::overflow_wrap::SpecifiedValue as ToComputedValue>::ComputedValue),
                _OverflowX(<longhands::overflow_x::SpecifiedValue as ToComputedValue>::ComputedValue),
                _PageBreakAfter(<longhands::page_break_after::SpecifiedValue as ToComputedValue>::ComputedValue),
                _PageBreakBefore(<longhands::page_break_before::SpecifiedValue as ToComputedValue>::ComputedValue),
                _PageBreakInside(<longhands::page_break_inside::SpecifiedValue as ToComputedValue>::ComputedValue),
                _PaintOrder(<::values::specified::SVGPaintOrder as ToComputedValue>::ComputedValue),
                _PointerEvents(<longhands::pointer_events::SpecifiedValue as ToComputedValue>::ComputedValue),
                _Position(<longhands::position::SpecifiedValue as ToComputedValue>::ComputedValue),
                _Resize(<longhands::resize::SpecifiedValue as ToComputedValue>::ComputedValue),
                _RubyAlign(<longhands::ruby_align::SpecifiedValue as ToComputedValue>::ComputedValue),
                _RubyPosition(<longhands::ruby_position::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ScrollBehavior(<longhands::scroll_behavior::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ShapeRendering(<longhands::shape_rendering::SpecifiedValue as ToComputedValue>::ComputedValue),
                _StrokeLinecap(<longhands::stroke_linecap::SpecifiedValue as ToComputedValue>::ComputedValue),
                _StrokeLinejoin(<longhands::stroke_linejoin::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TableLayout(<longhands::table_layout::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TextAlignLast(<longhands::text_align_last::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TextAnchor(<longhands::text_anchor::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TextCombineUpright(<longhands::text_combine_upright::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TextDecorationLine(<::values::specified::TextDecorationLine as ToComputedValue>::ComputedValue),
                _TextDecorationStyle(<longhands::text_decoration_style::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TextJustify(<longhands::text_justify::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TextOrientation(<longhands::text_orientation::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TextRendering(<longhands::text_rendering::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TextTransform(<longhands::text_transform::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TouchAction(<::values::specified::TouchAction as ToComputedValue>::ComputedValue),
                _TransformBox(<longhands::transform_box::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TransformStyle(<::values::specified::TransformStyle as ToComputedValue>::ComputedValue),
                _UnicodeBidi(<longhands::unicode_bidi::SpecifiedValue as ToComputedValue>::ComputedValue),
                _VectorEffect(<longhands::vector_effect::SpecifiedValue as ToComputedValue>::ComputedValue),
                _Visibility(<longhands::visibility::SpecifiedValue as ToComputedValue>::ComputedValue),
                _WhiteSpace(<longhands::white_space::SpecifiedValue as ToComputedValue>::ComputedValue),
                _WordBreak(<longhands::word_break::SpecifiedValue as ToComputedValue>::ComputedValue),
                _WritingMode(<longhands::writing_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ZIndex(<::values::specified::ZIndex as ToComputedValue>::ComputedValue),
                _MozBoxOrdinalGroup(<::values::specified::Integer as ToComputedValue>::ComputedValue),
                _Order(<::values::specified::Integer as ToComputedValue>::ComputedValue),
                _OverscrollBehaviorX(<::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue),
                _OverscrollBehaviorY(<::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue),
                _ScrollSnapTypeX(<::values::specified::ScrollSnapType as ToComputedValue>::ComputedValue),
                _ScrollSnapTypeY(<::values::specified::ScrollSnapType as ToComputedValue>::ComputedValue),
                _FlexGrow(<<::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
                _FlexShrink(<<::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
                _MozBoxFlex(<<::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
                _FloodOpacity(<::values::specified::Opacity as ToComputedValue>::ComputedValue),
                _MozWindowOpacity(<::values::specified::Opacity as ToComputedValue>::ComputedValue),
                _Opacity(<::values::specified::Opacity as ToComputedValue>::ComputedValue),
                _ShapeImageThreshold(<::values::specified::Opacity as ToComputedValue>::ComputedValue),
                _StopOpacity(<::values::specified::Opacity as ToComputedValue>::ComputedValue),
                _BorderBottomStyle(<::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
                _BorderLeftStyle(<::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
                _BorderRightStyle(<::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
                _BorderTopStyle(<::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
            }

            unsafe {
                let mut out = mem::uninitialized();
                ptr::write(
                    &mut out as *mut _ as *mut CopyVariants,
                    *(self as *const _ as *const CopyVariants),
                );
                return out;
            }
        }

        match *self {
            
            BackgroundAttachment(ref value) => {
                BackgroundAttachment(value.clone())
            }
            
            BackgroundBlendMode(ref value) => {
                BackgroundBlendMode(value.clone())
            }
            
            BackgroundClip(ref value) => {
                BackgroundClip(value.clone())
            }
            
            BackgroundImage(ref value) => {
                BackgroundImage(value.clone())
            }
            
            BackgroundOrigin(ref value) => {
                BackgroundOrigin(value.clone())
            }
            
            BackgroundPositionX(ref value) => {
                BackgroundPositionX(value.clone())
            }
            
            BackgroundPositionY(ref value) => {
                BackgroundPositionY(value.clone())
            }
            
            BackgroundRepeat(ref value) => {
                BackgroundRepeat(value.clone())
            }
            
            BackgroundSize(ref value) => {
                BackgroundSize(value.clone())
            }
            
            BorderImageOutset(ref value) => {
                BorderImageOutset(value.clone())
            }
            
            BorderImageSlice(ref value) => {
                BorderImageSlice(value.clone())
            }
            
            BorderImageSource(ref value) => {
                BorderImageSource(value.clone())
            }
            
            BorderImageWidth(ref value) => {
                BorderImageWidth(value.clone())
            }
            
            BorderSpacing(ref value) => {
                BorderSpacing(value.clone())
            }
            
            BoxShadow(ref value) => {
                BoxShadow(value.clone())
            }
            
            CaretColor(ref value) => {
                CaretColor(value.clone())
            }
            
            ClipPath(ref value) => {
                ClipPath(value.clone())
            }
            
            Color(ref value) => {
                Color(value.clone())
            }
            
            ColumnGap(ref value) => {
                ColumnGap(value.clone())
            }
            
            ColumnWidth(ref value) => {
                ColumnWidth(value.clone())
            }
            
            Content(ref value) => {
                Content(value.clone())
            }
            
            CounterIncrement(ref value) => {
                CounterIncrement(value.clone())
            }
            
            CounterReset(ref value) => {
                CounterReset(value.clone())
            }
            
            Cursor(ref value) => {
                Cursor(value.clone())
            }
            
            Display(ref value) => {
                Display(value.clone())
            }
            
            Filter(ref value) => {
                Filter(value.clone())
            }
            
            FontFamily(ref value) => {
                FontFamily(value.clone())
            }
            
            FontFeatureSettings(ref value) => {
                FontFeatureSettings(value.clone())
            }
            
            FontLanguageOverride(ref value) => {
                FontLanguageOverride(value.clone())
            }
            
            FontSize(ref value) => {
                FontSize(value.clone())
            }
            
            FontSizeAdjust(ref value) => {
                FontSizeAdjust(value.clone())
            }
            
            FontVariantAlternates(ref value) => {
                FontVariantAlternates(value.clone())
            }
            
            FontVariantEastAsian(ref value) => {
                FontVariantEastAsian(value.clone())
            }
            
            FontVariantLigatures(ref value) => {
                FontVariantLigatures(value.clone())
            }
            
            FontVariantNumeric(ref value) => {
                FontVariantNumeric(value.clone())
            }
            
            FontVariationSettings(ref value) => {
                FontVariationSettings(value.clone())
            }
            
            GridTemplateAreas(ref value) => {
                GridTemplateAreas(value.clone())
            }
            
            LetterSpacing(ref value) => {
                LetterSpacing(value.clone())
            }
            
            LineHeight(ref value) => {
                LineHeight(value.clone())
            }
            
            ListStyleImage(ref value) => {
                ListStyleImage(value.clone())
            }
            
            ListStyleType(ref value) => {
                ListStyleType(value.clone())
            }
            
            MaskClip(ref value) => {
                MaskClip(value.clone())
            }
            
            MaskComposite(ref value) => {
                MaskComposite(value.clone())
            }
            
            MaskImage(ref value) => {
                MaskImage(value.clone())
            }
            
            MaskMode(ref value) => {
                MaskMode(value.clone())
            }
            
            MaskOrigin(ref value) => {
                MaskOrigin(value.clone())
            }
            
            MaskPositionX(ref value) => {
                MaskPositionX(value.clone())
            }
            
            MaskPositionY(ref value) => {
                MaskPositionY(value.clone())
            }
            
            MaskRepeat(ref value) => {
                MaskRepeat(value.clone())
            }
            
            MaskSize(ref value) => {
                MaskSize(value.clone())
            }
            
            MozTabSize(ref value) => {
                MozTabSize(value.clone())
            }
            
            OutlineOffset(ref value) => {
                OutlineOffset(value.clone())
            }
            
            OverflowY(ref value) => {
                OverflowY(value.clone())
            }
            
            Perspective(ref value) => {
                Perspective(value.clone())
            }
            
            PerspectiveOrigin(ref value) => {
                PerspectiveOrigin(value.clone())
            }
            
            Quotes(ref value) => {
                Quotes(value.clone())
            }
            
            Rotate(ref value) => {
                Rotate(value.clone())
            }
            
            Scale(ref value) => {
                Scale(value.clone())
            }
            
            ScrollSnapCoordinate(ref value) => {
                ScrollSnapCoordinate(value.clone())
            }
            
            ShapeOutside(ref value) => {
                ShapeOutside(value.clone())
            }
            
            StrokeDasharray(ref value) => {
                StrokeDasharray(value.clone())
            }
            
            StrokeDashoffset(ref value) => {
                StrokeDashoffset(value.clone())
            }
            
            StrokeMiterlimit(ref value) => {
                StrokeMiterlimit(value.clone())
            }
            
            StrokeWidth(ref value) => {
                StrokeWidth(value.clone())
            }
            
            TextAlign(ref value) => {
                TextAlign(value.clone())
            }
            
            TextEmphasisPosition(ref value) => {
                TextEmphasisPosition(value.clone())
            }
            
            TextEmphasisStyle(ref value) => {
                TextEmphasisStyle(value.clone())
            }
            
            TextIndent(ref value) => {
                TextIndent(value.clone())
            }
            
            TextOverflow(ref value) => {
                TextOverflow(value.clone())
            }
            
            TextShadow(ref value) => {
                TextShadow(value.clone())
            }
            
            Translate(ref value) => {
                Translate(value.clone())
            }
            
            VerticalAlign(ref value) => {
                VerticalAlign(value.clone())
            }
            
            WillChange(ref value) => {
                WillChange(value.clone())
            }
            
            WordSpacing(ref value) => {
                WordSpacing(value.clone())
            }
            
            OverflowClipBoxBlock(ref value) |
OverflowClipBoxInline(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::OverflowClipBox as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            FillOpacity(ref value) |
StrokeOpacity(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::SVGOpacity as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            ScrollSnapPointsX(ref value) |
ScrollSnapPointsY(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ScrollSnapPoint as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            MozWindowTransform(ref value) |
Transform(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Transform as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            Clip(ref value) |
MozImageRegion(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ClipRectOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            GridTemplateColumns(ref value) |
GridTemplateRows(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::GridTemplateComponent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            ObjectPosition(ref value) |
ScrollSnapDestination(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Position as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            Fill(ref value) |
Stroke(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            GridAutoColumns(ref value) |
GridAutoRows(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TrackSize as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            MozWindowTransformOrigin(ref value) |
TransformOrigin(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TransformOrigin as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            MaxHeight(ref value) |
MaxWidth(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::MaxLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            FloodColor(ref value) |
LightingColor(ref value) |
MozFontSmoothingBackgroundColor(ref value) |
StopColor(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::RGBAColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            MarkerEnd(ref value) |
MarkerMid(ref value) |
MarkerStart(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::UrlOrNone as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            GridColumnEnd(ref value) |
GridColumnStart(ref value) |
GridRowEnd(ref value) |
GridRowStart(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::GridLine as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            BorderBottomLeftRadius(ref value) |
BorderBottomRightRadius(ref value) |
BorderTopLeftRadius(ref value) |
BorderTopRightRadius(ref value) |
MozOutlineRadiusBottomleft(ref value) |
MozOutlineRadiusBottomright(ref value) |
MozOutlineRadiusTopleft(ref value) |
MozOutlineRadiusTopright(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            FlexBasis(ref value) |
Height(ref value) |
MinHeight(ref value) |
MinWidth(ref value) |
Width(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::MozLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            GridColumnGap(ref value) |
GridRowGap(ref value) |
PaddingBottom(ref value) |
PaddingLeft(ref value) |
PaddingRight(ref value) |
PaddingTop(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::NonNegativeLengthOrPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            BorderBottomWidth(ref value) |
BorderLeftWidth(ref value) |
BorderRightWidth(ref value) |
BorderTopWidth(ref value) |
ColumnRuleWidth(ref value) |
OutlineWidth(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            WebkitTextStrokeWidth(ref value) => {
                WebkitTextStrokeWidth(value.clone())
            }
            
            BackgroundColor(ref value) |
BorderBottomColor(ref value) |
BorderLeftColor(ref value) |
BorderRightColor(ref value) |
BorderTopColor(ref value) |
ColumnRuleColor(ref value) |
OutlineColor(ref value) |
TextDecorationColor(ref value) |
TextEmphasisColor(ref value) |
WebkitTextFillColor(ref value) |
WebkitTextStrokeColor(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            
            Bottom(ref value) |
Left(ref value) |
MarginBottom(ref value) |
MarginLeft(ref value) |
MarginRight(ref value) |
MarginTop(ref value) |
Right(ref value) |
Top(ref value) => {
                unsafe {
                    let mut out = ManuallyDrop::new(mem::uninitialized());
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::LengthOrPercentageOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    ManuallyDrop::into_inner(out)
                }
            }
            _ => unsafe { debug_unreachable!() }
        }
    }
}

impl PartialEq for AnimationValue {
    #[inline]
    fn eq(&self, other: &Self) -> bool {
        use self::AnimationValue::*;

        unsafe {
            let this_tag = *(self as *const _ as *const u16);
            let other_tag = *(other as *const _ as *const u16);
            if this_tag != other_tag {
                return false;
            }

            match *self {
                AlignContent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::AlignContent as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                AlignItems(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::AlignItems as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                AlignSelf(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::AlignSelf as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackfaceVisibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::backface_visibility::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BorderCollapse(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::border_collapse::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BorderImageRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::BorderImageRepeat as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BoxDecorationBreak(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::box_decoration_break::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BoxSizing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::box_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                CaptionSide(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::caption_side::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Clear(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::clear::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ClipRule(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::clip_rule::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ColorAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::color_adjust::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ColorInterpolation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::color_interpolation::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ColorInterpolationFilters(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::color_interpolation_filters::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ColumnCount(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::ColumnCount as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                ColumnFill(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::column_fill::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ColumnRuleStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::column_rule_style::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ColumnSpan(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::column_span::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Contain(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Contain as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Direction(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::direction::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                DominantBaseline(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::dominant_baseline::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                EmptyCells(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::empty_cells::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FillRule(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::fill_rule::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FlexDirection(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::flex_direction::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FlexWrap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::flex_wrap::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Float(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::float::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontKerning(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_kerning::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontOpticalSizing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_optical_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontStretch(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_stretch::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_style::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontSynthesis(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontSynthesis as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontVariantCaps(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_variant_caps::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontVariantPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_variant_position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontWeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontWeight as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                GridAutoFlow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::GridAutoFlow as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Hyphens(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::hyphens::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ImageOrientation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ImageOrientation as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ImageRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::image_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ImeMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::ime_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                InitialLetter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::InitialLetter as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Isolation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::isolation::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                JustifyContent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::JustifyContent as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                JustifyItems(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::JustifyItems as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                JustifySelf(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::JustifySelf as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ListStylePosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::list_style_position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_type::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MixBlendMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mix_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozAppearance(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_appearance::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozBoxAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_align::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozBoxDirection(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_direction::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozBoxOrient(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_orient::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozBoxPack(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_pack::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozFloatEdge(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_float_edge::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozForceBrokenImageIcon(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::MozForceBrokenImageIcon as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozOrient(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_orient::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozOsxFontSmoothing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_osx_font_smoothing::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozStackSizing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_stack_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozTextSizeAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_text_size_adjust::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozUserFocus(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_user_focus::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozUserInput(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_user_input::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozUserModify(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_user_modify::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozUserSelect(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_user_select::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozWindowDragging(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_window_dragging::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozWindowShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_window_shadow::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ObjectFit(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::object_fit::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                OutlineStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::OutlineStyle as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                OverflowWrap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::overflow_wrap::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                OverflowX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::overflow_x::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                PageBreakAfter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::page_break_after::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                PageBreakBefore(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::page_break_before::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                PageBreakInside(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::page_break_inside::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                PaintOrder(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::SVGPaintOrder as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                PointerEvents(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::pointer_events::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Position(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Resize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::resize::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                RubyAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::ruby_align::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                RubyPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::ruby_position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ScrollBehavior(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::scroll_behavior::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ShapeRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::shape_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                StrokeLinecap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::stroke_linecap::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                StrokeLinejoin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::stroke_linejoin::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TableLayout(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::table_layout::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextAlignLast(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_align_last::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_anchor::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextCombineUpright(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_combine_upright::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextDecorationLine(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TextDecorationLine as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextDecorationStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_decoration_style::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextJustify(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_justify::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextOrientation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_orientation::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextTransform(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_transform::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TouchAction(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TouchAction as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TransformBox(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::transform_box::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TransformStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TransformStyle as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                UnicodeBidi(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::unicode_bidi::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                VectorEffect(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::vector_effect::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Visibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::visibility::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                WhiteSpace(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::white_space::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                WordBreak(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::word_break::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                WritingMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::writing_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ZIndex(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ZIndex as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozBoxOrdinalGroup(ref this) |
Order(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Integer as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                OverscrollBehaviorX(ref this) |
OverscrollBehaviorY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ScrollSnapTypeX(ref this) |
ScrollSnapTypeY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ScrollSnapType as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FlexGrow(ref this) |
FlexShrink(ref this) |
MozBoxFlex(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                FloodOpacity(ref this) |
MozWindowOpacity(ref this) |
Opacity(ref this) |
ShapeImageThreshold(ref this) |
StopOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Opacity as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BorderBottomStyle(ref this) |
BorderLeftStyle(ref this) |
BorderRightStyle(ref this) |
BorderTopStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::BorderStyle as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundAttachment(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_attachment::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundBlendMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundClip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_clip::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_image::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_origin::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::background_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                BorderImageOutset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::LengthOrNumberRect as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BorderImageSlice(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::BorderImageSlice as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BorderImageSource(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ImageLayer as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BorderImageWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::BorderImageWidth as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BorderSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::BorderSpacing as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                BoxShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::box_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                CaretColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::CaretColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                ClipPath(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::basic_shape::ClippingShape as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Color(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::ColorPropertyValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                ColumnGap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::length::NonNegativeLengthOrNormal as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                ColumnWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::length::NonNegativeLengthOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                Content(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Content as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                CounterIncrement(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::CounterIncrement as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                CounterReset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::CounterReset as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Cursor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Cursor as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Display(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Display as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Filter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                FontFamily(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontFamily as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontFeatureSettings(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontFeatureSettings as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontLanguageOverride(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontLanguageOverride as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::FontSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                FontSizeAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontSizeAdjust as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontVariantAlternates(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontVariantAlternates as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontVariantEastAsian(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontVariantEastAsian as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontVariantLigatures(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontVariantLigatures as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontVariantNumeric(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontVariantNumeric as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontVariationSettings(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontVariationSettings as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                GridTemplateAreas(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::GridTemplateAreas as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                LetterSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::LetterSpacing as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                LineHeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::LineHeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                ListStyleImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ListStyleImage as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ListStyleType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ListStyleType as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskClip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_clip::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskComposite(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_composite::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_image::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_origin::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_size::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozTabSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::MozTabSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                OutlineOffset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Length as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                OverflowY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::overflow_y::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Perspective(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::Perspective as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                PerspectiveOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::position::Position as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Quotes(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Quotes as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Rotate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Rotate as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Scale(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Scale as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ScrollSnapCoordinate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::scroll_snap_coordinate::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ShapeOutside(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::basic_shape::FloatAreaShape as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                StrokeDasharray(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::SVGStrokeDashArray as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                StrokeDashoffset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::SVGLength as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                StrokeMiterlimit(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::GreaterThanOrEqualToOneNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                StrokeWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::SVGWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                TextAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TextAlign as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextEmphasisPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_emphasis_position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextEmphasisStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TextEmphasisStyle as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextIndent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::LengthOrPercentage as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextOverflow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TextOverflow as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::text_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                Translate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Translate as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                VerticalAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::VerticalAlign as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                WillChange(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::WillChange as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                WordSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::WordSpacing as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                OverflowClipBoxBlock(ref this) |
OverflowClipBoxInline(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::OverflowClipBox as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FillOpacity(ref this) |
StrokeOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::SVGOpacity as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ScrollSnapPointsX(ref this) |
ScrollSnapPointsY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ScrollSnapPoint as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozWindowTransform(ref this) |
Transform(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Transform as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Clip(ref this) |
MozImageRegion(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ClipRectOrAuto as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                GridTemplateColumns(ref this) |
GridTemplateRows(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::GridTemplateComponent as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ObjectPosition(ref this) |
ScrollSnapDestination(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Position as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Fill(ref this) |
Stroke(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                GridAutoColumns(ref this) |
GridAutoRows(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TrackSize as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozWindowTransformOrigin(ref this) |
TransformOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TransformOrigin as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaxHeight(ref this) |
MaxWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::MaxLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                FloodColor(ref this) |
LightingColor(ref this) |
MozFontSmoothingBackgroundColor(ref this) |
StopColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::RGBAColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                MarkerEnd(ref this) |
MarkerMid(ref this) |
MarkerStart(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::UrlOrNone as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                GridColumnEnd(ref this) |
GridColumnStart(ref this) |
GridRowEnd(ref this) |
GridRowStart(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::GridLine as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BorderBottomLeftRadius(ref this) |
BorderBottomRightRadius(ref this) |
BorderTopLeftRadius(ref this) |
BorderTopRightRadius(ref this) |
MozOutlineRadiusBottomleft(ref this) |
MozOutlineRadiusBottomright(ref this) |
MozOutlineRadiusTopleft(ref this) |
MozOutlineRadiusTopright(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                FlexBasis(ref this) |
Height(ref this) |
MinHeight(ref this) |
MinWidth(ref this) |
Width(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::MozLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                GridColumnGap(ref this) |
GridRowGap(ref this) |
PaddingBottom(ref this) |
PaddingLeft(ref this) |
PaddingRight(ref this) |
PaddingTop(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::NonNegativeLengthOrPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                BorderBottomWidth(ref this) |
BorderLeftWidth(ref this) |
BorderRightWidth(ref this) |
BorderTopWidth(ref this) |
ColumnRuleWidth(ref this) |
OutlineWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                WebkitTextStrokeWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundColor(ref this) |
BorderBottomColor(ref this) |
BorderLeftColor(ref this) |
BorderRightColor(ref this) |
BorderTopColor(ref this) |
ColumnRuleColor(ref this) |
OutlineColor(ref this) |
TextDecorationColor(ref this) |
TextEmphasisColor(ref this) |
WebkitTextFillColor(ref this) |
WebkitTextStrokeColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                Bottom(ref this) |
Left(ref this) |
MarginBottom(ref this) |
MarginLeft(ref this) |
MarginRight(ref this) |
MarginTop(ref this) |
Right(ref this) |
Top(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::LengthOrPercentageOrAuto as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozControlCharacterVisibility(void) |
MozMathDisplay(void) |
MozMathVariant(void) |
MozMinFontSizeRatio(void) |
MozScriptLevel(void) |
MozScriptMinSize(void) |
MozScriptSizeMultiplier(void) |
MozTopLayer(void) |
XSpan(void) |
XTextZoom(void) |
BorderBlockEndStyle(void) |
BorderBlockStartStyle(void) |
BorderInlineEndStyle(void) |
BorderInlineStartStyle(void) |
AnimationDelay(void) |
AnimationDirection(void) |
AnimationDuration(void) |
AnimationFillMode(void) |
AnimationIterationCount(void) |
AnimationName(void) |
AnimationPlayState(void) |
AnimationTimingFunction(void) |
MozContextProperties(void) |
TransitionDelay(void) |
TransitionDuration(void) |
TransitionProperty(void) |
TransitionTimingFunction(void) |
XLang(void) |
MaxBlockSize(void) |
MaxInlineSize(void) |
MozBinding(void) |
BlockSize(void) |
InlineSize(void) |
MinBlockSize(void) |
MinInlineSize(void) |
PaddingBlockEnd(void) |
PaddingBlockStart(void) |
PaddingInlineEnd(void) |
PaddingInlineStart(void) |
BorderBlockEndWidth(void) |
BorderBlockStartWidth(void) |
BorderInlineEndWidth(void) |
BorderInlineStartWidth(void) |
BorderBlockEndColor(void) |
BorderBlockStartColor(void) |
BorderInlineEndColor(void) |
BorderInlineStartColor(void) |
MarginBlockEnd(void) |
MarginBlockStart(void) |
MarginInlineEnd(void) |
MarginInlineStart(void) |
OffsetBlockEnd(void) |
OffsetBlockStart(void) |
OffsetInlineEnd(void) |
OffsetInlineStart(void) => {
                    void::unreachable(void)
                }
            }
        }
    }
}

impl AnimationValue {
    /// Returns the longhand id this animated value corresponds to.
    #[inline]
    pub fn id(&self) -> LonghandId {
        let id = unsafe { *(self as *const _ as *const LonghandId) };
        debug_assert_eq!(id, match *self {
            AnimationValue::AlignContent(..) => LonghandId::AlignContent,
            AnimationValue::AlignItems(..) => LonghandId::AlignItems,
            AnimationValue::AlignSelf(..) => LonghandId::AlignSelf,
            AnimationValue::BackfaceVisibility(..) => LonghandId::BackfaceVisibility,
            AnimationValue::BorderCollapse(..) => LonghandId::BorderCollapse,
            AnimationValue::BorderImageRepeat(..) => LonghandId::BorderImageRepeat,
            AnimationValue::BoxDecorationBreak(..) => LonghandId::BoxDecorationBreak,
            AnimationValue::BoxSizing(..) => LonghandId::BoxSizing,
            AnimationValue::CaptionSide(..) => LonghandId::CaptionSide,
            AnimationValue::Clear(..) => LonghandId::Clear,
            AnimationValue::ClipRule(..) => LonghandId::ClipRule,
            AnimationValue::ColorAdjust(..) => LonghandId::ColorAdjust,
            AnimationValue::ColorInterpolation(..) => LonghandId::ColorInterpolation,
            AnimationValue::ColorInterpolationFilters(..) => LonghandId::ColorInterpolationFilters,
            AnimationValue::ColumnCount(..) => LonghandId::ColumnCount,
            AnimationValue::ColumnFill(..) => LonghandId::ColumnFill,
            AnimationValue::ColumnRuleStyle(..) => LonghandId::ColumnRuleStyle,
            AnimationValue::ColumnSpan(..) => LonghandId::ColumnSpan,
            AnimationValue::Contain(..) => LonghandId::Contain,
            AnimationValue::Direction(..) => LonghandId::Direction,
            AnimationValue::DominantBaseline(..) => LonghandId::DominantBaseline,
            AnimationValue::EmptyCells(..) => LonghandId::EmptyCells,
            AnimationValue::FillRule(..) => LonghandId::FillRule,
            AnimationValue::FlexDirection(..) => LonghandId::FlexDirection,
            AnimationValue::FlexWrap(..) => LonghandId::FlexWrap,
            AnimationValue::Float(..) => LonghandId::Float,
            AnimationValue::FontKerning(..) => LonghandId::FontKerning,
            AnimationValue::FontOpticalSizing(..) => LonghandId::FontOpticalSizing,
            AnimationValue::FontStretch(..) => LonghandId::FontStretch,
            AnimationValue::FontStyle(..) => LonghandId::FontStyle,
            AnimationValue::FontSynthesis(..) => LonghandId::FontSynthesis,
            AnimationValue::FontVariantCaps(..) => LonghandId::FontVariantCaps,
            AnimationValue::FontVariantPosition(..) => LonghandId::FontVariantPosition,
            AnimationValue::FontWeight(..) => LonghandId::FontWeight,
            AnimationValue::GridAutoFlow(..) => LonghandId::GridAutoFlow,
            AnimationValue::Hyphens(..) => LonghandId::Hyphens,
            AnimationValue::ImageOrientation(..) => LonghandId::ImageOrientation,
            AnimationValue::ImageRendering(..) => LonghandId::ImageRendering,
            AnimationValue::ImeMode(..) => LonghandId::ImeMode,
            AnimationValue::InitialLetter(..) => LonghandId::InitialLetter,
            AnimationValue::Isolation(..) => LonghandId::Isolation,
            AnimationValue::JustifyContent(..) => LonghandId::JustifyContent,
            AnimationValue::JustifyItems(..) => LonghandId::JustifyItems,
            AnimationValue::JustifySelf(..) => LonghandId::JustifySelf,
            AnimationValue::ListStylePosition(..) => LonghandId::ListStylePosition,
            AnimationValue::MaskType(..) => LonghandId::MaskType,
            AnimationValue::MixBlendMode(..) => LonghandId::MixBlendMode,
            AnimationValue::MozAppearance(..) => LonghandId::MozAppearance,
            AnimationValue::MozBoxAlign(..) => LonghandId::MozBoxAlign,
            AnimationValue::MozBoxDirection(..) => LonghandId::MozBoxDirection,
            AnimationValue::MozBoxOrient(..) => LonghandId::MozBoxOrient,
            AnimationValue::MozBoxPack(..) => LonghandId::MozBoxPack,
            AnimationValue::MozControlCharacterVisibility(void) => void::unreachable(void),
            AnimationValue::MozFloatEdge(..) => LonghandId::MozFloatEdge,
            AnimationValue::MozForceBrokenImageIcon(..) => LonghandId::MozForceBrokenImageIcon,
            AnimationValue::MozMathDisplay(void) => void::unreachable(void),
            AnimationValue::MozMathVariant(void) => void::unreachable(void),
            AnimationValue::MozMinFontSizeRatio(void) => void::unreachable(void),
            AnimationValue::MozOrient(..) => LonghandId::MozOrient,
            AnimationValue::MozOsxFontSmoothing(..) => LonghandId::MozOsxFontSmoothing,
            AnimationValue::MozScriptLevel(void) => void::unreachable(void),
            AnimationValue::MozScriptMinSize(void) => void::unreachable(void),
            AnimationValue::MozScriptSizeMultiplier(void) => void::unreachable(void),
            AnimationValue::MozStackSizing(..) => LonghandId::MozStackSizing,
            AnimationValue::MozTextSizeAdjust(..) => LonghandId::MozTextSizeAdjust,
            AnimationValue::MozTopLayer(void) => void::unreachable(void),
            AnimationValue::MozUserFocus(..) => LonghandId::MozUserFocus,
            AnimationValue::MozUserInput(..) => LonghandId::MozUserInput,
            AnimationValue::MozUserModify(..) => LonghandId::MozUserModify,
            AnimationValue::MozUserSelect(..) => LonghandId::MozUserSelect,
            AnimationValue::MozWindowDragging(..) => LonghandId::MozWindowDragging,
            AnimationValue::MozWindowShadow(..) => LonghandId::MozWindowShadow,
            AnimationValue::ObjectFit(..) => LonghandId::ObjectFit,
            AnimationValue::OutlineStyle(..) => LonghandId::OutlineStyle,
            AnimationValue::OverflowWrap(..) => LonghandId::OverflowWrap,
            AnimationValue::OverflowX(..) => LonghandId::OverflowX,
            AnimationValue::PageBreakAfter(..) => LonghandId::PageBreakAfter,
            AnimationValue::PageBreakBefore(..) => LonghandId::PageBreakBefore,
            AnimationValue::PageBreakInside(..) => LonghandId::PageBreakInside,
            AnimationValue::PaintOrder(..) => LonghandId::PaintOrder,
            AnimationValue::PointerEvents(..) => LonghandId::PointerEvents,
            AnimationValue::Position(..) => LonghandId::Position,
            AnimationValue::Resize(..) => LonghandId::Resize,
            AnimationValue::RubyAlign(..) => LonghandId::RubyAlign,
            AnimationValue::RubyPosition(..) => LonghandId::RubyPosition,
            AnimationValue::ScrollBehavior(..) => LonghandId::ScrollBehavior,
            AnimationValue::ShapeRendering(..) => LonghandId::ShapeRendering,
            AnimationValue::StrokeLinecap(..) => LonghandId::StrokeLinecap,
            AnimationValue::StrokeLinejoin(..) => LonghandId::StrokeLinejoin,
            AnimationValue::TableLayout(..) => LonghandId::TableLayout,
            AnimationValue::TextAlignLast(..) => LonghandId::TextAlignLast,
            AnimationValue::TextAnchor(..) => LonghandId::TextAnchor,
            AnimationValue::TextCombineUpright(..) => LonghandId::TextCombineUpright,
            AnimationValue::TextDecorationLine(..) => LonghandId::TextDecorationLine,
            AnimationValue::TextDecorationStyle(..) => LonghandId::TextDecorationStyle,
            AnimationValue::TextJustify(..) => LonghandId::TextJustify,
            AnimationValue::TextOrientation(..) => LonghandId::TextOrientation,
            AnimationValue::TextRendering(..) => LonghandId::TextRendering,
            AnimationValue::TextTransform(..) => LonghandId::TextTransform,
            AnimationValue::TouchAction(..) => LonghandId::TouchAction,
            AnimationValue::TransformBox(..) => LonghandId::TransformBox,
            AnimationValue::TransformStyle(..) => LonghandId::TransformStyle,
            AnimationValue::UnicodeBidi(..) => LonghandId::UnicodeBidi,
            AnimationValue::VectorEffect(..) => LonghandId::VectorEffect,
            AnimationValue::Visibility(..) => LonghandId::Visibility,
            AnimationValue::WhiteSpace(..) => LonghandId::WhiteSpace,
            AnimationValue::WordBreak(..) => LonghandId::WordBreak,
            AnimationValue::WritingMode(..) => LonghandId::WritingMode,
            AnimationValue::XSpan(void) => void::unreachable(void),
            AnimationValue::XTextZoom(void) => void::unreachable(void),
            AnimationValue::ZIndex(..) => LonghandId::ZIndex,
            AnimationValue::MozBoxOrdinalGroup(..) => LonghandId::MozBoxOrdinalGroup,
            AnimationValue::Order(..) => LonghandId::Order,
            AnimationValue::OverscrollBehaviorX(..) => LonghandId::OverscrollBehaviorX,
            AnimationValue::OverscrollBehaviorY(..) => LonghandId::OverscrollBehaviorY,
            AnimationValue::ScrollSnapTypeX(..) => LonghandId::ScrollSnapTypeX,
            AnimationValue::ScrollSnapTypeY(..) => LonghandId::ScrollSnapTypeY,
            AnimationValue::FlexGrow(..) => LonghandId::FlexGrow,
            AnimationValue::FlexShrink(..) => LonghandId::FlexShrink,
            AnimationValue::MozBoxFlex(..) => LonghandId::MozBoxFlex,
            AnimationValue::FloodOpacity(..) => LonghandId::FloodOpacity,
            AnimationValue::MozWindowOpacity(..) => LonghandId::MozWindowOpacity,
            AnimationValue::Opacity(..) => LonghandId::Opacity,
            AnimationValue::ShapeImageThreshold(..) => LonghandId::ShapeImageThreshold,
            AnimationValue::StopOpacity(..) => LonghandId::StopOpacity,
            AnimationValue::BorderBlockEndStyle(void) => void::unreachable(void),
            AnimationValue::BorderBlockStartStyle(void) => void::unreachable(void),
            AnimationValue::BorderBottomStyle(..) => LonghandId::BorderBottomStyle,
            AnimationValue::BorderInlineEndStyle(void) => void::unreachable(void),
            AnimationValue::BorderInlineStartStyle(void) => void::unreachable(void),
            AnimationValue::BorderLeftStyle(..) => LonghandId::BorderLeftStyle,
            AnimationValue::BorderRightStyle(..) => LonghandId::BorderRightStyle,
            AnimationValue::BorderTopStyle(..) => LonghandId::BorderTopStyle,
            AnimationValue::AnimationDelay(void) => void::unreachable(void),
            AnimationValue::AnimationDirection(void) => void::unreachable(void),
            AnimationValue::AnimationDuration(void) => void::unreachable(void),
            AnimationValue::AnimationFillMode(void) => void::unreachable(void),
            AnimationValue::AnimationIterationCount(void) => void::unreachable(void),
            AnimationValue::AnimationName(void) => void::unreachable(void),
            AnimationValue::AnimationPlayState(void) => void::unreachable(void),
            AnimationValue::AnimationTimingFunction(void) => void::unreachable(void),
            AnimationValue::BackgroundAttachment(..) => LonghandId::BackgroundAttachment,
            AnimationValue::BackgroundBlendMode(..) => LonghandId::BackgroundBlendMode,
            AnimationValue::BackgroundClip(..) => LonghandId::BackgroundClip,
            AnimationValue::BackgroundImage(..) => LonghandId::BackgroundImage,
            AnimationValue::BackgroundOrigin(..) => LonghandId::BackgroundOrigin,
            AnimationValue::BackgroundPositionX(..) => LonghandId::BackgroundPositionX,
            AnimationValue::BackgroundPositionY(..) => LonghandId::BackgroundPositionY,
            AnimationValue::BackgroundRepeat(..) => LonghandId::BackgroundRepeat,
            AnimationValue::BackgroundSize(..) => LonghandId::BackgroundSize,
            AnimationValue::BorderImageOutset(..) => LonghandId::BorderImageOutset,
            AnimationValue::BorderImageSlice(..) => LonghandId::BorderImageSlice,
            AnimationValue::BorderImageSource(..) => LonghandId::BorderImageSource,
            AnimationValue::BorderImageWidth(..) => LonghandId::BorderImageWidth,
            AnimationValue::BorderSpacing(..) => LonghandId::BorderSpacing,
            AnimationValue::BoxShadow(..) => LonghandId::BoxShadow,
            AnimationValue::CaretColor(..) => LonghandId::CaretColor,
            AnimationValue::ClipPath(..) => LonghandId::ClipPath,
            AnimationValue::Color(..) => LonghandId::Color,
            AnimationValue::ColumnGap(..) => LonghandId::ColumnGap,
            AnimationValue::ColumnWidth(..) => LonghandId::ColumnWidth,
            AnimationValue::Content(..) => LonghandId::Content,
            AnimationValue::CounterIncrement(..) => LonghandId::CounterIncrement,
            AnimationValue::CounterReset(..) => LonghandId::CounterReset,
            AnimationValue::Cursor(..) => LonghandId::Cursor,
            AnimationValue::Display(..) => LonghandId::Display,
            AnimationValue::Filter(..) => LonghandId::Filter,
            AnimationValue::FontFamily(..) => LonghandId::FontFamily,
            AnimationValue::FontFeatureSettings(..) => LonghandId::FontFeatureSettings,
            AnimationValue::FontLanguageOverride(..) => LonghandId::FontLanguageOverride,
            AnimationValue::FontSize(..) => LonghandId::FontSize,
            AnimationValue::FontSizeAdjust(..) => LonghandId::FontSizeAdjust,
            AnimationValue::FontVariantAlternates(..) => LonghandId::FontVariantAlternates,
            AnimationValue::FontVariantEastAsian(..) => LonghandId::FontVariantEastAsian,
            AnimationValue::FontVariantLigatures(..) => LonghandId::FontVariantLigatures,
            AnimationValue::FontVariantNumeric(..) => LonghandId::FontVariantNumeric,
            AnimationValue::FontVariationSettings(..) => LonghandId::FontVariationSettings,
            AnimationValue::GridTemplateAreas(..) => LonghandId::GridTemplateAreas,
            AnimationValue::LetterSpacing(..) => LonghandId::LetterSpacing,
            AnimationValue::LineHeight(..) => LonghandId::LineHeight,
            AnimationValue::ListStyleImage(..) => LonghandId::ListStyleImage,
            AnimationValue::ListStyleType(..) => LonghandId::ListStyleType,
            AnimationValue::MaskClip(..) => LonghandId::MaskClip,
            AnimationValue::MaskComposite(..) => LonghandId::MaskComposite,
            AnimationValue::MaskImage(..) => LonghandId::MaskImage,
            AnimationValue::MaskMode(..) => LonghandId::MaskMode,
            AnimationValue::MaskOrigin(..) => LonghandId::MaskOrigin,
            AnimationValue::MaskPositionX(..) => LonghandId::MaskPositionX,
            AnimationValue::MaskPositionY(..) => LonghandId::MaskPositionY,
            AnimationValue::MaskRepeat(..) => LonghandId::MaskRepeat,
            AnimationValue::MaskSize(..) => LonghandId::MaskSize,
            AnimationValue::MozContextProperties(void) => void::unreachable(void),
            AnimationValue::MozTabSize(..) => LonghandId::MozTabSize,
            AnimationValue::OutlineOffset(..) => LonghandId::OutlineOffset,
            AnimationValue::OverflowY(..) => LonghandId::OverflowY,
            AnimationValue::Perspective(..) => LonghandId::Perspective,
            AnimationValue::PerspectiveOrigin(..) => LonghandId::PerspectiveOrigin,
            AnimationValue::Quotes(..) => LonghandId::Quotes,
            AnimationValue::Rotate(..) => LonghandId::Rotate,
            AnimationValue::Scale(..) => LonghandId::Scale,
            AnimationValue::ScrollSnapCoordinate(..) => LonghandId::ScrollSnapCoordinate,
            AnimationValue::ShapeOutside(..) => LonghandId::ShapeOutside,
            AnimationValue::StrokeDasharray(..) => LonghandId::StrokeDasharray,
            AnimationValue::StrokeDashoffset(..) => LonghandId::StrokeDashoffset,
            AnimationValue::StrokeMiterlimit(..) => LonghandId::StrokeMiterlimit,
            AnimationValue::StrokeWidth(..) => LonghandId::StrokeWidth,
            AnimationValue::TextAlign(..) => LonghandId::TextAlign,
            AnimationValue::TextEmphasisPosition(..) => LonghandId::TextEmphasisPosition,
            AnimationValue::TextEmphasisStyle(..) => LonghandId::TextEmphasisStyle,
            AnimationValue::TextIndent(..) => LonghandId::TextIndent,
            AnimationValue::TextOverflow(..) => LonghandId::TextOverflow,
            AnimationValue::TextShadow(..) => LonghandId::TextShadow,
            AnimationValue::TransitionDelay(void) => void::unreachable(void),
            AnimationValue::TransitionDuration(void) => void::unreachable(void),
            AnimationValue::TransitionProperty(void) => void::unreachable(void),
            AnimationValue::TransitionTimingFunction(void) => void::unreachable(void),
            AnimationValue::Translate(..) => LonghandId::Translate,
            AnimationValue::VerticalAlign(..) => LonghandId::VerticalAlign,
            AnimationValue::WillChange(..) => LonghandId::WillChange,
            AnimationValue::WordSpacing(..) => LonghandId::WordSpacing,
            AnimationValue::XLang(void) => void::unreachable(void),
            AnimationValue::OverflowClipBoxBlock(..) => LonghandId::OverflowClipBoxBlock,
            AnimationValue::OverflowClipBoxInline(..) => LonghandId::OverflowClipBoxInline,
            AnimationValue::FillOpacity(..) => LonghandId::FillOpacity,
            AnimationValue::StrokeOpacity(..) => LonghandId::StrokeOpacity,
            AnimationValue::ScrollSnapPointsX(..) => LonghandId::ScrollSnapPointsX,
            AnimationValue::ScrollSnapPointsY(..) => LonghandId::ScrollSnapPointsY,
            AnimationValue::MozWindowTransform(..) => LonghandId::MozWindowTransform,
            AnimationValue::Transform(..) => LonghandId::Transform,
            AnimationValue::Clip(..) => LonghandId::Clip,
            AnimationValue::MozImageRegion(..) => LonghandId::MozImageRegion,
            AnimationValue::GridTemplateColumns(..) => LonghandId::GridTemplateColumns,
            AnimationValue::GridTemplateRows(..) => LonghandId::GridTemplateRows,
            AnimationValue::ObjectPosition(..) => LonghandId::ObjectPosition,
            AnimationValue::ScrollSnapDestination(..) => LonghandId::ScrollSnapDestination,
            AnimationValue::Fill(..) => LonghandId::Fill,
            AnimationValue::Stroke(..) => LonghandId::Stroke,
            AnimationValue::GridAutoColumns(..) => LonghandId::GridAutoColumns,
            AnimationValue::GridAutoRows(..) => LonghandId::GridAutoRows,
            AnimationValue::MozWindowTransformOrigin(..) => LonghandId::MozWindowTransformOrigin,
            AnimationValue::TransformOrigin(..) => LonghandId::TransformOrigin,
            AnimationValue::MaxBlockSize(void) => void::unreachable(void),
            AnimationValue::MaxHeight(..) => LonghandId::MaxHeight,
            AnimationValue::MaxInlineSize(void) => void::unreachable(void),
            AnimationValue::MaxWidth(..) => LonghandId::MaxWidth,
            AnimationValue::FloodColor(..) => LonghandId::FloodColor,
            AnimationValue::LightingColor(..) => LonghandId::LightingColor,
            AnimationValue::MozFontSmoothingBackgroundColor(..) => LonghandId::MozFontSmoothingBackgroundColor,
            AnimationValue::StopColor(..) => LonghandId::StopColor,
            AnimationValue::MarkerEnd(..) => LonghandId::MarkerEnd,
            AnimationValue::MarkerMid(..) => LonghandId::MarkerMid,
            AnimationValue::MarkerStart(..) => LonghandId::MarkerStart,
            AnimationValue::MozBinding(void) => void::unreachable(void),
            AnimationValue::GridColumnEnd(..) => LonghandId::GridColumnEnd,
            AnimationValue::GridColumnStart(..) => LonghandId::GridColumnStart,
            AnimationValue::GridRowEnd(..) => LonghandId::GridRowEnd,
            AnimationValue::GridRowStart(..) => LonghandId::GridRowStart,
            AnimationValue::BorderBottomLeftRadius(..) => LonghandId::BorderBottomLeftRadius,
            AnimationValue::BorderBottomRightRadius(..) => LonghandId::BorderBottomRightRadius,
            AnimationValue::BorderTopLeftRadius(..) => LonghandId::BorderTopLeftRadius,
            AnimationValue::BorderTopRightRadius(..) => LonghandId::BorderTopRightRadius,
            AnimationValue::MozOutlineRadiusBottomleft(..) => LonghandId::MozOutlineRadiusBottomleft,
            AnimationValue::MozOutlineRadiusBottomright(..) => LonghandId::MozOutlineRadiusBottomright,
            AnimationValue::MozOutlineRadiusTopleft(..) => LonghandId::MozOutlineRadiusTopleft,
            AnimationValue::MozOutlineRadiusTopright(..) => LonghandId::MozOutlineRadiusTopright,
            AnimationValue::BlockSize(void) => void::unreachable(void),
            AnimationValue::FlexBasis(..) => LonghandId::FlexBasis,
            AnimationValue::Height(..) => LonghandId::Height,
            AnimationValue::InlineSize(void) => void::unreachable(void),
            AnimationValue::MinBlockSize(void) => void::unreachable(void),
            AnimationValue::MinHeight(..) => LonghandId::MinHeight,
            AnimationValue::MinInlineSize(void) => void::unreachable(void),
            AnimationValue::MinWidth(..) => LonghandId::MinWidth,
            AnimationValue::Width(..) => LonghandId::Width,
            AnimationValue::GridColumnGap(..) => LonghandId::GridColumnGap,
            AnimationValue::GridRowGap(..) => LonghandId::GridRowGap,
            AnimationValue::PaddingBlockEnd(void) => void::unreachable(void),
            AnimationValue::PaddingBlockStart(void) => void::unreachable(void),
            AnimationValue::PaddingBottom(..) => LonghandId::PaddingBottom,
            AnimationValue::PaddingInlineEnd(void) => void::unreachable(void),
            AnimationValue::PaddingInlineStart(void) => void::unreachable(void),
            AnimationValue::PaddingLeft(..) => LonghandId::PaddingLeft,
            AnimationValue::PaddingRight(..) => LonghandId::PaddingRight,
            AnimationValue::PaddingTop(..) => LonghandId::PaddingTop,
            AnimationValue::BorderBlockEndWidth(void) => void::unreachable(void),
            AnimationValue::BorderBlockStartWidth(void) => void::unreachable(void),
            AnimationValue::BorderBottomWidth(..) => LonghandId::BorderBottomWidth,
            AnimationValue::BorderInlineEndWidth(void) => void::unreachable(void),
            AnimationValue::BorderInlineStartWidth(void) => void::unreachable(void),
            AnimationValue::BorderLeftWidth(..) => LonghandId::BorderLeftWidth,
            AnimationValue::BorderRightWidth(..) => LonghandId::BorderRightWidth,
            AnimationValue::BorderTopWidth(..) => LonghandId::BorderTopWidth,
            AnimationValue::ColumnRuleWidth(..) => LonghandId::ColumnRuleWidth,
            AnimationValue::OutlineWidth(..) => LonghandId::OutlineWidth,
            AnimationValue::WebkitTextStrokeWidth(..) => LonghandId::WebkitTextStrokeWidth,
            AnimationValue::BackgroundColor(..) => LonghandId::BackgroundColor,
            AnimationValue::BorderBlockEndColor(void) => void::unreachable(void),
            AnimationValue::BorderBlockStartColor(void) => void::unreachable(void),
            AnimationValue::BorderBottomColor(..) => LonghandId::BorderBottomColor,
            AnimationValue::BorderInlineEndColor(void) => void::unreachable(void),
            AnimationValue::BorderInlineStartColor(void) => void::unreachable(void),
            AnimationValue::BorderLeftColor(..) => LonghandId::BorderLeftColor,
            AnimationValue::BorderRightColor(..) => LonghandId::BorderRightColor,
            AnimationValue::BorderTopColor(..) => LonghandId::BorderTopColor,
            AnimationValue::ColumnRuleColor(..) => LonghandId::ColumnRuleColor,
            AnimationValue::OutlineColor(..) => LonghandId::OutlineColor,
            AnimationValue::TextDecorationColor(..) => LonghandId::TextDecorationColor,
            AnimationValue::TextEmphasisColor(..) => LonghandId::TextEmphasisColor,
            AnimationValue::WebkitTextFillColor(..) => LonghandId::WebkitTextFillColor,
            AnimationValue::WebkitTextStrokeColor(..) => LonghandId::WebkitTextStrokeColor,
            AnimationValue::Bottom(..) => LonghandId::Bottom,
            AnimationValue::Left(..) => LonghandId::Left,
            AnimationValue::MarginBlockEnd(void) => void::unreachable(void),
            AnimationValue::MarginBlockStart(void) => void::unreachable(void),
            AnimationValue::MarginBottom(..) => LonghandId::MarginBottom,
            AnimationValue::MarginInlineEnd(void) => void::unreachable(void),
            AnimationValue::MarginInlineStart(void) => void::unreachable(void),
            AnimationValue::MarginLeft(..) => LonghandId::MarginLeft,
            AnimationValue::MarginRight(..) => LonghandId::MarginRight,
            AnimationValue::MarginTop(..) => LonghandId::MarginTop,
            AnimationValue::OffsetBlockEnd(void) => void::unreachable(void),
            AnimationValue::OffsetBlockStart(void) => void::unreachable(void),
            AnimationValue::OffsetInlineEnd(void) => void::unreachable(void),
            AnimationValue::OffsetInlineStart(void) => void::unreachable(void),
            AnimationValue::Right(..) => LonghandId::Right,
            AnimationValue::Top(..) => LonghandId::Top,
        });
        id
    }

    /// "Uncompute" this animation value in order to be used inside the CSS
    /// cascade.
    pub fn uncompute(&self) -> PropertyDeclaration {
        use properties::longhands;
        use self::AnimationValue::*;

        use super::PropertyDeclarationVariantRepr;

        match *self {
            
            
            AlignContent(ref value) => {
                let value = ::values::specified::AlignContent::from_computed_value(&value);
                PropertyDeclaration::AlignContent(value)
            }
            
            AlignItems(ref value) => {
                let value = ::values::specified::AlignItems::from_computed_value(&value);
                PropertyDeclaration::AlignItems(value)
            }
            
            AlignSelf(ref value) => {
                let value = ::values::specified::AlignSelf::from_computed_value(&value);
                PropertyDeclaration::AlignSelf(value)
            }
            
            BackfaceVisibility(ref value) => {
                let value = longhands::backface_visibility::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackfaceVisibility(value)
            }
            
            BorderCollapse(ref value) => {
                let value = longhands::border_collapse::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BorderCollapse(value)
            }
            
            BorderImageRepeat(ref value) => {
                let value = ::values::specified::BorderImageRepeat::from_computed_value(&value);
                PropertyDeclaration::BorderImageRepeat(value)
            }
            
            BoxDecorationBreak(ref value) => {
                let value = longhands::box_decoration_break::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BoxDecorationBreak(value)
            }
            
            BoxSizing(ref value) => {
                let value = longhands::box_sizing::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BoxSizing(value)
            }
            
            CaptionSide(ref value) => {
                let value = longhands::caption_side::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::CaptionSide(value)
            }
            
            Clear(ref value) => {
                let value = longhands::clear::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::Clear(value)
            }
            
            ClipRule(ref value) => {
                let value = longhands::clip_rule::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ClipRule(value)
            }
            
            ColorAdjust(ref value) => {
                let value = longhands::color_adjust::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ColorAdjust(value)
            }
            
            ColorInterpolation(ref value) => {
                let value = longhands::color_interpolation::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ColorInterpolation(value)
            }
            
            ColorInterpolationFilters(ref value) => {
                let value = longhands::color_interpolation_filters::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ColorInterpolationFilters(value)
            }
            
            ColumnCount(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::ColumnCount::from_computed_value(&value);
                PropertyDeclaration::ColumnCount(value)
            }
            
            ColumnFill(ref value) => {
                let value = longhands::column_fill::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ColumnFill(value)
            }
            
            ColumnRuleStyle(ref value) => {
                let value = longhands::column_rule_style::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ColumnRuleStyle(value)
            }
            
            ColumnSpan(ref value) => {
                let value = longhands::column_span::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ColumnSpan(value)
            }
            
            Contain(ref value) => {
                let value = ::values::specified::Contain::from_computed_value(&value);
                PropertyDeclaration::Contain(value)
            }
            
            Direction(ref value) => {
                let value = longhands::direction::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::Direction(value)
            }
            
            DominantBaseline(ref value) => {
                let value = longhands::dominant_baseline::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::DominantBaseline(value)
            }
            
            EmptyCells(ref value) => {
                let value = longhands::empty_cells::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::EmptyCells(value)
            }
            
            FillRule(ref value) => {
                let value = longhands::fill_rule::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FillRule(value)
            }
            
            FlexDirection(ref value) => {
                let value = longhands::flex_direction::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FlexDirection(value)
            }
            
            FlexWrap(ref value) => {
                let value = longhands::flex_wrap::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FlexWrap(value)
            }
            
            Float(ref value) => {
                let value = longhands::float::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::Float(value)
            }
            
            FontKerning(ref value) => {
                let value = longhands::font_kerning::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FontKerning(value)
            }
            
            FontOpticalSizing(ref value) => {
                let value = longhands::font_optical_sizing::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FontOpticalSizing(value)
            }
            
            FontStretch(ref value) => {
                let value = longhands::font_stretch::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FontStretch(value)
            }
            
            FontStyle(ref value) => {
                let value = longhands::font_style::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FontStyle(value)
            }
            
            FontSynthesis(ref value) => {
                let value = ::values::specified::FontSynthesis::from_computed_value(&value);
                PropertyDeclaration::FontSynthesis(value)
            }
            
            FontVariantCaps(ref value) => {
                let value = longhands::font_variant_caps::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FontVariantCaps(value)
            }
            
            FontVariantPosition(ref value) => {
                let value = longhands::font_variant_position::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FontVariantPosition(value)
            }
            
            FontWeight(ref value) => {
                let value = ::values::specified::FontWeight::from_computed_value(&value);
                PropertyDeclaration::FontWeight(value)
            }
            
            GridAutoFlow(ref value) => {
                let value = ::values::specified::GridAutoFlow::from_computed_value(&value);
                PropertyDeclaration::GridAutoFlow(value)
            }
            
            Hyphens(ref value) => {
                let value = longhands::hyphens::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::Hyphens(value)
            }
            
            ImageOrientation(ref value) => {
                let value = ::values::specified::ImageOrientation::from_computed_value(&value);
                PropertyDeclaration::ImageOrientation(value)
            }
            
            ImageRendering(ref value) => {
                let value = longhands::image_rendering::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ImageRendering(value)
            }
            
            ImeMode(ref value) => {
                let value = longhands::ime_mode::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ImeMode(value)
            }
            
            InitialLetter(ref value) => {
                let value = ::values::specified::InitialLetter::from_computed_value(&value);
                PropertyDeclaration::InitialLetter(value)
            }
            
            Isolation(ref value) => {
                let value = longhands::isolation::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::Isolation(value)
            }
            
            JustifyContent(ref value) => {
                let value = ::values::specified::JustifyContent::from_computed_value(&value);
                PropertyDeclaration::JustifyContent(value)
            }
            
            JustifyItems(ref value) => {
                let value = ::values::specified::JustifyItems::from_computed_value(&value);
                PropertyDeclaration::JustifyItems(value)
            }
            
            JustifySelf(ref value) => {
                let value = ::values::specified::JustifySelf::from_computed_value(&value);
                PropertyDeclaration::JustifySelf(value)
            }
            
            ListStylePosition(ref value) => {
                let value = longhands::list_style_position::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ListStylePosition(value)
            }
            
            MaskType(ref value) => {
                let value = longhands::mask_type::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskType(value)
            }
            
            MixBlendMode(ref value) => {
                let value = longhands::mix_blend_mode::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MixBlendMode(value)
            }
            
            MozAppearance(ref value) => {
                let value = longhands::_moz_appearance::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozAppearance(value)
            }
            
            MozBoxAlign(ref value) => {
                let value = longhands::_moz_box_align::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozBoxAlign(value)
            }
            
            MozBoxDirection(ref value) => {
                let value = longhands::_moz_box_direction::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozBoxDirection(value)
            }
            
            MozBoxOrient(ref value) => {
                let value = longhands::_moz_box_orient::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozBoxOrient(value)
            }
            
            MozBoxPack(ref value) => {
                let value = longhands::_moz_box_pack::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozBoxPack(value)
            }
            
            MozFloatEdge(ref value) => {
                let value = longhands::_moz_float_edge::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozFloatEdge(value)
            }
            
            MozForceBrokenImageIcon(ref value) => {
                let value = ::values::specified::MozForceBrokenImageIcon::from_computed_value(&value);
                PropertyDeclaration::MozForceBrokenImageIcon(value)
            }
            
            MozOrient(ref value) => {
                let value = longhands::_moz_orient::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozOrient(value)
            }
            
            MozOsxFontSmoothing(ref value) => {
                let value = longhands::_moz_osx_font_smoothing::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozOsxFontSmoothing(value)
            }
            
            MozStackSizing(ref value) => {
                let value = longhands::_moz_stack_sizing::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozStackSizing(value)
            }
            
            MozTextSizeAdjust(ref value) => {
                let value = longhands::_moz_text_size_adjust::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozTextSizeAdjust(value)
            }
            
            MozUserFocus(ref value) => {
                let value = longhands::_moz_user_focus::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozUserFocus(value)
            }
            
            MozUserInput(ref value) => {
                let value = longhands::_moz_user_input::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozUserInput(value)
            }
            
            MozUserModify(ref value) => {
                let value = longhands::_moz_user_modify::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozUserModify(value)
            }
            
            MozUserSelect(ref value) => {
                let value = longhands::_moz_user_select::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozUserSelect(value)
            }
            
            MozWindowDragging(ref value) => {
                let value = longhands::_moz_window_dragging::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozWindowDragging(value)
            }
            
            MozWindowShadow(ref value) => {
                let value = longhands::_moz_window_shadow::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozWindowShadow(value)
            }
            
            ObjectFit(ref value) => {
                let value = longhands::object_fit::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ObjectFit(value)
            }
            
            OutlineStyle(ref value) => {
                let value = ::values::specified::OutlineStyle::from_computed_value(&value);
                PropertyDeclaration::OutlineStyle(value)
            }
            
            OverflowWrap(ref value) => {
                let value = longhands::overflow_wrap::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::OverflowWrap(value)
            }
            
            OverflowX(ref value) => {
                let value = longhands::overflow_x::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::OverflowX(value)
            }
            
            PageBreakAfter(ref value) => {
                let value = longhands::page_break_after::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::PageBreakAfter(value)
            }
            
            PageBreakBefore(ref value) => {
                let value = longhands::page_break_before::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::PageBreakBefore(value)
            }
            
            PageBreakInside(ref value) => {
                let value = longhands::page_break_inside::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::PageBreakInside(value)
            }
            
            PaintOrder(ref value) => {
                let value = ::values::specified::SVGPaintOrder::from_computed_value(&value);
                PropertyDeclaration::PaintOrder(value)
            }
            
            PointerEvents(ref value) => {
                let value = longhands::pointer_events::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::PointerEvents(value)
            }
            
            Position(ref value) => {
                let value = longhands::position::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::Position(value)
            }
            
            Resize(ref value) => {
                let value = longhands::resize::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::Resize(value)
            }
            
            RubyAlign(ref value) => {
                let value = longhands::ruby_align::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::RubyAlign(value)
            }
            
            RubyPosition(ref value) => {
                let value = longhands::ruby_position::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::RubyPosition(value)
            }
            
            ScrollBehavior(ref value) => {
                let value = longhands::scroll_behavior::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ScrollBehavior(value)
            }
            
            ShapeRendering(ref value) => {
                let value = longhands::shape_rendering::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ShapeRendering(value)
            }
            
            StrokeLinecap(ref value) => {
                let value = longhands::stroke_linecap::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::StrokeLinecap(value)
            }
            
            StrokeLinejoin(ref value) => {
                let value = longhands::stroke_linejoin::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::StrokeLinejoin(value)
            }
            
            TableLayout(ref value) => {
                let value = longhands::table_layout::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TableLayout(value)
            }
            
            TextAlignLast(ref value) => {
                let value = longhands::text_align_last::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextAlignLast(value)
            }
            
            TextAnchor(ref value) => {
                let value = longhands::text_anchor::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextAnchor(value)
            }
            
            TextCombineUpright(ref value) => {
                let value = longhands::text_combine_upright::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextCombineUpright(value)
            }
            
            TextDecorationLine(ref value) => {
                let value = ::values::specified::TextDecorationLine::from_computed_value(&value);
                PropertyDeclaration::TextDecorationLine(value)
            }
            
            TextDecorationStyle(ref value) => {
                let value = longhands::text_decoration_style::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextDecorationStyle(value)
            }
            
            TextJustify(ref value) => {
                let value = longhands::text_justify::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextJustify(value)
            }
            
            TextOrientation(ref value) => {
                let value = longhands::text_orientation::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextOrientation(value)
            }
            
            TextRendering(ref value) => {
                let value = longhands::text_rendering::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextRendering(value)
            }
            
            TextTransform(ref value) => {
                let value = longhands::text_transform::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextTransform(value)
            }
            
            TouchAction(ref value) => {
                let value = ::values::specified::TouchAction::from_computed_value(&value);
                PropertyDeclaration::TouchAction(value)
            }
            
            TransformBox(ref value) => {
                let value = longhands::transform_box::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TransformBox(value)
            }
            
            TransformStyle(ref value) => {
                let value = ::values::specified::TransformStyle::from_computed_value(&value);
                PropertyDeclaration::TransformStyle(value)
            }
            
            UnicodeBidi(ref value) => {
                let value = longhands::unicode_bidi::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::UnicodeBidi(value)
            }
            
            VectorEffect(ref value) => {
                let value = longhands::vector_effect::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::VectorEffect(value)
            }
            
            Visibility(ref value) => {
                let value = longhands::visibility::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::Visibility(value)
            }
            
            WhiteSpace(ref value) => {
                let value = longhands::white_space::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::WhiteSpace(value)
            }
            
            WordBreak(ref value) => {
                let value = longhands::word_break::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::WordBreak(value)
            }
            
            WritingMode(ref value) => {
                let value = longhands::writing_mode::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::WritingMode(value)
            }
            
            ZIndex(ref value) => {
                let value = ::values::specified::ZIndex::from_computed_value(&value);
                PropertyDeclaration::ZIndex(value)
            }
            
            MozBoxOrdinalGroup(ref value) |
Order(ref value) => {
                let value = ::values::specified::Integer::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::Integer>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            OverscrollBehaviorX(ref value) |
OverscrollBehaviorY(ref value) => {
                let value = ::values::specified::OverscrollBehavior::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::OverscrollBehavior>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            ScrollSnapTypeX(ref value) |
ScrollSnapTypeY(ref value) => {
                let value = ::values::specified::ScrollSnapType::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::ScrollSnapType>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            FlexGrow(ref value) |
FlexShrink(ref value) |
MozBoxFlex(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::NonNegativeNumber::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::NonNegativeNumber>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            FloodOpacity(ref value) |
MozWindowOpacity(ref value) |
Opacity(ref value) |
ShapeImageThreshold(ref value) |
StopOpacity(ref value) => {
                let value = ::values::specified::Opacity::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::Opacity>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            BorderBottomStyle(ref value) |
BorderLeftStyle(ref value) |
BorderRightStyle(ref value) |
BorderTopStyle(ref value) => {
                let value = ::values::specified::BorderStyle::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::BorderStyle>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            BackgroundAttachment(ref value) => {
                let value = longhands::background_attachment::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundAttachment(value)
            }
            
            BackgroundBlendMode(ref value) => {
                let value = longhands::background_blend_mode::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundBlendMode(value)
            }
            
            BackgroundClip(ref value) => {
                let value = longhands::background_clip::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundClip(value)
            }
            
            BackgroundImage(ref value) => {
                let value = longhands::background_image::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundImage(value)
            }
            
            BackgroundOrigin(ref value) => {
                let value = longhands::background_origin::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundOrigin(value)
            }
            
            BackgroundPositionX(ref value) => {
                let value = longhands::background_position_x::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundPositionX(value)
            }
            
            BackgroundPositionY(ref value) => {
                let value = longhands::background_position_y::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundPositionY(value)
            }
            
            BackgroundRepeat(ref value) => {
                let value = longhands::background_repeat::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundRepeat(value)
            }
            
            BackgroundSize(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = longhands::background_size::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundSize(value)
            }
            
            BorderImageOutset(ref value) => {
                let value = ::values::specified::LengthOrNumberRect::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::BorderImageOutset(value)
            }
            
            BorderImageSlice(ref value) => {
                let value = ::values::specified::BorderImageSlice::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::BorderImageSlice(value)
            }
            
            BorderImageSource(ref value) => {
                let value = ::values::specified::ImageLayer::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::BorderImageSource(value)
            }
            
            BorderImageWidth(ref value) => {
                let value = ::values::specified::BorderImageWidth::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::BorderImageWidth(value)
            }
            
            BorderSpacing(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::BorderSpacing::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::BorderSpacing(value)
            }
            
            BoxShadow(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = longhands::box_shadow::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BoxShadow(value)
            }
            
            CaretColor(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::CaretColor::from_computed_value(&value);
                PropertyDeclaration::CaretColor(value)
            }
            
            ClipPath(ref value) => {
                let value = ::values::specified::basic_shape::ClippingShape::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::ClipPath(value)
            }
            
            Color(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::ColorPropertyValue::from_computed_value(&value);
                PropertyDeclaration::Color(value)
            }
            
            ColumnGap(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::length::NonNegativeLengthOrNormal::from_computed_value(&value);
                PropertyDeclaration::ColumnGap(value)
            }
            
            ColumnWidth(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::length::NonNegativeLengthOrAuto::from_computed_value(&value);
                PropertyDeclaration::ColumnWidth(value)
            }
            
            Content(ref value) => {
                let value = ::values::specified::Content::from_computed_value(&value);
                PropertyDeclaration::Content(value)
            }
            
            CounterIncrement(ref value) => {
                let value = ::values::specified::CounterIncrement::from_computed_value(&value);
                PropertyDeclaration::CounterIncrement(value)
            }
            
            CounterReset(ref value) => {
                let value = ::values::specified::CounterReset::from_computed_value(&value);
                PropertyDeclaration::CounterReset(value)
            }
            
            Cursor(ref value) => {
                let value = ::values::specified::Cursor::from_computed_value(&value);
                PropertyDeclaration::Cursor(value)
            }
            
            Display(ref value) => {
                let value = ::values::specified::Display::from_computed_value(&value);
                PropertyDeclaration::Display(value)
            }
            
            Filter(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = longhands::filter::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::Filter(value)
            }
            
            FontFamily(ref value) => {
                let value = ::values::specified::FontFamily::from_computed_value(&value);
                PropertyDeclaration::FontFamily(value)
            }
            
            FontFeatureSettings(ref value) => {
                let value = ::values::specified::FontFeatureSettings::from_computed_value(&value);
                PropertyDeclaration::FontFeatureSettings(value)
            }
            
            FontLanguageOverride(ref value) => {
                let value = ::values::specified::FontLanguageOverride::from_computed_value(&value);
                PropertyDeclaration::FontLanguageOverride(value)
            }
            
            FontSize(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::FontSize::from_computed_value(&value);
                PropertyDeclaration::FontSize(value)
            }
            
            FontSizeAdjust(ref value) => {
                let value = ::values::specified::FontSizeAdjust::from_computed_value(&value);
                PropertyDeclaration::FontSizeAdjust(value)
            }
            
            FontVariantAlternates(ref value) => {
                let value = ::values::specified::FontVariantAlternates::from_computed_value(&value);
                PropertyDeclaration::FontVariantAlternates(value)
            }
            
            FontVariantEastAsian(ref value) => {
                let value = ::values::specified::FontVariantEastAsian::from_computed_value(&value);
                PropertyDeclaration::FontVariantEastAsian(value)
            }
            
            FontVariantLigatures(ref value) => {
                let value = ::values::specified::FontVariantLigatures::from_computed_value(&value);
                PropertyDeclaration::FontVariantLigatures(value)
            }
            
            FontVariantNumeric(ref value) => {
                let value = ::values::specified::FontVariantNumeric::from_computed_value(&value);
                PropertyDeclaration::FontVariantNumeric(value)
            }
            
            FontVariationSettings(ref value) => {
                let value = ::values::specified::FontVariationSettings::from_computed_value(&value);
                PropertyDeclaration::FontVariationSettings(value)
            }
            
            GridTemplateAreas(ref value) => {
                let value = ::values::specified::GridTemplateAreas::from_computed_value(&value);
                PropertyDeclaration::GridTemplateAreas(value)
            }
            
            LetterSpacing(ref value) => {
                let value = ::values::specified::LetterSpacing::from_computed_value(&value);
                PropertyDeclaration::LetterSpacing(value)
            }
            
            LineHeight(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::LineHeight::from_computed_value(&value);
                PropertyDeclaration::LineHeight(value)
            }
            
            ListStyleImage(ref value) => {
                let value = ::values::specified::ListStyleImage::from_computed_value(&value);
                PropertyDeclaration::ListStyleImage(value)
            }
            
            ListStyleType(ref value) => {
                let value = ::values::specified::ListStyleType::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::ListStyleType(value)
            }
            
            MaskClip(ref value) => {
                let value = longhands::mask_clip::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskClip(value)
            }
            
            MaskComposite(ref value) => {
                let value = longhands::mask_composite::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskComposite(value)
            }
            
            MaskImage(ref value) => {
                let value = longhands::mask_image::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskImage(value)
            }
            
            MaskMode(ref value) => {
                let value = longhands::mask_mode::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskMode(value)
            }
            
            MaskOrigin(ref value) => {
                let value = longhands::mask_origin::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskOrigin(value)
            }
            
            MaskPositionX(ref value) => {
                let value = longhands::mask_position_x::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskPositionX(value)
            }
            
            MaskPositionY(ref value) => {
                let value = longhands::mask_position_y::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskPositionY(value)
            }
            
            MaskRepeat(ref value) => {
                let value = longhands::mask_repeat::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskRepeat(value)
            }
            
            MaskSize(ref value) => {
                let value = longhands::mask_size::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskSize(value)
            }
            
            MozTabSize(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::MozTabSize::from_computed_value(&value);
                PropertyDeclaration::MozTabSize(value)
            }
            
            OutlineOffset(ref value) => {
                let value = ::values::specified::Length::from_computed_value(&value);
                PropertyDeclaration::OutlineOffset(value)
            }
            
            OverflowY(ref value) => {
                let value = longhands::overflow_y::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::OverflowY(value)
            }
            
            Perspective(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::Perspective::from_computed_value(&value);
                PropertyDeclaration::Perspective(value)
            }
            
            PerspectiveOrigin(ref value) => {
                let value = ::values::specified::position::Position::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::PerspectiveOrigin(value)
            }
            
            Quotes(ref value) => {
                let value = ::values::specified::Quotes::from_computed_value(&value);
                PropertyDeclaration::Quotes(value)
            }
            
            Rotate(ref value) => {
                let value = ::values::specified::Rotate::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::Rotate(value)
            }
            
            Scale(ref value) => {
                let value = ::values::specified::Scale::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::Scale(value)
            }
            
            ScrollSnapCoordinate(ref value) => {
                let value = longhands::scroll_snap_coordinate::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ScrollSnapCoordinate(value)
            }
            
            ShapeOutside(ref value) => {
                let value = ::values::specified::basic_shape::FloatAreaShape::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::ShapeOutside(value)
            }
            
            StrokeDasharray(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::SVGStrokeDashArray::from_computed_value(&value);
                PropertyDeclaration::StrokeDasharray(value)
            }
            
            StrokeDashoffset(ref value) => {
                let value = ::values::specified::SVGLength::from_computed_value(&value);
                PropertyDeclaration::StrokeDashoffset(value)
            }
            
            StrokeMiterlimit(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::GreaterThanOrEqualToOneNumber::from_computed_value(&value);
                PropertyDeclaration::StrokeMiterlimit(value)
            }
            
            StrokeWidth(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::SVGWidth::from_computed_value(&value);
                PropertyDeclaration::StrokeWidth(value)
            }
            
            TextAlign(ref value) => {
                let value = ::values::specified::TextAlign::from_computed_value(&value);
                PropertyDeclaration::TextAlign(value)
            }
            
            TextEmphasisPosition(ref value) => {
                let value = longhands::text_emphasis_position::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextEmphasisPosition(value)
            }
            
            TextEmphasisStyle(ref value) => {
                let value = ::values::specified::TextEmphasisStyle::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::TextEmphasisStyle(value)
            }
            
            TextIndent(ref value) => {
                let value = ::values::specified::LengthOrPercentage::from_computed_value(&value);
                PropertyDeclaration::TextIndent(value)
            }
            
            TextOverflow(ref value) => {
                let value = ::values::specified::TextOverflow::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::TextOverflow(value)
            }
            
            TextShadow(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = longhands::text_shadow::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextShadow(value)
            }
            
            Translate(ref value) => {
                let value = ::values::specified::Translate::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::Translate(value)
            }
            
            VerticalAlign(ref value) => {
                let value = ::values::specified::VerticalAlign::from_computed_value(&value);
                PropertyDeclaration::VerticalAlign(value)
            }
            
            WillChange(ref value) => {
                let value = ::values::specified::WillChange::from_computed_value(&value);
                PropertyDeclaration::WillChange(value)
            }
            
            WordSpacing(ref value) => {
                let value = ::values::specified::WordSpacing::from_computed_value(&value);
                PropertyDeclaration::WordSpacing(value)
            }
            
            OverflowClipBoxBlock(ref value) |
OverflowClipBoxInline(ref value) => {
                let value = ::values::specified::OverflowClipBox::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::OverflowClipBox>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            FillOpacity(ref value) |
StrokeOpacity(ref value) => {
                let value = ::values::specified::SVGOpacity::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::SVGOpacity>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            ScrollSnapPointsX(ref value) |
ScrollSnapPointsY(ref value) => {
                let value = ::values::specified::ScrollSnapPoint::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::ScrollSnapPoint>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            MozWindowTransform(ref value) |
Transform(ref value) => {
                let value = ::values::specified::Transform::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::Transform>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            Clip(ref value) |
MozImageRegion(ref value) => {
                let value = ::values::specified::ClipRectOrAuto::from_computed_value(&value);
                let value = Box::new(value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::ClipRectOrAuto>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            GridTemplateColumns(ref value) |
GridTemplateRows(ref value) => {
                let value = ::values::specified::GridTemplateComponent::from_computed_value(&value);
                let value = Box::new(value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::GridTemplateComponent>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            ObjectPosition(ref value) |
ScrollSnapDestination(ref value) => {
                let value = ::values::specified::Position::from_computed_value(&value);
                let value = Box::new(value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::Position>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            Fill(ref value) |
Stroke(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::SVGPaint::from_computed_value(&value);
                let value = Box::new(value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::SVGPaint>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            GridAutoColumns(ref value) |
GridAutoRows(ref value) => {
                let value = ::values::specified::TrackSize::from_computed_value(&value);
                let value = Box::new(value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::TrackSize>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            MozWindowTransformOrigin(ref value) |
TransformOrigin(ref value) => {
                let value = ::values::specified::TransformOrigin::from_computed_value(&value);
                let value = Box::new(value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::TransformOrigin>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            MaxHeight(ref value) |
MaxWidth(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::MaxLength::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::MaxLength>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            FloodColor(ref value) |
LightingColor(ref value) |
MozFontSmoothingBackgroundColor(ref value) |
StopColor(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::RGBAColor::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::RGBAColor>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            MarkerEnd(ref value) |
MarkerMid(ref value) |
MarkerStart(ref value) => {
                let value = ::values::specified::UrlOrNone::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::UrlOrNone>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            GridColumnEnd(ref value) |
GridColumnStart(ref value) |
GridRowEnd(ref value) |
GridRowStart(ref value) => {
                let value = ::values::specified::GridLine::from_computed_value(&value);
                let value = Box::new(value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::GridLine>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            BorderBottomLeftRadius(ref value) |
BorderBottomRightRadius(ref value) |
BorderTopLeftRadius(ref value) |
BorderTopRightRadius(ref value) |
MozOutlineRadiusBottomleft(ref value) |
MozOutlineRadiusBottomright(ref value) |
MozOutlineRadiusTopleft(ref value) |
MozOutlineRadiusTopright(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::BorderCornerRadius::from_computed_value(&value);
                let value = Box::new(value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<Box<::values::specified::BorderCornerRadius>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            FlexBasis(ref value) |
Height(ref value) |
MinHeight(ref value) |
MinWidth(ref value) |
Width(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::MozLength::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::MozLength>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            GridColumnGap(ref value) |
GridRowGap(ref value) |
PaddingBottom(ref value) |
PaddingLeft(ref value) |
PaddingRight(ref value) |
PaddingTop(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::NonNegativeLengthOrPercentage::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::NonNegativeLengthOrPercentage>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            BorderBottomWidth(ref value) |
BorderLeftWidth(ref value) |
BorderRightWidth(ref value) |
BorderTopWidth(ref value) |
ColumnRuleWidth(ref value) |
OutlineWidth(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::BorderSideWidth::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::BorderSideWidth>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            WebkitTextStrokeWidth(ref value) => {
                let value = ::values::specified::BorderSideWidth::from_computed_value(&value);
                PropertyDeclaration::WebkitTextStrokeWidth(value)
            }
            
            BackgroundColor(ref value) |
BorderBottomColor(ref value) |
BorderLeftColor(ref value) |
BorderRightColor(ref value) |
BorderTopColor(ref value) |
ColumnRuleColor(ref value) |
OutlineColor(ref value) |
TextDecorationColor(ref value) |
TextEmphasisColor(ref value) |
WebkitTextFillColor(ref value) |
WebkitTextStrokeColor(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = ::values::specified::Color::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::Color>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            
            Bottom(ref value) |
Left(ref value) |
MarginBottom(ref value) |
MarginLeft(ref value) |
MarginRight(ref value) |
MarginTop(ref value) |
Right(ref value) |
Top(ref value) => {
                let value = ::values::specified::LengthOrPercentageOrAuto::from_computed_value(&value);
                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut PropertyDeclarationVariantRepr<::values::specified::LengthOrPercentageOrAuto>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out
                }
            }
            MozControlCharacterVisibility(void) |
MozMathDisplay(void) |
MozMathVariant(void) |
MozMinFontSizeRatio(void) |
MozScriptLevel(void) |
MozScriptMinSize(void) |
MozScriptSizeMultiplier(void) |
MozTopLayer(void) |
XSpan(void) |
XTextZoom(void) |
BorderBlockEndStyle(void) |
BorderBlockStartStyle(void) |
BorderInlineEndStyle(void) |
BorderInlineStartStyle(void) |
AnimationDelay(void) |
AnimationDirection(void) |
AnimationDuration(void) |
AnimationFillMode(void) |
AnimationIterationCount(void) |
AnimationName(void) |
AnimationPlayState(void) |
AnimationTimingFunction(void) |
MozContextProperties(void) |
TransitionDelay(void) |
TransitionDuration(void) |
TransitionProperty(void) |
TransitionTimingFunction(void) |
XLang(void) |
MaxBlockSize(void) |
MaxInlineSize(void) |
MozBinding(void) |
BlockSize(void) |
InlineSize(void) |
MinBlockSize(void) |
MinInlineSize(void) |
PaddingBlockEnd(void) |
PaddingBlockStart(void) |
PaddingInlineEnd(void) |
PaddingInlineStart(void) |
BorderBlockEndWidth(void) |
BorderBlockStartWidth(void) |
BorderInlineEndWidth(void) |
BorderInlineStartWidth(void) |
BorderBlockEndColor(void) |
BorderBlockStartColor(void) |
BorderInlineEndColor(void) |
BorderInlineStartColor(void) |
MarginBlockEnd(void) |
MarginBlockStart(void) |
MarginInlineEnd(void) |
MarginInlineStart(void) |
OffsetBlockEnd(void) |
OffsetBlockStart(void) |
OffsetInlineEnd(void) |
OffsetInlineStart(void) => {
                void::unreachable(void)
            }
        }
    }

    /// Construct an AnimationValue from a property declaration.
    pub fn from_declaration(
        decl: &PropertyDeclaration,
        context: &mut Context,
        extra_custom_properties: Option<&Arc<::custom_properties::CustomPropertiesMap>>,
        initial: &ComputedValues
    ) -> Option<Self> {
        use super::PropertyDeclarationVariantRepr;

        

        let animatable = match *decl {
            PropertyDeclaration::AlignContent(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::AlignContent>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::AlignContent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::AlignItems(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::AlignItems>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::AlignItems as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::AlignSelf(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::AlignSelf>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::AlignSelf as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BackfaceVisibility(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::backface_visibility::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::backface_visibility::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BorderCollapse(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::border_collapse::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::border_collapse::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BorderImageRepeat(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::BorderImageRepeat>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::BorderImageRepeat as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BoxDecorationBreak(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::box_decoration_break::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::box_decoration_break::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BoxSizing(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::box_sizing::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::box_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::CaptionSide(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::caption_side::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::caption_side::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Clear(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::clear::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::clear::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ClipRule(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::clip_rule::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::clip_rule::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ColorAdjust(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::color_adjust::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::color_adjust::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ColorInterpolation(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::color_interpolation::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::color_interpolation::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ColorInterpolationFilters(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::color_interpolation_filters::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::color_interpolation_filters::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ColumnCount(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::ColumnCount>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::ColumnCount as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ColumnFill(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::column_fill::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::column_fill::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ColumnRuleStyle(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::column_rule_style::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::column_rule_style::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ColumnSpan(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::column_span::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::column_span::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Contain(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Contain>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Contain as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Direction(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::direction::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::direction::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::DominantBaseline(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::dominant_baseline::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::dominant_baseline::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::EmptyCells(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::empty_cells::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::empty_cells::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FillRule(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::fill_rule::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::fill_rule::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FlexDirection(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::flex_direction::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::flex_direction::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FlexWrap(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::flex_wrap::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::flex_wrap::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Float(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::float::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::float::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontKerning(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_kerning::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::font_kerning::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontOpticalSizing(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_optical_sizing::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::font_optical_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontStretch(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_stretch::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::font_stretch::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontStyle(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_style::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::font_style::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontSynthesis(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontSynthesis>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontSynthesis as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontVariantCaps(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_variant_caps::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::font_variant_caps::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontVariantPosition(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_variant_position::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::font_variant_position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontWeight(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontWeight>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontWeight as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::GridAutoFlow(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::GridAutoFlow>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::GridAutoFlow as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Hyphens(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::hyphens::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::hyphens::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ImageOrientation(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::ImageOrientation>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ImageOrientation as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ImageRendering(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::image_rendering::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::image_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ImeMode(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::ime_mode::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::ime_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::InitialLetter(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::InitialLetter>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::InitialLetter as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Isolation(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::isolation::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::isolation::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::JustifyContent(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::JustifyContent>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::JustifyContent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::JustifyItems(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::JustifyItems>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::JustifyItems as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::JustifySelf(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::JustifySelf>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::JustifySelf as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ListStylePosition(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::list_style_position::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::list_style_position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MaskType(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_type::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_type::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MixBlendMode(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mix_blend_mode::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mix_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozAppearance(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_appearance::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_appearance::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozBoxAlign(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_align::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_box_align::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozBoxDirection(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_direction::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_box_direction::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozBoxOrient(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_orient::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_box_orient::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozBoxPack(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_pack::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_box_pack::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozFloatEdge(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_float_edge::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_float_edge::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozForceBrokenImageIcon(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::MozForceBrokenImageIcon>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::MozForceBrokenImageIcon as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozOrient(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_orient::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_orient::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozOsxFontSmoothing(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_osx_font_smoothing::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_osx_font_smoothing::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozStackSizing(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_stack_sizing::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_stack_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozTextSizeAdjust(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_text_size_adjust::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_text_size_adjust::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozUserFocus(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_user_focus::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_user_focus::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozUserInput(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_user_input::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_user_input::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozUserModify(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_user_modify::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_user_modify::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozUserSelect(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_user_select::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_user_select::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozWindowDragging(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_window_dragging::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_window_dragging::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozWindowShadow(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_window_shadow::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_window_shadow::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ObjectFit(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::object_fit::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::object_fit::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::OutlineStyle(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::OutlineStyle>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::OutlineStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::OverflowWrap(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::overflow_wrap::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::overflow_wrap::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::OverflowX(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::overflow_x::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::overflow_x::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::PageBreakAfter(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::page_break_after::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::page_break_after::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::PageBreakBefore(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::page_break_before::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::page_break_before::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::PageBreakInside(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::page_break_inside::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::page_break_inside::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::PaintOrder(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::SVGPaintOrder>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::SVGPaintOrder as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::PointerEvents(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::pointer_events::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::pointer_events::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Position(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::position::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Resize(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::resize::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::resize::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::RubyAlign(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::ruby_align::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::ruby_align::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::RubyPosition(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::ruby_position::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::ruby_position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ScrollBehavior(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::scroll_behavior::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::scroll_behavior::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ShapeRendering(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::shape_rendering::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::shape_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::StrokeLinecap(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::stroke_linecap::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::stroke_linecap::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::StrokeLinejoin(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::stroke_linejoin::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::stroke_linejoin::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TableLayout(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::table_layout::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::table_layout::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextAlignLast(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_align_last::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_align_last::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextAnchor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_anchor::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_anchor::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextCombineUpright(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_combine_upright::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_combine_upright::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextDecorationLine(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::TextDecorationLine>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TextDecorationLine as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextDecorationStyle(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_decoration_style::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_decoration_style::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextJustify(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_justify::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_justify::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextOrientation(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_orientation::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_orientation::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextRendering(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_rendering::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextTransform(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_transform::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_transform::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TouchAction(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::TouchAction>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TouchAction as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TransformBox(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::transform_box::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::transform_box::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TransformStyle(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::TransformStyle>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TransformStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::UnicodeBidi(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::unicode_bidi::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::unicode_bidi::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::VectorEffect(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::vector_effect::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::vector_effect::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Visibility(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::visibility::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::visibility::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::WhiteSpace(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::white_space::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::white_space::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::WordBreak(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::word_break::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::word_break::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::WritingMode(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::writing_mode::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::writing_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ZIndex(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::ZIndex>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ZIndex as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozBoxOrdinalGroup(ref value) |
PropertyDeclaration::Order(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Integer>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Integer as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::OverscrollBehaviorX(ref value) |
PropertyDeclaration::OverscrollBehaviorY(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::OverscrollBehavior>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ScrollSnapTypeX(ref value) |
PropertyDeclaration::ScrollSnapTypeY(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::ScrollSnapType>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ScrollSnapType as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FlexGrow(ref value) |
PropertyDeclaration::FlexShrink(ref value) |
PropertyDeclaration::MozBoxFlex(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::NonNegativeNumber>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FloodOpacity(ref value) |
PropertyDeclaration::MozWindowOpacity(ref value) |
PropertyDeclaration::Opacity(ref value) |
PropertyDeclaration::ShapeImageThreshold(ref value) |
PropertyDeclaration::StopOpacity(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Opacity>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Opacity as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BorderBottomStyle(ref value) |
PropertyDeclaration::BorderLeftStyle(ref value) |
PropertyDeclaration::BorderRightStyle(ref value) |
PropertyDeclaration::BorderTopStyle(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::BorderStyle>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::BorderStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BackgroundAttachment(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_attachment::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_attachment::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BackgroundBlendMode(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_blend_mode::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BackgroundClip(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_clip::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_clip::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BackgroundImage(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_image::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_image::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BackgroundOrigin(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_origin::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_origin::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BackgroundPositionX(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_position_x::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BackgroundPositionY(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_position_y::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BackgroundRepeat(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_repeat::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BackgroundSize(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_size::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<longhands::background_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BorderImageOutset(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::LengthOrNumberRect>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::LengthOrNumberRect as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BorderImageSlice(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::BorderImageSlice>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::BorderImageSlice as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BorderImageSource(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::ImageLayer>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ImageLayer as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BorderImageWidth(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::BorderImageWidth>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::BorderImageWidth as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BorderSpacing(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::BorderSpacing>>)
                };
                context.for_non_inherited_property = None;
                let value = (**value).to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::BorderSpacing as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BoxShadow(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::box_shadow::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<longhands::box_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::CaretColor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::CaretColor>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::CaretColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ClipPath(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::basic_shape::ClippingShape>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::basic_shape::ClippingShape as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Color(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::ColorPropertyValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::ColorPropertyValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ColumnGap(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::length::NonNegativeLengthOrNormal>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::length::NonNegativeLengthOrNormal as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ColumnWidth(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::length::NonNegativeLengthOrAuto>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::length::NonNegativeLengthOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Content(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Content>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Content as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::CounterIncrement(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::CounterIncrement>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::CounterIncrement as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::CounterReset(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::CounterReset>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::CounterReset as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Cursor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Cursor>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Cursor as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Display(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Display>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Display as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Filter(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::filter::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<longhands::filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontFamily(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontFamily>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontFamily as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontFeatureSettings(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontFeatureSettings>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontFeatureSettings as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontLanguageOverride(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontLanguageOverride>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontLanguageOverride as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontSize(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontSize>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::FontSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontSizeAdjust(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontSizeAdjust>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontSizeAdjust as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontVariantAlternates(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontVariantAlternates>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontVariantAlternates as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontVariantEastAsian(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontVariantEastAsian>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontVariantEastAsian as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontVariantLigatures(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontVariantLigatures>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontVariantLigatures as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontVariantNumeric(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontVariantNumeric>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontVariantNumeric as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FontVariationSettings(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::FontVariationSettings>)
                };
                context.for_non_inherited_property = None;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontVariationSettings as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::GridTemplateAreas(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::GridTemplateAreas>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::GridTemplateAreas as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::LetterSpacing(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::LetterSpacing>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::LetterSpacing as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::LineHeight(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::LineHeight>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::LineHeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ListStyleImage(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::ListStyleImage>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ListStyleImage as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ListStyleType(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::ListStyleType>>)
                };
                context.for_non_inherited_property = None;
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ListStyleType as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MaskClip(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_clip::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_clip::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MaskComposite(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_composite::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_composite::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MaskImage(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_image::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_image::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MaskMode(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_mode::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MaskOrigin(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_origin::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_origin::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MaskPositionX(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_position_x::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MaskPositionY(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_position_y::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MaskRepeat(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_repeat::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MaskSize(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_size::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_size::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozTabSize(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::MozTabSize>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::MozTabSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::OutlineOffset(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Length>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Length as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::OverflowY(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::overflow_y::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::overflow_y::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Perspective(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Perspective>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::Perspective as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::PerspectiveOrigin(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::position::Position>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::position::Position as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Quotes(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Quotes>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Quotes as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Rotate(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::Rotate>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Rotate as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Scale(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::Scale>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Scale as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ScrollSnapCoordinate(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::scroll_snap_coordinate::SpecifiedValue>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::scroll_snap_coordinate::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ShapeOutside(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::basic_shape::FloatAreaShape>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::basic_shape::FloatAreaShape as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::StrokeDasharray(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::SVGStrokeDashArray>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::SVGStrokeDashArray as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::StrokeDashoffset(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::SVGLength>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::SVGLength as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::StrokeMiterlimit(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::GreaterThanOrEqualToOneNumber>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::GreaterThanOrEqualToOneNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::StrokeWidth(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::SVGWidth>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::SVGWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextAlign(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::TextAlign>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TextAlign as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextEmphasisPosition(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_emphasis_position::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_emphasis_position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextEmphasisStyle(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::TextEmphasisStyle>>)
                };
                context.for_non_inherited_property = None;
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TextEmphasisStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextIndent(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::LengthOrPercentage>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::LengthOrPercentage as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextOverflow(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::TextOverflow>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TextOverflow as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextShadow(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_shadow::SpecifiedValue>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<longhands::text_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Translate(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::Translate>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Translate as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::VerticalAlign(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::VerticalAlign>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::VerticalAlign as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::WillChange(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::WillChange>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::WillChange as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::WordSpacing(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::WordSpacing>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::WordSpacing as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::OverflowClipBoxBlock(ref value) |
PropertyDeclaration::OverflowClipBoxInline(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::OverflowClipBox>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::OverflowClipBox as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FillOpacity(ref value) |
PropertyDeclaration::StrokeOpacity(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::SVGOpacity>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::SVGOpacity as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ScrollSnapPointsX(ref value) |
PropertyDeclaration::ScrollSnapPointsY(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::ScrollSnapPoint>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ScrollSnapPoint as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozWindowTransform(ref value) |
PropertyDeclaration::Transform(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Transform>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Transform as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Clip(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::ClipRectOrAuto>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ClipRectOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozImageRegion(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::ClipRectOrAuto>>)
                };
                context.for_non_inherited_property = None;
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ClipRectOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::GridTemplateColumns(ref value) |
PropertyDeclaration::GridTemplateRows(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::GridTemplateComponent>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::GridTemplateComponent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::ObjectPosition(ref value) |
PropertyDeclaration::ScrollSnapDestination(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::Position>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Position as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Fill(ref value) |
PropertyDeclaration::Stroke(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::SVGPaint>>)
                };
                context.for_non_inherited_property = None;
                let value = (**value).to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::GridAutoColumns(ref value) |
PropertyDeclaration::GridAutoRows(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::TrackSize>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TrackSize as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozWindowTransformOrigin(ref value) |
PropertyDeclaration::TransformOrigin(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::TransformOrigin>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TransformOrigin as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MaxHeight(ref value) |
PropertyDeclaration::MaxWidth(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::MaxLength>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::MaxLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FloodColor(ref value) |
PropertyDeclaration::LightingColor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::RGBAColor>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::RGBAColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MozFontSmoothingBackgroundColor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::RGBAColor>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::RGBAColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::StopColor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::RGBAColor>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::RGBAColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::MarkerEnd(ref value) |
PropertyDeclaration::MarkerMid(ref value) |
PropertyDeclaration::MarkerStart(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::UrlOrNone>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::UrlOrNone as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::GridColumnEnd(ref value) |
PropertyDeclaration::GridColumnStart(ref value) |
PropertyDeclaration::GridRowEnd(ref value) |
PropertyDeclaration::GridRowStart(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::GridLine>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::GridLine as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BorderBottomLeftRadius(ref value) |
PropertyDeclaration::BorderBottomRightRadius(ref value) |
PropertyDeclaration::BorderTopLeftRadius(ref value) |
PropertyDeclaration::BorderTopRightRadius(ref value) |
PropertyDeclaration::MozOutlineRadiusBottomleft(ref value) |
PropertyDeclaration::MozOutlineRadiusBottomright(ref value) |
PropertyDeclaration::MozOutlineRadiusTopleft(ref value) |
PropertyDeclaration::MozOutlineRadiusTopright(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<::values::specified::BorderCornerRadius>>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = (**value).to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::FlexBasis(ref value) |
PropertyDeclaration::Height(ref value) |
PropertyDeclaration::MinHeight(ref value) |
PropertyDeclaration::MinWidth(ref value) |
PropertyDeclaration::Width(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::MozLength>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::MozLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::GridColumnGap(ref value) |
PropertyDeclaration::GridRowGap(ref value) |
PropertyDeclaration::PaddingBottom(ref value) |
PropertyDeclaration::PaddingLeft(ref value) |
PropertyDeclaration::PaddingRight(ref value) |
PropertyDeclaration::PaddingTop(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::NonNegativeLengthOrPercentage>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::NonNegativeLengthOrPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BorderBottomWidth(ref value) |
PropertyDeclaration::BorderLeftWidth(ref value) |
PropertyDeclaration::BorderRightWidth(ref value) |
PropertyDeclaration::BorderTopWidth(ref value) |
PropertyDeclaration::ColumnRuleWidth(ref value) |
PropertyDeclaration::OutlineWidth(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::BorderSideWidth>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::WebkitTextStrokeWidth(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::BorderSideWidth>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::BackgroundColor(ref value) |
PropertyDeclaration::BorderBottomColor(ref value) |
PropertyDeclaration::BorderLeftColor(ref value) |
PropertyDeclaration::BorderRightColor(ref value) |
PropertyDeclaration::BorderTopColor(ref value) |
PropertyDeclaration::ColumnRuleColor(ref value) |
PropertyDeclaration::OutlineColor(ref value) |
PropertyDeclaration::TextDecorationColor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Color>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::TextEmphasisColor(ref value) |
PropertyDeclaration::WebkitTextFillColor(ref value) |
PropertyDeclaration::WebkitTextStrokeColor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::Color>)
                };
                context.for_non_inherited_property = None;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::Bottom(ref value) |
PropertyDeclaration::Left(ref value) |
PropertyDeclaration::MarginBottom(ref value) |
PropertyDeclaration::MarginLeft(ref value) |
PropertyDeclaration::MarginRight(ref value) |
PropertyDeclaration::MarginTop(ref value) |
PropertyDeclaration::Right(ref value) |
PropertyDeclaration::Top(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<::values::specified::LengthOrPercentageOrAuto>)
                };
                context.for_non_inherited_property = unsafe {
                    Some(*(&decl_repr.tag as *const u16 as *const LonghandId))
                };
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::LengthOrPercentageOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: decl_repr.tag,
                            value,
                        },
                    );
                    out
                }
            }
            PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                match declaration.id {
                    // We put all the animatable properties first in the hopes
                    // that it might increase match locality.
                    LonghandId::AlignContent => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_align_content();
                        AnimationValue::AlignContent(computed)
                    },
                    LonghandId::AlignItems => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_align_items();
                        AnimationValue::AlignItems(computed)
                    },
                    LonghandId::AlignSelf => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_align_self();
                        AnimationValue::AlignSelf(computed)
                    },
                    LonghandId::BackfaceVisibility => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_backface_visibility();
                        AnimationValue::BackfaceVisibility(computed)
                    },
                    LonghandId::BorderCollapse => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtable()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtable()
                            },
                        };
                        let computed = style_struct.clone_border_collapse();
                        AnimationValue::BorderCollapse(computed)
                    },
                    LonghandId::BorderImageRepeat => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_image_repeat();
                        AnimationValue::BorderImageRepeat(computed)
                    },
                    LonghandId::BoxDecorationBreak => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_box_decoration_break();
                        AnimationValue::BoxDecorationBreak(computed)
                    },
                    LonghandId::BoxSizing => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_box_sizing();
                        AnimationValue::BoxSizing(computed)
                    },
                    LonghandId::CaptionSide => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtable()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtable()
                            },
                        };
                        let computed = style_struct.clone_caption_side();
                        AnimationValue::CaptionSide(computed)
                    },
                    LonghandId::Clear => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_clear();
                        AnimationValue::Clear(computed)
                    },
                    LonghandId::ClipRule => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_clip_rule();
                        AnimationValue::ClipRule(computed)
                    },
                    LonghandId::ColorAdjust => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedbox()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedbox()
                            },
                        };
                        let computed = style_struct.clone_color_adjust();
                        AnimationValue::ColorAdjust(computed)
                    },
                    LonghandId::ColorInterpolation => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_color_interpolation();
                        AnimationValue::ColorInterpolation(computed)
                    },
                    LonghandId::ColorInterpolationFilters => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_color_interpolation_filters();
                        AnimationValue::ColorInterpolationFilters(computed)
                    },
                    LonghandId::ColumnCount => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_count();
                        let computed = computed.to_animated_value();
                        AnimationValue::ColumnCount(computed)
                    },
                    LonghandId::ColumnFill => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_fill();
                        AnimationValue::ColumnFill(computed)
                    },
                    LonghandId::ColumnRuleStyle => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_rule_style();
                        AnimationValue::ColumnRuleStyle(computed)
                    },
                    LonghandId::ColumnSpan => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_span();
                        AnimationValue::ColumnSpan(computed)
                    },
                    LonghandId::Contain => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_contain();
                        AnimationValue::Contain(computed)
                    },
                    LonghandId::Direction => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedbox()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedbox()
                            },
                        };
                        let computed = style_struct.clone_direction();
                        AnimationValue::Direction(computed)
                    },
                    LonghandId::DominantBaseline => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_dominant_baseline();
                        AnimationValue::DominantBaseline(computed)
                    },
                    LonghandId::EmptyCells => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtable()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtable()
                            },
                        };
                        let computed = style_struct.clone_empty_cells();
                        AnimationValue::EmptyCells(computed)
                    },
                    LonghandId::FillRule => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_fill_rule();
                        AnimationValue::FillRule(computed)
                    },
                    LonghandId::FlexDirection => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_flex_direction();
                        AnimationValue::FlexDirection(computed)
                    },
                    LonghandId::FlexWrap => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_flex_wrap();
                        AnimationValue::FlexWrap(computed)
                    },
                    LonghandId::Float => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_float();
                        AnimationValue::Float(computed)
                    },
                    LonghandId::FontKerning => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_kerning();
                        AnimationValue::FontKerning(computed)
                    },
                    LonghandId::FontOpticalSizing => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_optical_sizing();
                        AnimationValue::FontOpticalSizing(computed)
                    },
                    LonghandId::FontStretch => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_stretch();
                        AnimationValue::FontStretch(computed)
                    },
                    LonghandId::FontStyle => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_style();
                        AnimationValue::FontStyle(computed)
                    },
                    LonghandId::FontSynthesis => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_synthesis();
                        AnimationValue::FontSynthesis(computed)
                    },
                    LonghandId::FontVariantCaps => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_variant_caps();
                        AnimationValue::FontVariantCaps(computed)
                    },
                    LonghandId::FontVariantPosition => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_variant_position();
                        AnimationValue::FontVariantPosition(computed)
                    },
                    LonghandId::FontWeight => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_weight();
                        AnimationValue::FontWeight(computed)
                    },
                    LonghandId::GridAutoFlow => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_auto_flow();
                        AnimationValue::GridAutoFlow(computed)
                    },
                    LonghandId::Hyphens => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_hyphens();
                        AnimationValue::Hyphens(computed)
                    },
                    LonghandId::ImageOrientation => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedbox()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedbox()
                            },
                        };
                        let computed = style_struct.clone_image_orientation();
                        AnimationValue::ImageOrientation(computed)
                    },
                    LonghandId::ImageRendering => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedbox()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedbox()
                            },
                        };
                        let computed = style_struct.clone_image_rendering();
                        AnimationValue::ImageRendering(computed)
                    },
                    LonghandId::ImeMode => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone_ime_mode();
                        AnimationValue::ImeMode(computed)
                    },
                    LonghandId::InitialLetter => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct.clone_initial_letter();
                        AnimationValue::InitialLetter(computed)
                    },
                    LonghandId::Isolation => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_isolation();
                        AnimationValue::Isolation(computed)
                    },
                    LonghandId::JustifyContent => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_justify_content();
                        AnimationValue::JustifyContent(computed)
                    },
                    LonghandId::JustifyItems => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_justify_items();
                        AnimationValue::JustifyItems(computed)
                    },
                    LonghandId::JustifySelf => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_justify_self();
                        AnimationValue::JustifySelf(computed)
                    },
                    LonghandId::ListStylePosition => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_list()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_list()
                            },
                        };
                        let computed = style_struct.clone_list_style_position();
                        AnimationValue::ListStylePosition(computed)
                    },
                    LonghandId::MaskType => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_type();
                        AnimationValue::MaskType(computed)
                    },
                    LonghandId::MixBlendMode => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct.clone_mix_blend_mode();
                        AnimationValue::MixBlendMode(computed)
                    },
                    LonghandId::MozAppearance => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone__moz_appearance();
                        AnimationValue::MozAppearance(computed)
                    },
                    LonghandId::MozBoxAlign => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct.clone__moz_box_align();
                        AnimationValue::MozBoxAlign(computed)
                    },
                    LonghandId::MozBoxDirection => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct.clone__moz_box_direction();
                        AnimationValue::MozBoxDirection(computed)
                    },
                    LonghandId::MozBoxOrient => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct.clone__moz_box_orient();
                        AnimationValue::MozBoxOrient(computed)
                    },
                    LonghandId::MozBoxPack => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct.clone__moz_box_pack();
                        AnimationValue::MozBoxPack(computed)
                    },
                    LonghandId::MozFloatEdge => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone__moz_float_edge();
                        AnimationValue::MozFloatEdge(computed)
                    },
                    LonghandId::MozForceBrokenImageIcon => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone__moz_force_broken_image_icon();
                        AnimationValue::MozForceBrokenImageIcon(computed)
                    },
                    LonghandId::MozOrient => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone__moz_orient();
                        AnimationValue::MozOrient(computed)
                    },
                    LonghandId::MozOsxFontSmoothing => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone__moz_osx_font_smoothing();
                        AnimationValue::MozOsxFontSmoothing(computed)
                    },
                    LonghandId::MozStackSizing => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct.clone__moz_stack_sizing();
                        AnimationValue::MozStackSizing(computed)
                    },
                    LonghandId::MozTextSizeAdjust => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone__moz_text_size_adjust();
                        AnimationValue::MozTextSizeAdjust(computed)
                    },
                    LonghandId::MozUserFocus => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_pointing()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_pointing()
                            },
                        };
                        let computed = style_struct.clone__moz_user_focus();
                        AnimationValue::MozUserFocus(computed)
                    },
                    LonghandId::MozUserInput => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_pointing()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_pointing()
                            },
                        };
                        let computed = style_struct.clone__moz_user_input();
                        AnimationValue::MozUserInput(computed)
                    },
                    LonghandId::MozUserModify => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_pointing()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_pointing()
                            },
                        };
                        let computed = style_struct.clone__moz_user_modify();
                        AnimationValue::MozUserModify(computed)
                    },
                    LonghandId::MozUserSelect => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone__moz_user_select();
                        AnimationValue::MozUserSelect(computed)
                    },
                    LonghandId::MozWindowDragging => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone__moz_window_dragging();
                        AnimationValue::MozWindowDragging(computed)
                    },
                    LonghandId::MozWindowShadow => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone__moz_window_shadow();
                        AnimationValue::MozWindowShadow(computed)
                    },
                    LonghandId::ObjectFit => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_object_fit();
                        AnimationValue::ObjectFit(computed)
                    },
                    LonghandId::OutlineStyle => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone_outline_style();
                        AnimationValue::OutlineStyle(computed)
                    },
                    LonghandId::OverflowWrap => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_overflow_wrap();
                        AnimationValue::OverflowWrap(computed)
                    },
                    LonghandId::OverflowX => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_overflow_x();
                        AnimationValue::OverflowX(computed)
                    },
                    LonghandId::PageBreakAfter => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_page_break_after();
                        AnimationValue::PageBreakAfter(computed)
                    },
                    LonghandId::PageBreakBefore => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_page_break_before();
                        AnimationValue::PageBreakBefore(computed)
                    },
                    LonghandId::PageBreakInside => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_page_break_inside();
                        AnimationValue::PageBreakInside(computed)
                    },
                    LonghandId::PaintOrder => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_paint_order();
                        AnimationValue::PaintOrder(computed)
                    },
                    LonghandId::PointerEvents => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_pointing()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_pointing()
                            },
                        };
                        let computed = style_struct.clone_pointer_events();
                        AnimationValue::PointerEvents(computed)
                    },
                    LonghandId::Position => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_position();
                        AnimationValue::Position(computed)
                    },
                    LonghandId::Resize => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_resize();
                        AnimationValue::Resize(computed)
                    },
                    LonghandId::RubyAlign => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_ruby_align();
                        AnimationValue::RubyAlign(computed)
                    },
                    LonghandId::RubyPosition => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_ruby_position();
                        AnimationValue::RubyPosition(computed)
                    },
                    LonghandId::ScrollBehavior => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_scroll_behavior();
                        AnimationValue::ScrollBehavior(computed)
                    },
                    LonghandId::ShapeRendering => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_shape_rendering();
                        AnimationValue::ShapeRendering(computed)
                    },
                    LonghandId::StrokeLinecap => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke_linecap();
                        AnimationValue::StrokeLinecap(computed)
                    },
                    LonghandId::StrokeLinejoin => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke_linejoin();
                        AnimationValue::StrokeLinejoin(computed)
                    },
                    LonghandId::TableLayout => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_table()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_table()
                            },
                        };
                        let computed = style_struct.clone_table_layout();
                        AnimationValue::TableLayout(computed)
                    },
                    LonghandId::TextAlignLast => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_align_last();
                        AnimationValue::TextAlignLast(computed)
                    },
                    LonghandId::TextAnchor => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_text_anchor();
                        AnimationValue::TextAnchor(computed)
                    },
                    LonghandId::TextCombineUpright => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_combine_upright();
                        AnimationValue::TextCombineUpright(computed)
                    },
                    LonghandId::TextDecorationLine => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct.clone_text_decoration_line();
                        AnimationValue::TextDecorationLine(computed)
                    },
                    LonghandId::TextDecorationStyle => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct.clone_text_decoration_style();
                        AnimationValue::TextDecorationStyle(computed)
                    },
                    LonghandId::TextJustify => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_justify();
                        AnimationValue::TextJustify(computed)
                    },
                    LonghandId::TextOrientation => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedbox()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedbox()
                            },
                        };
                        let computed = style_struct.clone_text_orientation();
                        AnimationValue::TextOrientation(computed)
                    },
                    LonghandId::TextRendering => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_rendering();
                        AnimationValue::TextRendering(computed)
                    },
                    LonghandId::TextTransform => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_transform();
                        AnimationValue::TextTransform(computed)
                    },
                    LonghandId::TouchAction => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_touch_action();
                        AnimationValue::TouchAction(computed)
                    },
                    LonghandId::TransformBox => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_transform_box();
                        AnimationValue::TransformBox(computed)
                    },
                    LonghandId::TransformStyle => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_transform_style();
                        AnimationValue::TransformStyle(computed)
                    },
                    LonghandId::UnicodeBidi => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct.clone_unicode_bidi();
                        AnimationValue::UnicodeBidi(computed)
                    },
                    LonghandId::VectorEffect => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_vector_effect();
                        AnimationValue::VectorEffect(computed)
                    },
                    LonghandId::Visibility => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedbox()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedbox()
                            },
                        };
                        let computed = style_struct.clone_visibility();
                        AnimationValue::Visibility(computed)
                    },
                    LonghandId::WhiteSpace => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_white_space();
                        AnimationValue::WhiteSpace(computed)
                    },
                    LonghandId::WordBreak => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_word_break();
                        AnimationValue::WordBreak(computed)
                    },
                    LonghandId::WritingMode => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedbox()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedbox()
                            },
                        };
                        let computed = style_struct.clone_writing_mode();
                        AnimationValue::WritingMode(computed)
                    },
                    LonghandId::ZIndex => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_z_index();
                        AnimationValue::ZIndex(computed)
                    },
                    LonghandId::MozBoxOrdinalGroup => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct.clone__moz_box_ordinal_group();
                        AnimationValue::MozBoxOrdinalGroup(computed)
                    },
                    LonghandId::Order => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_order();
                        AnimationValue::Order(computed)
                    },
                    LonghandId::OverscrollBehaviorX => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_overscroll_behavior_x();
                        AnimationValue::OverscrollBehaviorX(computed)
                    },
                    LonghandId::OverscrollBehaviorY => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_overscroll_behavior_y();
                        AnimationValue::OverscrollBehaviorY(computed)
                    },
                    LonghandId::ScrollSnapTypeX => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_scroll_snap_type_x();
                        AnimationValue::ScrollSnapTypeX(computed)
                    },
                    LonghandId::ScrollSnapTypeY => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_scroll_snap_type_y();
                        AnimationValue::ScrollSnapTypeY(computed)
                    },
                    LonghandId::FlexGrow => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_flex_grow();
                        let computed = computed.to_animated_value();
                        AnimationValue::FlexGrow(computed)
                    },
                    LonghandId::FlexShrink => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_flex_shrink();
                        let computed = computed.to_animated_value();
                        AnimationValue::FlexShrink(computed)
                    },
                    LonghandId::MozBoxFlex => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct.clone__moz_box_flex();
                        let computed = computed.to_animated_value();
                        AnimationValue::MozBoxFlex(computed)
                    },
                    LonghandId::FloodOpacity => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_flood_opacity();
                        AnimationValue::FloodOpacity(computed)
                    },
                    LonghandId::MozWindowOpacity => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone__moz_window_opacity();
                        AnimationValue::MozWindowOpacity(computed)
                    },
                    LonghandId::Opacity => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct.clone_opacity();
                        AnimationValue::Opacity(computed)
                    },
                    LonghandId::ShapeImageThreshold => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_shape_image_threshold();
                        AnimationValue::ShapeImageThreshold(computed)
                    },
                    LonghandId::StopOpacity => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_stop_opacity();
                        AnimationValue::StopOpacity(computed)
                    },
                    LonghandId::BorderBottomStyle => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_bottom_style();
                        AnimationValue::BorderBottomStyle(computed)
                    },
                    LonghandId::BorderLeftStyle => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_left_style();
                        AnimationValue::BorderLeftStyle(computed)
                    },
                    LonghandId::BorderRightStyle => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_right_style();
                        AnimationValue::BorderRightStyle(computed)
                    },
                    LonghandId::BorderTopStyle => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_top_style();
                        AnimationValue::BorderTopStyle(computed)
                    },
                    LonghandId::BackgroundAttachment => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_attachment();
                        AnimationValue::BackgroundAttachment(computed)
                    },
                    LonghandId::BackgroundBlendMode => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_blend_mode();
                        AnimationValue::BackgroundBlendMode(computed)
                    },
                    LonghandId::BackgroundClip => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_clip();
                        AnimationValue::BackgroundClip(computed)
                    },
                    LonghandId::BackgroundImage => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_image();
                        AnimationValue::BackgroundImage(computed)
                    },
                    LonghandId::BackgroundOrigin => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_origin();
                        AnimationValue::BackgroundOrigin(computed)
                    },
                    LonghandId::BackgroundPositionX => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_position_x();
                        AnimationValue::BackgroundPositionX(computed)
                    },
                    LonghandId::BackgroundPositionY => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_position_y();
                        AnimationValue::BackgroundPositionY(computed)
                    },
                    LonghandId::BackgroundRepeat => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_repeat();
                        AnimationValue::BackgroundRepeat(computed)
                    },
                    LonghandId::BackgroundSize => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_size();
                        let computed = computed.to_animated_value();
                        AnimationValue::BackgroundSize(computed)
                    },
                    LonghandId::BorderImageOutset => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_image_outset();
                        AnimationValue::BorderImageOutset(computed)
                    },
                    LonghandId::BorderImageSlice => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_image_slice();
                        AnimationValue::BorderImageSlice(computed)
                    },
                    LonghandId::BorderImageSource => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_image_source();
                        AnimationValue::BorderImageSource(computed)
                    },
                    LonghandId::BorderImageWidth => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_image_width();
                        AnimationValue::BorderImageWidth(computed)
                    },
                    LonghandId::BorderSpacing => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtable()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtable()
                            },
                        };
                        let computed = style_struct.clone_border_spacing();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderSpacing(computed)
                    },
                    LonghandId::BoxShadow => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct.clone_box_shadow();
                        let computed = computed.to_animated_value();
                        AnimationValue::BoxShadow(computed)
                    },
                    LonghandId::CaretColor => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_pointing()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_pointing()
                            },
                        };
                        let computed = style_struct.clone_caret_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::CaretColor(computed)
                    },
                    LonghandId::ClipPath => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_clip_path();
                        AnimationValue::ClipPath(computed)
                    },
                    LonghandId::Color => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_color()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_color()
                            },
                        };
                        let computed = style_struct.clone_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::Color(computed)
                    },
                    LonghandId::ColumnGap => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_gap();
                        let computed = computed.to_animated_value();
                        AnimationValue::ColumnGap(computed)
                    },
                    LonghandId::ColumnWidth => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::ColumnWidth(computed)
                    },
                    LonghandId::Content => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_counters()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_counters()
                            },
                        };
                        let computed = style_struct.clone_content();
                        AnimationValue::Content(computed)
                    },
                    LonghandId::CounterIncrement => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_counters()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_counters()
                            },
                        };
                        let computed = style_struct.clone_counter_increment();
                        AnimationValue::CounterIncrement(computed)
                    },
                    LonghandId::CounterReset => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_counters()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_counters()
                            },
                        };
                        let computed = style_struct.clone_counter_reset();
                        AnimationValue::CounterReset(computed)
                    },
                    LonghandId::Cursor => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_pointing()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_pointing()
                            },
                        };
                        let computed = style_struct.clone_cursor();
                        AnimationValue::Cursor(computed)
                    },
                    LonghandId::Display => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_display();
                        AnimationValue::Display(computed)
                    },
                    LonghandId::Filter => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct.clone_filter();
                        let computed = computed.to_animated_value();
                        AnimationValue::Filter(computed)
                    },
                    LonghandId::FontFamily => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_family();
                        AnimationValue::FontFamily(computed)
                    },
                    LonghandId::FontFeatureSettings => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_feature_settings();
                        AnimationValue::FontFeatureSettings(computed)
                    },
                    LonghandId::FontLanguageOverride => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_language_override();
                        AnimationValue::FontLanguageOverride(computed)
                    },
                    LonghandId::FontSize => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_size();
                        let computed = computed.to_animated_value();
                        AnimationValue::FontSize(computed)
                    },
                    LonghandId::FontSizeAdjust => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_size_adjust();
                        AnimationValue::FontSizeAdjust(computed)
                    },
                    LonghandId::FontVariantAlternates => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_variant_alternates();
                        AnimationValue::FontVariantAlternates(computed)
                    },
                    LonghandId::FontVariantEastAsian => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_variant_east_asian();
                        AnimationValue::FontVariantEastAsian(computed)
                    },
                    LonghandId::FontVariantLigatures => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_variant_ligatures();
                        AnimationValue::FontVariantLigatures(computed)
                    },
                    LonghandId::FontVariantNumeric => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_variant_numeric();
                        AnimationValue::FontVariantNumeric(computed)
                    },
                    LonghandId::FontVariationSettings => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_variation_settings();
                        AnimationValue::FontVariationSettings(computed)
                    },
                    LonghandId::GridTemplateAreas => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_template_areas();
                        AnimationValue::GridTemplateAreas(computed)
                    },
                    LonghandId::LetterSpacing => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_letter_spacing();
                        AnimationValue::LetterSpacing(computed)
                    },
                    LonghandId::LineHeight => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_line_height();
                        let computed = computed.to_animated_value();
                        AnimationValue::LineHeight(computed)
                    },
                    LonghandId::ListStyleImage => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_list()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_list()
                            },
                        };
                        let computed = style_struct.clone_list_style_image();
                        AnimationValue::ListStyleImage(computed)
                    },
                    LonghandId::ListStyleType => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_list()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_list()
                            },
                        };
                        let computed = style_struct.clone_list_style_type();
                        AnimationValue::ListStyleType(computed)
                    },
                    LonghandId::MaskClip => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_clip();
                        AnimationValue::MaskClip(computed)
                    },
                    LonghandId::MaskComposite => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_composite();
                        AnimationValue::MaskComposite(computed)
                    },
                    LonghandId::MaskImage => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_image();
                        AnimationValue::MaskImage(computed)
                    },
                    LonghandId::MaskMode => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_mode();
                        AnimationValue::MaskMode(computed)
                    },
                    LonghandId::MaskOrigin => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_origin();
                        AnimationValue::MaskOrigin(computed)
                    },
                    LonghandId::MaskPositionX => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_position_x();
                        AnimationValue::MaskPositionX(computed)
                    },
                    LonghandId::MaskPositionY => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_position_y();
                        AnimationValue::MaskPositionY(computed)
                    },
                    LonghandId::MaskRepeat => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_repeat();
                        AnimationValue::MaskRepeat(computed)
                    },
                    LonghandId::MaskSize => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_size();
                        AnimationValue::MaskSize(computed)
                    },
                    LonghandId::MozTabSize => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone__moz_tab_size();
                        let computed = computed.to_animated_value();
                        AnimationValue::MozTabSize(computed)
                    },
                    LonghandId::OutlineOffset => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone_outline_offset();
                        AnimationValue::OutlineOffset(computed)
                    },
                    LonghandId::OverflowY => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_overflow_y();
                        AnimationValue::OverflowY(computed)
                    },
                    LonghandId::Perspective => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_perspective();
                        let computed = computed.to_animated_value();
                        AnimationValue::Perspective(computed)
                    },
                    LonghandId::PerspectiveOrigin => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_perspective_origin();
                        AnimationValue::PerspectiveOrigin(computed)
                    },
                    LonghandId::Quotes => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_list()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_list()
                            },
                        };
                        let computed = style_struct.clone_quotes();
                        AnimationValue::Quotes(computed)
                    },
                    LonghandId::Rotate => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_rotate();
                        AnimationValue::Rotate(computed)
                    },
                    LonghandId::Scale => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_scale();
                        AnimationValue::Scale(computed)
                    },
                    LonghandId::ScrollSnapCoordinate => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_scroll_snap_coordinate();
                        AnimationValue::ScrollSnapCoordinate(computed)
                    },
                    LonghandId::ShapeOutside => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_shape_outside();
                        AnimationValue::ShapeOutside(computed)
                    },
                    LonghandId::StrokeDasharray => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke_dasharray();
                        let computed = computed.to_animated_value();
                        AnimationValue::StrokeDasharray(computed)
                    },
                    LonghandId::StrokeDashoffset => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke_dashoffset();
                        AnimationValue::StrokeDashoffset(computed)
                    },
                    LonghandId::StrokeMiterlimit => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke_miterlimit();
                        let computed = computed.to_animated_value();
                        AnimationValue::StrokeMiterlimit(computed)
                    },
                    LonghandId::StrokeWidth => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::StrokeWidth(computed)
                    },
                    LonghandId::TextAlign => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_align();
                        AnimationValue::TextAlign(computed)
                    },
                    LonghandId::TextEmphasisPosition => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_emphasis_position();
                        AnimationValue::TextEmphasisPosition(computed)
                    },
                    LonghandId::TextEmphasisStyle => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_emphasis_style();
                        AnimationValue::TextEmphasisStyle(computed)
                    },
                    LonghandId::TextIndent => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_indent();
                        AnimationValue::TextIndent(computed)
                    },
                    LonghandId::TextOverflow => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct.clone_text_overflow();
                        AnimationValue::TextOverflow(computed)
                    },
                    LonghandId::TextShadow => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_shadow();
                        let computed = computed.to_animated_value();
                        AnimationValue::TextShadow(computed)
                    },
                    LonghandId::Translate => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_translate();
                        AnimationValue::Translate(computed)
                    },
                    LonghandId::VerticalAlign => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_vertical_align();
                        AnimationValue::VerticalAlign(computed)
                    },
                    LonghandId::WillChange => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_will_change();
                        AnimationValue::WillChange(computed)
                    },
                    LonghandId::WordSpacing => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_word_spacing();
                        AnimationValue::WordSpacing(computed)
                    },
                    LonghandId::OverflowClipBoxBlock => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_overflow_clip_box_block();
                        AnimationValue::OverflowClipBoxBlock(computed)
                    },
                    LonghandId::OverflowClipBoxInline => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_overflow_clip_box_inline();
                        AnimationValue::OverflowClipBoxInline(computed)
                    },
                    LonghandId::FillOpacity => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_fill_opacity();
                        AnimationValue::FillOpacity(computed)
                    },
                    LonghandId::StrokeOpacity => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke_opacity();
                        AnimationValue::StrokeOpacity(computed)
                    },
                    LonghandId::ScrollSnapPointsX => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_scroll_snap_points_x();
                        AnimationValue::ScrollSnapPointsX(computed)
                    },
                    LonghandId::ScrollSnapPointsY => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_scroll_snap_points_y();
                        AnimationValue::ScrollSnapPointsY(computed)
                    },
                    LonghandId::MozWindowTransform => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone__moz_window_transform();
                        AnimationValue::MozWindowTransform(computed)
                    },
                    LonghandId::Transform => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_transform();
                        AnimationValue::Transform(computed)
                    },
                    LonghandId::Clip => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct.clone_clip();
                        AnimationValue::Clip(computed)
                    },
                    LonghandId::MozImageRegion => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_list()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_list()
                            },
                        };
                        let computed = style_struct.clone__moz_image_region();
                        AnimationValue::MozImageRegion(computed)
                    },
                    LonghandId::GridTemplateColumns => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_template_columns();
                        AnimationValue::GridTemplateColumns(computed)
                    },
                    LonghandId::GridTemplateRows => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_template_rows();
                        AnimationValue::GridTemplateRows(computed)
                    },
                    LonghandId::ObjectPosition => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_object_position();
                        AnimationValue::ObjectPosition(computed)
                    },
                    LonghandId::ScrollSnapDestination => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_scroll_snap_destination();
                        AnimationValue::ScrollSnapDestination(computed)
                    },
                    LonghandId::Fill => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_fill();
                        let computed = computed.to_animated_value();
                        AnimationValue::Fill(computed)
                    },
                    LonghandId::Stroke => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke();
                        let computed = computed.to_animated_value();
                        AnimationValue::Stroke(computed)
                    },
                    LonghandId::GridAutoColumns => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_auto_columns();
                        AnimationValue::GridAutoColumns(computed)
                    },
                    LonghandId::GridAutoRows => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_auto_rows();
                        AnimationValue::GridAutoRows(computed)
                    },
                    LonghandId::MozWindowTransformOrigin => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone__moz_window_transform_origin();
                        AnimationValue::MozWindowTransformOrigin(computed)
                    },
                    LonghandId::TransformOrigin => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_transform_origin();
                        AnimationValue::TransformOrigin(computed)
                    },
                    LonghandId::MaxHeight => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_max_height();
                        let computed = computed.to_animated_value();
                        AnimationValue::MaxHeight(computed)
                    },
                    LonghandId::MaxWidth => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_max_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::MaxWidth(computed)
                    },
                    LonghandId::FloodColor => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_flood_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::FloodColor(computed)
                    },
                    LonghandId::LightingColor => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_lighting_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::LightingColor(computed)
                    },
                    LonghandId::MozFontSmoothingBackgroundColor => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone__moz_font_smoothing_background_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::MozFontSmoothingBackgroundColor(computed)
                    },
                    LonghandId::StopColor => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_stop_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::StopColor(computed)
                    },
                    LonghandId::MarkerEnd => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_marker_end();
                        AnimationValue::MarkerEnd(computed)
                    },
                    LonghandId::MarkerMid => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_marker_mid();
                        AnimationValue::MarkerMid(computed)
                    },
                    LonghandId::MarkerStart => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_marker_start();
                        AnimationValue::MarkerStart(computed)
                    },
                    LonghandId::GridColumnEnd => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_column_end();
                        AnimationValue::GridColumnEnd(computed)
                    },
                    LonghandId::GridColumnStart => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_column_start();
                        AnimationValue::GridColumnStart(computed)
                    },
                    LonghandId::GridRowEnd => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_row_end();
                        AnimationValue::GridRowEnd(computed)
                    },
                    LonghandId::GridRowStart => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_row_start();
                        AnimationValue::GridRowStart(computed)
                    },
                    LonghandId::BorderBottomLeftRadius => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_bottom_left_radius();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderBottomLeftRadius(computed)
                    },
                    LonghandId::BorderBottomRightRadius => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_bottom_right_radius();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderBottomRightRadius(computed)
                    },
                    LonghandId::BorderTopLeftRadius => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_top_left_radius();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderTopLeftRadius(computed)
                    },
                    LonghandId::BorderTopRightRadius => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_top_right_radius();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderTopRightRadius(computed)
                    },
                    LonghandId::MozOutlineRadiusBottomleft => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone__moz_outline_radius_bottomleft();
                        let computed = computed.to_animated_value();
                        AnimationValue::MozOutlineRadiusBottomleft(computed)
                    },
                    LonghandId::MozOutlineRadiusBottomright => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone__moz_outline_radius_bottomright();
                        let computed = computed.to_animated_value();
                        AnimationValue::MozOutlineRadiusBottomright(computed)
                    },
                    LonghandId::MozOutlineRadiusTopleft => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone__moz_outline_radius_topleft();
                        let computed = computed.to_animated_value();
                        AnimationValue::MozOutlineRadiusTopleft(computed)
                    },
                    LonghandId::MozOutlineRadiusTopright => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone__moz_outline_radius_topright();
                        let computed = computed.to_animated_value();
                        AnimationValue::MozOutlineRadiusTopright(computed)
                    },
                    LonghandId::FlexBasis => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_flex_basis();
                        let computed = computed.to_animated_value();
                        AnimationValue::FlexBasis(computed)
                    },
                    LonghandId::Height => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_height();
                        let computed = computed.to_animated_value();
                        AnimationValue::Height(computed)
                    },
                    LonghandId::MinHeight => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_min_height();
                        let computed = computed.to_animated_value();
                        AnimationValue::MinHeight(computed)
                    },
                    LonghandId::MinWidth => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_min_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::MinWidth(computed)
                    },
                    LonghandId::Width => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::Width(computed)
                    },
                    LonghandId::GridColumnGap => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_column_gap();
                        let computed = computed.to_animated_value();
                        AnimationValue::GridColumnGap(computed)
                    },
                    LonghandId::GridRowGap => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_row_gap();
                        let computed = computed.to_animated_value();
                        AnimationValue::GridRowGap(computed)
                    },
                    LonghandId::PaddingBottom => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct.clone_padding_bottom();
                        let computed = computed.to_animated_value();
                        AnimationValue::PaddingBottom(computed)
                    },
                    LonghandId::PaddingLeft => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct.clone_padding_left();
                        let computed = computed.to_animated_value();
                        AnimationValue::PaddingLeft(computed)
                    },
                    LonghandId::PaddingRight => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct.clone_padding_right();
                        let computed = computed.to_animated_value();
                        AnimationValue::PaddingRight(computed)
                    },
                    LonghandId::PaddingTop => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct.clone_padding_top();
                        let computed = computed.to_animated_value();
                        AnimationValue::PaddingTop(computed)
                    },
                    LonghandId::BorderBottomWidth => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_bottom_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderBottomWidth(computed)
                    },
                    LonghandId::BorderLeftWidth => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_left_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderLeftWidth(computed)
                    },
                    LonghandId::BorderRightWidth => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_right_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderRightWidth(computed)
                    },
                    LonghandId::BorderTopWidth => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_top_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderTopWidth(computed)
                    },
                    LonghandId::ColumnRuleWidth => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_rule_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::ColumnRuleWidth(computed)
                    },
                    LonghandId::OutlineWidth => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone_outline_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::OutlineWidth(computed)
                    },
                    LonghandId::WebkitTextStrokeWidth => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone__webkit_text_stroke_width();
                        AnimationValue::WebkitTextStrokeWidth(computed)
                    },
                    LonghandId::BackgroundColor => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::BackgroundColor(computed)
                    },
                    LonghandId::BorderBottomColor => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_bottom_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderBottomColor(computed)
                    },
                    LonghandId::BorderLeftColor => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_left_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderLeftColor(computed)
                    },
                    LonghandId::BorderRightColor => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_right_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderRightColor(computed)
                    },
                    LonghandId::BorderTopColor => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_top_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderTopColor(computed)
                    },
                    LonghandId::ColumnRuleColor => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_rule_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::ColumnRuleColor(computed)
                    },
                    LonghandId::OutlineColor => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone_outline_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::OutlineColor(computed)
                    },
                    LonghandId::TextDecorationColor => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct.clone_text_decoration_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::TextDecorationColor(computed)
                    },
                    LonghandId::TextEmphasisColor => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_emphasis_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::TextEmphasisColor(computed)
                    },
                    LonghandId::WebkitTextFillColor => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone__webkit_text_fill_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::WebkitTextFillColor(computed)
                    },
                    LonghandId::WebkitTextStrokeColor => {
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone__webkit_text_stroke_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::WebkitTextStrokeColor(computed)
                    },
                    LonghandId::Bottom => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_bottom();
                        AnimationValue::Bottom(computed)
                    },
                    LonghandId::Left => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_left();
                        AnimationValue::Left(computed)
                    },
                    LonghandId::MarginBottom => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct.clone_margin_bottom();
                        AnimationValue::MarginBottom(computed)
                    },
                    LonghandId::MarginLeft => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct.clone_margin_left();
                        AnimationValue::MarginLeft(computed)
                    },
                    LonghandId::MarginRight => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct.clone_margin_right();
                        AnimationValue::MarginRight(computed)
                    },
                    LonghandId::MarginTop => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct.clone_margin_top();
                        AnimationValue::MarginTop(computed)
                    },
                    LonghandId::Right => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_right();
                        AnimationValue::Right(computed)
                    },
                    LonghandId::Top => {
                        let style_struct = match declaration.keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_top();
                        AnimationValue::Top(computed)
                    },
                    LonghandId::MozControlCharacterVisibility => return None,
                    LonghandId::MozMathDisplay => return None,
                    LonghandId::MozMathVariant => return None,
                    LonghandId::MozMinFontSizeRatio => return None,
                    LonghandId::MozScriptLevel => return None,
                    LonghandId::MozScriptMinSize => return None,
                    LonghandId::MozScriptSizeMultiplier => return None,
                    LonghandId::MozTopLayer => return None,
                    LonghandId::XSpan => return None,
                    LonghandId::XTextZoom => return None,
                    LonghandId::BorderBlockEndStyle => return None,
                    LonghandId::BorderBlockStartStyle => return None,
                    LonghandId::BorderInlineEndStyle => return None,
                    LonghandId::BorderInlineStartStyle => return None,
                    LonghandId::AnimationDelay => return None,
                    LonghandId::AnimationDirection => return None,
                    LonghandId::AnimationDuration => return None,
                    LonghandId::AnimationFillMode => return None,
                    LonghandId::AnimationIterationCount => return None,
                    LonghandId::AnimationName => return None,
                    LonghandId::AnimationPlayState => return None,
                    LonghandId::AnimationTimingFunction => return None,
                    LonghandId::MozContextProperties => return None,
                    LonghandId::TransitionDelay => return None,
                    LonghandId::TransitionDuration => return None,
                    LonghandId::TransitionProperty => return None,
                    LonghandId::TransitionTimingFunction => return None,
                    LonghandId::XLang => return None,
                    LonghandId::MaxBlockSize => return None,
                    LonghandId::MaxInlineSize => return None,
                    LonghandId::MozBinding => return None,
                    LonghandId::BlockSize => return None,
                    LonghandId::InlineSize => return None,
                    LonghandId::MinBlockSize => return None,
                    LonghandId::MinInlineSize => return None,
                    LonghandId::PaddingBlockEnd => return None,
                    LonghandId::PaddingBlockStart => return None,
                    LonghandId::PaddingInlineEnd => return None,
                    LonghandId::PaddingInlineStart => return None,
                    LonghandId::BorderBlockEndWidth => return None,
                    LonghandId::BorderBlockStartWidth => return None,
                    LonghandId::BorderInlineEndWidth => return None,
                    LonghandId::BorderInlineStartWidth => return None,
                    LonghandId::BorderBlockEndColor => return None,
                    LonghandId::BorderBlockStartColor => return None,
                    LonghandId::BorderInlineEndColor => return None,
                    LonghandId::BorderInlineStartColor => return None,
                    LonghandId::MarginBlockEnd => return None,
                    LonghandId::MarginBlockStart => return None,
                    LonghandId::MarginInlineEnd => return None,
                    LonghandId::MarginInlineStart => return None,
                    LonghandId::OffsetBlockEnd => return None,
                    LonghandId::OffsetBlockStart => return None,
                    LonghandId::OffsetInlineEnd => return None,
                    LonghandId::OffsetInlineStart => return None,
                }
            },
            PropertyDeclaration::WithVariables(ref declaration) => {
                let substituted = {
                    let custom_properties =
                        extra_custom_properties.or_else(|| context.style().custom_properties());

                    declaration.value.substitute_variables(
                        declaration.id,
                        custom_properties,
                        context.quirks_mode,
                    )
                };
                return AnimationValue::from_declaration(
                    &substituted,
                    context,
                    extra_custom_properties,
                    initial,
                )
            },
            _ => return None // non animatable properties will get included because of shorthands. ignore.
        };
        Some(animatable)
    }

    /// Get an AnimationValue for an AnimatableLonghand from a given computed values.
    pub fn from_computed_values(
        property: LonghandId,
        computed_values: &ComputedValues
    ) -> Option<Self> {
        Some(match property {
            LonghandId::AlignContent => {
                let computed = computed_values
                    .get_position()
                    .clone_align_content();
                AnimationValue::AlignContent(
                    computed
                )
            }
            LonghandId::AlignItems => {
                let computed = computed_values
                    .get_position()
                    .clone_align_items();
                AnimationValue::AlignItems(
                    computed
                )
            }
            LonghandId::AlignSelf => {
                let computed = computed_values
                    .get_position()
                    .clone_align_self();
                AnimationValue::AlignSelf(
                    computed
                )
            }
            LonghandId::BackfaceVisibility => {
                let computed = computed_values
                    .get_box()
                    .clone_backface_visibility();
                AnimationValue::BackfaceVisibility(
                    computed
                )
            }
            LonghandId::BorderCollapse => {
                let computed = computed_values
                    .get_inheritedtable()
                    .clone_border_collapse();
                AnimationValue::BorderCollapse(
                    computed
                )
            }
            LonghandId::BorderImageRepeat => {
                let computed = computed_values
                    .get_border()
                    .clone_border_image_repeat();
                AnimationValue::BorderImageRepeat(
                    computed
                )
            }
            LonghandId::BoxDecorationBreak => {
                let computed = computed_values
                    .get_border()
                    .clone_box_decoration_break();
                AnimationValue::BoxDecorationBreak(
                    computed
                )
            }
            LonghandId::BoxSizing => {
                let computed = computed_values
                    .get_position()
                    .clone_box_sizing();
                AnimationValue::BoxSizing(
                    computed
                )
            }
            LonghandId::CaptionSide => {
                let computed = computed_values
                    .get_inheritedtable()
                    .clone_caption_side();
                AnimationValue::CaptionSide(
                    computed
                )
            }
            LonghandId::Clear => {
                let computed = computed_values
                    .get_box()
                    .clone_clear();
                AnimationValue::Clear(
                    computed
                )
            }
            LonghandId::ClipRule => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_clip_rule();
                AnimationValue::ClipRule(
                    computed
                )
            }
            LonghandId::ColorAdjust => {
                let computed = computed_values
                    .get_inheritedbox()
                    .clone_color_adjust();
                AnimationValue::ColorAdjust(
                    computed
                )
            }
            LonghandId::ColorInterpolation => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_color_interpolation();
                AnimationValue::ColorInterpolation(
                    computed
                )
            }
            LonghandId::ColorInterpolationFilters => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_color_interpolation_filters();
                AnimationValue::ColorInterpolationFilters(
                    computed
                )
            }
            LonghandId::ColumnCount => {
                let computed = computed_values
                    .get_column()
                    .clone_column_count();
                AnimationValue::ColumnCount(
                    computed.to_animated_value()
                )
            }
            LonghandId::ColumnFill => {
                let computed = computed_values
                    .get_column()
                    .clone_column_fill();
                AnimationValue::ColumnFill(
                    computed
                )
            }
            LonghandId::ColumnRuleStyle => {
                let computed = computed_values
                    .get_column()
                    .clone_column_rule_style();
                AnimationValue::ColumnRuleStyle(
                    computed
                )
            }
            LonghandId::ColumnSpan => {
                let computed = computed_values
                    .get_column()
                    .clone_column_span();
                AnimationValue::ColumnSpan(
                    computed
                )
            }
            LonghandId::Contain => {
                let computed = computed_values
                    .get_box()
                    .clone_contain();
                AnimationValue::Contain(
                    computed
                )
            }
            LonghandId::Direction => {
                let computed = computed_values
                    .get_inheritedbox()
                    .clone_direction();
                AnimationValue::Direction(
                    computed
                )
            }
            LonghandId::DominantBaseline => {
                let computed = computed_values
                    .get_svg()
                    .clone_dominant_baseline();
                AnimationValue::DominantBaseline(
                    computed
                )
            }
            LonghandId::EmptyCells => {
                let computed = computed_values
                    .get_inheritedtable()
                    .clone_empty_cells();
                AnimationValue::EmptyCells(
                    computed
                )
            }
            LonghandId::FillRule => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_fill_rule();
                AnimationValue::FillRule(
                    computed
                )
            }
            LonghandId::FlexDirection => {
                let computed = computed_values
                    .get_position()
                    .clone_flex_direction();
                AnimationValue::FlexDirection(
                    computed
                )
            }
            LonghandId::FlexWrap => {
                let computed = computed_values
                    .get_position()
                    .clone_flex_wrap();
                AnimationValue::FlexWrap(
                    computed
                )
            }
            LonghandId::Float => {
                let computed = computed_values
                    .get_box()
                    .clone_float();
                AnimationValue::Float(
                    computed
                )
            }
            LonghandId::FontKerning => {
                let computed = computed_values
                    .get_font()
                    .clone_font_kerning();
                AnimationValue::FontKerning(
                    computed
                )
            }
            LonghandId::FontOpticalSizing => {
                let computed = computed_values
                    .get_font()
                    .clone_font_optical_sizing();
                AnimationValue::FontOpticalSizing(
                    computed
                )
            }
            LonghandId::FontStretch => {
                let computed = computed_values
                    .get_font()
                    .clone_font_stretch();
                AnimationValue::FontStretch(
                    computed
                )
            }
            LonghandId::FontStyle => {
                let computed = computed_values
                    .get_font()
                    .clone_font_style();
                AnimationValue::FontStyle(
                    computed
                )
            }
            LonghandId::FontSynthesis => {
                let computed = computed_values
                    .get_font()
                    .clone_font_synthesis();
                AnimationValue::FontSynthesis(
                    computed
                )
            }
            LonghandId::FontVariantCaps => {
                let computed = computed_values
                    .get_font()
                    .clone_font_variant_caps();
                AnimationValue::FontVariantCaps(
                    computed
                )
            }
            LonghandId::FontVariantPosition => {
                let computed = computed_values
                    .get_font()
                    .clone_font_variant_position();
                AnimationValue::FontVariantPosition(
                    computed
                )
            }
            LonghandId::FontWeight => {
                let computed = computed_values
                    .get_font()
                    .clone_font_weight();
                AnimationValue::FontWeight(
                    computed
                )
            }
            LonghandId::GridAutoFlow => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_auto_flow();
                AnimationValue::GridAutoFlow(
                    computed
                )
            }
            LonghandId::Hyphens => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_hyphens();
                AnimationValue::Hyphens(
                    computed
                )
            }
            LonghandId::ImageOrientation => {
                let computed = computed_values
                    .get_inheritedbox()
                    .clone_image_orientation();
                AnimationValue::ImageOrientation(
                    computed
                )
            }
            LonghandId::ImageRendering => {
                let computed = computed_values
                    .get_inheritedbox()
                    .clone_image_rendering();
                AnimationValue::ImageRendering(
                    computed
                )
            }
            LonghandId::ImeMode => {
                let computed = computed_values
                    .get_ui()
                    .clone_ime_mode();
                AnimationValue::ImeMode(
                    computed
                )
            }
            LonghandId::InitialLetter => {
                let computed = computed_values
                    .get_text()
                    .clone_initial_letter();
                AnimationValue::InitialLetter(
                    computed
                )
            }
            LonghandId::Isolation => {
                let computed = computed_values
                    .get_box()
                    .clone_isolation();
                AnimationValue::Isolation(
                    computed
                )
            }
            LonghandId::JustifyContent => {
                let computed = computed_values
                    .get_position()
                    .clone_justify_content();
                AnimationValue::JustifyContent(
                    computed
                )
            }
            LonghandId::JustifyItems => {
                let computed = computed_values
                    .get_position()
                    .clone_justify_items();
                AnimationValue::JustifyItems(
                    computed
                )
            }
            LonghandId::JustifySelf => {
                let computed = computed_values
                    .get_position()
                    .clone_justify_self();
                AnimationValue::JustifySelf(
                    computed
                )
            }
            LonghandId::ListStylePosition => {
                let computed = computed_values
                    .get_list()
                    .clone_list_style_position();
                AnimationValue::ListStylePosition(
                    computed
                )
            }
            LonghandId::MaskType => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_type();
                AnimationValue::MaskType(
                    computed
                )
            }
            LonghandId::MixBlendMode => {
                let computed = computed_values
                    .get_effects()
                    .clone_mix_blend_mode();
                AnimationValue::MixBlendMode(
                    computed
                )
            }
            LonghandId::MozAppearance => {
                let computed = computed_values
                    .get_box()
                    .clone__moz_appearance();
                AnimationValue::MozAppearance(
                    computed
                )
            }
            LonghandId::MozBoxAlign => {
                let computed = computed_values
                    .get_xul()
                    .clone__moz_box_align();
                AnimationValue::MozBoxAlign(
                    computed
                )
            }
            LonghandId::MozBoxDirection => {
                let computed = computed_values
                    .get_xul()
                    .clone__moz_box_direction();
                AnimationValue::MozBoxDirection(
                    computed
                )
            }
            LonghandId::MozBoxOrient => {
                let computed = computed_values
                    .get_xul()
                    .clone__moz_box_orient();
                AnimationValue::MozBoxOrient(
                    computed
                )
            }
            LonghandId::MozBoxPack => {
                let computed = computed_values
                    .get_xul()
                    .clone__moz_box_pack();
                AnimationValue::MozBoxPack(
                    computed
                )
            }
            LonghandId::MozFloatEdge => {
                let computed = computed_values
                    .get_border()
                    .clone__moz_float_edge();
                AnimationValue::MozFloatEdge(
                    computed
                )
            }
            LonghandId::MozForceBrokenImageIcon => {
                let computed = computed_values
                    .get_ui()
                    .clone__moz_force_broken_image_icon();
                AnimationValue::MozForceBrokenImageIcon(
                    computed
                )
            }
            LonghandId::MozOrient => {
                let computed = computed_values
                    .get_box()
                    .clone__moz_orient();
                AnimationValue::MozOrient(
                    computed
                )
            }
            LonghandId::MozOsxFontSmoothing => {
                let computed = computed_values
                    .get_font()
                    .clone__moz_osx_font_smoothing();
                AnimationValue::MozOsxFontSmoothing(
                    computed
                )
            }
            LonghandId::MozStackSizing => {
                let computed = computed_values
                    .get_xul()
                    .clone__moz_stack_sizing();
                AnimationValue::MozStackSizing(
                    computed
                )
            }
            LonghandId::MozTextSizeAdjust => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone__moz_text_size_adjust();
                AnimationValue::MozTextSizeAdjust(
                    computed
                )
            }
            LonghandId::MozUserFocus => {
                let computed = computed_values
                    .get_pointing()
                    .clone__moz_user_focus();
                AnimationValue::MozUserFocus(
                    computed
                )
            }
            LonghandId::MozUserInput => {
                let computed = computed_values
                    .get_pointing()
                    .clone__moz_user_input();
                AnimationValue::MozUserInput(
                    computed
                )
            }
            LonghandId::MozUserModify => {
                let computed = computed_values
                    .get_pointing()
                    .clone__moz_user_modify();
                AnimationValue::MozUserModify(
                    computed
                )
            }
            LonghandId::MozUserSelect => {
                let computed = computed_values
                    .get_ui()
                    .clone__moz_user_select();
                AnimationValue::MozUserSelect(
                    computed
                )
            }
            LonghandId::MozWindowDragging => {
                let computed = computed_values
                    .get_ui()
                    .clone__moz_window_dragging();
                AnimationValue::MozWindowDragging(
                    computed
                )
            }
            LonghandId::MozWindowShadow => {
                let computed = computed_values
                    .get_ui()
                    .clone__moz_window_shadow();
                AnimationValue::MozWindowShadow(
                    computed
                )
            }
            LonghandId::ObjectFit => {
                let computed = computed_values
                    .get_position()
                    .clone_object_fit();
                AnimationValue::ObjectFit(
                    computed
                )
            }
            LonghandId::OutlineStyle => {
                let computed = computed_values
                    .get_outline()
                    .clone_outline_style();
                AnimationValue::OutlineStyle(
                    computed
                )
            }
            LonghandId::OverflowWrap => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_overflow_wrap();
                AnimationValue::OverflowWrap(
                    computed
                )
            }
            LonghandId::OverflowX => {
                let computed = computed_values
                    .get_box()
                    .clone_overflow_x();
                AnimationValue::OverflowX(
                    computed
                )
            }
            LonghandId::PageBreakAfter => {
                let computed = computed_values
                    .get_box()
                    .clone_page_break_after();
                AnimationValue::PageBreakAfter(
                    computed
                )
            }
            LonghandId::PageBreakBefore => {
                let computed = computed_values
                    .get_box()
                    .clone_page_break_before();
                AnimationValue::PageBreakBefore(
                    computed
                )
            }
            LonghandId::PageBreakInside => {
                let computed = computed_values
                    .get_box()
                    .clone_page_break_inside();
                AnimationValue::PageBreakInside(
                    computed
                )
            }
            LonghandId::PaintOrder => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_paint_order();
                AnimationValue::PaintOrder(
                    computed
                )
            }
            LonghandId::PointerEvents => {
                let computed = computed_values
                    .get_pointing()
                    .clone_pointer_events();
                AnimationValue::PointerEvents(
                    computed
                )
            }
            LonghandId::Position => {
                let computed = computed_values
                    .get_box()
                    .clone_position();
                AnimationValue::Position(
                    computed
                )
            }
            LonghandId::Resize => {
                let computed = computed_values
                    .get_box()
                    .clone_resize();
                AnimationValue::Resize(
                    computed
                )
            }
            LonghandId::RubyAlign => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_ruby_align();
                AnimationValue::RubyAlign(
                    computed
                )
            }
            LonghandId::RubyPosition => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_ruby_position();
                AnimationValue::RubyPosition(
                    computed
                )
            }
            LonghandId::ScrollBehavior => {
                let computed = computed_values
                    .get_box()
                    .clone_scroll_behavior();
                AnimationValue::ScrollBehavior(
                    computed
                )
            }
            LonghandId::ShapeRendering => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_shape_rendering();
                AnimationValue::ShapeRendering(
                    computed
                )
            }
            LonghandId::StrokeLinecap => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke_linecap();
                AnimationValue::StrokeLinecap(
                    computed
                )
            }
            LonghandId::StrokeLinejoin => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke_linejoin();
                AnimationValue::StrokeLinejoin(
                    computed
                )
            }
            LonghandId::TableLayout => {
                let computed = computed_values
                    .get_table()
                    .clone_table_layout();
                AnimationValue::TableLayout(
                    computed
                )
            }
            LonghandId::TextAlignLast => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_align_last();
                AnimationValue::TextAlignLast(
                    computed
                )
            }
            LonghandId::TextAnchor => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_text_anchor();
                AnimationValue::TextAnchor(
                    computed
                )
            }
            LonghandId::TextCombineUpright => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_combine_upright();
                AnimationValue::TextCombineUpright(
                    computed
                )
            }
            LonghandId::TextDecorationLine => {
                let computed = computed_values
                    .get_text()
                    .clone_text_decoration_line();
                AnimationValue::TextDecorationLine(
                    computed
                )
            }
            LonghandId::TextDecorationStyle => {
                let computed = computed_values
                    .get_text()
                    .clone_text_decoration_style();
                AnimationValue::TextDecorationStyle(
                    computed
                )
            }
            LonghandId::TextJustify => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_justify();
                AnimationValue::TextJustify(
                    computed
                )
            }
            LonghandId::TextOrientation => {
                let computed = computed_values
                    .get_inheritedbox()
                    .clone_text_orientation();
                AnimationValue::TextOrientation(
                    computed
                )
            }
            LonghandId::TextRendering => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_rendering();
                AnimationValue::TextRendering(
                    computed
                )
            }
            LonghandId::TextTransform => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_transform();
                AnimationValue::TextTransform(
                    computed
                )
            }
            LonghandId::TouchAction => {
                let computed = computed_values
                    .get_box()
                    .clone_touch_action();
                AnimationValue::TouchAction(
                    computed
                )
            }
            LonghandId::TransformBox => {
                let computed = computed_values
                    .get_box()
                    .clone_transform_box();
                AnimationValue::TransformBox(
                    computed
                )
            }
            LonghandId::TransformStyle => {
                let computed = computed_values
                    .get_box()
                    .clone_transform_style();
                AnimationValue::TransformStyle(
                    computed
                )
            }
            LonghandId::UnicodeBidi => {
                let computed = computed_values
                    .get_text()
                    .clone_unicode_bidi();
                AnimationValue::UnicodeBidi(
                    computed
                )
            }
            LonghandId::VectorEffect => {
                let computed = computed_values
                    .get_svg()
                    .clone_vector_effect();
                AnimationValue::VectorEffect(
                    computed
                )
            }
            LonghandId::Visibility => {
                let computed = computed_values
                    .get_inheritedbox()
                    .clone_visibility();
                AnimationValue::Visibility(
                    computed
                )
            }
            LonghandId::WhiteSpace => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_white_space();
                AnimationValue::WhiteSpace(
                    computed
                )
            }
            LonghandId::WordBreak => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_word_break();
                AnimationValue::WordBreak(
                    computed
                )
            }
            LonghandId::WritingMode => {
                let computed = computed_values
                    .get_inheritedbox()
                    .clone_writing_mode();
                AnimationValue::WritingMode(
                    computed
                )
            }
            LonghandId::ZIndex => {
                let computed = computed_values
                    .get_position()
                    .clone_z_index();
                AnimationValue::ZIndex(
                    computed
                )
            }
            LonghandId::MozBoxOrdinalGroup => {
                let computed = computed_values
                    .get_xul()
                    .clone__moz_box_ordinal_group();
                AnimationValue::MozBoxOrdinalGroup(
                    computed
                )
            }
            LonghandId::Order => {
                let computed = computed_values
                    .get_position()
                    .clone_order();
                AnimationValue::Order(
                    computed
                )
            }
            LonghandId::OverscrollBehaviorX => {
                let computed = computed_values
                    .get_box()
                    .clone_overscroll_behavior_x();
                AnimationValue::OverscrollBehaviorX(
                    computed
                )
            }
            LonghandId::OverscrollBehaviorY => {
                let computed = computed_values
                    .get_box()
                    .clone_overscroll_behavior_y();
                AnimationValue::OverscrollBehaviorY(
                    computed
                )
            }
            LonghandId::ScrollSnapTypeX => {
                let computed = computed_values
                    .get_box()
                    .clone_scroll_snap_type_x();
                AnimationValue::ScrollSnapTypeX(
                    computed
                )
            }
            LonghandId::ScrollSnapTypeY => {
                let computed = computed_values
                    .get_box()
                    .clone_scroll_snap_type_y();
                AnimationValue::ScrollSnapTypeY(
                    computed
                )
            }
            LonghandId::FlexGrow => {
                let computed = computed_values
                    .get_position()
                    .clone_flex_grow();
                AnimationValue::FlexGrow(
                    computed.to_animated_value()
                )
            }
            LonghandId::FlexShrink => {
                let computed = computed_values
                    .get_position()
                    .clone_flex_shrink();
                AnimationValue::FlexShrink(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozBoxFlex => {
                let computed = computed_values
                    .get_xul()
                    .clone__moz_box_flex();
                AnimationValue::MozBoxFlex(
                    computed.to_animated_value()
                )
            }
            LonghandId::FloodOpacity => {
                let computed = computed_values
                    .get_svg()
                    .clone_flood_opacity();
                AnimationValue::FloodOpacity(
                    computed
                )
            }
            LonghandId::MozWindowOpacity => {
                let computed = computed_values
                    .get_ui()
                    .clone__moz_window_opacity();
                AnimationValue::MozWindowOpacity(
                    computed
                )
            }
            LonghandId::Opacity => {
                let computed = computed_values
                    .get_effects()
                    .clone_opacity();
                AnimationValue::Opacity(
                    computed
                )
            }
            LonghandId::ShapeImageThreshold => {
                let computed = computed_values
                    .get_box()
                    .clone_shape_image_threshold();
                AnimationValue::ShapeImageThreshold(
                    computed
                )
            }
            LonghandId::StopOpacity => {
                let computed = computed_values
                    .get_svg()
                    .clone_stop_opacity();
                AnimationValue::StopOpacity(
                    computed
                )
            }
            LonghandId::BorderBottomStyle => {
                let computed = computed_values
                    .get_border()
                    .clone_border_bottom_style();
                AnimationValue::BorderBottomStyle(
                    computed
                )
            }
            LonghandId::BorderLeftStyle => {
                let computed = computed_values
                    .get_border()
                    .clone_border_left_style();
                AnimationValue::BorderLeftStyle(
                    computed
                )
            }
            LonghandId::BorderRightStyle => {
                let computed = computed_values
                    .get_border()
                    .clone_border_right_style();
                AnimationValue::BorderRightStyle(
                    computed
                )
            }
            LonghandId::BorderTopStyle => {
                let computed = computed_values
                    .get_border()
                    .clone_border_top_style();
                AnimationValue::BorderTopStyle(
                    computed
                )
            }
            LonghandId::BackgroundAttachment => {
                let computed = computed_values
                    .get_background()
                    .clone_background_attachment();
                AnimationValue::BackgroundAttachment(
                    computed
                )
            }
            LonghandId::BackgroundBlendMode => {
                let computed = computed_values
                    .get_background()
                    .clone_background_blend_mode();
                AnimationValue::BackgroundBlendMode(
                    computed
                )
            }
            LonghandId::BackgroundClip => {
                let computed = computed_values
                    .get_background()
                    .clone_background_clip();
                AnimationValue::BackgroundClip(
                    computed
                )
            }
            LonghandId::BackgroundImage => {
                let computed = computed_values
                    .get_background()
                    .clone_background_image();
                AnimationValue::BackgroundImage(
                    computed
                )
            }
            LonghandId::BackgroundOrigin => {
                let computed = computed_values
                    .get_background()
                    .clone_background_origin();
                AnimationValue::BackgroundOrigin(
                    computed
                )
            }
            LonghandId::BackgroundPositionX => {
                let computed = computed_values
                    .get_background()
                    .clone_background_position_x();
                AnimationValue::BackgroundPositionX(
                    computed
                )
            }
            LonghandId::BackgroundPositionY => {
                let computed = computed_values
                    .get_background()
                    .clone_background_position_y();
                AnimationValue::BackgroundPositionY(
                    computed
                )
            }
            LonghandId::BackgroundRepeat => {
                let computed = computed_values
                    .get_background()
                    .clone_background_repeat();
                AnimationValue::BackgroundRepeat(
                    computed
                )
            }
            LonghandId::BackgroundSize => {
                let computed = computed_values
                    .get_background()
                    .clone_background_size();
                AnimationValue::BackgroundSize(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderImageOutset => {
                let computed = computed_values
                    .get_border()
                    .clone_border_image_outset();
                AnimationValue::BorderImageOutset(
                    computed
                )
            }
            LonghandId::BorderImageSlice => {
                let computed = computed_values
                    .get_border()
                    .clone_border_image_slice();
                AnimationValue::BorderImageSlice(
                    computed
                )
            }
            LonghandId::BorderImageSource => {
                let computed = computed_values
                    .get_border()
                    .clone_border_image_source();
                AnimationValue::BorderImageSource(
                    computed
                )
            }
            LonghandId::BorderImageWidth => {
                let computed = computed_values
                    .get_border()
                    .clone_border_image_width();
                AnimationValue::BorderImageWidth(
                    computed
                )
            }
            LonghandId::BorderSpacing => {
                let computed = computed_values
                    .get_inheritedtable()
                    .clone_border_spacing();
                AnimationValue::BorderSpacing(
                    computed.to_animated_value()
                )
            }
            LonghandId::BoxShadow => {
                let computed = computed_values
                    .get_effects()
                    .clone_box_shadow();
                AnimationValue::BoxShadow(
                    computed.to_animated_value()
                )
            }
            LonghandId::CaretColor => {
                let computed = computed_values
                    .get_pointing()
                    .clone_caret_color();
                AnimationValue::CaretColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::ClipPath => {
                let computed = computed_values
                    .get_svg()
                    .clone_clip_path();
                AnimationValue::ClipPath(
                    computed
                )
            }
            LonghandId::Color => {
                let computed = computed_values
                    .get_color()
                    .clone_color();
                AnimationValue::Color(
                    computed.to_animated_value()
                )
            }
            LonghandId::ColumnGap => {
                let computed = computed_values
                    .get_column()
                    .clone_column_gap();
                AnimationValue::ColumnGap(
                    computed.to_animated_value()
                )
            }
            LonghandId::ColumnWidth => {
                let computed = computed_values
                    .get_column()
                    .clone_column_width();
                AnimationValue::ColumnWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::Content => {
                let computed = computed_values
                    .get_counters()
                    .clone_content();
                AnimationValue::Content(
                    computed
                )
            }
            LonghandId::CounterIncrement => {
                let computed = computed_values
                    .get_counters()
                    .clone_counter_increment();
                AnimationValue::CounterIncrement(
                    computed
                )
            }
            LonghandId::CounterReset => {
                let computed = computed_values
                    .get_counters()
                    .clone_counter_reset();
                AnimationValue::CounterReset(
                    computed
                )
            }
            LonghandId::Cursor => {
                let computed = computed_values
                    .get_pointing()
                    .clone_cursor();
                AnimationValue::Cursor(
                    computed
                )
            }
            LonghandId::Display => {
                let computed = computed_values
                    .get_box()
                    .clone_display();
                AnimationValue::Display(
                    computed
                )
            }
            LonghandId::Filter => {
                let computed = computed_values
                    .get_effects()
                    .clone_filter();
                AnimationValue::Filter(
                    computed.to_animated_value()
                )
            }
            LonghandId::FontFamily => {
                let computed = computed_values
                    .get_font()
                    .clone_font_family();
                AnimationValue::FontFamily(
                    computed
                )
            }
            LonghandId::FontFeatureSettings => {
                let computed = computed_values
                    .get_font()
                    .clone_font_feature_settings();
                AnimationValue::FontFeatureSettings(
                    computed
                )
            }
            LonghandId::FontLanguageOverride => {
                let computed = computed_values
                    .get_font()
                    .clone_font_language_override();
                AnimationValue::FontLanguageOverride(
                    computed
                )
            }
            LonghandId::FontSize => {
                let computed = computed_values
                    .get_font()
                    .clone_font_size();
                AnimationValue::FontSize(
                    computed.to_animated_value()
                )
            }
            LonghandId::FontSizeAdjust => {
                let computed = computed_values
                    .get_font()
                    .clone_font_size_adjust();
                AnimationValue::FontSizeAdjust(
                    computed
                )
            }
            LonghandId::FontVariantAlternates => {
                let computed = computed_values
                    .get_font()
                    .clone_font_variant_alternates();
                AnimationValue::FontVariantAlternates(
                    computed
                )
            }
            LonghandId::FontVariantEastAsian => {
                let computed = computed_values
                    .get_font()
                    .clone_font_variant_east_asian();
                AnimationValue::FontVariantEastAsian(
                    computed
                )
            }
            LonghandId::FontVariantLigatures => {
                let computed = computed_values
                    .get_font()
                    .clone_font_variant_ligatures();
                AnimationValue::FontVariantLigatures(
                    computed
                )
            }
            LonghandId::FontVariantNumeric => {
                let computed = computed_values
                    .get_font()
                    .clone_font_variant_numeric();
                AnimationValue::FontVariantNumeric(
                    computed
                )
            }
            LonghandId::FontVariationSettings => {
                let computed = computed_values
                    .get_font()
                    .clone_font_variation_settings();
                AnimationValue::FontVariationSettings(
                    computed
                )
            }
            LonghandId::GridTemplateAreas => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_template_areas();
                AnimationValue::GridTemplateAreas(
                    computed
                )
            }
            LonghandId::LetterSpacing => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_letter_spacing();
                AnimationValue::LetterSpacing(
                    computed
                )
            }
            LonghandId::LineHeight => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_line_height();
                AnimationValue::LineHeight(
                    computed.to_animated_value()
                )
            }
            LonghandId::ListStyleImage => {
                let computed = computed_values
                    .get_list()
                    .clone_list_style_image();
                AnimationValue::ListStyleImage(
                    computed
                )
            }
            LonghandId::ListStyleType => {
                let computed = computed_values
                    .get_list()
                    .clone_list_style_type();
                AnimationValue::ListStyleType(
                    computed
                )
            }
            LonghandId::MaskClip => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_clip();
                AnimationValue::MaskClip(
                    computed
                )
            }
            LonghandId::MaskComposite => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_composite();
                AnimationValue::MaskComposite(
                    computed
                )
            }
            LonghandId::MaskImage => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_image();
                AnimationValue::MaskImage(
                    computed
                )
            }
            LonghandId::MaskMode => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_mode();
                AnimationValue::MaskMode(
                    computed
                )
            }
            LonghandId::MaskOrigin => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_origin();
                AnimationValue::MaskOrigin(
                    computed
                )
            }
            LonghandId::MaskPositionX => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_position_x();
                AnimationValue::MaskPositionX(
                    computed
                )
            }
            LonghandId::MaskPositionY => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_position_y();
                AnimationValue::MaskPositionY(
                    computed
                )
            }
            LonghandId::MaskRepeat => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_repeat();
                AnimationValue::MaskRepeat(
                    computed
                )
            }
            LonghandId::MaskSize => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_size();
                AnimationValue::MaskSize(
                    computed
                )
            }
            LonghandId::MozTabSize => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone__moz_tab_size();
                AnimationValue::MozTabSize(
                    computed.to_animated_value()
                )
            }
            LonghandId::OutlineOffset => {
                let computed = computed_values
                    .get_outline()
                    .clone_outline_offset();
                AnimationValue::OutlineOffset(
                    computed
                )
            }
            LonghandId::OverflowY => {
                let computed = computed_values
                    .get_box()
                    .clone_overflow_y();
                AnimationValue::OverflowY(
                    computed
                )
            }
            LonghandId::Perspective => {
                let computed = computed_values
                    .get_box()
                    .clone_perspective();
                AnimationValue::Perspective(
                    computed.to_animated_value()
                )
            }
            LonghandId::PerspectiveOrigin => {
                let computed = computed_values
                    .get_box()
                    .clone_perspective_origin();
                AnimationValue::PerspectiveOrigin(
                    computed
                )
            }
            LonghandId::Quotes => {
                let computed = computed_values
                    .get_list()
                    .clone_quotes();
                AnimationValue::Quotes(
                    computed
                )
            }
            LonghandId::Rotate => {
                let computed = computed_values
                    .get_box()
                    .clone_rotate();
                AnimationValue::Rotate(
                    computed
                )
            }
            LonghandId::Scale => {
                let computed = computed_values
                    .get_box()
                    .clone_scale();
                AnimationValue::Scale(
                    computed
                )
            }
            LonghandId::ScrollSnapCoordinate => {
                let computed = computed_values
                    .get_box()
                    .clone_scroll_snap_coordinate();
                AnimationValue::ScrollSnapCoordinate(
                    computed
                )
            }
            LonghandId::ShapeOutside => {
                let computed = computed_values
                    .get_box()
                    .clone_shape_outside();
                AnimationValue::ShapeOutside(
                    computed
                )
            }
            LonghandId::StrokeDasharray => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke_dasharray();
                AnimationValue::StrokeDasharray(
                    computed.to_animated_value()
                )
            }
            LonghandId::StrokeDashoffset => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke_dashoffset();
                AnimationValue::StrokeDashoffset(
                    computed
                )
            }
            LonghandId::StrokeMiterlimit => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke_miterlimit();
                AnimationValue::StrokeMiterlimit(
                    computed.to_animated_value()
                )
            }
            LonghandId::StrokeWidth => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke_width();
                AnimationValue::StrokeWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::TextAlign => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_align();
                AnimationValue::TextAlign(
                    computed
                )
            }
            LonghandId::TextEmphasisPosition => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_emphasis_position();
                AnimationValue::TextEmphasisPosition(
                    computed
                )
            }
            LonghandId::TextEmphasisStyle => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_emphasis_style();
                AnimationValue::TextEmphasisStyle(
                    computed
                )
            }
            LonghandId::TextIndent => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_indent();
                AnimationValue::TextIndent(
                    computed
                )
            }
            LonghandId::TextOverflow => {
                let computed = computed_values
                    .get_text()
                    .clone_text_overflow();
                AnimationValue::TextOverflow(
                    computed
                )
            }
            LonghandId::TextShadow => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_shadow();
                AnimationValue::TextShadow(
                    computed.to_animated_value()
                )
            }
            LonghandId::Translate => {
                let computed = computed_values
                    .get_box()
                    .clone_translate();
                AnimationValue::Translate(
                    computed
                )
            }
            LonghandId::VerticalAlign => {
                let computed = computed_values
                    .get_box()
                    .clone_vertical_align();
                AnimationValue::VerticalAlign(
                    computed
                )
            }
            LonghandId::WillChange => {
                let computed = computed_values
                    .get_box()
                    .clone_will_change();
                AnimationValue::WillChange(
                    computed
                )
            }
            LonghandId::WordSpacing => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_word_spacing();
                AnimationValue::WordSpacing(
                    computed
                )
            }
            LonghandId::OverflowClipBoxBlock => {
                let computed = computed_values
                    .get_box()
                    .clone_overflow_clip_box_block();
                AnimationValue::OverflowClipBoxBlock(
                    computed
                )
            }
            LonghandId::OverflowClipBoxInline => {
                let computed = computed_values
                    .get_box()
                    .clone_overflow_clip_box_inline();
                AnimationValue::OverflowClipBoxInline(
                    computed
                )
            }
            LonghandId::FillOpacity => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_fill_opacity();
                AnimationValue::FillOpacity(
                    computed
                )
            }
            LonghandId::StrokeOpacity => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke_opacity();
                AnimationValue::StrokeOpacity(
                    computed
                )
            }
            LonghandId::ScrollSnapPointsX => {
                let computed = computed_values
                    .get_box()
                    .clone_scroll_snap_points_x();
                AnimationValue::ScrollSnapPointsX(
                    computed
                )
            }
            LonghandId::ScrollSnapPointsY => {
                let computed = computed_values
                    .get_box()
                    .clone_scroll_snap_points_y();
                AnimationValue::ScrollSnapPointsY(
                    computed
                )
            }
            LonghandId::MozWindowTransform => {
                let computed = computed_values
                    .get_ui()
                    .clone__moz_window_transform();
                AnimationValue::MozWindowTransform(
                    computed
                )
            }
            LonghandId::Transform => {
                let computed = computed_values
                    .get_box()
                    .clone_transform();
                AnimationValue::Transform(
                    computed
                )
            }
            LonghandId::Clip => {
                let computed = computed_values
                    .get_effects()
                    .clone_clip();
                AnimationValue::Clip(
                    computed
                )
            }
            LonghandId::MozImageRegion => {
                let computed = computed_values
                    .get_list()
                    .clone__moz_image_region();
                AnimationValue::MozImageRegion(
                    computed
                )
            }
            LonghandId::GridTemplateColumns => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_template_columns();
                AnimationValue::GridTemplateColumns(
                    computed
                )
            }
            LonghandId::GridTemplateRows => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_template_rows();
                AnimationValue::GridTemplateRows(
                    computed
                )
            }
            LonghandId::ObjectPosition => {
                let computed = computed_values
                    .get_position()
                    .clone_object_position();
                AnimationValue::ObjectPosition(
                    computed
                )
            }
            LonghandId::ScrollSnapDestination => {
                let computed = computed_values
                    .get_box()
                    .clone_scroll_snap_destination();
                AnimationValue::ScrollSnapDestination(
                    computed
                )
            }
            LonghandId::Fill => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_fill();
                AnimationValue::Fill(
                    computed.to_animated_value()
                )
            }
            LonghandId::Stroke => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke();
                AnimationValue::Stroke(
                    computed.to_animated_value()
                )
            }
            LonghandId::GridAutoColumns => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_auto_columns();
                AnimationValue::GridAutoColumns(
                    computed
                )
            }
            LonghandId::GridAutoRows => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_auto_rows();
                AnimationValue::GridAutoRows(
                    computed
                )
            }
            LonghandId::MozWindowTransformOrigin => {
                let computed = computed_values
                    .get_ui()
                    .clone__moz_window_transform_origin();
                AnimationValue::MozWindowTransformOrigin(
                    computed
                )
            }
            LonghandId::TransformOrigin => {
                let computed = computed_values
                    .get_box()
                    .clone_transform_origin();
                AnimationValue::TransformOrigin(
                    computed
                )
            }
            LonghandId::MaxHeight => {
                let computed = computed_values
                    .get_position()
                    .clone_max_height();
                AnimationValue::MaxHeight(
                    computed.to_animated_value()
                )
            }
            LonghandId::MaxWidth => {
                let computed = computed_values
                    .get_position()
                    .clone_max_width();
                AnimationValue::MaxWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::FloodColor => {
                let computed = computed_values
                    .get_svg()
                    .clone_flood_color();
                AnimationValue::FloodColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::LightingColor => {
                let computed = computed_values
                    .get_svg()
                    .clone_lighting_color();
                AnimationValue::LightingColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozFontSmoothingBackgroundColor => {
                let computed = computed_values
                    .get_font()
                    .clone__moz_font_smoothing_background_color();
                AnimationValue::MozFontSmoothingBackgroundColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::StopColor => {
                let computed = computed_values
                    .get_svg()
                    .clone_stop_color();
                AnimationValue::StopColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::MarkerEnd => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_marker_end();
                AnimationValue::MarkerEnd(
                    computed
                )
            }
            LonghandId::MarkerMid => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_marker_mid();
                AnimationValue::MarkerMid(
                    computed
                )
            }
            LonghandId::MarkerStart => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_marker_start();
                AnimationValue::MarkerStart(
                    computed
                )
            }
            LonghandId::GridColumnEnd => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_column_end();
                AnimationValue::GridColumnEnd(
                    computed
                )
            }
            LonghandId::GridColumnStart => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_column_start();
                AnimationValue::GridColumnStart(
                    computed
                )
            }
            LonghandId::GridRowEnd => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_row_end();
                AnimationValue::GridRowEnd(
                    computed
                )
            }
            LonghandId::GridRowStart => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_row_start();
                AnimationValue::GridRowStart(
                    computed
                )
            }
            LonghandId::BorderBottomLeftRadius => {
                let computed = computed_values
                    .get_border()
                    .clone_border_bottom_left_radius();
                AnimationValue::BorderBottomLeftRadius(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderBottomRightRadius => {
                let computed = computed_values
                    .get_border()
                    .clone_border_bottom_right_radius();
                AnimationValue::BorderBottomRightRadius(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderTopLeftRadius => {
                let computed = computed_values
                    .get_border()
                    .clone_border_top_left_radius();
                AnimationValue::BorderTopLeftRadius(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderTopRightRadius => {
                let computed = computed_values
                    .get_border()
                    .clone_border_top_right_radius();
                AnimationValue::BorderTopRightRadius(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozOutlineRadiusBottomleft => {
                let computed = computed_values
                    .get_outline()
                    .clone__moz_outline_radius_bottomleft();
                AnimationValue::MozOutlineRadiusBottomleft(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozOutlineRadiusBottomright => {
                let computed = computed_values
                    .get_outline()
                    .clone__moz_outline_radius_bottomright();
                AnimationValue::MozOutlineRadiusBottomright(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozOutlineRadiusTopleft => {
                let computed = computed_values
                    .get_outline()
                    .clone__moz_outline_radius_topleft();
                AnimationValue::MozOutlineRadiusTopleft(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozOutlineRadiusTopright => {
                let computed = computed_values
                    .get_outline()
                    .clone__moz_outline_radius_topright();
                AnimationValue::MozOutlineRadiusTopright(
                    computed.to_animated_value()
                )
            }
            LonghandId::FlexBasis => {
                let computed = computed_values
                    .get_position()
                    .clone_flex_basis();
                AnimationValue::FlexBasis(
                    computed.to_animated_value()
                )
            }
            LonghandId::Height => {
                let computed = computed_values
                    .get_position()
                    .clone_height();
                AnimationValue::Height(
                    computed.to_animated_value()
                )
            }
            LonghandId::MinHeight => {
                let computed = computed_values
                    .get_position()
                    .clone_min_height();
                AnimationValue::MinHeight(
                    computed.to_animated_value()
                )
            }
            LonghandId::MinWidth => {
                let computed = computed_values
                    .get_position()
                    .clone_min_width();
                AnimationValue::MinWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::Width => {
                let computed = computed_values
                    .get_position()
                    .clone_width();
                AnimationValue::Width(
                    computed.to_animated_value()
                )
            }
            LonghandId::GridColumnGap => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_column_gap();
                AnimationValue::GridColumnGap(
                    computed.to_animated_value()
                )
            }
            LonghandId::GridRowGap => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_row_gap();
                AnimationValue::GridRowGap(
                    computed.to_animated_value()
                )
            }
            LonghandId::PaddingBottom => {
                let computed = computed_values
                    .get_padding()
                    .clone_padding_bottom();
                AnimationValue::PaddingBottom(
                    computed.to_animated_value()
                )
            }
            LonghandId::PaddingLeft => {
                let computed = computed_values
                    .get_padding()
                    .clone_padding_left();
                AnimationValue::PaddingLeft(
                    computed.to_animated_value()
                )
            }
            LonghandId::PaddingRight => {
                let computed = computed_values
                    .get_padding()
                    .clone_padding_right();
                AnimationValue::PaddingRight(
                    computed.to_animated_value()
                )
            }
            LonghandId::PaddingTop => {
                let computed = computed_values
                    .get_padding()
                    .clone_padding_top();
                AnimationValue::PaddingTop(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderBottomWidth => {
                let computed = computed_values
                    .get_border()
                    .clone_border_bottom_width();
                AnimationValue::BorderBottomWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderLeftWidth => {
                let computed = computed_values
                    .get_border()
                    .clone_border_left_width();
                AnimationValue::BorderLeftWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderRightWidth => {
                let computed = computed_values
                    .get_border()
                    .clone_border_right_width();
                AnimationValue::BorderRightWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderTopWidth => {
                let computed = computed_values
                    .get_border()
                    .clone_border_top_width();
                AnimationValue::BorderTopWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::ColumnRuleWidth => {
                let computed = computed_values
                    .get_column()
                    .clone_column_rule_width();
                AnimationValue::ColumnRuleWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::OutlineWidth => {
                let computed = computed_values
                    .get_outline()
                    .clone_outline_width();
                AnimationValue::OutlineWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::WebkitTextStrokeWidth => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone__webkit_text_stroke_width();
                AnimationValue::WebkitTextStrokeWidth(
                    computed
                )
            }
            LonghandId::BackgroundColor => {
                let computed = computed_values
                    .get_background()
                    .clone_background_color();
                AnimationValue::BackgroundColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderBottomColor => {
                let computed = computed_values
                    .get_border()
                    .clone_border_bottom_color();
                AnimationValue::BorderBottomColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderLeftColor => {
                let computed = computed_values
                    .get_border()
                    .clone_border_left_color();
                AnimationValue::BorderLeftColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderRightColor => {
                let computed = computed_values
                    .get_border()
                    .clone_border_right_color();
                AnimationValue::BorderRightColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderTopColor => {
                let computed = computed_values
                    .get_border()
                    .clone_border_top_color();
                AnimationValue::BorderTopColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::ColumnRuleColor => {
                let computed = computed_values
                    .get_column()
                    .clone_column_rule_color();
                AnimationValue::ColumnRuleColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::OutlineColor => {
                let computed = computed_values
                    .get_outline()
                    .clone_outline_color();
                AnimationValue::OutlineColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::TextDecorationColor => {
                let computed = computed_values
                    .get_text()
                    .clone_text_decoration_color();
                AnimationValue::TextDecorationColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::TextEmphasisColor => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_emphasis_color();
                AnimationValue::TextEmphasisColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::WebkitTextFillColor => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone__webkit_text_fill_color();
                AnimationValue::WebkitTextFillColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::WebkitTextStrokeColor => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone__webkit_text_stroke_color();
                AnimationValue::WebkitTextStrokeColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::Bottom => {
                let computed = computed_values
                    .get_position()
                    .clone_bottom();
                AnimationValue::Bottom(
                    computed
                )
            }
            LonghandId::Left => {
                let computed = computed_values
                    .get_position()
                    .clone_left();
                AnimationValue::Left(
                    computed
                )
            }
            LonghandId::MarginBottom => {
                let computed = computed_values
                    .get_margin()
                    .clone_margin_bottom();
                AnimationValue::MarginBottom(
                    computed
                )
            }
            LonghandId::MarginLeft => {
                let computed = computed_values
                    .get_margin()
                    .clone_margin_left();
                AnimationValue::MarginLeft(
                    computed
                )
            }
            LonghandId::MarginRight => {
                let computed = computed_values
                    .get_margin()
                    .clone_margin_right();
                AnimationValue::MarginRight(
                    computed
                )
            }
            LonghandId::MarginTop => {
                let computed = computed_values
                    .get_margin()
                    .clone_margin_top();
                AnimationValue::MarginTop(
                    computed
                )
            }
            LonghandId::Right => {
                let computed = computed_values
                    .get_position()
                    .clone_right();
                AnimationValue::Right(
                    computed
                )
            }
            LonghandId::Top => {
                let computed = computed_values
                    .get_position()
                    .clone_top();
                AnimationValue::Top(
                    computed
                )
            }
            _ => return None,
        })
    }
}

fn animate_discrete<T: Clone>(this: &T, other: &T, procedure: Procedure) -> Result<T, ()> {
    if let Procedure::Interpolate { progress } = procedure {
        Ok(if progress < 0.5 { this.clone() } else { other.clone() })
    } else {
        Err(())
    }
}

impl Animate for AnimationValue {
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        Ok(unsafe {
            use self::AnimationValue::*;

            let this_tag = *(self as *const _ as *const u16);
            let other_tag = *(other as *const _ as *const u16);
            if this_tag != other_tag {
                panic!("Unexpected AnimationValue::animate call");
            }

            match *self {
                
                AlignContent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::AlignContent as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::AlignContent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                AlignItems(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::AlignItems as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::AlignItems as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                AlignSelf(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::AlignSelf as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::AlignSelf as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BackfaceVisibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::backface_visibility::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::backface_visibility::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BorderCollapse(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::border_collapse::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::border_collapse::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BorderImageRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::BorderImageRepeat as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::BorderImageRepeat as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BoxDecorationBreak(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::box_decoration_break::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::box_decoration_break::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BoxSizing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::box_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::box_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                CaptionSide(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::caption_side::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::caption_side::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Clear(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::clear::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::clear::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ClipRule(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::clip_rule::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::clip_rule::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ColorAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::color_adjust::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::color_adjust::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ColorInterpolation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::color_interpolation::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::color_interpolation::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ColorInterpolationFilters(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::color_interpolation_filters::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::color_interpolation_filters::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ColumnCount(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::ColumnCount as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::ColumnCount as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ColumnFill(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::column_fill::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::column_fill::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ColumnRuleStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::column_rule_style::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::column_rule_style::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ColumnSpan(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::column_span::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::column_span::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Contain(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Contain as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Contain as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Direction(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::direction::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::direction::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                DominantBaseline(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::dominant_baseline::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::dominant_baseline::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                EmptyCells(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::empty_cells::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::empty_cells::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FillRule(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::fill_rule::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::fill_rule::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FlexDirection(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::flex_direction::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::flex_direction::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FlexWrap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::flex_wrap::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::flex_wrap::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Float(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::float::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::float::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontKerning(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_kerning::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::font_kerning::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontOpticalSizing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_optical_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::font_optical_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontStretch(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_stretch::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::font_stretch::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_style::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::font_style::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontSynthesis(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontSynthesis as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontSynthesis as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontVariantCaps(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_variant_caps::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::font_variant_caps::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontVariantPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_variant_position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::font_variant_position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontWeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontWeight as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontWeight as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                GridAutoFlow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::GridAutoFlow as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::GridAutoFlow as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Hyphens(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::hyphens::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::hyphens::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ImageOrientation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ImageOrientation as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ImageOrientation as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ImageRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::image_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::image_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ImeMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::ime_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::ime_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                InitialLetter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::InitialLetter as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::InitialLetter as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Isolation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::isolation::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::isolation::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                JustifyContent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::JustifyContent as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::JustifyContent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                JustifyItems(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::JustifyItems as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::JustifyItems as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                JustifySelf(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::JustifySelf as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::JustifySelf as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ListStylePosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::list_style_position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::list_style_position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MaskType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_type::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_type::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MixBlendMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mix_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mix_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozAppearance(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_appearance::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_appearance::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozBoxAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_align::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_box_align::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozBoxDirection(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_direction::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_box_direction::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozBoxOrient(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_orient::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_box_orient::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozBoxPack(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_pack::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_box_pack::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozFloatEdge(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_float_edge::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_float_edge::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozForceBrokenImageIcon(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::MozForceBrokenImageIcon as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::MozForceBrokenImageIcon as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozOrient(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_orient::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_orient::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozOsxFontSmoothing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_osx_font_smoothing::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_osx_font_smoothing::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozStackSizing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_stack_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_stack_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozTextSizeAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_text_size_adjust::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_text_size_adjust::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozUserFocus(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_user_focus::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_user_focus::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozUserInput(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_user_input::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_user_input::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozUserModify(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_user_modify::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_user_modify::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozUserSelect(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_user_select::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_user_select::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozWindowDragging(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_window_dragging::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_window_dragging::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozWindowShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_window_shadow::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::_moz_window_shadow::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ObjectFit(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::object_fit::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::object_fit::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                OutlineStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::OutlineStyle as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::OutlineStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                OverflowWrap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::overflow_wrap::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::overflow_wrap::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                OverflowX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::overflow_x::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::overflow_x::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                PageBreakAfter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::page_break_after::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::page_break_after::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                PageBreakBefore(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::page_break_before::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::page_break_before::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                PageBreakInside(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::page_break_inside::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::page_break_inside::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                PaintOrder(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::SVGPaintOrder as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::SVGPaintOrder as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                PointerEvents(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::pointer_events::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::pointer_events::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Position(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Resize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::resize::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::resize::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                RubyAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::ruby_align::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::ruby_align::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                RubyPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::ruby_position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::ruby_position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ScrollBehavior(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::scroll_behavior::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::scroll_behavior::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ShapeRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::shape_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::shape_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                StrokeLinecap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::stroke_linecap::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::stroke_linecap::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                StrokeLinejoin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::stroke_linejoin::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::stroke_linejoin::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TableLayout(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::table_layout::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::table_layout::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TextAlignLast(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_align_last::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_align_last::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TextAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_anchor::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_anchor::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TextCombineUpright(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_combine_upright::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_combine_upright::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TextDecorationLine(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TextDecorationLine as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TextDecorationLine as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TextDecorationStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_decoration_style::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_decoration_style::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TextJustify(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_justify::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_justify::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TextOrientation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_orientation::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_orientation::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TextRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TextTransform(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_transform::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_transform::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TouchAction(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TouchAction as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TouchAction as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TransformBox(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::transform_box::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::transform_box::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TransformStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TransformStyle as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TransformStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                UnicodeBidi(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::unicode_bidi::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::unicode_bidi::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                VectorEffect(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::vector_effect::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::vector_effect::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Visibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::visibility::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::visibility::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                WhiteSpace(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::white_space::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::white_space::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                WordBreak(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::word_break::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::word_break::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                WritingMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::writing_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::writing_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ZIndex(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ZIndex as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ZIndex as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozBoxOrdinalGroup(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Integer as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Integer as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Order(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Integer as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Integer as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                OverscrollBehaviorX(ref this) |
OverscrollBehaviorY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ScrollSnapTypeX(ref this) |
ScrollSnapTypeY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ScrollSnapType as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ScrollSnapType as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FlexGrow(ref this) |
FlexShrink(ref this) |
MozBoxFlex(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FloodOpacity(ref this) |
MozWindowOpacity(ref this) |
Opacity(ref this) |
ShapeImageThreshold(ref this) |
StopOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Opacity as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Opacity as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BorderBottomStyle(ref this) |
BorderLeftStyle(ref this) |
BorderRightStyle(ref this) |
BorderTopStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::BorderStyle as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::BorderStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BackgroundAttachment(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_attachment::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_attachment::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BackgroundBlendMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BackgroundClip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_clip::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_clip::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BackgroundImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_image::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_image::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BackgroundOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_origin::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_origin::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BackgroundPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BackgroundPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BackgroundRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::background_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BackgroundSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::background_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<longhands::background_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BorderImageOutset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::LengthOrNumberRect as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::LengthOrNumberRect as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BorderImageSlice(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::BorderImageSlice as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::BorderImageSlice as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BorderImageSource(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ImageLayer as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ImageLayer as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BorderImageWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::BorderImageWidth as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::BorderImageWidth as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BorderSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::BorderSpacing as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::BorderSpacing as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BoxShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::box_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<longhands::box_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                CaretColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::CaretColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::CaretColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ClipPath(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::basic_shape::ClippingShape as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::basic_shape::ClippingShape as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Color(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::ColorPropertyValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::ColorPropertyValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ColumnGap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::length::NonNegativeLengthOrNormal as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::length::NonNegativeLengthOrNormal as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ColumnWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::length::NonNegativeLengthOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::length::NonNegativeLengthOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Content(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Content as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Content as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                CounterIncrement(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::CounterIncrement as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::CounterIncrement as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                CounterReset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::CounterReset as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::CounterReset as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Cursor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Cursor as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Cursor as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Display(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Display as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Display as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Filter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<longhands::filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontFamily(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontFamily as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontFamily as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontFeatureSettings(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontFeatureSettings as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontFeatureSettings as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontLanguageOverride(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontLanguageOverride as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontLanguageOverride as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::FontSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::FontSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontSizeAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontSizeAdjust as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontSizeAdjust as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontVariantAlternates(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontVariantAlternates as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontVariantAlternates as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontVariantEastAsian(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontVariantEastAsian as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontVariantEastAsian as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontVariantLigatures(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontVariantLigatures as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontVariantLigatures as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontVariantNumeric(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontVariantNumeric as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontVariantNumeric as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FontVariationSettings(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontVariationSettings as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::FontVariationSettings as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                GridTemplateAreas(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::GridTemplateAreas as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::GridTemplateAreas as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                LetterSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::LetterSpacing as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::LetterSpacing as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                LineHeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::LineHeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::LineHeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ListStyleImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ListStyleImage as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ListStyleImage as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ListStyleType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ListStyleType as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ListStyleType as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MaskClip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_clip::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_clip::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MaskComposite(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_composite::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_composite::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MaskImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_image::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_image::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MaskMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MaskOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_origin::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_origin::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MaskPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MaskPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MaskRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MaskSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_size::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::mask_size::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozTabSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::MozTabSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::MozTabSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                OutlineOffset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Length as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Length as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                OverflowY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::overflow_y::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::overflow_y::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Perspective(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::Perspective as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::Perspective as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                PerspectiveOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::position::Position as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::position::Position as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Quotes(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Quotes as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Quotes as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Rotate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Rotate as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Rotate as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Scale(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Scale as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Scale as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ScrollSnapCoordinate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::scroll_snap_coordinate::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::scroll_snap_coordinate::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ShapeOutside(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::basic_shape::FloatAreaShape as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::basic_shape::FloatAreaShape as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                StrokeDasharray(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::SVGStrokeDashArray as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::SVGStrokeDashArray as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                StrokeDashoffset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::SVGLength as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::SVGLength as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                StrokeMiterlimit(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::GreaterThanOrEqualToOneNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::GreaterThanOrEqualToOneNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                StrokeWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::SVGWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::SVGWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TextAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TextAlign as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TextAlign as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TextEmphasisPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_emphasis_position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<longhands::text_emphasis_position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TextEmphasisStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TextEmphasisStyle as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TextEmphasisStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TextIndent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::LengthOrPercentage as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::LengthOrPercentage as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TextOverflow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TextOverflow as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TextOverflow as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                TextShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::text_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<longhands::text_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Translate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Translate as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Translate as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                VerticalAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::VerticalAlign as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::VerticalAlign as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                WillChange(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::WillChange as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::WillChange as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                WordSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::WordSpacing as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::WordSpacing as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                OverflowClipBoxBlock(ref this) |
OverflowClipBoxInline(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::OverflowClipBox as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::OverflowClipBox as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FillOpacity(ref this) |
StrokeOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::SVGOpacity as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::SVGOpacity as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ScrollSnapPointsX(ref this) |
ScrollSnapPointsY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ScrollSnapPoint as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ScrollSnapPoint as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozWindowTransform(ref this) |
Transform(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Transform as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Transform as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Clip(ref this) |
MozImageRegion(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ClipRectOrAuto as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::ClipRectOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                GridTemplateColumns(ref this) |
GridTemplateRows(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::GridTemplateComponent as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::GridTemplateComponent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ObjectPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Position as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Position as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                ScrollSnapDestination(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Position as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::Position as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Fill(ref this) |
Stroke(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                GridAutoColumns(ref this) |
GridAutoRows(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TrackSize as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TrackSize as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozWindowTransformOrigin(ref this) |
TransformOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TransformOrigin as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::TransformOrigin as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MaxHeight(ref this) |
MaxWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::MaxLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::MaxLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FloodColor(ref this) |
LightingColor(ref this) |
MozFontSmoothingBackgroundColor(ref this) |
StopColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::RGBAColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::RGBAColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MarkerEnd(ref this) |
MarkerMid(ref this) |
MarkerStart(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::UrlOrNone as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::UrlOrNone as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                GridColumnEnd(ref this) |
GridColumnStart(ref this) |
GridRowEnd(ref this) |
GridRowStart(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::GridLine as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::GridLine as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BorderBottomLeftRadius(ref this) |
BorderBottomRightRadius(ref this) |
BorderTopLeftRadius(ref this) |
BorderTopRightRadius(ref this) |
MozOutlineRadiusBottomleft(ref this) |
MozOutlineRadiusBottomright(ref this) |
MozOutlineRadiusTopleft(ref this) |
MozOutlineRadiusTopright(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                FlexBasis(ref this) |
Height(ref this) |
MinHeight(ref this) |
MinWidth(ref this) |
Width(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::MozLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::MozLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                GridColumnGap(ref this) |
GridRowGap(ref this) |
PaddingBottom(ref this) |
PaddingLeft(ref this) |
PaddingRight(ref this) |
PaddingTop(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::NonNegativeLengthOrPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::NonNegativeLengthOrPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BorderBottomWidth(ref this) |
BorderLeftWidth(ref this) |
BorderRightWidth(ref this) |
BorderTopWidth(ref this) |
ColumnRuleWidth(ref this) |
OutlineWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                WebkitTextStrokeWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                BackgroundColor(ref this) |
BorderBottomColor(ref this) |
BorderLeftColor(ref this) |
BorderRightColor(ref this) |
BorderTopColor(ref this) |
ColumnRuleColor(ref this) |
OutlineColor(ref this) |
TextDecorationColor(ref this) |
TextEmphasisColor(ref this) |
WebkitTextFillColor(ref this) |
WebkitTextStrokeColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                Bottom(ref this) |
Left(ref this) |
MarginBottom(ref this) |
MarginLeft(ref this) |
MarginRight(ref this) |
MarginTop(ref this) |
Right(ref this) |
Top(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::LengthOrPercentageOrAuto as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::uninitialized();
                    ptr::write(
                        &mut out as *mut _ as *mut AnimationValueVariantRepr<<::values::specified::LengthOrPercentageOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out
                }
                MozControlCharacterVisibility(void) |
MozMathDisplay(void) |
MozMathVariant(void) |
MozMinFontSizeRatio(void) |
MozScriptLevel(void) |
MozScriptMinSize(void) |
MozScriptSizeMultiplier(void) |
MozTopLayer(void) |
XSpan(void) |
XTextZoom(void) |
BorderBlockEndStyle(void) |
BorderBlockStartStyle(void) |
BorderInlineEndStyle(void) |
BorderInlineStartStyle(void) |
AnimationDelay(void) |
AnimationDirection(void) |
AnimationDuration(void) |
AnimationFillMode(void) |
AnimationIterationCount(void) |
AnimationName(void) |
AnimationPlayState(void) |
AnimationTimingFunction(void) |
MozContextProperties(void) |
TransitionDelay(void) |
TransitionDuration(void) |
TransitionProperty(void) |
TransitionTimingFunction(void) |
XLang(void) |
MaxBlockSize(void) |
MaxInlineSize(void) |
MozBinding(void) |
BlockSize(void) |
InlineSize(void) |
MinBlockSize(void) |
MinInlineSize(void) |
PaddingBlockEnd(void) |
PaddingBlockStart(void) |
PaddingInlineEnd(void) |
PaddingInlineStart(void) |
BorderBlockEndWidth(void) |
BorderBlockStartWidth(void) |
BorderInlineEndWidth(void) |
BorderInlineStartWidth(void) |
BorderBlockEndColor(void) |
BorderBlockStartColor(void) |
BorderInlineEndColor(void) |
BorderInlineStartColor(void) |
MarginBlockEnd(void) |
MarginBlockStart(void) |
MarginInlineEnd(void) |
MarginInlineStart(void) |
OffsetBlockEnd(void) |
OffsetBlockStart(void) |
OffsetInlineEnd(void) |
OffsetInlineStart(void) => {
                    void::unreachable(void)
                }
            }
        })
    }
}



impl ComputeSquaredDistance for AnimationValue {
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        unsafe {
            use self::AnimationValue::*;

            let this_tag = *(self as *const _ as *const u16);
            let other_tag = *(other as *const _ as *const u16);
            if this_tag != other_tag {
                panic!("Unexpected AnimationValue::compute_squared_distance call");
            }

            match *self {
                ColumnCount(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::ColumnCount as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FontStretch(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_stretch::SpecifiedValue as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FontWeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontWeight as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Visibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::visibility::SpecifiedValue as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ZIndex(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ZIndex as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Order(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Integer as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FlexGrow(ref this) |
FlexShrink(ref this) |
MozBoxFlex(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FloodOpacity(ref this) |
MozWindowOpacity(ref this) |
Opacity(ref this) |
ShapeImageThreshold(ref this) |
StopOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Opacity as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BackgroundPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BackgroundPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BackgroundSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::background_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BorderSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::BorderSpacing as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BoxShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::box_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                CaretColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::CaretColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ClipPath(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::basic_shape::ClippingShape as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Color(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::ColorPropertyValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ColumnGap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::length::NonNegativeLengthOrNormal as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ColumnWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::length::NonNegativeLengthOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Filter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FontSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::FontSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FontSizeAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontSizeAdjust as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FontVariationSettings(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::FontVariationSettings as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                LetterSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::LetterSpacing as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                LineHeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::LineHeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                MaskPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                MaskPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                MaskSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_size::SpecifiedValue as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                MozTabSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::MozTabSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                OutlineOffset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Length as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Perspective(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::Perspective as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                PerspectiveOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::position::Position as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Rotate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Rotate as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Scale(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Scale as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ShapeOutside(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::basic_shape::FloatAreaShape as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                StrokeDasharray(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::SVGStrokeDashArray as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                StrokeDashoffset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::SVGLength as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                StrokeMiterlimit(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::GreaterThanOrEqualToOneNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                StrokeWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::SVGWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                TextIndent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::LengthOrPercentage as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                TextShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::text_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Translate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Translate as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                VerticalAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::VerticalAlign as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                WordSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::WordSpacing as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FillOpacity(ref this) |
StrokeOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::SVGOpacity as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                MozWindowTransform(ref this) |
Transform(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Transform as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Clip(ref this) |
MozImageRegion(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::ClipRectOrAuto as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ObjectPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::Position as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Fill(ref this) |
Stroke(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                MozWindowTransformOrigin(ref this) |
TransformOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::TransformOrigin as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                MaxHeight(ref this) |
MaxWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::MaxLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FloodColor(ref this) |
LightingColor(ref this) |
MozFontSmoothingBackgroundColor(ref this) |
StopColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::RGBAColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BorderBottomLeftRadius(ref this) |
BorderBottomRightRadius(ref this) |
BorderTopLeftRadius(ref this) |
BorderTopRightRadius(ref this) |
MozOutlineRadiusBottomleft(ref this) |
MozOutlineRadiusBottomright(ref this) |
MozOutlineRadiusTopleft(ref this) |
MozOutlineRadiusTopright(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FlexBasis(ref this) |
Height(ref this) |
MinHeight(ref this) |
MinWidth(ref this) |
Width(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::MozLength as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                GridColumnGap(ref this) |
GridRowGap(ref this) |
PaddingBottom(ref this) |
PaddingLeft(ref this) |
PaddingRight(ref this) |
PaddingTop(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::NonNegativeLengthOrPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BorderBottomWidth(ref this) |
BorderLeftWidth(ref this) |
BorderRightWidth(ref this) |
BorderTopWidth(ref this) |
ColumnRuleWidth(ref this) |
OutlineWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BackgroundColor(ref this) |
BorderBottomColor(ref this) |
BorderLeftColor(ref this) |
BorderRightColor(ref this) |
BorderTopColor(ref this) |
ColumnRuleColor(ref this) |
OutlineColor(ref this) |
TextDecorationColor(ref this) |
TextEmphasisColor(ref this) |
WebkitTextFillColor(ref this) |
WebkitTextStrokeColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Bottom(ref this) |
Left(ref this) |
MarginBottom(ref this) |
MarginLeft(ref this) |
MarginRight(ref this) |
MarginTop(ref this) |
Right(ref this) |
Top(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<::values::specified::LengthOrPercentageOrAuto as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                _ => Err(()),
            }
        }
    }
}

impl ToAnimatedZero for AnimationValue {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        match *self {
            AnimationValue::ColumnCount(ref base) => {
                Ok(AnimationValue::ColumnCount(base.to_animated_zero()?))
            },
            AnimationValue::FontStretch(ref base) => {
                Ok(AnimationValue::FontStretch(base.to_animated_zero()?))
            },
            AnimationValue::FontWeight(ref base) => {
                Ok(AnimationValue::FontWeight(base.to_animated_zero()?))
            },
            AnimationValue::Visibility(ref base) => {
                Ok(AnimationValue::Visibility(base.to_animated_zero()?))
            },
            AnimationValue::ZIndex(ref base) => {
                Ok(AnimationValue::ZIndex(base.to_animated_zero()?))
            },
            AnimationValue::Order(ref base) => {
                Ok(AnimationValue::Order(base.to_animated_zero()?))
            },
            AnimationValue::FlexGrow(ref base) => {
                Ok(AnimationValue::FlexGrow(base.to_animated_zero()?))
            },
            AnimationValue::FlexShrink(ref base) => {
                Ok(AnimationValue::FlexShrink(base.to_animated_zero()?))
            },
            AnimationValue::MozBoxFlex(ref base) => {
                Ok(AnimationValue::MozBoxFlex(base.to_animated_zero()?))
            },
            AnimationValue::FloodOpacity(ref base) => {
                Ok(AnimationValue::FloodOpacity(base.to_animated_zero()?))
            },
            AnimationValue::MozWindowOpacity(ref base) => {
                Ok(AnimationValue::MozWindowOpacity(base.to_animated_zero()?))
            },
            AnimationValue::Opacity(ref base) => {
                Ok(AnimationValue::Opacity(base.to_animated_zero()?))
            },
            AnimationValue::ShapeImageThreshold(ref base) => {
                Ok(AnimationValue::ShapeImageThreshold(base.to_animated_zero()?))
            },
            AnimationValue::StopOpacity(ref base) => {
                Ok(AnimationValue::StopOpacity(base.to_animated_zero()?))
            },
            AnimationValue::BackgroundPositionX(ref base) => {
                Ok(AnimationValue::BackgroundPositionX(base.to_animated_zero()?))
            },
            AnimationValue::BackgroundPositionY(ref base) => {
                Ok(AnimationValue::BackgroundPositionY(base.to_animated_zero()?))
            },
            AnimationValue::BackgroundSize(ref base) => {
                Ok(AnimationValue::BackgroundSize(base.to_animated_zero()?))
            },
            AnimationValue::BorderSpacing(ref base) => {
                Ok(AnimationValue::BorderSpacing(base.to_animated_zero()?))
            },
            AnimationValue::BoxShadow(ref base) => {
                Ok(AnimationValue::BoxShadow(base.to_animated_zero()?))
            },
            AnimationValue::CaretColor(ref base) => {
                Ok(AnimationValue::CaretColor(base.to_animated_zero()?))
            },
            AnimationValue::ClipPath(ref base) => {
                Ok(AnimationValue::ClipPath(base.to_animated_zero()?))
            },
            AnimationValue::Color(ref base) => {
                Ok(AnimationValue::Color(base.to_animated_zero()?))
            },
            AnimationValue::ColumnGap(ref base) => {
                Ok(AnimationValue::ColumnGap(base.to_animated_zero()?))
            },
            AnimationValue::ColumnWidth(ref base) => {
                Ok(AnimationValue::ColumnWidth(base.to_animated_zero()?))
            },
            AnimationValue::Filter(ref base) => {
                Ok(AnimationValue::Filter(base.to_animated_zero()?))
            },
            AnimationValue::FontSize(ref base) => {
                Ok(AnimationValue::FontSize(base.to_animated_zero()?))
            },
            AnimationValue::FontSizeAdjust(ref base) => {
                Ok(AnimationValue::FontSizeAdjust(base.to_animated_zero()?))
            },
            AnimationValue::FontVariationSettings(ref base) => {
                Ok(AnimationValue::FontVariationSettings(base.to_animated_zero()?))
            },
            AnimationValue::LetterSpacing(ref base) => {
                Ok(AnimationValue::LetterSpacing(base.to_animated_zero()?))
            },
            AnimationValue::LineHeight(ref base) => {
                Ok(AnimationValue::LineHeight(base.to_animated_zero()?))
            },
            AnimationValue::MaskPositionX(ref base) => {
                Ok(AnimationValue::MaskPositionX(base.to_animated_zero()?))
            },
            AnimationValue::MaskPositionY(ref base) => {
                Ok(AnimationValue::MaskPositionY(base.to_animated_zero()?))
            },
            AnimationValue::MaskSize(ref base) => {
                Ok(AnimationValue::MaskSize(base.to_animated_zero()?))
            },
            AnimationValue::MozTabSize(ref base) => {
                Ok(AnimationValue::MozTabSize(base.to_animated_zero()?))
            },
            AnimationValue::OutlineOffset(ref base) => {
                Ok(AnimationValue::OutlineOffset(base.to_animated_zero()?))
            },
            AnimationValue::Perspective(ref base) => {
                Ok(AnimationValue::Perspective(base.to_animated_zero()?))
            },
            AnimationValue::PerspectiveOrigin(ref base) => {
                Ok(AnimationValue::PerspectiveOrigin(base.to_animated_zero()?))
            },
            AnimationValue::Rotate(ref base) => {
                Ok(AnimationValue::Rotate(base.to_animated_zero()?))
            },
            AnimationValue::Scale(ref base) => {
                Ok(AnimationValue::Scale(base.to_animated_zero()?))
            },
            AnimationValue::ShapeOutside(ref base) => {
                Ok(AnimationValue::ShapeOutside(base.to_animated_zero()?))
            },
            AnimationValue::StrokeDasharray(ref base) => {
                Ok(AnimationValue::StrokeDasharray(base.to_animated_zero()?))
            },
            AnimationValue::StrokeDashoffset(ref base) => {
                Ok(AnimationValue::StrokeDashoffset(base.to_animated_zero()?))
            },
            AnimationValue::StrokeMiterlimit(ref base) => {
                Ok(AnimationValue::StrokeMiterlimit(base.to_animated_zero()?))
            },
            AnimationValue::StrokeWidth(ref base) => {
                Ok(AnimationValue::StrokeWidth(base.to_animated_zero()?))
            },
            AnimationValue::TextIndent(ref base) => {
                Ok(AnimationValue::TextIndent(base.to_animated_zero()?))
            },
            AnimationValue::TextShadow(ref base) => {
                Ok(AnimationValue::TextShadow(base.to_animated_zero()?))
            },
            AnimationValue::Translate(ref base) => {
                Ok(AnimationValue::Translate(base.to_animated_zero()?))
            },
            AnimationValue::VerticalAlign(ref base) => {
                Ok(AnimationValue::VerticalAlign(base.to_animated_zero()?))
            },
            AnimationValue::WordSpacing(ref base) => {
                Ok(AnimationValue::WordSpacing(base.to_animated_zero()?))
            },
            AnimationValue::FillOpacity(ref base) => {
                Ok(AnimationValue::FillOpacity(base.to_animated_zero()?))
            },
            AnimationValue::StrokeOpacity(ref base) => {
                Ok(AnimationValue::StrokeOpacity(base.to_animated_zero()?))
            },
            AnimationValue::MozWindowTransform(ref base) => {
                Ok(AnimationValue::MozWindowTransform(base.to_animated_zero()?))
            },
            AnimationValue::Transform(ref base) => {
                Ok(AnimationValue::Transform(base.to_animated_zero()?))
            },
            AnimationValue::Clip(ref base) => {
                Ok(AnimationValue::Clip(base.to_animated_zero()?))
            },
            AnimationValue::MozImageRegion(ref base) => {
                Ok(AnimationValue::MozImageRegion(base.to_animated_zero()?))
            },
            AnimationValue::ObjectPosition(ref base) => {
                Ok(AnimationValue::ObjectPosition(base.to_animated_zero()?))
            },
            AnimationValue::Fill(ref base) => {
                Ok(AnimationValue::Fill(base.to_animated_zero()?))
            },
            AnimationValue::Stroke(ref base) => {
                Ok(AnimationValue::Stroke(base.to_animated_zero()?))
            },
            AnimationValue::MozWindowTransformOrigin(ref base) => {
                Ok(AnimationValue::MozWindowTransformOrigin(base.to_animated_zero()?))
            },
            AnimationValue::TransformOrigin(ref base) => {
                Ok(AnimationValue::TransformOrigin(base.to_animated_zero()?))
            },
            AnimationValue::MaxHeight(ref base) => {
                Ok(AnimationValue::MaxHeight(base.to_animated_zero()?))
            },
            AnimationValue::MaxWidth(ref base) => {
                Ok(AnimationValue::MaxWidth(base.to_animated_zero()?))
            },
            AnimationValue::FloodColor(ref base) => {
                Ok(AnimationValue::FloodColor(base.to_animated_zero()?))
            },
            AnimationValue::LightingColor(ref base) => {
                Ok(AnimationValue::LightingColor(base.to_animated_zero()?))
            },
            AnimationValue::MozFontSmoothingBackgroundColor(ref base) => {
                Ok(AnimationValue::MozFontSmoothingBackgroundColor(base.to_animated_zero()?))
            },
            AnimationValue::StopColor(ref base) => {
                Ok(AnimationValue::StopColor(base.to_animated_zero()?))
            },
            AnimationValue::BorderBottomLeftRadius(ref base) => {
                Ok(AnimationValue::BorderBottomLeftRadius(base.to_animated_zero()?))
            },
            AnimationValue::BorderBottomRightRadius(ref base) => {
                Ok(AnimationValue::BorderBottomRightRadius(base.to_animated_zero()?))
            },
            AnimationValue::BorderTopLeftRadius(ref base) => {
                Ok(AnimationValue::BorderTopLeftRadius(base.to_animated_zero()?))
            },
            AnimationValue::BorderTopRightRadius(ref base) => {
                Ok(AnimationValue::BorderTopRightRadius(base.to_animated_zero()?))
            },
            AnimationValue::MozOutlineRadiusBottomleft(ref base) => {
                Ok(AnimationValue::MozOutlineRadiusBottomleft(base.to_animated_zero()?))
            },
            AnimationValue::MozOutlineRadiusBottomright(ref base) => {
                Ok(AnimationValue::MozOutlineRadiusBottomright(base.to_animated_zero()?))
            },
            AnimationValue::MozOutlineRadiusTopleft(ref base) => {
                Ok(AnimationValue::MozOutlineRadiusTopleft(base.to_animated_zero()?))
            },
            AnimationValue::MozOutlineRadiusTopright(ref base) => {
                Ok(AnimationValue::MozOutlineRadiusTopright(base.to_animated_zero()?))
            },
            AnimationValue::FlexBasis(ref base) => {
                Ok(AnimationValue::FlexBasis(base.to_animated_zero()?))
            },
            AnimationValue::Height(ref base) => {
                Ok(AnimationValue::Height(base.to_animated_zero()?))
            },
            AnimationValue::MinHeight(ref base) => {
                Ok(AnimationValue::MinHeight(base.to_animated_zero()?))
            },
            AnimationValue::MinWidth(ref base) => {
                Ok(AnimationValue::MinWidth(base.to_animated_zero()?))
            },
            AnimationValue::Width(ref base) => {
                Ok(AnimationValue::Width(base.to_animated_zero()?))
            },
            AnimationValue::GridColumnGap(ref base) => {
                Ok(AnimationValue::GridColumnGap(base.to_animated_zero()?))
            },
            AnimationValue::GridRowGap(ref base) => {
                Ok(AnimationValue::GridRowGap(base.to_animated_zero()?))
            },
            AnimationValue::PaddingBottom(ref base) => {
                Ok(AnimationValue::PaddingBottom(base.to_animated_zero()?))
            },
            AnimationValue::PaddingLeft(ref base) => {
                Ok(AnimationValue::PaddingLeft(base.to_animated_zero()?))
            },
            AnimationValue::PaddingRight(ref base) => {
                Ok(AnimationValue::PaddingRight(base.to_animated_zero()?))
            },
            AnimationValue::PaddingTop(ref base) => {
                Ok(AnimationValue::PaddingTop(base.to_animated_zero()?))
            },
            AnimationValue::BorderBottomWidth(ref base) => {
                Ok(AnimationValue::BorderBottomWidth(base.to_animated_zero()?))
            },
            AnimationValue::BorderLeftWidth(ref base) => {
                Ok(AnimationValue::BorderLeftWidth(base.to_animated_zero()?))
            },
            AnimationValue::BorderRightWidth(ref base) => {
                Ok(AnimationValue::BorderRightWidth(base.to_animated_zero()?))
            },
            AnimationValue::BorderTopWidth(ref base) => {
                Ok(AnimationValue::BorderTopWidth(base.to_animated_zero()?))
            },
            AnimationValue::ColumnRuleWidth(ref base) => {
                Ok(AnimationValue::ColumnRuleWidth(base.to_animated_zero()?))
            },
            AnimationValue::OutlineWidth(ref base) => {
                Ok(AnimationValue::OutlineWidth(base.to_animated_zero()?))
            },
            AnimationValue::BackgroundColor(ref base) => {
                Ok(AnimationValue::BackgroundColor(base.to_animated_zero()?))
            },
            AnimationValue::BorderBottomColor(ref base) => {
                Ok(AnimationValue::BorderBottomColor(base.to_animated_zero()?))
            },
            AnimationValue::BorderLeftColor(ref base) => {
                Ok(AnimationValue::BorderLeftColor(base.to_animated_zero()?))
            },
            AnimationValue::BorderRightColor(ref base) => {
                Ok(AnimationValue::BorderRightColor(base.to_animated_zero()?))
            },
            AnimationValue::BorderTopColor(ref base) => {
                Ok(AnimationValue::BorderTopColor(base.to_animated_zero()?))
            },
            AnimationValue::ColumnRuleColor(ref base) => {
                Ok(AnimationValue::ColumnRuleColor(base.to_animated_zero()?))
            },
            AnimationValue::OutlineColor(ref base) => {
                Ok(AnimationValue::OutlineColor(base.to_animated_zero()?))
            },
            AnimationValue::TextDecorationColor(ref base) => {
                Ok(AnimationValue::TextDecorationColor(base.to_animated_zero()?))
            },
            AnimationValue::TextEmphasisColor(ref base) => {
                Ok(AnimationValue::TextEmphasisColor(base.to_animated_zero()?))
            },
            AnimationValue::WebkitTextFillColor(ref base) => {
                Ok(AnimationValue::WebkitTextFillColor(base.to_animated_zero()?))
            },
            AnimationValue::WebkitTextStrokeColor(ref base) => {
                Ok(AnimationValue::WebkitTextStrokeColor(base.to_animated_zero()?))
            },
            AnimationValue::Bottom(ref base) => {
                Ok(AnimationValue::Bottom(base.to_animated_zero()?))
            },
            AnimationValue::Left(ref base) => {
                Ok(AnimationValue::Left(base.to_animated_zero()?))
            },
            AnimationValue::MarginBottom(ref base) => {
                Ok(AnimationValue::MarginBottom(base.to_animated_zero()?))
            },
            AnimationValue::MarginLeft(ref base) => {
                Ok(AnimationValue::MarginLeft(base.to_animated_zero()?))
            },
            AnimationValue::MarginRight(ref base) => {
                Ok(AnimationValue::MarginRight(base.to_animated_zero()?))
            },
            AnimationValue::MarginTop(ref base) => {
                Ok(AnimationValue::MarginTop(base.to_animated_zero()?))
            },
            AnimationValue::Right(ref base) => {
                Ok(AnimationValue::Right(base.to_animated_zero()?))
            },
            AnimationValue::Top(ref base) => {
                Ok(AnimationValue::Top(base.to_animated_zero()?))
            },
            _ => Err(()),
        }
    }
}

impl RepeatableListAnimatable for LengthOrPercentage {}
impl RepeatableListAnimatable for Either<f32, LengthOrPercentage> {}
impl RepeatableListAnimatable for Either<NonNegativeNumber, NonNegativeLengthOrPercentage> {}
impl RepeatableListAnimatable for SvgLengthOrPercentageOrNumber<LengthOrPercentage, Number> {}

macro_rules! repeated_vec_impl {
    ($($ty:ty),*) => {
        $(impl<T> Animate for $ty
        where
            T: RepeatableListAnimatable,
        {
            fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
                // If the length of either list is zero, the least common multiple is undefined.
                if self.is_empty() || other.is_empty() {
                    return Err(());
                }
                use num_integer::lcm;
                let len = lcm(self.len(), other.len());
                self.iter().cycle().zip(other.iter().cycle()).take(len).map(|(this, other)| {
                    this.animate(other, procedure)
                }).collect()
            }
        }

        impl<T> ComputeSquaredDistance for $ty
        where
            T: ComputeSquaredDistance + RepeatableListAnimatable,
        {
            #[inline]
            fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
                if self.is_empty() || other.is_empty() {
                    return Err(());
                }
                use num_integer::lcm;
                let len = lcm(self.len(), other.len());
                self.iter().cycle().zip(other.iter().cycle()).take(len).map(|(this, other)| {
                    this.compute_squared_distance(other)
                }).sum()
            }
        })*
    };
}

repeated_vec_impl!(SmallVec<[T; 1]>, Vec<T>);

/// <https://drafts.csswg.org/css-transitions/#animtype-visibility>
impl Animate for Visibility {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        let (this_weight, other_weight) = procedure.weights();
        match (*self, *other) {
            (Visibility::Visible, _) => {
                Ok(if this_weight > 0.0 { *self } else { *other })
            },
            (_, Visibility::Visible) => {
                Ok(if other_weight > 0.0 { *other } else { *self })
            },
            _ => Err(()),
        }
    }
}

impl ComputeSquaredDistance for Visibility {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        Ok(SquaredDistance::from_sqrt(if *self == *other { 0. } else { 1. }))
    }
}

impl ToAnimatedZero for Visibility {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        Err(())
    }
}

/// <https://drafts.csswg.org/css-transitions/#animtype-lpcalc>
impl Animate for CalcLengthOrPercentage {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        let animate_percentage_half = |this: Option<Percentage>, other: Option<Percentage>| {
            if this.is_none() && other.is_none() {
                return Ok(None);
            }
            let this = this.unwrap_or_default();
            let other = other.unwrap_or_default();
            Ok(Some(this.animate(&other, procedure)?))
        };

        let length = self.unclamped_length().animate(&other.unclamped_length(), procedure)?;
        let percentage = animate_percentage_half(self.percentage, other.percentage)?;
        Ok(CalcLengthOrPercentage::with_clamping_mode(length, percentage, self.clamping_mode))
    }
}

impl ToAnimatedZero for LengthOrPercentageOrAuto {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        match *self {
            LengthOrPercentageOrAuto::Length(_) |
            LengthOrPercentageOrAuto::Percentage(_) |
            LengthOrPercentageOrAuto::Calc(_) => {
                Ok(LengthOrPercentageOrAuto::Length(Length::new(0.)))
            },
            LengthOrPercentageOrAuto::Auto => Err(()),
        }
    }
}

impl ToAnimatedZero for LengthOrPercentageOrNone {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        match *self {
            LengthOrPercentageOrNone::Length(_) |
            LengthOrPercentageOrNone::Percentage(_) |
            LengthOrPercentageOrNone::Calc(_) => {
                Ok(LengthOrPercentageOrNone::Length(Length::new(0.)))
            },
            LengthOrPercentageOrNone::None => Err(()),
        }
    }
}

impl ToAnimatedZero for MaxLength {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
}

/// <http://dev.w3.org/csswg/css-transitions/#animtype-font-weight>
impl Animate for FontWeight {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        let a = self.0 as f64;
        let b = other.0 as f64;
        const NORMAL: f64 = 400.;
        let (this_weight, other_weight) = procedure.weights();
        let weight = (a - NORMAL) * this_weight + (b - NORMAL) * other_weight + NORMAL;
        let weight = (weight.max(100.).min(900.) / 100.).round() * 100.;
        Ok(FontWeight(weight as u16))
    }
}

impl ToAnimatedZero for FontWeight {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        Ok(FontWeight::normal())
    }
}

/// <https://drafts.csswg.org/css-fonts/#font-stretch-prop>
impl Animate for FontStretch {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()>
    {
        let from = f64::from(*self);
        let to = f64::from(*other);
        let normal = f64::from(FontStretch::Normal);
        let (this_weight, other_weight) = procedure.weights();
        let result = (from - normal) * this_weight + (to - normal) * other_weight + normal;
        Ok(result.into())
    }
}

impl ComputeSquaredDistance for FontStretch {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        f64::from(*self).compute_squared_distance(&(*other).into())
    }
}

impl ToAnimatedZero for FontStretch {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
}

/// We should treat font stretch as real number in order to interpolate this property.
/// <https://drafts.csswg.org/css-fonts-3/#font-stretch-animation>
impl From<FontStretch> for f64 {
    fn from(stretch: FontStretch) -> f64 {
        use self::FontStretch::*;
        match stretch {
            UltraCondensed => 1.0,
            ExtraCondensed => 2.0,
            Condensed => 3.0,
            SemiCondensed => 4.0,
            Normal => 5.0,
            SemiExpanded => 6.0,
            Expanded => 7.0,
            ExtraExpanded => 8.0,
            UltraExpanded => 9.0,
        }
    }
}

impl Into<FontStretch> for f64 {
    fn into(self) -> FontStretch {
        use properties::longhands::font_stretch::computed_value::T::*;
        let index = (self + 0.5).floor().min(9.0).max(1.0);
        static FONT_STRETCH_ENUM_MAP: [FontStretch; 9] =
            [ UltraCondensed, ExtraCondensed, Condensed, SemiCondensed, Normal,
              SemiExpanded, Expanded, ExtraExpanded, UltraExpanded ];
        FONT_STRETCH_ENUM_MAP[(index - 1.0) as usize]
    }
}

/// <https://drafts.csswg.org/css-fonts-4/#font-variation-settings-def>
impl Animate for FontVariationSettings {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        FontSettingTagIter::new(self, other)?
            .map(|r| r.and_then(|(st, ot)| st.animate(&ot, procedure)))
            .collect::<Result<Vec<ComputedVariationValue>, ()>>()
            .map(|v| GenericFontSettings(v.into_boxed_slice()))
    }
}

impl ComputeSquaredDistance for FontVariationSettings {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        FontSettingTagIter::new(self, other)?
            .map(|r| r.and_then(|(st, ot)| st.compute_squared_distance(&ot)))
            .sum()
    }
}

impl ToAnimatedZero for FontVariationSettings {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        Err(())
    }
}

type ComputedVariationValue = VariationValue<Number>;

// FIXME: Could do a rename, this is only used for font variations.
struct FontSettingTagIterState<'a> {
    tags: Vec<(&'a ComputedVariationValue)>,
    index: usize,
    prev_tag: FontTag,
}

impl<'a> FontSettingTagIterState<'a> {
    fn new(tags: Vec<&'a ComputedVariationValue>) -> FontSettingTagIterState<'a> {
        FontSettingTagIterState {
            index: tags.len(),
            tags,
            prev_tag: FontTag(0),
        }
    }
}

/// Iterator for font-variation-settings tag lists
///
/// [CSS fonts level 4](https://drafts.csswg.org/css-fonts-4/#descdef-font-face-font-variation-settings)
/// defines the animation of font-variation-settings as follows:
///
///   Two declarations of font-feature-settings[sic] can be animated between if
///   they are "like".  "Like" declarations are ones where the same set of
///   properties appear (in any order).  Because succesive[sic] duplicate
///   properties are applied instead of prior duplicate properties, two
///   declarations can be "like" even if they have differing number of
///   properties. If two declarations are "like" then animation occurs pairwise
///   between corresponding values in the declarations.
///
/// In other words if we have the following lists:
///
///   "wght" 1.4, "wdth" 5, "wght" 2
///   "wdth" 8, "wght" 4, "wdth" 10
///
/// We should animate between:
///
///   "wdth" 5, "wght" 2
///   "wght" 4, "wdth" 10
///
/// This iterator supports this by sorting the two lists, then iterating them in
/// reverse, and skipping entries with repeated tag names. It will return
/// Some(Err()) if it reaches the end of one list before the other, or if the
/// tag names do not match.
///
/// For the above example, this iterator would return:
///
///   Some(Ok("wght" 2, "wght" 4))
///   Some(Ok("wdth" 5, "wdth" 10))
///   None
///
struct FontSettingTagIter<'a> {
    a_state: FontSettingTagIterState<'a>,
    b_state: FontSettingTagIterState<'a>,
}

impl<'a> FontSettingTagIter<'a> {
    fn new(
        a_settings: &'a FontVariationSettings,
        b_settings: &'a FontVariationSettings,
    ) -> Result<FontSettingTagIter<'a>, ()> {
        if a_settings.0.is_empty() || b_settings.0.is_empty() {
            return Err(());
        }
        fn as_new_sorted_tags(tags: &[ComputedVariationValue]) -> Vec<&ComputedVariationValue> {
            use std::iter::FromIterator;
            let mut sorted_tags = Vec::from_iter(tags.iter());
            sorted_tags.sort_by_key(|k| k.tag.0);
            sorted_tags
        };

        Ok(FontSettingTagIter {
            a_state: FontSettingTagIterState::new(as_new_sorted_tags(&a_settings.0)),
            b_state: FontSettingTagIterState::new(as_new_sorted_tags(&b_settings.0)),
        })
    }

    fn next_tag(state: &mut FontSettingTagIterState<'a>) -> Option<&'a ComputedVariationValue> {
        if state.index == 0 {
            return None;
        }

        state.index -= 1;
        let tag = state.tags[state.index];
        if tag.tag == state.prev_tag {
            FontSettingTagIter::next_tag(state)
        } else {
            state.prev_tag = tag.tag;
            Some(tag)
        }
    }
}

impl<'a> Iterator for FontSettingTagIter<'a> {
    type Item = Result<(&'a ComputedVariationValue, &'a ComputedVariationValue), ()>;

    fn next(&mut self) -> Option<Result<(&'a ComputedVariationValue, &'a ComputedVariationValue), ()>> {
        match (
            FontSettingTagIter::next_tag(&mut self.a_state),
            FontSettingTagIter::next_tag(&mut self.b_state),
        ) {
            (Some(at), Some(bt)) if at.tag == bt.tag => Some(Ok((at, bt))),
            (None, None) => None,
            _ => Some(Err(())), // Mismatch number of unique tags or tag names.
        }
    }
}

impl<H, V> RepeatableListAnimatable for generic_position::Position<H, V>
    where H: RepeatableListAnimatable, V: RepeatableListAnimatable {}

/// <https://drafts.csswg.org/css-transitions/#animtype-rect>
impl Animate for ClipRect {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        use values::computed::Length;
        let animate_component = |this: &Option<Length>, other: &Option<Length>| {
            match (this.animate(other, procedure)?, procedure) {
                (None, Procedure::Interpolate { .. }) => Ok(None),
                (None, _) => Err(()),
                (result, _) => Ok(result),
            }
        };

        Ok(ClipRect {
            top:    animate_component(&self.top, &other.top)?,
            right:  animate_component(&self.right, &other.right)?,
            bottom: animate_component(&self.bottom, &other.bottom)?,
            left:   animate_component(&self.left, &other.left)?,
        })
    }
}

impl ToAnimatedZero for ClipRect {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
}

fn animate_multiplicative_factor(
    this: CSSFloat,
    other: CSSFloat,
    procedure: Procedure,
) -> Result<CSSFloat, ()> {
    Ok((this - 1.).animate(&(other - 1.), procedure)? + 1.)
}

/// <http://dev.w3.org/csswg/css-transforms/#interpolation-of-transforms>
impl Animate for ComputedTransformOperation {
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        match (self, other) {
            (
                &TransformOperation::Matrix3D(ref this),
                &TransformOperation::Matrix3D(ref other),
            ) => {
                Ok(TransformOperation::Matrix3D(
                    this.animate(other, procedure)?,
                ))
            },
            (
                &TransformOperation::Matrix(ref this),
                &TransformOperation::Matrix(ref other),
            ) => {
                Ok(TransformOperation::Matrix(
                    this.animate(other, procedure)?,
                ))
            },
            (
                &TransformOperation::Skew(ref fx, None),
                &TransformOperation::Skew(ref tx, None),
            ) => {
                Ok(TransformOperation::Skew(
                    fx.animate(tx, procedure)?,
                    None,
                ))
            },
            (
                &TransformOperation::Skew(ref fx, ref fy),
                &TransformOperation::Skew(ref tx, ref ty),
            ) => {
                Ok(TransformOperation::Skew(
                    fx.animate(tx, procedure)?,
                    Some(fy.unwrap_or(Angle::zero()).animate(&ty.unwrap_or(Angle::zero()), procedure)?)
                ))
            },
            (
                &TransformOperation::SkewX(ref f),
                &TransformOperation::SkewX(ref t),
            ) => {
                Ok(TransformOperation::SkewX(
                    f.animate(t, procedure)?,
                ))
            },
            (
                &TransformOperation::SkewY(ref f),
                &TransformOperation::SkewY(ref t),
            ) => {
                Ok(TransformOperation::SkewY(
                    f.animate(t, procedure)?,
                ))
            },
            (
                &TransformOperation::Translate3D(ref fx, ref fy, ref fz),
                &TransformOperation::Translate3D(ref tx, ref ty, ref tz),
            ) => {
                Ok(TransformOperation::Translate3D(
                    fx.animate(tx, procedure)?,
                    fy.animate(ty, procedure)?,
                    fz.animate(tz, procedure)?,
                ))
            },
            (
                &TransformOperation::Translate(ref fx, None),
                &TransformOperation::Translate(ref tx, None),
            ) => {
                Ok(TransformOperation::Translate(
                    fx.animate(tx, procedure)?,
                    None
                ))
            },
            (
                &TransformOperation::Translate(ref fx, ref fy),
                &TransformOperation::Translate(ref tx, ref ty),
            ) => {
                Ok(TransformOperation::Translate(
                    fx.animate(tx, procedure)?,
                    Some(fy.unwrap_or(LengthOrPercentage::zero())
                        .animate(&ty.unwrap_or(LengthOrPercentage::zero()), procedure)?)
                ))
            },
            (
                &TransformOperation::TranslateX(ref f),
                &TransformOperation::TranslateX(ref t),
            ) => {
                Ok(TransformOperation::TranslateX(
                    f.animate(t, procedure)?
                ))
            },
            (
                &TransformOperation::TranslateY(ref f),
                &TransformOperation::TranslateY(ref t),
            ) => {
                Ok(TransformOperation::TranslateY(
                    f.animate(t, procedure)?
                ))
            },
            (
                &TransformOperation::TranslateZ(ref f),
                &TransformOperation::TranslateZ(ref t),
            ) => {
                Ok(TransformOperation::TranslateZ(
                    f.animate(t, procedure)?
                ))
            },
            (
                &TransformOperation::Scale3D(ref fx, ref fy, ref fz),
                &TransformOperation::Scale3D(ref tx, ref ty, ref tz),
            ) => {
                Ok(TransformOperation::Scale3D(
                    animate_multiplicative_factor(*fx, *tx, procedure)?,
                    animate_multiplicative_factor(*fy, *ty, procedure)?,
                    animate_multiplicative_factor(*fz, *tz, procedure)?,
                ))
            },
            (
                &TransformOperation::ScaleX(ref f),
                &TransformOperation::ScaleX(ref t),
            ) => {
                Ok(TransformOperation::ScaleX(
                    animate_multiplicative_factor(*f, *t, procedure)?
                ))
            },
            (
                &TransformOperation::ScaleY(ref f),
                &TransformOperation::ScaleY(ref t),
            ) => {
                Ok(TransformOperation::ScaleY(
                    animate_multiplicative_factor(*f, *t, procedure)?
                ))
            },
            (
                &TransformOperation::ScaleZ(ref f),
                &TransformOperation::ScaleZ(ref t),
            ) => {
                Ok(TransformOperation::ScaleZ(
                    animate_multiplicative_factor(*f, *t, procedure)?
                ))
            },
            (
                &TransformOperation::Scale(ref f, None),
                &TransformOperation::Scale(ref t, None),
            ) => {
                Ok(TransformOperation::Scale(
                    animate_multiplicative_factor(*f, *t, procedure)?,
                    None
                ))
            },
            (
                &TransformOperation::Scale(ref fx, ref fy),
                &TransformOperation::Scale(ref tx, ref ty),
            ) => {
                Ok(TransformOperation::Scale(
                    animate_multiplicative_factor(*fx, *tx, procedure)?,
                    Some(animate_multiplicative_factor(fy.unwrap_or(*fx), ty.unwrap_or(*tx), procedure)?),
                ))
            },
            (
                &TransformOperation::Rotate3D(fx, fy, fz, fa),
                &TransformOperation::Rotate3D(tx, ty, tz, ta),
            ) => {
                let (fx, fy, fz, fa) = transform::get_normalized_vector_and_angle(fx, fy, fz, fa);
                let (tx, ty, tz, ta) = transform::get_normalized_vector_and_angle(tx, ty, tz, ta);
                if (fx, fy, fz) == (tx, ty, tz) {
                    let ia = fa.animate(&ta, procedure)?;
                    Ok(TransformOperation::Rotate3D(fx, fy, fz, ia))
                } else {
                    let matrix_f = rotate_to_matrix(fx, fy, fz, fa);
                    let matrix_t = rotate_to_matrix(tx, ty, tz, ta);
                    Ok(TransformOperation::Matrix3D(
                        matrix_f.animate(&matrix_t, procedure)?,
                    ))
                }
            },
            (
                &TransformOperation::RotateX(fa),
                &TransformOperation::RotateX(ta),
            ) => {
                Ok(TransformOperation::RotateX(
                    fa.animate(&ta, procedure)?
                ))
            },
            (
                &TransformOperation::RotateY(fa),
                &TransformOperation::RotateY(ta),
            ) => {
                Ok(TransformOperation::RotateY(
                    fa.animate(&ta, procedure)?
                ))
            },
            (
                &TransformOperation::RotateZ(fa),
                &TransformOperation::RotateZ(ta),
            ) => {
                Ok(TransformOperation::RotateZ(
                    fa.animate(&ta, procedure)?
                ))
            },
            (
                &TransformOperation::Rotate(fa),
                &TransformOperation::Rotate(ta),
            ) => {
                Ok(TransformOperation::Rotate(
                    fa.animate(&ta, procedure)?
                ))
            },
            (
                &TransformOperation::Rotate(fa),
                &TransformOperation::RotateZ(ta),
            ) => {
                Ok(TransformOperation::Rotate(
                    fa.animate(&ta, procedure)?
                ))
            },
            (
                &TransformOperation::RotateZ(fa),
                &TransformOperation::Rotate(ta),
            ) => {
                Ok(TransformOperation::Rotate(
                    fa.animate(&ta, procedure)?
                ))
            },
            (
                &TransformOperation::Perspective(ref fd),
                &TransformOperation::Perspective(ref td),
            ) => {
                let mut fd_matrix = Matrix3D::identity();
                let mut td_matrix = Matrix3D::identity();
                if fd.px() > 0. {
                    fd_matrix.m34 = -1. / fd.px();
                }
                if td.px() > 0. {
                    td_matrix.m34 = -1. / td.px();
                }
                Ok(TransformOperation::Matrix3D(
                    fd_matrix.animate(&td_matrix, procedure)?,
                ))
            },
            _ if self.is_translate() && other.is_translate() => {
                self.to_translate_3d().animate(&other.to_translate_3d(), procedure)
            }
            _ if self.is_scale() && other.is_scale() => {
                self.to_scale_3d().animate(&other.to_scale_3d(), procedure)
            }
            _ => Err(()),
        }
    }
}

fn is_matched_operation(first: &ComputedTransformOperation, second: &ComputedTransformOperation) -> bool {
    match (first, second) {
        (&TransformOperation::Matrix(..),
         &TransformOperation::Matrix(..)) |
        (&TransformOperation::Matrix3D(..),
         &TransformOperation::Matrix3D(..)) |
        (&TransformOperation::Skew(..),
         &TransformOperation::Skew(..)) |
        (&TransformOperation::SkewX(..),
         &TransformOperation::SkewX(..)) |
        (&TransformOperation::SkewY(..),
         &TransformOperation::SkewY(..)) |
        (&TransformOperation::Rotate(..),
         &TransformOperation::Rotate(..)) |
        (&TransformOperation::Rotate3D(..),
         &TransformOperation::Rotate3D(..)) |
        (&TransformOperation::RotateX(..),
         &TransformOperation::RotateX(..)) |
        (&TransformOperation::RotateY(..),
         &TransformOperation::RotateY(..)) |
        (&TransformOperation::RotateZ(..),
         &TransformOperation::RotateZ(..)) |
        (&TransformOperation::Perspective(..),
         &TransformOperation::Perspective(..)) => true,
        // we animate scale and translate operations against each other
        (a, b) if a.is_translate() && b.is_translate() => true,
        (a, b) if a.is_scale() && b.is_scale() => true,
        // InterpolateMatrix and AccumulateMatrix are for mismatched transform.
        _ => false
    }
}

/// <https://www.w3.org/TR/css-transforms-1/#Rotate3dDefined>
fn rotate_to_matrix(x: f32, y: f32, z: f32, a: Angle) -> Matrix3D {
    let half_rad = a.radians() / 2.0;
    let sc = (half_rad).sin() * (half_rad).cos();
    let sq = (half_rad).sin().powi(2);

    Matrix3D {
        m11: 1.0 - 2.0 * (y * y + z * z) * sq,
        m12: 2.0 * (x * y * sq + z * sc),
        m13: 2.0 * (x * z * sq - y * sc),
        m14: 0.0,

        m21: 2.0 * (x * y * sq - z * sc),
        m22: 1.0 - 2.0 * (x * x + z * z) * sq,
        m23: 2.0 * (y * z * sq + x * sc),
        m24: 0.0,

        m31: 2.0 * (x * z * sq + y * sc),
        m32: 2.0 * (y * z * sq - x * sc),
        m33: 1.0 - 2.0 * (x * x + y * y) * sq,
        m34: 0.0,

        m41: 0.0,
        m42: 0.0,
        m43: 0.0,
        m44: 1.0
    }
}

/// A 2d matrix for interpolation.
#[derive(Clone, ComputeSquaredDistance, Copy, Debug)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
#[allow(missing_docs)]
// FIXME: We use custom derive for ComputeSquaredDistance. However, If possible, we should convert
// the InnerMatrix2D into types with physical meaning. This custom derive computes the squared
// distance from each matrix item, and this makes the result different from that in Gecko if we
// have skew factor in the Matrix3D.
pub struct InnerMatrix2D {
    pub m11: CSSFloat, pub m12: CSSFloat,
    pub m21: CSSFloat, pub m22: CSSFloat,
}

/// A 2d translation function.
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
#[derive(Animate, Clone, ComputeSquaredDistance, Copy, Debug)]
pub struct Translate2D(f32, f32);

/// A 2d scale function.
#[derive(Clone, ComputeSquaredDistance, Copy, Debug)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub struct Scale2D(f32, f32);

/// A decomposed 2d matrix.
#[derive(Clone, Copy, Debug)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub struct MatrixDecomposed2D {
    /// The translation function.
    pub translate: Translate2D,
    /// The scale function.
    pub scale: Scale2D,
    /// The rotation angle.
    pub angle: f32,
    /// The inner matrix.
    pub matrix: InnerMatrix2D,
}

impl Animate for InnerMatrix2D {
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        Ok(InnerMatrix2D {
            m11: animate_multiplicative_factor(self.m11, other.m11, procedure)?,
            m12: self.m12.animate(&other.m12, procedure)?,
            m21: self.m21.animate(&other.m21, procedure)?,
            m22: animate_multiplicative_factor(self.m22, other.m22, procedure)?,
        })
    }
}

impl Animate for Scale2D {
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        Ok(Scale2D(
            animate_multiplicative_factor(self.0, other.0, procedure)?,
            animate_multiplicative_factor(self.1, other.1, procedure)?,
        ))
    }
}

impl Animate for MatrixDecomposed2D {
    /// <https://drafts.csswg.org/css-transforms/#interpolation-of-decomposed-2d-matrix-values>
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        // If x-axis of one is flipped, and y-axis of the other,
        // convert to an unflipped rotation.
        let mut scale = self.scale;
        let mut angle = self.angle;
        let mut other_angle = other.angle;
        if (scale.0 < 0.0 && other.scale.1 < 0.0) || (scale.1 < 0.0 && other.scale.0 < 0.0) {
            scale.0 = -scale.0;
            scale.1 = -scale.1;
            angle += if angle < 0.0 {180.} else {-180.};
        }

        // Don't rotate the long way around.
        if angle == 0.0 {
            angle = 360.
        }
        if other_angle == 0.0 {
            other_angle = 360.
        }

        if (angle - other_angle).abs() > 180. {
            if angle > other_angle {
                angle -= 360.
            }
            else{
                other_angle -= 360.
            }
        }

        // Interpolate all values.
        let translate = self.translate.animate(&other.translate, procedure)?;
        let scale = scale.animate(&other.scale, procedure)?;
        let angle = angle.animate(&other_angle, procedure)?;
        let matrix = self.matrix.animate(&other.matrix, procedure)?;

        Ok(MatrixDecomposed2D {
            translate: translate,
            scale: scale,
            angle: angle,
            matrix: matrix,
        })
    }
}

impl ComputeSquaredDistance for MatrixDecomposed2D {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        // Use Radian to compute the distance.
        const RAD_PER_DEG: f64 = ::std::f64::consts::PI / 180.0;
        let angle1 = self.angle as f64 * RAD_PER_DEG;
        let angle2 = other.angle as f64 * RAD_PER_DEG;
        Ok(self.translate.compute_squared_distance(&other.translate)? +
           self.scale.compute_squared_distance(&other.scale)? +
           angle1.compute_squared_distance(&angle2)? +
           self.matrix.compute_squared_distance(&other.matrix)?)
    }
}

impl Animate for Matrix3D {
    #[cfg(feature = "servo")]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        if self.is_3d() || other.is_3d() {
            let decomposed_from = decompose_3d_matrix(*self);
            let decomposed_to = decompose_3d_matrix(*other);
            match (decomposed_from, decomposed_to) {
                (Ok(this), Ok(other)) => {
                    Ok(Matrix3D::from(this.animate(&other, procedure)?))
                },
                // Matrices can be undecomposable due to couple reasons, e.g.,
                // non-invertible matrices. In this case, we should report Err
                // here, and let the caller do the fallback procedure.
                _ => Err(())
            }
        } else {
            let this = MatrixDecomposed2D::from(*self);
            let other = MatrixDecomposed2D::from(*other);
            Ok(Matrix3D::from(this.animate(&other, procedure)?))
        }
    }

    #[cfg(feature = "gecko")]
    // Gecko doesn't exactly follow the spec here; we use a different procedure
    // to match it
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        let (from, to) = if self.is_3d() || other.is_3d() {
            (decompose_3d_matrix(*self), decompose_3d_matrix(*other))
        } else {
            (decompose_2d_matrix(self), decompose_2d_matrix(other))
        };
        match (from, to) {
            (Ok(from), Ok(to)) => {
                Ok(Matrix3D::from(from.animate(&to, procedure)?))
            },
            // Matrices can be undecomposable due to couple reasons, e.g.,
            // non-invertible matrices. In this case, we should report Err here,
            // and let the caller do the fallback procedure.
            _ => Err(())
        }
    }
}

impl Animate for Matrix {
    #[cfg(feature = "servo")]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        let this = Matrix3D::from(*self);
        let other = Matrix3D::from(*other);
        let this = MatrixDecomposed2D::from(this);
        let other = MatrixDecomposed2D::from(other);
        Ok(Matrix3D::from(this.animate(&other, procedure)?).into_2d()?)
    }

    #[cfg(feature = "gecko")]
    // Gecko doesn't exactly follow the spec here; we use a different procedure
    // to match it
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        let from = decompose_2d_matrix(&(*self).into());
        let to = decompose_2d_matrix(&(*other).into());
        match (from, to) {
            (Ok(from), Ok(to)) => {
                Matrix3D::from(from.animate(&to, procedure)?).into_2d()
            },
            // Matrices can be undecomposable due to couple reasons, e.g.,
            // non-invertible matrices. In this case, we should report Err here,
            // and let the caller do the fallback procedure.
            _ => Err(())
        }
    }
}

impl ComputeSquaredDistance for Matrix3D {
    #[inline]
    #[cfg(feature = "servo")]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        if self.is_3d() || other.is_3d() {
            let from = decompose_3d_matrix(*self)?;
            let to = decompose_3d_matrix(*other)?;
            from.compute_squared_distance(&to)
        } else {
            let from = MatrixDecomposed2D::from(*self);
            let to = MatrixDecomposed2D::from(*other);
            from.compute_squared_distance(&to)
        }
    }

    #[inline]
    #[cfg(feature = "gecko")]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        let (from, to) = if self.is_3d() || other.is_3d() {
            (decompose_3d_matrix(*self)?, decompose_3d_matrix(*other)?)
        } else {
            (decompose_2d_matrix(self)?, decompose_2d_matrix(other)?)
        };
        from.compute_squared_distance(&to)
    }
}

impl From<Matrix3D> for MatrixDecomposed2D {
    /// Decompose a 2D matrix.
    /// <https://drafts.csswg.org/css-transforms/#decomposing-a-2d-matrix>
    fn from(matrix: Matrix3D) -> MatrixDecomposed2D {
        let mut row0x = matrix.m11;
        let mut row0y = matrix.m12;
        let mut row1x = matrix.m21;
        let mut row1y = matrix.m22;

        let translate = Translate2D(matrix.m41, matrix.m42);
        let mut scale = Scale2D((row0x * row0x + row0y * row0y).sqrt(),
                                (row1x * row1x + row1y * row1y).sqrt());

        // If determinant is negative, one axis was flipped.
        let determinant = row0x * row1y - row0y * row1x;
        if determinant < 0. {
            if row0x < row1y {
                scale.0 = -scale.0;
            } else {
                scale.1 = -scale.1;
            }
        }

        // Renormalize matrix to remove scale.
        if scale.0 != 0.0 {
            row0x *= 1. / scale.0;
            row0y *= 1. / scale.0;
        }
        if scale.1 != 0.0 {
            row1x *= 1. / scale.1;
            row1y *= 1. / scale.1;
        }

        // Compute rotation and renormalize matrix.
        let mut angle = row0y.atan2(row0x);
        if angle != 0.0 {
            let sn = -row0y;
            let cs = row0x;
            let m11 = row0x;
            let m12 = row0y;
            let m21 = row1x;
            let m22 = row1y;
            row0x = cs * m11 + sn * m21;
            row0y = cs * m12 + sn * m22;
            row1x = -sn * m11 + cs * m21;
            row1y = -sn * m12 + cs * m22;
        }

        let m = InnerMatrix2D {
            m11: row0x, m12: row0y,
            m21: row1x, m22: row1y,
        };

        // Convert into degrees because our rotation functions expect it.
        angle = angle.to_degrees();
        MatrixDecomposed2D {
            translate: translate,
            scale: scale,
            angle: angle,
            matrix: m,
        }
    }
}

impl From<MatrixDecomposed2D> for Matrix3D {
    /// Recompose a 2D matrix.
    /// <https://drafts.csswg.org/css-transforms/#recomposing-to-a-2d-matrix>
    fn from(decomposed: MatrixDecomposed2D) -> Matrix3D {
        let mut computed_matrix = Matrix3D::identity();
        computed_matrix.m11 = decomposed.matrix.m11;
        computed_matrix.m12 = decomposed.matrix.m12;
        computed_matrix.m21 = decomposed.matrix.m21;
        computed_matrix.m22 = decomposed.matrix.m22;

        // Translate matrix.
        computed_matrix.m41 = decomposed.translate.0;
        computed_matrix.m42 = decomposed.translate.1;

        // Rotate matrix.
        let angle = decomposed.angle.to_radians();
        let cos_angle = angle.cos();
        let sin_angle = angle.sin();

        let mut rotate_matrix = Matrix3D::identity();
        rotate_matrix.m11 = cos_angle;
        rotate_matrix.m12 = sin_angle;
        rotate_matrix.m21 = -sin_angle;
        rotate_matrix.m22 = cos_angle;

        // Multiplication of computed_matrix and rotate_matrix
        computed_matrix = multiply(rotate_matrix, computed_matrix);

        // Scale matrix.
        computed_matrix.m11 *= decomposed.scale.0;
        computed_matrix.m12 *= decomposed.scale.0;
        computed_matrix.m21 *= decomposed.scale.1;
        computed_matrix.m22 *= decomposed.scale.1;
        computed_matrix
    }
}

#[cfg(feature = "gecko")]
impl<'a> From< &'a RawGeckoGfxMatrix4x4> for Matrix3D {
    fn from(m: &'a RawGeckoGfxMatrix4x4) -> Matrix3D {
        Matrix3D {
            m11: m[0],  m12: m[1],  m13: m[2],  m14: m[3],
            m21: m[4],  m22: m[5],  m23: m[6],  m24: m[7],
            m31: m[8],  m32: m[9],  m33: m[10], m34: m[11],
            m41: m[12], m42: m[13], m43: m[14], m44: m[15],
        }
    }
}

#[cfg(feature = "gecko")]
impl From<Matrix3D> for RawGeckoGfxMatrix4x4 {
    fn from(matrix: Matrix3D) -> RawGeckoGfxMatrix4x4 {
        [ matrix.m11, matrix.m12, matrix.m13, matrix.m14,
          matrix.m21, matrix.m22, matrix.m23, matrix.m24,
          matrix.m31, matrix.m32, matrix.m33, matrix.m34,
          matrix.m41, matrix.m42, matrix.m43, matrix.m44 ]
    }
}

/// A 3d translation.
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
#[derive(Animate, Clone, ComputeSquaredDistance, Copy, Debug)]
pub struct Translate3D(f32, f32, f32);

/// A 3d scale function.
#[derive(Clone, ComputeSquaredDistance, Copy, Debug)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub struct Scale3D(f32, f32, f32);

/// A 3d skew function.
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
#[derive(Animate, Clone, Copy, Debug)]
pub struct Skew(f32, f32, f32);

/// A 3d perspective transformation.
#[derive(Clone, ComputeSquaredDistance, Copy, Debug)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub struct Perspective(f32, f32, f32, f32);

/// A quaternion used to represent a rotation.
#[derive(Clone, Copy, Debug)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub struct Quaternion(f64, f64, f64, f64);

/// A decomposed 3d matrix.
#[derive(Animate, Clone, ComputeSquaredDistance, Copy, Debug)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub struct MatrixDecomposed3D {
    /// A translation function.
    pub translate: Translate3D,
    /// A scale function.
    pub scale: Scale3D,
    /// The skew component of the transformation.
    pub skew: Skew,
    /// The perspective component of the transformation.
    pub perspective: Perspective,
    /// The quaternion used to represent the rotation.
    pub quaternion: Quaternion,
}

impl Quaternion {
    /// Return a quaternion from a unit direction vector and angle (unit: radian).
    #[inline]
    fn from_direction_and_angle(vector: &DirectionVector, angle: f64) -> Self {
        debug_assert!((vector.length() - 1.).abs() < 0.0001,
                      "Only accept an unit direction vector to create a quaternion");
        // Reference:
        // https://en.wikipedia.org/wiki/Quaternions_and_spatial_rotation
        //
        // if the direction axis is (x, y, z) = xi + yj + zk,
        // and the angle is |theta|, this formula can be done using
        // an extension of Euler's formula:
        //   q = cos(theta/2) + (xi + yj + zk)(sin(theta/2))
        //     = cos(theta/2) +
        //       x*sin(theta/2)i + y*sin(theta/2)j + z*sin(theta/2)k
        Quaternion(vector.x as f64 * (angle / 2.).sin(),
                   vector.y as f64 * (angle / 2.).sin(),
                   vector.z as f64 * (angle / 2.).sin(),
                   (angle / 2.).cos())
    }

    /// Calculate the dot product.
    #[inline]
    fn dot(&self, other: &Self) -> f64 {
        self.0 * other.0 + self.1 * other.1 + self.2 * other.2 + self.3 * other.3
    }
}

impl Animate for Quaternion {
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        use std::f64;

        let (this_weight, other_weight) = procedure.weights();
        debug_assert!((this_weight + other_weight - 1.0f64).abs() <= f64::EPSILON ||
                      other_weight == 1.0f64 || other_weight == 0.0f64,
                      "animate should only be used for interpolating or accumulating transforms");

        // We take a specialized code path for accumulation (where other_weight is 1)
        if other_weight == 1.0 {
            if this_weight == 0.0 {
                return Ok(*other);
            }

            let clamped_w = self.3.min(1.0).max(-1.0);

            // Determine the scale factor.
            let mut theta = clamped_w.acos();
            let mut scale = if theta == 0.0 { 0.0 } else { 1.0 / theta.sin() };
            theta *= this_weight;
            scale *= theta.sin();

            // Scale the self matrix by this_weight.
            let mut scaled_self = *self;
                scaled_self.0 *= scale;
                scaled_self.1 *= scale;
                scaled_self.2 *= scale;
            scaled_self.3 = theta.cos();

            // Multiply scaled-self by other.
            let a = &scaled_self;
            let b = other;
            return Ok(Quaternion(
                a.3 * b.0 + a.0 * b.3 + a.1 * b.2 - a.2 * b.1,
                a.3 * b.1 - a.0 * b.2 + a.1 * b.3 + a.2 * b.0,
                a.3 * b.2 + a.0 * b.1 - a.1 * b.0 + a.2 * b.3,
                a.3 * b.3 - a.0 * b.0 - a.1 * b.1 - a.2 * b.2,
            ));
        }

        let mut product = self.0 * other.0 +
                          self.1 * other.1 +
                          self.2 * other.2 +
                          self.3 * other.3;

        // Clamp product to -1.0 <= product <= 1.0
        product = product.min(1.0);
        product = product.max(-1.0);

        if product == 1.0 {
            return Ok(*self);
        }

        let theta = product.acos();
        let w = (other_weight * theta).sin() * 1.0 / (1.0 - product * product).sqrt();

        let mut a = *self;
        let mut b = *other;
        let mut result = Quaternion(0., 0., 0., 0.,);
            a.0 *= (other_weight * theta).cos() - product * w;
            b.0 *= w;
            result.0 = a.0 + b.0;
            a.1 *= (other_weight * theta).cos() - product * w;
            b.1 *= w;
            result.1 = a.1 + b.1;
            a.2 *= (other_weight * theta).cos() - product * w;
            b.2 *= w;
            result.2 = a.2 + b.2;
            a.3 *= (other_weight * theta).cos() - product * w;
            b.3 *= w;
            result.3 = a.3 + b.3;

        Ok(result)
    }
}

impl ComputeSquaredDistance for Quaternion {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        // Use quaternion vectors to get the angle difference. Both q1 and q2 are unit vectors,
        // so we can get their angle difference by:
        // cos(theta/2) = (q1 dot q2) / (|q1| * |q2|) = q1 dot q2.
        let distance = self.dot(other).max(-1.0).min(1.0).acos() * 2.0;
        Ok(SquaredDistance::from_sqrt(distance))
    }
}

/// Decompose a 3D matrix.
/// <https://drafts.csswg.org/css-transforms/#decomposing-a-3d-matrix>
fn decompose_3d_matrix(mut matrix: Matrix3D) -> Result<MatrixDecomposed3D, ()> {
    // Normalize the matrix.
    if matrix.m44 == 0.0 {
        return Err(());
    }

    let scaling_factor = matrix.m44;
            matrix.m11 /= scaling_factor;
            matrix.m12 /= scaling_factor;
            matrix.m13 /= scaling_factor;
            matrix.m14 /= scaling_factor;
            matrix.m21 /= scaling_factor;
            matrix.m22 /= scaling_factor;
            matrix.m23 /= scaling_factor;
            matrix.m24 /= scaling_factor;
            matrix.m31 /= scaling_factor;
            matrix.m32 /= scaling_factor;
            matrix.m33 /= scaling_factor;
            matrix.m34 /= scaling_factor;
            matrix.m41 /= scaling_factor;
            matrix.m42 /= scaling_factor;
            matrix.m43 /= scaling_factor;
            matrix.m44 /= scaling_factor;

    // perspective_matrix is used to solve for perspective, but it also provides
    // an easy way to test for singularity of the upper 3x3 component.
    let mut perspective_matrix = matrix;

        perspective_matrix.m14 = 0.0;
        perspective_matrix.m24 = 0.0;
        perspective_matrix.m34 = 0.0;
    perspective_matrix.m44 = 1.0;

    if perspective_matrix.determinant() == 0.0 {
        return Err(());
    }

    // First, isolate perspective.
    let perspective = if matrix.m14 != 0.0 || matrix.m24 != 0.0 || matrix.m34 != 0.0 {
        let right_hand_side: [f32; 4] = [
            matrix.m14,
            matrix.m24,
            matrix.m34,
            matrix.m44
        ];

        perspective_matrix = perspective_matrix.inverse().unwrap();

        // Transpose perspective_matrix
        perspective_matrix = Matrix3D {
                    m11: perspective_matrix.m11,
                    m12: perspective_matrix.m21,
                    m13: perspective_matrix.m31,
                    m14: perspective_matrix.m41,
                    m21: perspective_matrix.m12,
                    m22: perspective_matrix.m22,
                    m23: perspective_matrix.m32,
                    m24: perspective_matrix.m42,
                    m31: perspective_matrix.m13,
                    m32: perspective_matrix.m23,
                    m33: perspective_matrix.m33,
                    m34: perspective_matrix.m43,
                    m41: perspective_matrix.m14,
                    m42: perspective_matrix.m24,
                    m43: perspective_matrix.m34,
                    m44: perspective_matrix.m44,
        };

        // Multiply right_hand_side with perspective_matrix
        let mut tmp: [f32; 4] = [0.0; 4];
            tmp[0] = (right_hand_side[0] * perspective_matrix.m11) +
                            (right_hand_side[1] * perspective_matrix.m21) +
                            (right_hand_side[2] * perspective_matrix.m31) +
                            (right_hand_side[3] * perspective_matrix.m41);
            tmp[1] = (right_hand_side[0] * perspective_matrix.m12) +
                            (right_hand_side[1] * perspective_matrix.m22) +
                            (right_hand_side[2] * perspective_matrix.m32) +
                            (right_hand_side[3] * perspective_matrix.m42);
            tmp[2] = (right_hand_side[0] * perspective_matrix.m13) +
                            (right_hand_side[1] * perspective_matrix.m23) +
                            (right_hand_side[2] * perspective_matrix.m33) +
                            (right_hand_side[3] * perspective_matrix.m43);
            tmp[3] = (right_hand_side[0] * perspective_matrix.m14) +
                            (right_hand_side[1] * perspective_matrix.m24) +
                            (right_hand_side[2] * perspective_matrix.m34) +
                            (right_hand_side[3] * perspective_matrix.m44);

        Perspective(tmp[0], tmp[1], tmp[2], tmp[3])
    } else {
        Perspective(0.0, 0.0, 0.0, 1.0)
    };

    // Next take care of translation
    let translate = Translate3D (
        matrix.m41,
        matrix.m42,
        matrix.m43
    );

    // Now get scale and shear. 'row' is a 3 element array of 3 component vectors
    let mut row: [[f32; 3]; 3] = [[0.0; 3]; 3];
        row[0][0] = matrix.m11;
        row[0][1] = matrix.m12;
        row[0][2] = matrix.m13;
        row[1][0] = matrix.m21;
        row[1][1] = matrix.m22;
        row[1][2] = matrix.m23;
        row[2][0] = matrix.m31;
        row[2][1] = matrix.m32;
        row[2][2] = matrix.m33;

    // Compute X scale factor and normalize first row.
    let row0len = (row[0][0] * row[0][0] + row[0][1] * row[0][1] + row[0][2] * row[0][2]).sqrt();
    let mut scale = Scale3D(row0len, 0.0, 0.0);
    row[0] = [row[0][0] / row0len, row[0][1] / row0len, row[0][2] / row0len];

    // Compute XY shear factor and make 2nd row orthogonal to 1st.
    let mut skew = Skew(dot(row[0], row[1]), 0.0, 0.0);
    row[1] = combine(row[1], row[0], 1.0, -skew.0);

    // Now, compute Y scale and normalize 2nd row.
    let row1len = (row[1][0] * row[1][0] + row[1][1] * row[1][1] + row[1][2] * row[1][2]).sqrt();
    scale.1 = row1len;
    row[1] = [row[1][0] / row1len, row[1][1] / row1len, row[1][2] / row1len];
    skew.0 /= scale.1;

    // Compute XZ and YZ shears, orthogonalize 3rd row
    skew.1 = dot(row[0], row[2]);
    row[2] = combine(row[2], row[0], 1.0, -skew.1);
    skew.2 = dot(row[1], row[2]);
    row[2] = combine(row[2], row[1], 1.0, -skew.2);

    // Next, get Z scale and normalize 3rd row.
    let row2len = (row[2][0] * row[2][0] + row[2][1] * row[2][1] + row[2][2] * row[2][2]).sqrt();
    scale.2 = row2len;
    row[2] = [row[2][0] / row2len, row[2][1] / row2len, row[2][2] / row2len];
    skew.1 /= scale.2;
    skew.2 /= scale.2;

    // At this point, the matrix (in rows) is orthonormal.
    // Check for a coordinate system flip.  If the determinant
    // is -1, then negate the matrix and the scaling factors.
    let pdum3 = cross(row[1], row[2]);
    if dot(row[0], pdum3) < 0.0 {
            scale.0 *= -1.0;
            row[0][0] *= -1.0;
            row[0][1] *= -1.0;
            row[0][2] *= -1.0;
            scale.1 *= -1.0;
            row[1][0] *= -1.0;
            row[1][1] *= -1.0;
            row[1][2] *= -1.0;
            scale.2 *= -1.0;
            row[2][0] *= -1.0;
            row[2][1] *= -1.0;
            row[2][2] *= -1.0;
    }

    // Now, get the rotations out
    let mut quaternion = Quaternion (
        0.5 * ((1.0 + row[0][0] - row[1][1] - row[2][2]).max(0.0) as f64).sqrt(),
        0.5 * ((1.0 - row[0][0] + row[1][1] - row[2][2]).max(0.0) as f64).sqrt(),
        0.5 * ((1.0 - row[0][0] - row[1][1] + row[2][2]).max(0.0) as f64).sqrt(),
        0.5 * ((1.0 + row[0][0] + row[1][1] + row[2][2]).max(0.0) as f64).sqrt()
    );

    if row[2][1] > row[1][2] {
        quaternion.0 = -quaternion.0
    }
    if row[0][2] > row[2][0] {
        quaternion.1 = -quaternion.1
    }
    if row[1][0] > row[0][1] {
        quaternion.2 = -quaternion.2
    }

    Ok(MatrixDecomposed3D {
        translate: translate,
        scale: scale,
        skew: skew,
        perspective: perspective,
        quaternion: quaternion
    })
}

/// Decompose a 2D matrix for Gecko.
// Use the algorithm from nsStyleTransformMatrix::Decompose2DMatrix() in Gecko.
#[cfg(feature = "gecko")]
fn decompose_2d_matrix(matrix: &Matrix3D) -> Result<MatrixDecomposed3D, ()> {
    // The index is column-major, so the equivalent transform matrix is:
    // | m11 m21  0 m41 |  =>  | m11 m21 | and translate(m41, m42)
    // | m12 m22  0 m42 |      | m12 m22 |
    // |   0   0  1   0 |
    // |   0   0  0   1 |
    let (mut m11, mut m12) = (matrix.m11, matrix.m12);
    let (mut m21, mut m22) = (matrix.m21, matrix.m22);
    // Check if this is a singular matrix.
    if m11 * m22 == m12 * m21 {
        return Err(());
    }

    let mut scale_x = (m11 * m11 + m12 * m12).sqrt();
    m11 /= scale_x;
    m12 /= scale_x;

    let mut shear_xy = m11 * m21 + m12 * m22;
    m21 -= m11 * shear_xy;
    m22 -= m12 * shear_xy;

    let scale_y = (m21 * m21 + m22 * m22).sqrt();
    m21 /= scale_y;
    m22 /= scale_y;
    shear_xy /= scale_y;

    let determinant = m11 * m22 - m12 * m21;
    // Determinant should now be 1 or -1.
    if 0.99 > determinant.abs() || determinant.abs() > 1.01 {
        return Err(());
    }

    if determinant < 0. {
        m11 = -m11;
        m12 = -m12;
        shear_xy = -shear_xy;
        scale_x = -scale_x;
    }

    Ok(MatrixDecomposed3D {
        translate: Translate3D(matrix.m41, matrix.m42, 0.),
        scale: Scale3D(scale_x, scale_y, 1.),
        skew: Skew(shear_xy, 0., 0.),
        perspective: Perspective(0., 0., 0., 1.),
        quaternion: Quaternion::from_direction_and_angle(&DirectionVector::new(0., 0., 1.),
                                                         m12.atan2(m11) as f64)
    })
}

// Combine 2 point.
fn combine(a: [f32; 3], b: [f32; 3], ascl: f32, bscl: f32) -> [f32; 3] {
    [
        (ascl * a[0]) + (bscl * b[0]),
        (ascl * a[1]) + (bscl * b[1]),
        (ascl * a[2]) + (bscl * b[2])
    ]
}

// Dot product.
fn dot(a: [f32; 3], b: [f32; 3]) -> f32 {
    a[0] * b[0] + a[1] * b[1] + a[2] * b[2]
}

// Cross product.
fn cross(row1: [f32; 3], row2: [f32; 3]) -> [f32; 3] {
    [
        row1[1] * row2[2] - row1[2] * row2[1],
        row1[2] * row2[0] - row1[0] * row2[2],
        row1[0] * row2[1] - row1[1] * row2[0]
    ]
}

impl Animate for Scale3D {
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        Ok(Scale3D(
            animate_multiplicative_factor(self.0, other.0, procedure)?,
            animate_multiplicative_factor(self.1, other.1, procedure)?,
            animate_multiplicative_factor(self.2, other.2, procedure)?,
        ))
    }
}

impl ComputeSquaredDistance for Skew {
    // We have to use atan() to convert the skew factors into skew angles, so implement
    // ComputeSquaredDistance manually.
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        Ok(self.0.atan().compute_squared_distance(&other.0.atan())? +
           self.1.atan().compute_squared_distance(&other.1.atan())? +
           self.2.atan().compute_squared_distance(&other.2.atan())?)
    }
}

impl Animate for Perspective {
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        Ok(Perspective(
            self.0.animate(&other.0, procedure)?,
            self.1.animate(&other.1, procedure)?,
            self.2.animate(&other.2, procedure)?,
            animate_multiplicative_factor(self.3, other.3, procedure)?,
        ))
    }
}

impl From<MatrixDecomposed3D> for Matrix3D {
    /// Recompose a 3D matrix.
    /// <https://drafts.csswg.org/css-transforms/#recomposing-to-a-3d-matrix>
    fn from(decomposed: MatrixDecomposed3D) -> Matrix3D {
        let mut matrix = Matrix3D::identity();

        // Apply perspective
            matrix.m14 = decomposed.perspective.0;
            matrix.m24 = decomposed.perspective.1;
            matrix.m34 = decomposed.perspective.2;
            matrix.m44 = decomposed.perspective.3;

        // Apply translation
                matrix.m41 += decomposed.translate.0 * matrix.m11;
                matrix.m41 += decomposed.translate.1 * matrix.m21;
                matrix.m41 += decomposed.translate.2 * matrix.m31;
                matrix.m42 += decomposed.translate.0 * matrix.m12;
                matrix.m42 += decomposed.translate.1 * matrix.m22;
                matrix.m42 += decomposed.translate.2 * matrix.m32;
                matrix.m43 += decomposed.translate.0 * matrix.m13;
                matrix.m43 += decomposed.translate.1 * matrix.m23;
                matrix.m43 += decomposed.translate.2 * matrix.m33;

        // Apply rotation
        let x = decomposed.quaternion.0;
        let y = decomposed.quaternion.1;
        let z = decomposed.quaternion.2;
        let w = decomposed.quaternion.3;

        // Construct a composite rotation matrix from the quaternion values
        // rotationMatrix is a identity 4x4 matrix initially
        let mut rotation_matrix = Matrix3D::identity();
        rotation_matrix.m11 = 1.0 - 2.0 * (y * y + z * z) as f32;
        rotation_matrix.m12 = 2.0 * (x * y + z * w) as f32;
        rotation_matrix.m13 = 2.0 * (x * z - y * w) as f32;
        rotation_matrix.m21 = 2.0 * (x * y - z * w) as f32;
        rotation_matrix.m22 = 1.0 - 2.0 * (x * x + z * z) as f32;
        rotation_matrix.m23 = 2.0 * (y * z + x * w) as f32;
        rotation_matrix.m31 = 2.0 * (x * z + y * w) as f32;
        rotation_matrix.m32 = 2.0 * (y * z - x * w) as f32;
        rotation_matrix.m33 = 1.0 - 2.0 * (x * x + y * y) as f32;

        matrix = multiply(rotation_matrix, matrix);

        // Apply skew
        let mut temp = Matrix3D::identity();
        if decomposed.skew.2 != 0.0 {
            temp.m32 = decomposed.skew.2;
            matrix = multiply(temp, matrix);
        }

        if decomposed.skew.1 != 0.0 {
            temp.m32 = 0.0;
            temp.m31 = decomposed.skew.1;
            matrix = multiply(temp, matrix);
        }

        if decomposed.skew.0 != 0.0 {
            temp.m31 = 0.0;
            temp.m21 = decomposed.skew.0;
            matrix = multiply(temp, matrix);
        }

        // Apply scale
                matrix.m11 *= decomposed.scale.0;
                matrix.m12 *= decomposed.scale.0;
                matrix.m13 *= decomposed.scale.0;
                matrix.m21 *= decomposed.scale.1;
                matrix.m22 *= decomposed.scale.1;
                matrix.m23 *= decomposed.scale.1;
                matrix.m31 *= decomposed.scale.2;
                matrix.m32 *= decomposed.scale.2;
                matrix.m33 *= decomposed.scale.2;

        matrix
    }
}

// Multiplication of two 4x4 matrices.
fn multiply(a: Matrix3D, b: Matrix3D) -> Matrix3D {
    let mut a_clone = a;
            a_clone.m11 = (a.m11 * b.m11) +
                               (a.m12 * b.m21) +
                               (a.m13 * b.m31) +
                               (a.m14 * b.m41);
            a_clone.m12 = (a.m11 * b.m12) +
                               (a.m12 * b.m22) +
                               (a.m13 * b.m32) +
                               (a.m14 * b.m42);
            a_clone.m13 = (a.m11 * b.m13) +
                               (a.m12 * b.m23) +
                               (a.m13 * b.m33) +
                               (a.m14 * b.m43);
            a_clone.m14 = (a.m11 * b.m14) +
                               (a.m12 * b.m24) +
                               (a.m13 * b.m34) +
                               (a.m14 * b.m44);
            a_clone.m21 = (a.m21 * b.m11) +
                               (a.m22 * b.m21) +
                               (a.m23 * b.m31) +
                               (a.m24 * b.m41);
            a_clone.m22 = (a.m21 * b.m12) +
                               (a.m22 * b.m22) +
                               (a.m23 * b.m32) +
                               (a.m24 * b.m42);
            a_clone.m23 = (a.m21 * b.m13) +
                               (a.m22 * b.m23) +
                               (a.m23 * b.m33) +
                               (a.m24 * b.m43);
            a_clone.m24 = (a.m21 * b.m14) +
                               (a.m22 * b.m24) +
                               (a.m23 * b.m34) +
                               (a.m24 * b.m44);
            a_clone.m31 = (a.m31 * b.m11) +
                               (a.m32 * b.m21) +
                               (a.m33 * b.m31) +
                               (a.m34 * b.m41);
            a_clone.m32 = (a.m31 * b.m12) +
                               (a.m32 * b.m22) +
                               (a.m33 * b.m32) +
                               (a.m34 * b.m42);
            a_clone.m33 = (a.m31 * b.m13) +
                               (a.m32 * b.m23) +
                               (a.m33 * b.m33) +
                               (a.m34 * b.m43);
            a_clone.m34 = (a.m31 * b.m14) +
                               (a.m32 * b.m24) +
                               (a.m33 * b.m34) +
                               (a.m34 * b.m44);
            a_clone.m41 = (a.m41 * b.m11) +
                               (a.m42 * b.m21) +
                               (a.m43 * b.m31) +
                               (a.m44 * b.m41);
            a_clone.m42 = (a.m41 * b.m12) +
                               (a.m42 * b.m22) +
                               (a.m43 * b.m32) +
                               (a.m44 * b.m42);
            a_clone.m43 = (a.m41 * b.m13) +
                               (a.m42 * b.m23) +
                               (a.m43 * b.m33) +
                               (a.m44 * b.m43);
            a_clone.m44 = (a.m41 * b.m14) +
                               (a.m42 * b.m24) +
                               (a.m43 * b.m34) +
                               (a.m44 * b.m44);
    a_clone
}

impl Matrix3D {
    fn is_3d(&self) -> bool {
        self.m13 != 0.0 || self.m14 != 0.0 ||
        self.m23 != 0.0 || self.m24 != 0.0 ||
        self.m31 != 0.0 || self.m32 != 0.0 || self.m33 != 1.0 || self.m34 != 0.0 ||
        self.m43 != 0.0 || self.m44 != 1.0
    }

    fn determinant(&self) -> CSSFloat {
        self.m14 * self.m23 * self.m32 * self.m41 -
        self.m13 * self.m24 * self.m32 * self.m41 -
        self.m14 * self.m22 * self.m33 * self.m41 +
        self.m12 * self.m24 * self.m33 * self.m41 +
        self.m13 * self.m22 * self.m34 * self.m41 -
        self.m12 * self.m23 * self.m34 * self.m41 -
        self.m14 * self.m23 * self.m31 * self.m42 +
        self.m13 * self.m24 * self.m31 * self.m42 +
        self.m14 * self.m21 * self.m33 * self.m42 -
        self.m11 * self.m24 * self.m33 * self.m42 -
        self.m13 * self.m21 * self.m34 * self.m42 +
        self.m11 * self.m23 * self.m34 * self.m42 +
        self.m14 * self.m22 * self.m31 * self.m43 -
        self.m12 * self.m24 * self.m31 * self.m43 -
        self.m14 * self.m21 * self.m32 * self.m43 +
        self.m11 * self.m24 * self.m32 * self.m43 +
        self.m12 * self.m21 * self.m34 * self.m43 -
        self.m11 * self.m22 * self.m34 * self.m43 -
        self.m13 * self.m22 * self.m31 * self.m44 +
        self.m12 * self.m23 * self.m31 * self.m44 +
        self.m13 * self.m21 * self.m32 * self.m44 -
        self.m11 * self.m23 * self.m32 * self.m44 -
        self.m12 * self.m21 * self.m33 * self.m44 +
        self.m11 * self.m22 * self.m33 * self.m44
    }

    fn inverse(&self) -> Option<Matrix3D> {
        let mut det = self.determinant();

        if det == 0.0 {
            return None;
        }

        det = 1.0 / det;
        let x = Matrix3D {
            m11: det *
            (self.m23*self.m34*self.m42 - self.m24*self.m33*self.m42 +
             self.m24*self.m32*self.m43 - self.m22*self.m34*self.m43 -
             self.m23*self.m32*self.m44 + self.m22*self.m33*self.m44),
            m12: det *
            (self.m14*self.m33*self.m42 - self.m13*self.m34*self.m42 -
             self.m14*self.m32*self.m43 + self.m12*self.m34*self.m43 +
             self.m13*self.m32*self.m44 - self.m12*self.m33*self.m44),
            m13: det *
            (self.m13*self.m24*self.m42 - self.m14*self.m23*self.m42 +
             self.m14*self.m22*self.m43 - self.m12*self.m24*self.m43 -
             self.m13*self.m22*self.m44 + self.m12*self.m23*self.m44),
            m14: det *
            (self.m14*self.m23*self.m32 - self.m13*self.m24*self.m32 -
             self.m14*self.m22*self.m33 + self.m12*self.m24*self.m33 +
             self.m13*self.m22*self.m34 - self.m12*self.m23*self.m34),
            m21: det *
            (self.m24*self.m33*self.m41 - self.m23*self.m34*self.m41 -
             self.m24*self.m31*self.m43 + self.m21*self.m34*self.m43 +
             self.m23*self.m31*self.m44 - self.m21*self.m33*self.m44),
            m22: det *
            (self.m13*self.m34*self.m41 - self.m14*self.m33*self.m41 +
             self.m14*self.m31*self.m43 - self.m11*self.m34*self.m43 -
             self.m13*self.m31*self.m44 + self.m11*self.m33*self.m44),
            m23: det *
            (self.m14*self.m23*self.m41 - self.m13*self.m24*self.m41 -
             self.m14*self.m21*self.m43 + self.m11*self.m24*self.m43 +
             self.m13*self.m21*self.m44 - self.m11*self.m23*self.m44),
            m24: det *
            (self.m13*self.m24*self.m31 - self.m14*self.m23*self.m31 +
             self.m14*self.m21*self.m33 - self.m11*self.m24*self.m33 -
             self.m13*self.m21*self.m34 + self.m11*self.m23*self.m34),
            m31: det *
            (self.m22*self.m34*self.m41 - self.m24*self.m32*self.m41 +
             self.m24*self.m31*self.m42 - self.m21*self.m34*self.m42 -
             self.m22*self.m31*self.m44 + self.m21*self.m32*self.m44),
            m32: det *
            (self.m14*self.m32*self.m41 - self.m12*self.m34*self.m41 -
             self.m14*self.m31*self.m42 + self.m11*self.m34*self.m42 +
             self.m12*self.m31*self.m44 - self.m11*self.m32*self.m44),
            m33: det *
            (self.m12*self.m24*self.m41 - self.m14*self.m22*self.m41 +
             self.m14*self.m21*self.m42 - self.m11*self.m24*self.m42 -
             self.m12*self.m21*self.m44 + self.m11*self.m22*self.m44),
            m34: det *
            (self.m14*self.m22*self.m31 - self.m12*self.m24*self.m31 -
             self.m14*self.m21*self.m32 + self.m11*self.m24*self.m32 +
             self.m12*self.m21*self.m34 - self.m11*self.m22*self.m34),
            m41: det *
            (self.m23*self.m32*self.m41 - self.m22*self.m33*self.m41 -
             self.m23*self.m31*self.m42 + self.m21*self.m33*self.m42 +
             self.m22*self.m31*self.m43 - self.m21*self.m32*self.m43),
            m42: det *
            (self.m12*self.m33*self.m41 - self.m13*self.m32*self.m41 +
             self.m13*self.m31*self.m42 - self.m11*self.m33*self.m42 -
             self.m12*self.m31*self.m43 + self.m11*self.m32*self.m43),
            m43: det *
            (self.m13*self.m22*self.m41 - self.m12*self.m23*self.m41 -
             self.m13*self.m21*self.m42 + self.m11*self.m23*self.m42 +
             self.m12*self.m21*self.m43 - self.m11*self.m22*self.m43),
            m44: det *
            (self.m12*self.m23*self.m31 - self.m13*self.m22*self.m31 +
             self.m13*self.m21*self.m32 - self.m11*self.m23*self.m32 -
             self.m12*self.m21*self.m33 + self.m11*self.m22*self.m33),
        };

        Some(x)
    }
}

/// <https://drafts.csswg.org/css-transforms-2/#propdef-rotate>
impl ComputedRotate {
    fn fill_unspecified(rotate: &ComputedRotate) -> Result<(Number, Number, Number, Angle), ()> {
        // According to the spec:
        // https://drafts.csswg.org/css-transforms-2/#individual-transforms
        //
        // If the axis is unspecified, it defaults to "0 0 1"
        match *rotate {
            Rotate::None =>
                Ok((0., 0., 1., Angle::zero())),
            Rotate::Rotate3D(rx, ry, rz, angle) => Ok((rx, ry, rz, angle)),
            Rotate::Rotate(angle) => Ok((0., 0., 1., angle)),
        }
    }
}

impl Animate for ComputedRotate {
    #[inline]
    fn animate(
        &self,
        other: &Self,
        procedure: Procedure,
    ) -> Result<Self, ()> {
        let from = ComputedRotate::fill_unspecified(self)?;
        let to = ComputedRotate::fill_unspecified(other)?;

        let (fx, fy, fz, fa) = transform::get_normalized_vector_and_angle(from.0, from.1, from.2, from.3);
        let (tx, ty, tz, ta) = transform::get_normalized_vector_and_angle(to.0, to.1, to.2, to.3);
        if (fx, fy, fz) == (tx, ty, tz) {
            return Ok(Rotate::Rotate3D(fx, fy, fz, fa.animate(&ta, procedure)?));
        }

        let fv = DirectionVector::new(fx, fy, fz);
        let tv = DirectionVector::new(tx, ty, tz);
        let fq = Quaternion::from_direction_and_angle(&fv, fa.radians64());
        let tq = Quaternion::from_direction_and_angle(&tv, ta.radians64());

        let rq = Quaternion::animate(&fq, &tq, procedure)?;
        let (x, y, z, angle) =
            transform::get_normalized_vector_and_angle(rq.0 as f32,
                                                       rq.1 as f32,
                                                       rq.2 as f32,
                                                       rq.3.acos() as f32 *2.0);

        Ok(Rotate::Rotate3D(x, y, z, Angle::from_radians(angle)))
    }
}

/// <https://drafts.csswg.org/css-transforms-2/#propdef-translate>
impl ComputedTranslate {
    fn fill_unspecified(translate: &ComputedTranslate)
        -> Result<(LengthOrPercentage, LengthOrPercentage, Length), ()> {
        // According to the spec:
        // https://drafts.csswg.org/css-transforms-2/#individual-transforms
        //
        // Unspecified translations default to 0px
        match *translate {
            Translate::None => {
                Ok((LengthOrPercentage::Length(Length::zero()),
                    LengthOrPercentage::Length(Length::zero()),
                    Length::zero()))
            },
            Translate::Translate3D(tx, ty, tz) => Ok((tx, ty, tz)),
            Translate::Translate(tx, ty) => Ok((tx, ty, Length::zero())),
            Translate::TranslateX(tx) => Ok((tx, LengthOrPercentage::Length(Length::zero()), Length::zero())),
        }
    }
}

impl Animate for ComputedTranslate {
    #[inline]
    fn animate(
        &self,
        other: &Self,
        procedure: Procedure,
    ) -> Result<Self, ()> {
        let from = ComputedTranslate::fill_unspecified(self)?;
        let to = ComputedTranslate::fill_unspecified(other)?;

        Ok(Translate::Translate3D(from.0.animate(&to.0, procedure)?,
                                  from.1.animate(&to.1, procedure)?,
                                  from.2.animate(&to.2, procedure)?))
    }
}

/// <https://drafts.csswg.org/css-transforms-2/#propdef-scale>
impl ComputedScale {
    fn fill_unspecified(scale: &ComputedScale)
        -> Result<(Number, Number, Number), ()> {
        // According to the spec:
        // https://drafts.csswg.org/css-transforms-2/#individual-transforms
        //
        // Unspecified scales default to 1
        match *scale {
            Scale::None => Ok((1.0, 1.0, 1.0)),
            Scale::Scale3D(sx, sy, sz) => Ok((sx, sy, sz)),
            Scale::Scale(sx, sy) => Ok((sx, sy, 1.)),
            Scale::ScaleX(sx) => Ok((sx, 1., 1.)),
        }
    }
}

impl Animate for ComputedScale {
    #[inline]
    fn animate(
        &self,
        other: &Self,
        procedure: Procedure,
    ) -> Result<Self, ()> {
        let from = ComputedScale::fill_unspecified(self)?;
        let to = ComputedScale::fill_unspecified(other)?;

        if procedure == Procedure::Add {
            // scale(x1,y1,z1)*scale(x2,y2,z2) = scale(x1*x2, y1*y2, z1*z2)
            return Ok(Scale::Scale3D(from.0 * to.0, from.1 * to.1, from.2 * to.2));
        }

        Ok(Scale::Scale3D(animate_multiplicative_factor(from.0, to.0, procedure)?,
                          animate_multiplicative_factor(from.1, to.1, procedure)?,
                          animate_multiplicative_factor(from.2, to.2, procedure)?))
    }
}

/// <https://drafts.csswg.org/css-transforms/#interpolation-of-transforms>
impl Animate for ComputedTransform {
    #[inline]
    fn animate(
        &self,
        other_: &Self,
        procedure: Procedure,
    ) -> Result<Self, ()> {

        let animate_equal_lists = |this: &[ComputedTransformOperation],
                                   other: &[ComputedTransformOperation]|
                                   -> Result<ComputedTransform, ()> {
            Ok(Transform(this.iter().zip(other)
                             .map(|(this, other)| this.animate(other, procedure))
                             .collect::<Result<Vec<_>, _>>()?))
            // If we can't animate for a pair of matched transform lists
            // this means we have at least one undecomposable matrix,
            // so we should bubble out Err here, and let the caller do
            // the fallback procedure.
        };
        if self.0.is_empty() && other_.0.is_empty() {
            return Ok(Transform(vec![]));
        }


        let this = &self.0;
        let other = &other_.0;

        if procedure == Procedure::Add {
            let result = this.iter().chain(other).cloned().collect::<Vec<_>>();
            return Ok(Transform(result));
        }


        // For matched transform lists.
        {
            if this.len() == other.len() {
                let is_matched_transforms = this.iter().zip(other).all(|(this, other)| {
                    is_matched_operation(this, other)
                });

                if is_matched_transforms {
                    return animate_equal_lists(this, other);
                }
            }
        }

        // For mismatched transform lists.
        let mut owned_this = this.clone();
        let mut owned_other = other.clone();

        if this.is_empty() {
            let this = other_.to_animated_zero()?.0;
            if this.iter().zip(other).all(|(this, other)| is_matched_operation(this, other)) {
                return animate_equal_lists(&this, other)
            }
            owned_this = this;
        }
        if other.is_empty() {
            let other = self.to_animated_zero()?.0;
            if this.iter().zip(&other).all(|(this, other)| is_matched_operation(this, other)) {
                return animate_equal_lists(this, &other)
            }
            owned_other = other;
        }

        match procedure {
            Procedure::Add => Err(()),
            Procedure::Interpolate { progress } => {
                Ok(Transform(vec![TransformOperation::InterpolateMatrix {
                    from_list: Transform(owned_this),
                    to_list: Transform(owned_other),
                    progress: Percentage(progress as f32),
                }]))
            },
            Procedure::Accumulate { count } => {
                Ok(Transform(vec![TransformOperation::AccumulateMatrix {
                    from_list: Transform(owned_this),
                    to_list: Transform(owned_other),
                    count: cmp::min(count, i32::max_value() as u64) as i32,
                }]))
            },
        }
    }
}

// This might not be the most useful definition of distance. It might be better, for example,
// to trace the distance travelled by a point as its transform is interpolated between the two
// lists. That, however, proves to be quite complicated so we take a simple approach for now.
// See https://bugzilla.mozilla.org/show_bug.cgi?id=1318591#c0.
impl ComputeSquaredDistance for ComputedTransformOperation {
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        // For translate, We don't want to require doing layout in order to calculate the result, so
        // drop the percentage part. However, dropping percentage makes us impossible to
        // compute the distance for the percentage-percentage case, but Gecko uses the
        // same formula, so it's fine for now.
        // Note: We use pixel value to compute the distance for translate, so we have to
        // convert Au into px.
        let extract_pixel_length = |lop: &LengthOrPercentage| {
            match *lop {
                LengthOrPercentage::Length(px) => px.px(),
                LengthOrPercentage::Percentage(_) => 0.,
                LengthOrPercentage::Calc(calc) => calc.length().px(),
            }
        };
        match (self, other) {
            (
                &TransformOperation::Matrix3D(ref this),
                &TransformOperation::Matrix3D(ref other),
            ) => {
                this.compute_squared_distance(other)
            },
            (
                &TransformOperation::Matrix(ref this),
                &TransformOperation::Matrix(ref other),
            ) => {
                let this: Matrix3D = (*this).into();
                let other: Matrix3D = (*other).into();
                this.compute_squared_distance(&other)
            },


            (
                &TransformOperation::Skew(ref fx, ref fy),
                &TransformOperation::Skew(ref tx, ref ty),
            ) => {
                Ok(
                    fx.compute_squared_distance(&tx)? +
                    fy.compute_squared_distance(&ty)?,
                )
            },
            (
                &TransformOperation::SkewX(ref f),
                &TransformOperation::SkewX(ref t),
            ) | (
                &TransformOperation::SkewY(ref f),
                &TransformOperation::SkewY(ref t),
            ) => {
                f.compute_squared_distance(&t)
            },
            (
                &TransformOperation::Translate3D(ref fx, ref fy, ref fz),
                &TransformOperation::Translate3D(ref tx, ref ty, ref tz),
            ) => {
                let fx = extract_pixel_length(&fx);
                let fy = extract_pixel_length(&fy);
                let tx = extract_pixel_length(&tx);
                let ty = extract_pixel_length(&ty);

                Ok(
                    fx.compute_squared_distance(&tx)? +
                    fy.compute_squared_distance(&ty)? +
                    fz.compute_squared_distance(&tz)?,
                )
            },
            (
                &TransformOperation::Scale3D(ref fx, ref fy, ref fz),
                &TransformOperation::Scale3D(ref tx, ref ty, ref tz),
            ) => {
                Ok(
                    fx.compute_squared_distance(&tx)? +
                    fy.compute_squared_distance(&ty)? +
                    fz.compute_squared_distance(&tz)?,
                )
            },
            (
                &TransformOperation::Rotate3D(fx, fy, fz, fa),
                &TransformOperation::Rotate3D(tx, ty, tz, ta),
            ) => {
                let (fx, fy, fz, angle1) =
                    transform::get_normalized_vector_and_angle(fx, fy, fz, fa);
                let (tx, ty, tz, angle2) =
                    transform::get_normalized_vector_and_angle(tx, ty, tz, ta);
                if (fx, fy, fz) == (tx, ty, tz) {
                    angle1.compute_squared_distance(&angle2)
                } else {
                    let v1 = DirectionVector::new(fx, fy, fz);
                    let v2 = DirectionVector::new(tx, ty, tz);
                    let q1 = Quaternion::from_direction_and_angle(&v1, angle1.radians64());
                    let q2 = Quaternion::from_direction_and_angle(&v2, angle2.radians64());
                    q1.compute_squared_distance(&q2)
                }
            }
            (
                &TransformOperation::RotateX(fa),
                &TransformOperation::RotateX(ta),
            ) |
            (
                &TransformOperation::RotateY(fa),
                &TransformOperation::RotateY(ta),
            ) |
            (
                &TransformOperation::RotateZ(fa),
                &TransformOperation::RotateZ(ta),
            ) |
            (
                &TransformOperation::Rotate(fa),
                &TransformOperation::Rotate(ta),
            ) => {
                fa.compute_squared_distance(&ta)
            }
            (
                &TransformOperation::Perspective(ref fd),
                &TransformOperation::Perspective(ref td),
            ) => {
                let mut fd_matrix = Matrix3D::identity();
                let mut td_matrix = Matrix3D::identity();
                if fd.px() > 0. {
                    fd_matrix.m34 = -1. / fd.px();
                }

                if td.px() > 0. {
                    td_matrix.m34 = -1. / td.px();
                }
                fd_matrix.compute_squared_distance(&td_matrix)
            }
            (
                &TransformOperation::Perspective(ref p),
                &TransformOperation::Matrix3D(ref m),
            ) | (
                &TransformOperation::Matrix3D(ref m),
                &TransformOperation::Perspective(ref p),
            ) => {
                let mut p_matrix = Matrix3D::identity();
                if p.px() > 0. {
                    p_matrix.m34 = -1. / p.px();
                }
                p_matrix.compute_squared_distance(&m)
            }
            // Gecko cross-interpolates amongst all translate and all scale
            // functions (See ToPrimitive in layout/style/StyleAnimationValue.cpp)
            // without falling back to InterpolateMatrix
            _ if self.is_translate() && other.is_translate() => {
                self.to_translate_3d().compute_squared_distance(&other.to_translate_3d())
            }
            _ if self.is_scale() && other.is_scale() => {
                self.to_scale_3d().compute_squared_distance(&other.to_scale_3d())
            }
            _ => Err(()),
        }
    }
}

impl ComputeSquaredDistance for ComputedTransform {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        let list1 = &self.0;
        let list2 = &other.0;

        let squared_dist: Result<SquaredDistance, _> = list1.iter().zip_longest(list2).map(|it| {
            match it {
                EitherOrBoth::Both(this, other) => {
                    this.compute_squared_distance(other)
                },
                EitherOrBoth::Left(list) | EitherOrBoth::Right(list) => {
                    list.to_animated_zero()?.compute_squared_distance(list)
                },
            }
        }).sum();

        // Roll back to matrix interpolation if there is any Err(()) in the transform lists, such
        // as mismatched transform functions.
        if let Err(_) = squared_dist {
            let matrix1: Matrix3D = self.to_transform_3d_matrix(None)?.0.into();
            let matrix2: Matrix3D = other.to_transform_3d_matrix(None)?.0.into();
            return matrix1.compute_squared_distance(&matrix2);
        }
        squared_dist
    }
}

/// Animated SVGPaint
pub type IntermediateSVGPaint = SVGPaint<AnimatedRGBA, ComputedUrl>;

/// Animated SVGPaintKind
pub type IntermediateSVGPaintKind = SVGPaintKind<AnimatedRGBA, ComputedUrl>;

impl ToAnimatedZero for IntermediateSVGPaint {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        Ok(IntermediateSVGPaint {
            kind: self.kind.to_animated_zero()?,
            fallback: self.fallback.and_then(|v| v.to_animated_zero().ok()),
        })
    }
}

impl From<NonNegativeLengthOrPercentage> for NumberOrPercentage {
    fn from(lop: NonNegativeLengthOrPercentage) -> NumberOrPercentage {
        lop.0.into()
    }
}

impl From<NonNegativeNumber> for NumberOrPercentage {
    fn from(num: NonNegativeNumber) -> NumberOrPercentage {
        num.0.into()
    }
}

impl From<LengthOrPercentage> for NumberOrPercentage {
    fn from(lop: LengthOrPercentage) -> NumberOrPercentage {
        match lop {
            LengthOrPercentage::Length(len) => NumberOrPercentage::Number(len.px()),
            LengthOrPercentage::Percentage(p) => NumberOrPercentage::Percentage(p),
            LengthOrPercentage::Calc(_) => {
                panic!("We dont't expected calc interpolation for SvgLengthOrPercentageOrNumber");
            },
        }
    }
}

impl From<Number> for NumberOrPercentage {
    fn from(num: Number) -> NumberOrPercentage {
        NumberOrPercentage::Number(num)
    }
}

fn convert_to_number_or_percentage<LengthOrPercentageType, NumberType>(
    from: SvgLengthOrPercentageOrNumber<LengthOrPercentageType, NumberType>)
    -> NumberOrPercentage
    where LengthOrPercentageType: Into<NumberOrPercentage>,
          NumberType: Into<NumberOrPercentage>
{
    match from {
        SvgLengthOrPercentageOrNumber::LengthOrPercentage(lop) => {
            lop.into()
        }
        SvgLengthOrPercentageOrNumber::Number(num) => {
            num.into()
        }
    }
}

fn convert_from_number_or_percentage<LengthOrPercentageType, NumberType>(
    from: NumberOrPercentage)
    -> SvgLengthOrPercentageOrNumber<LengthOrPercentageType, NumberType>
    where LengthOrPercentageType: From<LengthOrPercentage>,
          NumberType: From<Number>
{
    match from {
        NumberOrPercentage::Number(num) =>
            SvgLengthOrPercentageOrNumber::Number(num.into()),
        NumberOrPercentage::Percentage(p) =>
            SvgLengthOrPercentageOrNumber::LengthOrPercentage(
                (LengthOrPercentage::Percentage(p)).into())
    }
}

impl <L, N> Animate for SvgLengthOrPercentageOrNumber<L, N>
where
    L: Animate + From<LengthOrPercentage> + Into<NumberOrPercentage> + Copy,
    N: Animate + From<Number> + Into<NumberOrPercentage>,
    LengthOrPercentage: From<L>,
    Self: Copy,
{
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        if self.has_calc() || other.has_calc() {
            // TODO: We need to treat calc value.
            // https://bugzilla.mozilla.org/show_bug.cgi?id=1386967
            return Err(());
        }

        let this = convert_to_number_or_percentage(*self);
        let other = convert_to_number_or_percentage(*other);

        match (this, other) {
            (
                NumberOrPercentage::Number(ref this),
                NumberOrPercentage::Number(ref other),
            ) => {
                Ok(convert_from_number_or_percentage(
                    NumberOrPercentage::Number(this.animate(other, procedure)?)
                ))
            },
            (
                NumberOrPercentage::Percentage(ref this),
                NumberOrPercentage::Percentage(ref other),
            ) => {
                Ok(convert_from_number_or_percentage(
                    NumberOrPercentage::Percentage(this.animate(other, procedure)?)
                ))
            },
            _ => Err(()),
        }
    }
}

impl<L> Animate for SVGLength<L>
where
    L: Animate + Clone,
{
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        match (self, other) {
            (&SVGLength::Length(ref this), &SVGLength::Length(ref other)) => {
                Ok(SVGLength::Length(this.animate(other, procedure)?))
            },
            _ => Err(()),
        }
    }
}

/// <https://www.w3.org/TR/SVG11/painting.html#StrokeDasharrayProperty>
impl<L> Animate for SVGStrokeDashArray<L>
where
    L: Clone + RepeatableListAnimatable,
{
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        if matches!(procedure, Procedure::Add | Procedure::Accumulate { .. }) {
            // Non-additive.
            return Err(());
        }
        match (self, other) {
            (&SVGStrokeDashArray::Values(ref this), &SVGStrokeDashArray::Values(ref other)) => {
                Ok(SVGStrokeDashArray::Values(this.animate(other, procedure)?))
            },
            _ => Err(()),
        }
    }
}

impl<L> ToAnimatedZero for SVGStrokeDashArray<L>
where
    L: ToAnimatedZero,
{
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        match *self {
            SVGStrokeDashArray::Values(ref values) => {
                Ok(SVGStrokeDashArray::Values(
                    values.iter().map(ToAnimatedZero::to_animated_zero).collect::<Result<Vec<_>, _>>()?,
                ))
            }
            SVGStrokeDashArray::ContextValue => Ok(SVGStrokeDashArray::ContextValue),
        }
    }
}

impl<O> Animate for SVGOpacity<O>
where
    O: Animate + Clone,
{
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        match (self, other) {
            (&SVGOpacity::Opacity(ref this), &SVGOpacity::Opacity(ref other)) => {
                Ok(SVGOpacity::Opacity(this.animate(other, procedure)?))
            },
            _ => Err(()),
        }
    }
}



/// <https://drafts.fxtf.org/filters/#animation-of-filters>
impl Animate for AnimatedFilter {
    fn animate(
        &self,
        other: &Self,
        procedure: Procedure,
    ) -> Result<Self, ()> {
        match (self, other) {
            (&Filter::Blur(ref this), &Filter::Blur(ref other)) => {
                Ok(Filter::Blur(this.animate(other, procedure)?))
            },
            (&Filter::Grayscale(ref this), &Filter::Grayscale(ref other)) => {
                Ok(Filter::Grayscale(this.animate(other, procedure)?))
            },
            (&Filter::HueRotate(ref this), &Filter::HueRotate(ref other)) => {
                Ok(Filter::HueRotate(this.animate(other, procedure)?))
            },
            (&Filter::Invert(ref this), &Filter::Invert(ref other)) => {
                Ok(Filter::Invert(this.animate(other, procedure)?))
            },
            (&Filter::Sepia(ref this), &Filter::Sepia(ref other)) => {
                Ok(Filter::Sepia(this.animate(other, procedure)?))
            },
            (&Filter::Brightness(this), &Filter::Brightness(other)) => {
                Ok(Filter::Brightness(animate_multiplicative_factor(this, other, procedure)?))
            },
            (&Filter::Contrast(this), &Filter::Contrast(other)) => {
                Ok(Filter::Contrast(animate_multiplicative_factor(this, other, procedure)?))
            },
            (&Filter::Opacity(this), &Filter::Opacity(other)) => {
                Ok(Filter::Opacity(animate_multiplicative_factor(this, other, procedure)?))
            },
            (&Filter::Saturate(this), &Filter::Saturate(other)) => {
                Ok(Filter::Saturate(animate_multiplicative_factor(this, other, procedure)?))
            },
            (&Filter::DropShadow(ref this), &Filter::DropShadow(ref other)) => {
                Ok(Filter::DropShadow(this.animate(other, procedure)?))
            },
            _ => Err(()),
        }
    }
}

/// <http://dev.w3.org/csswg/css-transforms/#none-transform-animation>
impl ToAnimatedZero for AnimatedFilter {
    fn to_animated_zero(&self) -> Result<Self, ()> {
        match *self {
            Filter::Blur(ref this) => Ok(Filter::Blur(this.to_animated_zero()?)),
            Filter::Grayscale(ref this) => Ok(Filter::Grayscale(this.to_animated_zero()?)),
            Filter::HueRotate(ref this) => Ok(Filter::HueRotate(this.to_animated_zero()?)),
            Filter::Invert(ref this) => Ok(Filter::Invert(this.to_animated_zero()?)),
            Filter::Sepia(ref this) => Ok(Filter::Sepia(this.to_animated_zero()?)),
            Filter::Brightness(_) => Ok(Filter::Brightness(1.)),
            Filter::Contrast(_) => Ok(Filter::Contrast(1.)),
            Filter::Opacity(_) => Ok(Filter::Opacity(1.)),
            Filter::Saturate(_) => Ok(Filter::Saturate(1.)),
            Filter::DropShadow(ref this) => Ok(Filter::DropShadow(this.to_animated_zero()?)),
            _ => Err(()),
        }
    }
}

impl Animate for AnimatedFilterList {
    #[inline]
    fn animate(
        &self,
        other: &Self,
        procedure: Procedure,
    ) -> Result<Self, ()> {
        if procedure == Procedure::Add {
            return Ok(AnimatedFilterList(
                self.0.iter().chain(other.0.iter()).cloned().collect(),
            ));
        }
        Ok(AnimatedFilterList(self.0.iter().zip_longest(other.0.iter()).map(|it| {
            match it {
                EitherOrBoth::Both(this, other) => {
                    this.animate(other, procedure)
                },
                EitherOrBoth::Left(this) => {
                    this.animate(&this.to_animated_zero()?, procedure)
                },
                EitherOrBoth::Right(other) => {
                    other.to_animated_zero()?.animate(other, procedure)
                },
            }
        }).collect::<Result<Vec<_>, _>>()?))
    }
}

impl ComputeSquaredDistance for AnimatedFilterList {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        self.0.iter().zip_longest(other.0.iter()).map(|it| {
            match it {
                EitherOrBoth::Both(this, other) => {
                    this.compute_squared_distance(other)
                },
                EitherOrBoth::Left(list) | EitherOrBoth::Right(list) => {
                    list.to_animated_zero()?.compute_squared_distance(list)
                },
            }
        }).sum()
    }
}

/// A comparator to sort PropertyIds such that longhands are sorted before shorthands,
/// shorthands with fewer components are sorted before shorthands with more components,
/// and otherwise shorthands are sorted by IDL name as defined by [Web Animations][property-order].
///
/// Using this allows us to prioritize values specified by longhands (or smaller
/// shorthand subsets) when longhands and shorthands are both specified on the one keyframe.
///
/// Example orderings that result from this:
///
///   margin-left, margin
///
/// and:
///
///   border-top-color, border-color, border-top, border
///
/// [property-order] https://drafts.csswg.org/web-animations/#calculating-computed-keyframes
pub fn compare_property_priority(a: &PropertyId, b: &PropertyId) -> cmp::Ordering {
    match (a.as_shorthand(), b.as_shorthand()) {
        // Within shorthands, sort by the number of subproperties, then by IDL name.
        (Ok(a), Ok(b)) => {
            let subprop_count_a = a.longhands().count();
            let subprop_count_b = b.longhands().count();
            subprop_count_a
                .cmp(&subprop_count_b)
                .then_with(|| {
                    get_idl_name_sort_order(a).cmp(&get_idl_name_sort_order(b))
                })
        },

        // Longhands go before shorthands.
        (Ok(_), Err(_)) => cmp::Ordering::Greater,
        (Err(_), Ok(_)) => cmp::Ordering::Less,

        // Both are longhands or custom properties in which case they don't overlap and should
        // sort equally.
        _ => cmp::Ordering::Equal,
    }
}

fn get_idl_name_sort_order(shorthand: ShorthandId) -> u32 {

    match shorthand {
            ShorthandId::MozOutlineRadius => 0,
            ShorthandId::WebkitTextStroke => 1,
            ShorthandId::All => 2,
            ShorthandId::Animation => 3,
            ShorthandId::Background => 4,
            ShorthandId::BackgroundPosition => 5,
            ShorthandId::Border => 6,
            ShorthandId::BorderBlockEnd => 7,
            ShorthandId::BorderBlockStart => 8,
            ShorthandId::BorderBottom => 9,
            ShorthandId::BorderColor => 10,
            ShorthandId::BorderImage => 11,
            ShorthandId::BorderInlineEnd => 12,
            ShorthandId::BorderInlineStart => 13,
            ShorthandId::BorderLeft => 14,
            ShorthandId::BorderRadius => 15,
            ShorthandId::BorderRight => 16,
            ShorthandId::BorderStyle => 17,
            ShorthandId::BorderTop => 18,
            ShorthandId::BorderWidth => 19,
            ShorthandId::ColumnRule => 20,
            ShorthandId::Columns => 21,
            ShorthandId::Flex => 22,
            ShorthandId::FlexFlow => 23,
            ShorthandId::Font => 24,
            ShorthandId::FontVariant => 25,
            ShorthandId::Grid => 26,
            ShorthandId::GridArea => 27,
            ShorthandId::GridColumn => 28,
            ShorthandId::GridGap => 29,
            ShorthandId::GridRow => 30,
            ShorthandId::GridTemplate => 31,
            ShorthandId::ListStyle => 32,
            ShorthandId::Margin => 33,
            ShorthandId::Marker => 34,
            ShorthandId::Mask => 35,
            ShorthandId::MaskPosition => 36,
            ShorthandId::Outline => 37,
            ShorthandId::Overflow => 38,
            ShorthandId::OverflowClipBox => 39,
            ShorthandId::OverscrollBehavior => 40,
            ShorthandId::Padding => 41,
            ShorthandId::PlaceContent => 42,
            ShorthandId::PlaceItems => 43,
            ShorthandId::PlaceSelf => 44,
            ShorthandId::ScrollSnapType => 45,
            ShorthandId::TextDecoration => 46,
            ShorthandId::TextEmphasis => 47,
            ShorthandId::Transition => 48,
    }
}

}

/// A longhand or shorthand property.
#[derive(Clone, Copy, Debug)]
pub struct NonCustomPropertyId(usize);

impl NonCustomPropertyId {
    #[cfg(feature = "gecko")]
    fn to_nscsspropertyid(self) -> nsCSSPropertyID {
        static MAP: [nsCSSPropertyID; 485] = [
                
    nsCSSPropertyID::eCSSProperty_align_content,
                
    nsCSSPropertyID::eCSSProperty_align_items,
                
    nsCSSPropertyID::eCSSProperty_align_self,
                
    nsCSSPropertyID::eCSSProperty_backface_visibility,
                
    nsCSSPropertyID::eCSSProperty_border_collapse,
                
    nsCSSPropertyID::eCSSProperty_border_image_repeat,
                
    nsCSSPropertyID::eCSSProperty_box_decoration_break,
                
    nsCSSPropertyID::eCSSProperty_box_sizing,
                
    nsCSSPropertyID::eCSSProperty_caption_side,
                
    nsCSSPropertyID::eCSSProperty_clear,
                
    nsCSSPropertyID::eCSSProperty_clip_rule,
                
    nsCSSPropertyID::eCSSProperty_color_adjust,
                
    nsCSSPropertyID::eCSSProperty_color_interpolation,
                
    nsCSSPropertyID::eCSSProperty_color_interpolation_filters,
                
    nsCSSPropertyID::eCSSProperty_column_count,
                
    nsCSSPropertyID::eCSSProperty_column_fill,
                
    nsCSSPropertyID::eCSSProperty_column_rule_style,
                
    nsCSSPropertyID::eCSSProperty_column_span,
                
    nsCSSPropertyID::eCSSProperty_contain,
                
    nsCSSPropertyID::eCSSProperty_direction,
                
    nsCSSPropertyID::eCSSProperty_dominant_baseline,
                
    nsCSSPropertyID::eCSSProperty_empty_cells,
                
    nsCSSPropertyID::eCSSProperty_fill_rule,
                
    nsCSSPropertyID::eCSSProperty_flex_direction,
                
    nsCSSPropertyID::eCSSProperty_flex_wrap,
                
    nsCSSPropertyID::eCSSProperty_float_,
                
    nsCSSPropertyID::eCSSProperty_font_kerning,
                
    nsCSSPropertyID::eCSSProperty_font_optical_sizing,
                
    nsCSSPropertyID::eCSSProperty_font_stretch,
                
    nsCSSPropertyID::eCSSProperty_font_style,
                
    nsCSSPropertyID::eCSSProperty_font_synthesis,
                
    nsCSSPropertyID::eCSSProperty_font_variant_caps,
                
    nsCSSPropertyID::eCSSProperty_font_variant_position,
                
    nsCSSPropertyID::eCSSProperty_font_weight,
                
    nsCSSPropertyID::eCSSProperty_grid_auto_flow,
                
    nsCSSPropertyID::eCSSProperty_hyphens,
                
    nsCSSPropertyID::eCSSProperty_image_orientation,
                
    nsCSSPropertyID::eCSSProperty_image_rendering,
                
    nsCSSPropertyID::eCSSProperty_ime_mode,
                
    nsCSSPropertyID::eCSSProperty_initial_letter,
                
    nsCSSPropertyID::eCSSProperty_isolation,
                
    nsCSSPropertyID::eCSSProperty_justify_content,
                
    nsCSSPropertyID::eCSSProperty_justify_items,
                
    nsCSSPropertyID::eCSSProperty_justify_self,
                
    nsCSSPropertyID::eCSSProperty_list_style_position,
                
    nsCSSPropertyID::eCSSProperty_mask_type,
                
    nsCSSPropertyID::eCSSProperty_mix_blend_mode,
                
    nsCSSPropertyID::eCSSProperty__moz_appearance,
                
    nsCSSPropertyID::eCSSProperty__moz_box_align,
                
    nsCSSPropertyID::eCSSProperty__moz_box_direction,
                
    nsCSSPropertyID::eCSSProperty__moz_box_orient,
                
    nsCSSPropertyID::eCSSProperty__moz_box_pack,
                
    nsCSSPropertyID::eCSSProperty__moz_control_character_visibility,
                
    nsCSSPropertyID::eCSSProperty__moz_float_edge,
                
    nsCSSPropertyID::eCSSProperty__moz_force_broken_image_icon,
                
    nsCSSPropertyID::eCSSProperty__moz_math_display,
                
    nsCSSPropertyID::eCSSProperty__moz_math_variant,
                
    nsCSSPropertyID::eCSSProperty__moz_min_font_size_ratio,
                
    nsCSSPropertyID::eCSSProperty__moz_orient,
                
    nsCSSPropertyID::eCSSProperty__moz_osx_font_smoothing,
                
    nsCSSPropertyID::eCSSProperty__moz_script_level,
                
    nsCSSPropertyID::eCSSProperty__moz_script_min_size,
                
    nsCSSPropertyID::eCSSProperty__moz_script_size_multiplier,
                
    nsCSSPropertyID::eCSSProperty__moz_stack_sizing,
                
    nsCSSPropertyID::eCSSProperty__moz_text_size_adjust,
                
    nsCSSPropertyID::eCSSProperty__moz_top_layer,
                
    nsCSSPropertyID::eCSSProperty__moz_user_focus,
                
    nsCSSPropertyID::eCSSProperty__moz_user_input,
                
    nsCSSPropertyID::eCSSProperty__moz_user_modify,
                
    nsCSSPropertyID::eCSSProperty__moz_user_select,
                
    nsCSSPropertyID::eCSSProperty__moz_window_dragging,
                
    nsCSSPropertyID::eCSSProperty__moz_window_shadow,
                
    nsCSSPropertyID::eCSSProperty_object_fit,
                
    nsCSSPropertyID::eCSSProperty_outline_style,
                
    nsCSSPropertyID::eCSSProperty_overflow_wrap,
                
    nsCSSPropertyID::eCSSProperty_overflow_x,
                
    nsCSSPropertyID::eCSSProperty_page_break_after,
                
    nsCSSPropertyID::eCSSProperty_page_break_before,
                
    nsCSSPropertyID::eCSSProperty_page_break_inside,
                
    nsCSSPropertyID::eCSSProperty_paint_order,
                
    nsCSSPropertyID::eCSSProperty_pointer_events,
                
    nsCSSPropertyID::eCSSProperty_position,
                
    nsCSSPropertyID::eCSSProperty_resize,
                
    nsCSSPropertyID::eCSSProperty_ruby_align,
                
    nsCSSPropertyID::eCSSProperty_ruby_position,
                
    nsCSSPropertyID::eCSSProperty_scroll_behavior,
                
    nsCSSPropertyID::eCSSProperty_shape_rendering,
                
    nsCSSPropertyID::eCSSProperty_stroke_linecap,
                
    nsCSSPropertyID::eCSSProperty_stroke_linejoin,
                
    nsCSSPropertyID::eCSSProperty_table_layout,
                
    nsCSSPropertyID::eCSSProperty_text_align_last,
                
    nsCSSPropertyID::eCSSProperty_text_anchor,
                
    nsCSSPropertyID::eCSSProperty_text_combine_upright,
                
    nsCSSPropertyID::eCSSProperty_text_decoration_line,
                
    nsCSSPropertyID::eCSSProperty_text_decoration_style,
                
    nsCSSPropertyID::eCSSProperty_text_justify,
                
    nsCSSPropertyID::eCSSProperty_text_orientation,
                
    nsCSSPropertyID::eCSSProperty_text_rendering,
                
    nsCSSPropertyID::eCSSProperty_text_transform,
                
    nsCSSPropertyID::eCSSProperty_touch_action,
                
    nsCSSPropertyID::eCSSProperty_transform_box,
                
    nsCSSPropertyID::eCSSProperty_transform_style,
                
    nsCSSPropertyID::eCSSProperty_unicode_bidi,
                
    nsCSSPropertyID::eCSSProperty_vector_effect,
                
    nsCSSPropertyID::eCSSProperty_visibility,
                
    nsCSSPropertyID::eCSSProperty_white_space,
                
    nsCSSPropertyID::eCSSProperty_word_break,
                
    nsCSSPropertyID::eCSSProperty_writing_mode,
                
    nsCSSPropertyID::eCSSProperty__x_span,
                
    nsCSSPropertyID::eCSSProperty__x_text_zoom,
                
    nsCSSPropertyID::eCSSProperty_z_index,
                
    nsCSSPropertyID::eCSSProperty__moz_box_ordinal_group,
                
    nsCSSPropertyID::eCSSProperty_order,
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_x,
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_y,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_x,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_y,
                
    nsCSSPropertyID::eCSSProperty_flex_grow,
                
    nsCSSPropertyID::eCSSProperty_flex_shrink,
                
    nsCSSPropertyID::eCSSProperty__moz_box_flex,
                
    nsCSSPropertyID::eCSSProperty_flood_opacity,
                
    nsCSSPropertyID::eCSSProperty__moz_window_opacity,
                
    nsCSSPropertyID::eCSSProperty_opacity,
                
    nsCSSPropertyID::eCSSProperty_shape_image_threshold,
                
    nsCSSPropertyID::eCSSProperty_stop_opacity,
                
    nsCSSPropertyID::eCSSProperty_border_block_end_style,
                
    nsCSSPropertyID::eCSSProperty_border_block_start_style,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_style,
                
    nsCSSPropertyID::eCSSProperty_border_inline_end_style,
                
    nsCSSPropertyID::eCSSProperty_border_inline_start_style,
                
    nsCSSPropertyID::eCSSProperty_border_left_style,
                
    nsCSSPropertyID::eCSSProperty_border_right_style,
                
    nsCSSPropertyID::eCSSProperty_border_top_style,
                
    nsCSSPropertyID::eCSSProperty_animation_delay,
                
    nsCSSPropertyID::eCSSProperty_animation_direction,
                
    nsCSSPropertyID::eCSSProperty_animation_duration,
                
    nsCSSPropertyID::eCSSProperty_animation_fill_mode,
                
    nsCSSPropertyID::eCSSProperty_animation_iteration_count,
                
    nsCSSPropertyID::eCSSProperty_animation_name,
                
    nsCSSPropertyID::eCSSProperty_animation_play_state,
                
    nsCSSPropertyID::eCSSProperty_animation_timing_function,
                
    nsCSSPropertyID::eCSSProperty_background_attachment,
                
    nsCSSPropertyID::eCSSProperty_background_blend_mode,
                
    nsCSSPropertyID::eCSSProperty_background_clip,
                
    nsCSSPropertyID::eCSSProperty_background_image,
                
    nsCSSPropertyID::eCSSProperty_background_origin,
                
    nsCSSPropertyID::eCSSProperty_background_position_x,
                
    nsCSSPropertyID::eCSSProperty_background_position_y,
                
    nsCSSPropertyID::eCSSProperty_background_repeat,
                
    nsCSSPropertyID::eCSSProperty_background_size,
                
    nsCSSPropertyID::eCSSProperty_border_image_outset,
                
    nsCSSPropertyID::eCSSProperty_border_image_slice,
                
    nsCSSPropertyID::eCSSProperty_border_image_source,
                
    nsCSSPropertyID::eCSSProperty_border_image_width,
                
    nsCSSPropertyID::eCSSProperty_border_spacing,
                
    nsCSSPropertyID::eCSSProperty_box_shadow,
                
    nsCSSPropertyID::eCSSProperty_caret_color,
                
    nsCSSPropertyID::eCSSProperty_clip_path,
                
    nsCSSPropertyID::eCSSProperty_color,
                
    nsCSSPropertyID::eCSSProperty_column_gap,
                
    nsCSSPropertyID::eCSSProperty_column_width,
                
    nsCSSPropertyID::eCSSProperty_content,
                
    nsCSSPropertyID::eCSSProperty_counter_increment,
                
    nsCSSPropertyID::eCSSProperty_counter_reset,
                
    nsCSSPropertyID::eCSSProperty_cursor,
                
    nsCSSPropertyID::eCSSProperty_display,
                
    nsCSSPropertyID::eCSSProperty_filter,
                
    nsCSSPropertyID::eCSSProperty_font_family,
                
    nsCSSPropertyID::eCSSProperty_font_feature_settings,
                
    nsCSSPropertyID::eCSSProperty_font_language_override,
                
    nsCSSPropertyID::eCSSProperty_font_size,
                
    nsCSSPropertyID::eCSSProperty_font_size_adjust,
                
    nsCSSPropertyID::eCSSProperty_font_variant_alternates,
                
    nsCSSPropertyID::eCSSProperty_font_variant_east_asian,
                
    nsCSSPropertyID::eCSSProperty_font_variant_ligatures,
                
    nsCSSPropertyID::eCSSProperty_font_variant_numeric,
                
    nsCSSPropertyID::eCSSProperty_font_variation_settings,
                
    nsCSSPropertyID::eCSSProperty_grid_template_areas,
                
    nsCSSPropertyID::eCSSProperty_letter_spacing,
                
    nsCSSPropertyID::eCSSProperty_line_height,
                
    nsCSSPropertyID::eCSSProperty_list_style_image,
                
    nsCSSPropertyID::eCSSProperty_list_style_type,
                
    nsCSSPropertyID::eCSSProperty_mask_clip,
                
    nsCSSPropertyID::eCSSProperty_mask_composite,
                
    nsCSSPropertyID::eCSSProperty_mask_image,
                
    nsCSSPropertyID::eCSSProperty_mask_mode,
                
    nsCSSPropertyID::eCSSProperty_mask_origin,
                
    nsCSSPropertyID::eCSSProperty_mask_position_x,
                
    nsCSSPropertyID::eCSSProperty_mask_position_y,
                
    nsCSSPropertyID::eCSSProperty_mask_repeat,
                
    nsCSSPropertyID::eCSSProperty_mask_size,
                
    nsCSSPropertyID::eCSSProperty__moz_context_properties,
                
    nsCSSPropertyID::eCSSProperty__moz_tab_size,
                
    nsCSSPropertyID::eCSSProperty_outline_offset,
                
    nsCSSPropertyID::eCSSProperty_overflow_y,
                
    nsCSSPropertyID::eCSSProperty_perspective,
                
    nsCSSPropertyID::eCSSProperty_perspective_origin,
                
    nsCSSPropertyID::eCSSProperty_quotes,
                
    nsCSSPropertyID::eCSSProperty_rotate,
                
    nsCSSPropertyID::eCSSProperty_scale,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_coordinate,
                
    nsCSSPropertyID::eCSSProperty_shape_outside,
                
    nsCSSPropertyID::eCSSProperty_stroke_dasharray,
                
    nsCSSPropertyID::eCSSProperty_stroke_dashoffset,
                
    nsCSSPropertyID::eCSSProperty_stroke_miterlimit,
                
    nsCSSPropertyID::eCSSProperty_stroke_width,
                
    nsCSSPropertyID::eCSSProperty_text_align,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_position,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_style,
                
    nsCSSPropertyID::eCSSProperty_text_indent,
                
    nsCSSPropertyID::eCSSProperty_text_overflow,
                
    nsCSSPropertyID::eCSSProperty_text_shadow,
                
    nsCSSPropertyID::eCSSProperty_transition_delay,
                
    nsCSSPropertyID::eCSSProperty_transition_duration,
                
    nsCSSPropertyID::eCSSProperty_transition_property,
                
    nsCSSPropertyID::eCSSProperty_transition_timing_function,
                
    nsCSSPropertyID::eCSSProperty_translate,
                
    nsCSSPropertyID::eCSSProperty_vertical_align,
                
    nsCSSPropertyID::eCSSProperty_will_change,
                
    nsCSSPropertyID::eCSSProperty_word_spacing,
                
    nsCSSPropertyID::eCSSProperty__x_lang,
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_block,
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_inline,
                
    nsCSSPropertyID::eCSSProperty_fill_opacity,
                
    nsCSSPropertyID::eCSSProperty_stroke_opacity,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_x,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_y,
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform,
                
    nsCSSPropertyID::eCSSProperty_transform,
                
    nsCSSPropertyID::eCSSProperty_clip,
                
    nsCSSPropertyID::eCSSProperty__moz_image_region,
                
    nsCSSPropertyID::eCSSProperty_grid_template_columns,
                
    nsCSSPropertyID::eCSSProperty_grid_template_rows,
                
    nsCSSPropertyID::eCSSProperty_object_position,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_destination,
                
    nsCSSPropertyID::eCSSProperty_fill,
                
    nsCSSPropertyID::eCSSProperty_stroke,
                
    nsCSSPropertyID::eCSSProperty_grid_auto_columns,
                
    nsCSSPropertyID::eCSSProperty_grid_auto_rows,
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform_origin,
                
    nsCSSPropertyID::eCSSProperty_transform_origin,
                
    nsCSSPropertyID::eCSSProperty_max_block_size,
                
    nsCSSPropertyID::eCSSProperty_max_height,
                
    nsCSSPropertyID::eCSSProperty_max_inline_size,
                
    nsCSSPropertyID::eCSSProperty_max_width,
                
    nsCSSPropertyID::eCSSProperty_flood_color,
                
    nsCSSPropertyID::eCSSProperty_lighting_color,
                
    nsCSSPropertyID::eCSSProperty__moz_font_smoothing_background_color,
                
    nsCSSPropertyID::eCSSProperty_stop_color,
                
    nsCSSPropertyID::eCSSProperty_marker_end,
                
    nsCSSPropertyID::eCSSProperty_marker_mid,
                
    nsCSSPropertyID::eCSSProperty_marker_start,
                
    nsCSSPropertyID::eCSSProperty__moz_binding,
                
    nsCSSPropertyID::eCSSProperty_grid_column_end,
                
    nsCSSPropertyID::eCSSProperty_grid_column_start,
                
    nsCSSPropertyID::eCSSProperty_grid_row_end,
                
    nsCSSPropertyID::eCSSProperty_grid_row_start,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_left_radius,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_right_radius,
                
    nsCSSPropertyID::eCSSProperty_border_top_left_radius,
                
    nsCSSPropertyID::eCSSProperty_border_top_right_radius,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomleft,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomright,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topleft,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topright,
                
    nsCSSPropertyID::eCSSProperty_block_size,
                
    nsCSSPropertyID::eCSSProperty_flex_basis,
                
    nsCSSPropertyID::eCSSProperty_height,
                
    nsCSSPropertyID::eCSSProperty_inline_size,
                
    nsCSSPropertyID::eCSSProperty_min_block_size,
                
    nsCSSPropertyID::eCSSProperty_min_height,
                
    nsCSSPropertyID::eCSSProperty_min_inline_size,
                
    nsCSSPropertyID::eCSSProperty_min_width,
                
    nsCSSPropertyID::eCSSProperty_width,
                
    nsCSSPropertyID::eCSSProperty_grid_column_gap,
                
    nsCSSPropertyID::eCSSProperty_grid_row_gap,
                
    nsCSSPropertyID::eCSSProperty_padding_block_end,
                
    nsCSSPropertyID::eCSSProperty_padding_block_start,
                
    nsCSSPropertyID::eCSSProperty_padding_bottom,
                
    nsCSSPropertyID::eCSSProperty_padding_inline_end,
                
    nsCSSPropertyID::eCSSProperty_padding_inline_start,
                
    nsCSSPropertyID::eCSSProperty_padding_left,
                
    nsCSSPropertyID::eCSSProperty_padding_right,
                
    nsCSSPropertyID::eCSSProperty_padding_top,
                
    nsCSSPropertyID::eCSSProperty_border_block_end_width,
                
    nsCSSPropertyID::eCSSProperty_border_block_start_width,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_width,
                
    nsCSSPropertyID::eCSSProperty_border_inline_end_width,
                
    nsCSSPropertyID::eCSSProperty_border_inline_start_width,
                
    nsCSSPropertyID::eCSSProperty_border_left_width,
                
    nsCSSPropertyID::eCSSProperty_border_right_width,
                
    nsCSSPropertyID::eCSSProperty_border_top_width,
                
    nsCSSPropertyID::eCSSProperty_column_rule_width,
                
    nsCSSPropertyID::eCSSProperty_outline_width,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_width,
                
    nsCSSPropertyID::eCSSProperty_background_color,
                
    nsCSSPropertyID::eCSSProperty_border_block_end_color,
                
    nsCSSPropertyID::eCSSProperty_border_block_start_color,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_color,
                
    nsCSSPropertyID::eCSSProperty_border_inline_end_color,
                
    nsCSSPropertyID::eCSSProperty_border_inline_start_color,
                
    nsCSSPropertyID::eCSSProperty_border_left_color,
                
    nsCSSPropertyID::eCSSProperty_border_right_color,
                
    nsCSSPropertyID::eCSSProperty_border_top_color,
                
    nsCSSPropertyID::eCSSProperty_column_rule_color,
                
    nsCSSPropertyID::eCSSProperty_outline_color,
                
    nsCSSPropertyID::eCSSProperty_text_decoration_color,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_color,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_fill_color,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_color,
                
    nsCSSPropertyID::eCSSProperty_bottom,
                
    nsCSSPropertyID::eCSSProperty_left,
                
    nsCSSPropertyID::eCSSProperty_margin_block_end,
                
    nsCSSPropertyID::eCSSProperty_margin_block_start,
                
    nsCSSPropertyID::eCSSProperty_margin_bottom,
                
    nsCSSPropertyID::eCSSProperty_margin_inline_end,
                
    nsCSSPropertyID::eCSSProperty_margin_inline_start,
                
    nsCSSPropertyID::eCSSProperty_margin_left,
                
    nsCSSPropertyID::eCSSProperty_margin_right,
                
    nsCSSPropertyID::eCSSProperty_margin_top,
                
    nsCSSPropertyID::eCSSProperty_offset_block_end,
                
    nsCSSPropertyID::eCSSProperty_offset_block_start,
                
    nsCSSPropertyID::eCSSProperty_offset_inline_end,
                
    nsCSSPropertyID::eCSSProperty_offset_inline_start,
                
    nsCSSPropertyID::eCSSProperty_right,
                
    nsCSSPropertyID::eCSSProperty_top,
                
    nsCSSPropertyID::eCSSProperty_background,
                
    nsCSSPropertyID::eCSSProperty_background_position,
                
    nsCSSPropertyID::eCSSProperty_border_color,
                
    nsCSSPropertyID::eCSSProperty_border_style,
                
    nsCSSPropertyID::eCSSProperty_border_width,
                
    nsCSSPropertyID::eCSSProperty_border_top,
                
    nsCSSPropertyID::eCSSProperty_border_left,
                
    nsCSSPropertyID::eCSSProperty_border_bottom,
                
    nsCSSPropertyID::eCSSProperty_border_right,
                
    nsCSSPropertyID::eCSSProperty_border_block_start,
                
    nsCSSPropertyID::eCSSProperty_border_block_end,
                
    nsCSSPropertyID::eCSSProperty_border_inline_start,
                
    nsCSSPropertyID::eCSSProperty_border_inline_end,
                
    nsCSSPropertyID::eCSSProperty_border,
                
    nsCSSPropertyID::eCSSProperty_border_radius,
                
    nsCSSPropertyID::eCSSProperty_border_image,
                
    nsCSSPropertyID::eCSSProperty_overflow,
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box,
                
    nsCSSPropertyID::eCSSProperty_transition,
                
    nsCSSPropertyID::eCSSProperty_animation,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type,
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior,
                
    nsCSSPropertyID::eCSSProperty_columns,
                
    nsCSSPropertyID::eCSSProperty_column_rule,
                
    nsCSSPropertyID::eCSSProperty_font,
                
    nsCSSPropertyID::eCSSProperty_font_variant,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke,
                
    nsCSSPropertyID::eCSSProperty_list_style,
                
    nsCSSPropertyID::eCSSProperty_margin,
                
    nsCSSPropertyID::eCSSProperty_mask,
                
    nsCSSPropertyID::eCSSProperty_mask_position,
                
    nsCSSPropertyID::eCSSProperty_outline,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius,
                
    nsCSSPropertyID::eCSSProperty_padding,
                
    nsCSSPropertyID::eCSSProperty_flex_flow,
                
    nsCSSPropertyID::eCSSProperty_flex,
                
    nsCSSPropertyID::eCSSProperty_grid_gap,
                
    nsCSSPropertyID::eCSSProperty_grid_row,
                
    nsCSSPropertyID::eCSSProperty_grid_column,
                
    nsCSSPropertyID::eCSSProperty_grid_area,
                
    nsCSSPropertyID::eCSSProperty_grid_template,
                
    nsCSSPropertyID::eCSSProperty_grid,
                
    nsCSSPropertyID::eCSSProperty_place_content,
                
    nsCSSPropertyID::eCSSProperty_place_self,
                
    nsCSSPropertyID::eCSSProperty_place_items,
                
    nsCSSPropertyID::eCSSProperty_marker,
                
    nsCSSPropertyID::eCSSProperty_text_decoration,
                
    nsCSSPropertyID::eCSSProperty_all,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackgroundClip,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackgroundOrigin,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackgroundSize,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStartColor,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStartStyle,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStartWidth,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEndColor,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEndStyle,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEndWidth,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderTopLeftRadius,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderTopRightRadius,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderBottomRightRadius,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderBottomLeftRadius,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionDuration,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionDuration,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionTimingFunction,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionTimingFunction,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionProperty,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionProperty,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionDelay,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionDelay,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationName,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationName,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationDuration,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationDuration,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationTimingFunction,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationTimingFunction,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationIterationCount,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationIterationCount,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationDirection,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationDirection,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationPlayState,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationPlayState,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationFillMode,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationFillMode,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationDelay,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationDelay,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransform,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozTransform,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozPerspective,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitPerspective,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozPerspectiveOrigin,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitPerspectiveOrigin,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozBackfaceVisibility,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackfaceVisibility,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozTransformStyle,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransformStyle,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozTransformOrigin,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransformOrigin,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnWidth,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnCount,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnGap,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnFill,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRuleWidth,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRuleColor,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnSpan,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRuleStyle,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxShadow,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFilter,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozFontFeatureSettings,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozFontLanguageOverride,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozHyphens,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTextSizeAdjust,
                
    nsCSSPropertyID::eCSSPropertyAlias_WordWrap,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozMarginStart,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozMarginEnd,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozPaddingStart,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozPaddingEnd,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexDirection,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexWrap,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitJustifyContent,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAlignContent,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAlignItems,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexGrow,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexShrink,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAlignSelf,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitOrder,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexBasis,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozBoxSizing,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxSizing,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitUserSelect,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskRepeat,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskPositionX,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskPositionY,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskClip,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskOrigin,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskSize,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskComposite,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskImage,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxAlign,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxDirection,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxFlex,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxOrient,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxPack,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxOrdinalGroup,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStart,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEnd,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderRadius,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderImage,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderImage,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozTransition,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransition,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimation,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimation,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozColumns,
                
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRule,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMask,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskPosition,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexFlow,
                
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlex,
        ];

        MAP[self.0]
    }

    #[inline]
    fn enabled_for_all_content(self) -> bool {
        
static EXPERIMENTAL: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0x8060840, 0x8004190, 0x90200000, 0x81e0018, 0x4000, 0x10000, 0x610003c0, 0x406, 0x0, 0x300040, 0xc800000, 0x400002, 0x0, 0x4000, 0x0, 0x0]
};


        
static ALWAYS_ENABLED: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0xf7f9f7bf, 0x847fbe6f, 0x6fdfff7d, 0xf5e1cfe7, 0xffffbfff, 0xfffeffff, 0x8efffc3f, 0xff7f7bf1, 0xffffffff, 0xffcfffbf, 0xf37fffff, 0xffbffffd, 0xffffffff, 0xffffbfff, 0xffffffff, 0x1f]
};


        let passes_pref_check = || {
                unsafe { structs::nsCSSProps_gPropertyEnabled[self.to_nscsspropertyid() as usize] }
        };

        if ALWAYS_ENABLED.contains(self) {
            return true
        }

        if EXPERIMENTAL.contains(self) && passes_pref_check() {
            return true
        }

        false
    }

    fn allowed_in(self, context: &ParserContext) -> bool {
        debug_assert!(
            matches!(
                context.rule_type(),
                CssRuleType::Keyframe | CssRuleType::Page | CssRuleType::Style
            ),
            "Declarations are only expected inside a keyframe, page, or style rule."
        );

        
static DISALLOWED_IN_KEYFRAME_BLOCK: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0x0, 0x0, 0x0, 0x0, 0xf60, 0x0, 0x0, 0x0, 0x0, 0x0, 0x2000000, 0x0, 0xffc3000, 0x0, 0x60000000, 0x0]
};

        
static DISALLOWED_IN_PAGE_RULE: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffff, 0xffffffff, 0xfffffff7, 0xffffffff, 0xfe7fffff, 0xffffffff, 0x1f]
};

        match context.rule_type() {
            CssRuleType::Keyframe if DISALLOWED_IN_KEYFRAME_BLOCK.contains(self) => {
                return false;
            }
            CssRuleType::Page if DISALLOWED_IN_PAGE_RULE.contains(self) => {
                return false;
            }
            _ => {}
        }

        // The semantics of these are kinda hard to reason about, what follows
        // is a description of the different combinations that can happen with
        // these three sets.
        //
        // Experimental properties are generally controlled by prefs, but an
        // experimental property explicitly enabled in certain context (UA or
        // chrome sheets) is always usable in the context regardless of the
        // pref value.
        //
        // Non-experimental properties are either normal properties which are
        // usable everywhere, or internal-only properties which are only usable
        // in certain context they are explicitly enabled in.
        if self.enabled_for_all_content() {
            return true;
        }

        
static ENABLED_IN_UA_SHEETS: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0x0, 0x12800000, 0x82, 0x2000000, 0x0, 0x0, 0x60000000, 0x808008, 0x0, 0x0, 0x800000, 0x0, 0x0, 0x0, 0x0, 0x0]
};

        
static ENABLED_IN_CHROME: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0x0, 0x0, 0x80, 0x2000000, 0x0, 0x0, 0x0, 0x808008, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0]
};


        if context.stylesheet_origin == Origin::UserAgent &&
            ENABLED_IN_UA_SHEETS.contains(self)
        {
            return true
        }

        if context.chrome_rules_enabled() && ENABLED_IN_CHROME.contains(self) {
            return true
        }

        false
    }
}

impl From<LonghandId> for NonCustomPropertyId {
    fn from(id: LonghandId) -> Self {
        NonCustomPropertyId(id as usize)
    }
}

impl From<ShorthandId> for NonCustomPropertyId {
    fn from(id: ShorthandId) -> Self {
        NonCustomPropertyId((id as usize) + 326)
    }
}

impl From<AliasId> for NonCustomPropertyId {
    fn from(id: AliasId) -> Self {
        NonCustomPropertyId(id as usize + 375)
    }
}

/// A set of all properties
#[derive(Clone, PartialEq)]
pub struct NonCustomPropertyIdSet {
    storage: [u32; (485 - 1 + 32) / 32]
}

impl NonCustomPropertyIdSet {
    /// Creates an empty `NonCustomPropertyIdSet`.
    pub fn new() -> Self {
        Self {
            storage: Default::default(),
        }
    }

    /// Insert a non-custom-property in the set.
    #[inline]
    pub fn insert(&mut self, id: NonCustomPropertyId) {
        let bit = id.0;
        self.storage[bit / 32] |= 1 << (bit % 32);
    }

    /// Return whether the given property is in the set
    #[inline]
    pub fn contains(&self, id: NonCustomPropertyId) -> bool {
        let bit = id.0;
        (self.storage[bit / 32] & (1 << (bit % 32))) != 0
    }
}





/// A set of longhand properties
#[derive(Clone, Debug, MallocSizeOf, PartialEq)]
pub struct LonghandIdSet {
    storage: [u32; (326 - 1 + 32) / 32]
}

/// An iterator over a set of longhand ids.
pub struct LonghandIdSetIterator<'a> {
    longhands: &'a LonghandIdSet,
    cur: usize,
}

impl<'a> Iterator for LonghandIdSetIterator<'a> {
    type Item = LonghandId;

    fn next(&mut self) -> Option<Self::Item> {
        use std::mem;

        loop {
            if self.cur >= 326 {
                return None;
            }

            let id: LonghandId = unsafe { mem::transmute(self.cur as u16) };
            self.cur += 1;

            if self.longhands.contains(id) {
                return Some(id);
            }
        }
    }
}

impl LonghandIdSet {
    /// Iterate over the current longhand id set.
    pub fn iter(&self) -> LonghandIdSetIterator {
        LonghandIdSetIterator { longhands: self, cur: 0, }
    }

    /// Returns whether this set contains at least every longhand that `other`
    /// also contains.
    pub fn contains_all(&self, other: &Self) -> bool {
        for (self_cell, other_cell) in self.storage.iter().zip(other.storage.iter()) {
            if (*self_cell & *other_cell) != *other_cell {
                return false;
            }
        }
        true
    }

    /// Returns whether this set contains any longhand that `other` also contains.
    pub fn contains_any(&self, other: &Self) -> bool {
        for (self_cell, other_cell) in self.storage.iter().zip(other.storage.iter()) {
            if (*self_cell & *other_cell) != 0 {
                return true;
            }
        }
        false
    }

    /// Create an empty set
    #[inline]
    pub fn new() -> LonghandIdSet {
        LonghandIdSet { storage: [0; (326 - 1 + 32) / 32] }
    }

    /// Return whether the given property is in the set
    #[inline]
    pub fn contains(&self, id: LonghandId) -> bool {
        let bit = id as usize;
        (self.storage[bit / 32] & (1 << (bit % 32))) != 0
    }

    /// Return whether this set contains any reset longhand.
    #[inline]
    pub fn contains_any_reset(&self) -> bool {
        
static RESET: LonghandIdSet = LonghandIdSet {
    
    storage: [0x397c2ef, 0x846fefc4, 0x62267be2, 0xffffd0f8, 0xabffffff, 0x7fc2006f, 0x67f403de, 0xf17fe7be, 0xffffffff, 0xffc7ffbf, 0x3f]
};

        self.contains_any(&RESET)
    }

    /// Add the given property to the set
    #[inline]
    pub fn insert(&mut self, id: LonghandId) {
        let bit = id as usize;
        self.storage[bit / 32] |= 1 << (bit % 32);
    }

    /// Remove the given property from the set
    #[inline]
    pub fn remove(&mut self, id: LonghandId) {
        let bit = id as usize;
        self.storage[bit / 32] &= !(1 << (bit % 32));
    }

    /// Clear all bits
    #[inline]
    pub fn clear(&mut self) {
        for cell in &mut self.storage {
            *cell = 0
        }
    }

    /// Returns whether the set is empty.
    #[inline]
    pub fn is_empty(&self) -> bool {
        self.storage.iter().all(|c| *c == 0)
    }
}

/// An enum to represent a CSS Wide keyword.
#[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
pub enum CSSWideKeyword {
    /// The `initial` keyword.
    Initial,
    /// The `inherit` keyword.
    Inherit,
    /// The `unset` keyword.
    Unset,
}

impl CSSWideKeyword {
    fn to_str(&self) -> &'static str {
        match *self {
            CSSWideKeyword::Initial => "initial",
            CSSWideKeyword::Inherit => "inherit",
            CSSWideKeyword::Unset => "unset",
        }
    }

    /// Takes the result of cssparser::Parser::expect_ident() and converts it
    /// to a CSSWideKeyword.
    pub fn from_ident<'i>(ident: &str) -> Option<Self> {
        match_ignore_ascii_case! { ident,
            // If modifying this set of keyword, also update values::CustomIdent::from_ident
            "initial" => Some(CSSWideKeyword::Initial),
            "inherit" => Some(CSSWideKeyword::Inherit),
            "unset" => Some(CSSWideKeyword::Unset),
            _ => None
        }
    }
}

impl CSSWideKeyword {
    fn parse(input: &mut Parser) -> Result<Self, ()> {
        let ident = input.expect_ident().map_err(|_| ())?.clone();
        input.expect_exhausted().map_err(|_| ())?;
        CSSWideKeyword::from_ident(&ident).ok_or(())
    }
}

bitflags! {
    /// A set of flags for properties.
    pub struct PropertyFlags: u8 {
        /// This property requires a stacking context.
        const CREATES_STACKING_CONTEXT = 1 << 0;
        /// This property has values that can establish a containing block for
        /// fixed positioned and absolutely positioned elements.
        const FIXPOS_CB = 1 << 1;
        /// This property has values that can establish a containing block for
        /// absolutely positioned elements.
        const ABSPOS_CB = 1 << 2;
        /// This longhand property applies to ::first-letter.
        const APPLIES_TO_FIRST_LETTER = 1 << 3;
        /// This longhand property applies to ::first-line.
        const APPLIES_TO_FIRST_LINE = 1 << 4;
        /// This longhand property applies to ::placeholder.
        const APPLIES_TO_PLACEHOLDER = 1 << 5;
    }
}

/// An identifier for a given longhand property.
#[derive(Clone, Copy, Eq, Hash, MallocSizeOf, PartialEq)]
#[repr(u16)]
pub enum LonghandId {
        /// align-content
        AlignContent = 0,
        /// align-items
        AlignItems = 1,
        /// align-self
        AlignSelf = 2,
        /// backface-visibility
        BackfaceVisibility = 3,
        /// border-collapse
        BorderCollapse = 4,
        /// border-image-repeat
        BorderImageRepeat = 5,
        /// box-decoration-break
        BoxDecorationBreak = 6,
        /// box-sizing
        BoxSizing = 7,
        /// caption-side
        CaptionSide = 8,
        /// clear
        Clear = 9,
        /// clip-rule
        ClipRule = 10,
        /// color-adjust
        ColorAdjust = 11,
        /// color-interpolation
        ColorInterpolation = 12,
        /// color-interpolation-filters
        ColorInterpolationFilters = 13,
        /// column-count
        ColumnCount = 14,
        /// column-fill
        ColumnFill = 15,
        /// column-rule-style
        ColumnRuleStyle = 16,
        /// column-span
        ColumnSpan = 17,
        /// contain
        Contain = 18,
        /// direction
        Direction = 19,
        /// dominant-baseline
        DominantBaseline = 20,
        /// empty-cells
        EmptyCells = 21,
        /// fill-rule
        FillRule = 22,
        /// flex-direction
        FlexDirection = 23,
        /// flex-wrap
        FlexWrap = 24,
        /// float
        Float = 25,
        /// font-kerning
        FontKerning = 26,
        /// font-optical-sizing
        FontOpticalSizing = 27,
        /// font-stretch
        FontStretch = 28,
        /// font-style
        FontStyle = 29,
        /// font-synthesis
        FontSynthesis = 30,
        /// font-variant-caps
        FontVariantCaps = 31,
        /// font-variant-position
        FontVariantPosition = 32,
        /// font-weight
        FontWeight = 33,
        /// grid-auto-flow
        GridAutoFlow = 34,
        /// hyphens
        Hyphens = 35,
        /// image-orientation
        ImageOrientation = 36,
        /// image-rendering
        ImageRendering = 37,
        /// ime-mode
        ImeMode = 38,
        /// initial-letter
        InitialLetter = 39,
        /// isolation
        Isolation = 40,
        /// justify-content
        JustifyContent = 41,
        /// justify-items
        JustifyItems = 42,
        /// justify-self
        JustifySelf = 43,
        /// list-style-position
        ListStylePosition = 44,
        /// mask-type
        MaskType = 45,
        /// mix-blend-mode
        MixBlendMode = 46,
        /// -moz-appearance
        MozAppearance = 47,
        /// -moz-box-align
        MozBoxAlign = 48,
        /// -moz-box-direction
        MozBoxDirection = 49,
        /// -moz-box-orient
        MozBoxOrient = 50,
        /// -moz-box-pack
        MozBoxPack = 51,
        /// -moz-control-character-visibility
        MozControlCharacterVisibility = 52,
        /// -moz-float-edge
        MozFloatEdge = 53,
        /// -moz-force-broken-image-icon
        MozForceBrokenImageIcon = 54,
        /// -moz-math-display
        MozMathDisplay = 55,
        /// -moz-math-variant
        MozMathVariant = 56,
        /// -moz-min-font-size-ratio
        MozMinFontSizeRatio = 57,
        /// -moz-orient
        MozOrient = 58,
        /// -moz-osx-font-smoothing
        MozOsxFontSmoothing = 59,
        /// -moz-script-level
        MozScriptLevel = 60,
        /// -moz-script-min-size
        MozScriptMinSize = 61,
        /// -moz-script-size-multiplier
        MozScriptSizeMultiplier = 62,
        /// -moz-stack-sizing
        MozStackSizing = 63,
        /// -moz-text-size-adjust
        MozTextSizeAdjust = 64,
        /// -moz-top-layer
        MozTopLayer = 65,
        /// -moz-user-focus
        MozUserFocus = 66,
        /// -moz-user-input
        MozUserInput = 67,
        /// -moz-user-modify
        MozUserModify = 68,
        /// -moz-user-select
        MozUserSelect = 69,
        /// -moz-window-dragging
        MozWindowDragging = 70,
        /// -moz-window-shadow
        MozWindowShadow = 71,
        /// object-fit
        ObjectFit = 72,
        /// outline-style
        OutlineStyle = 73,
        /// overflow-wrap
        OverflowWrap = 74,
        /// overflow-x
        OverflowX = 75,
        /// page-break-after
        PageBreakAfter = 76,
        /// page-break-before
        PageBreakBefore = 77,
        /// page-break-inside
        PageBreakInside = 78,
        /// paint-order
        PaintOrder = 79,
        /// pointer-events
        PointerEvents = 80,
        /// position
        Position = 81,
        /// resize
        Resize = 82,
        /// ruby-align
        RubyAlign = 83,
        /// ruby-position
        RubyPosition = 84,
        /// scroll-behavior
        ScrollBehavior = 85,
        /// shape-rendering
        ShapeRendering = 86,
        /// stroke-linecap
        StrokeLinecap = 87,
        /// stroke-linejoin
        StrokeLinejoin = 88,
        /// table-layout
        TableLayout = 89,
        /// text-align-last
        TextAlignLast = 90,
        /// text-anchor
        TextAnchor = 91,
        /// text-combine-upright
        TextCombineUpright = 92,
        /// text-decoration-line
        TextDecorationLine = 93,
        /// text-decoration-style
        TextDecorationStyle = 94,
        /// text-justify
        TextJustify = 95,
        /// text-orientation
        TextOrientation = 96,
        /// text-rendering
        TextRendering = 97,
        /// text-transform
        TextTransform = 98,
        /// touch-action
        TouchAction = 99,
        /// transform-box
        TransformBox = 100,
        /// transform-style
        TransformStyle = 101,
        /// unicode-bidi
        UnicodeBidi = 102,
        /// vector-effect
        VectorEffect = 103,
        /// visibility
        Visibility = 104,
        /// white-space
        WhiteSpace = 105,
        /// word-break
        WordBreak = 106,
        /// writing-mode
        WritingMode = 107,
        /// -x-span
        XSpan = 108,
        /// -x-text-zoom
        XTextZoom = 109,
        /// z-index
        ZIndex = 110,
        /// -moz-box-ordinal-group
        MozBoxOrdinalGroup = 111,
        /// order
        Order = 112,
        /// overscroll-behavior-x
        OverscrollBehaviorX = 113,
        /// overscroll-behavior-y
        OverscrollBehaviorY = 114,
        /// scroll-snap-type-x
        ScrollSnapTypeX = 115,
        /// scroll-snap-type-y
        ScrollSnapTypeY = 116,
        /// flex-grow
        FlexGrow = 117,
        /// flex-shrink
        FlexShrink = 118,
        /// -moz-box-flex
        MozBoxFlex = 119,
        /// flood-opacity
        FloodOpacity = 120,
        /// -moz-window-opacity
        MozWindowOpacity = 121,
        /// opacity
        Opacity = 122,
        /// shape-image-threshold
        ShapeImageThreshold = 123,
        /// stop-opacity
        StopOpacity = 124,
        /// border-block-end-style
        BorderBlockEndStyle = 125,
        /// border-block-start-style
        BorderBlockStartStyle = 126,
        /// border-bottom-style
        BorderBottomStyle = 127,
        /// border-inline-end-style
        BorderInlineEndStyle = 128,
        /// border-inline-start-style
        BorderInlineStartStyle = 129,
        /// border-left-style
        BorderLeftStyle = 130,
        /// border-right-style
        BorderRightStyle = 131,
        /// border-top-style
        BorderTopStyle = 132,
        /// animation-delay
        AnimationDelay = 133,
        /// animation-direction
        AnimationDirection = 134,
        /// animation-duration
        AnimationDuration = 135,
        /// animation-fill-mode
        AnimationFillMode = 136,
        /// animation-iteration-count
        AnimationIterationCount = 137,
        /// animation-name
        AnimationName = 138,
        /// animation-play-state
        AnimationPlayState = 139,
        /// animation-timing-function
        AnimationTimingFunction = 140,
        /// background-attachment
        BackgroundAttachment = 141,
        /// background-blend-mode
        BackgroundBlendMode = 142,
        /// background-clip
        BackgroundClip = 143,
        /// background-image
        BackgroundImage = 144,
        /// background-origin
        BackgroundOrigin = 145,
        /// background-position-x
        BackgroundPositionX = 146,
        /// background-position-y
        BackgroundPositionY = 147,
        /// background-repeat
        BackgroundRepeat = 148,
        /// background-size
        BackgroundSize = 149,
        /// border-image-outset
        BorderImageOutset = 150,
        /// border-image-slice
        BorderImageSlice = 151,
        /// border-image-source
        BorderImageSource = 152,
        /// border-image-width
        BorderImageWidth = 153,
        /// border-spacing
        BorderSpacing = 154,
        /// box-shadow
        BoxShadow = 155,
        /// caret-color
        CaretColor = 156,
        /// clip-path
        ClipPath = 157,
        /// color
        Color = 158,
        /// column-gap
        ColumnGap = 159,
        /// column-width
        ColumnWidth = 160,
        /// content
        Content = 161,
        /// counter-increment
        CounterIncrement = 162,
        /// counter-reset
        CounterReset = 163,
        /// cursor
        Cursor = 164,
        /// display
        Display = 165,
        /// filter
        Filter = 166,
        /// font-family
        FontFamily = 167,
        /// font-feature-settings
        FontFeatureSettings = 168,
        /// font-language-override
        FontLanguageOverride = 169,
        /// font-size
        FontSize = 170,
        /// font-size-adjust
        FontSizeAdjust = 171,
        /// font-variant-alternates
        FontVariantAlternates = 172,
        /// font-variant-east-asian
        FontVariantEastAsian = 173,
        /// font-variant-ligatures
        FontVariantLigatures = 174,
        /// font-variant-numeric
        FontVariantNumeric = 175,
        /// font-variation-settings
        FontVariationSettings = 176,
        /// grid-template-areas
        GridTemplateAreas = 177,
        /// letter-spacing
        LetterSpacing = 178,
        /// line-height
        LineHeight = 179,
        /// list-style-image
        ListStyleImage = 180,
        /// list-style-type
        ListStyleType = 181,
        /// mask-clip
        MaskClip = 182,
        /// mask-composite
        MaskComposite = 183,
        /// mask-image
        MaskImage = 184,
        /// mask-mode
        MaskMode = 185,
        /// mask-origin
        MaskOrigin = 186,
        /// mask-position-x
        MaskPositionX = 187,
        /// mask-position-y
        MaskPositionY = 188,
        /// mask-repeat
        MaskRepeat = 189,
        /// mask-size
        MaskSize = 190,
        /// -moz-context-properties
        MozContextProperties = 191,
        /// -moz-tab-size
        MozTabSize = 192,
        /// outline-offset
        OutlineOffset = 193,
        /// overflow-y
        OverflowY = 194,
        /// perspective
        Perspective = 195,
        /// perspective-origin
        PerspectiveOrigin = 196,
        /// quotes
        Quotes = 197,
        /// rotate
        Rotate = 198,
        /// scale
        Scale = 199,
        /// scroll-snap-coordinate
        ScrollSnapCoordinate = 200,
        /// shape-outside
        ShapeOutside = 201,
        /// stroke-dasharray
        StrokeDasharray = 202,
        /// stroke-dashoffset
        StrokeDashoffset = 203,
        /// stroke-miterlimit
        StrokeMiterlimit = 204,
        /// stroke-width
        StrokeWidth = 205,
        /// text-align
        TextAlign = 206,
        /// text-emphasis-position
        TextEmphasisPosition = 207,
        /// text-emphasis-style
        TextEmphasisStyle = 208,
        /// text-indent
        TextIndent = 209,
        /// text-overflow
        TextOverflow = 210,
        /// text-shadow
        TextShadow = 211,
        /// transition-delay
        TransitionDelay = 212,
        /// transition-duration
        TransitionDuration = 213,
        /// transition-property
        TransitionProperty = 214,
        /// transition-timing-function
        TransitionTimingFunction = 215,
        /// translate
        Translate = 216,
        /// vertical-align
        VerticalAlign = 217,
        /// will-change
        WillChange = 218,
        /// word-spacing
        WordSpacing = 219,
        /// -x-lang
        XLang = 220,
        /// overflow-clip-box-block
        OverflowClipBoxBlock = 221,
        /// overflow-clip-box-inline
        OverflowClipBoxInline = 222,
        /// fill-opacity
        FillOpacity = 223,
        /// stroke-opacity
        StrokeOpacity = 224,
        /// scroll-snap-points-x
        ScrollSnapPointsX = 225,
        /// scroll-snap-points-y
        ScrollSnapPointsY = 226,
        /// -moz-window-transform
        MozWindowTransform = 227,
        /// transform
        Transform = 228,
        /// clip
        Clip = 229,
        /// -moz-image-region
        MozImageRegion = 230,
        /// grid-template-columns
        GridTemplateColumns = 231,
        /// grid-template-rows
        GridTemplateRows = 232,
        /// object-position
        ObjectPosition = 233,
        /// scroll-snap-destination
        ScrollSnapDestination = 234,
        /// fill
        Fill = 235,
        /// stroke
        Stroke = 236,
        /// grid-auto-columns
        GridAutoColumns = 237,
        /// grid-auto-rows
        GridAutoRows = 238,
        /// -moz-window-transform-origin
        MozWindowTransformOrigin = 239,
        /// transform-origin
        TransformOrigin = 240,
        /// max-block-size
        MaxBlockSize = 241,
        /// max-height
        MaxHeight = 242,
        /// max-inline-size
        MaxInlineSize = 243,
        /// max-width
        MaxWidth = 244,
        /// flood-color
        FloodColor = 245,
        /// lighting-color
        LightingColor = 246,
        /// -moz-font-smoothing-background-color
        MozFontSmoothingBackgroundColor = 247,
        /// stop-color
        StopColor = 248,
        /// marker-end
        MarkerEnd = 249,
        /// marker-mid
        MarkerMid = 250,
        /// marker-start
        MarkerStart = 251,
        /// -moz-binding
        MozBinding = 252,
        /// grid-column-end
        GridColumnEnd = 253,
        /// grid-column-start
        GridColumnStart = 254,
        /// grid-row-end
        GridRowEnd = 255,
        /// grid-row-start
        GridRowStart = 256,
        /// border-bottom-left-radius
        BorderBottomLeftRadius = 257,
        /// border-bottom-right-radius
        BorderBottomRightRadius = 258,
        /// border-top-left-radius
        BorderTopLeftRadius = 259,
        /// border-top-right-radius
        BorderTopRightRadius = 260,
        /// -moz-outline-radius-bottomleft
        MozOutlineRadiusBottomleft = 261,
        /// -moz-outline-radius-bottomright
        MozOutlineRadiusBottomright = 262,
        /// -moz-outline-radius-topleft
        MozOutlineRadiusTopleft = 263,
        /// -moz-outline-radius-topright
        MozOutlineRadiusTopright = 264,
        /// block-size
        BlockSize = 265,
        /// flex-basis
        FlexBasis = 266,
        /// height
        Height = 267,
        /// inline-size
        InlineSize = 268,
        /// min-block-size
        MinBlockSize = 269,
        /// min-height
        MinHeight = 270,
        /// min-inline-size
        MinInlineSize = 271,
        /// min-width
        MinWidth = 272,
        /// width
        Width = 273,
        /// grid-column-gap
        GridColumnGap = 274,
        /// grid-row-gap
        GridRowGap = 275,
        /// padding-block-end
        PaddingBlockEnd = 276,
        /// padding-block-start
        PaddingBlockStart = 277,
        /// padding-bottom
        PaddingBottom = 278,
        /// padding-inline-end
        PaddingInlineEnd = 279,
        /// padding-inline-start
        PaddingInlineStart = 280,
        /// padding-left
        PaddingLeft = 281,
        /// padding-right
        PaddingRight = 282,
        /// padding-top
        PaddingTop = 283,
        /// border-block-end-width
        BorderBlockEndWidth = 284,
        /// border-block-start-width
        BorderBlockStartWidth = 285,
        /// border-bottom-width
        BorderBottomWidth = 286,
        /// border-inline-end-width
        BorderInlineEndWidth = 287,
        /// border-inline-start-width
        BorderInlineStartWidth = 288,
        /// border-left-width
        BorderLeftWidth = 289,
        /// border-right-width
        BorderRightWidth = 290,
        /// border-top-width
        BorderTopWidth = 291,
        /// column-rule-width
        ColumnRuleWidth = 292,
        /// outline-width
        OutlineWidth = 293,
        /// -webkit-text-stroke-width
        WebkitTextStrokeWidth = 294,
        /// background-color
        BackgroundColor = 295,
        /// border-block-end-color
        BorderBlockEndColor = 296,
        /// border-block-start-color
        BorderBlockStartColor = 297,
        /// border-bottom-color
        BorderBottomColor = 298,
        /// border-inline-end-color
        BorderInlineEndColor = 299,
        /// border-inline-start-color
        BorderInlineStartColor = 300,
        /// border-left-color
        BorderLeftColor = 301,
        /// border-right-color
        BorderRightColor = 302,
        /// border-top-color
        BorderTopColor = 303,
        /// column-rule-color
        ColumnRuleColor = 304,
        /// outline-color
        OutlineColor = 305,
        /// text-decoration-color
        TextDecorationColor = 306,
        /// text-emphasis-color
        TextEmphasisColor = 307,
        /// -webkit-text-fill-color
        WebkitTextFillColor = 308,
        /// -webkit-text-stroke-color
        WebkitTextStrokeColor = 309,
        /// bottom
        Bottom = 310,
        /// left
        Left = 311,
        /// margin-block-end
        MarginBlockEnd = 312,
        /// margin-block-start
        MarginBlockStart = 313,
        /// margin-bottom
        MarginBottom = 314,
        /// margin-inline-end
        MarginInlineEnd = 315,
        /// margin-inline-start
        MarginInlineStart = 316,
        /// margin-left
        MarginLeft = 317,
        /// margin-right
        MarginRight = 318,
        /// margin-top
        MarginTop = 319,
        /// offset-block-end
        OffsetBlockEnd = 320,
        /// offset-block-start
        OffsetBlockStart = 321,
        /// offset-inline-end
        OffsetInlineEnd = 322,
        /// offset-inline-start
        OffsetInlineStart = 323,
        /// right
        Right = 324,
        /// top
        Top = 325,
}

impl ToCss for LonghandId {
    #[inline]
    fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
    where
        W: Write,
    {
        dest.write_str(self.name())
    }
}

impl fmt::Debug for LonghandId {
    fn fmt(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
        formatter.write_str(self.name())
    }
}

impl LonghandId {
    /// Get the name of this longhand property.
    pub fn name(&self) -> &'static str {
        match *self {
                LonghandId::AlignContent => "align-content",
                LonghandId::AlignItems => "align-items",
                LonghandId::AlignSelf => "align-self",
                LonghandId::BackfaceVisibility => "backface-visibility",
                LonghandId::BorderCollapse => "border-collapse",
                LonghandId::BorderImageRepeat => "border-image-repeat",
                LonghandId::BoxDecorationBreak => "box-decoration-break",
                LonghandId::BoxSizing => "box-sizing",
                LonghandId::CaptionSide => "caption-side",
                LonghandId::Clear => "clear",
                LonghandId::ClipRule => "clip-rule",
                LonghandId::ColorAdjust => "color-adjust",
                LonghandId::ColorInterpolation => "color-interpolation",
                LonghandId::ColorInterpolationFilters => "color-interpolation-filters",
                LonghandId::ColumnCount => "column-count",
                LonghandId::ColumnFill => "column-fill",
                LonghandId::ColumnRuleStyle => "column-rule-style",
                LonghandId::ColumnSpan => "column-span",
                LonghandId::Contain => "contain",
                LonghandId::Direction => "direction",
                LonghandId::DominantBaseline => "dominant-baseline",
                LonghandId::EmptyCells => "empty-cells",
                LonghandId::FillRule => "fill-rule",
                LonghandId::FlexDirection => "flex-direction",
                LonghandId::FlexWrap => "flex-wrap",
                LonghandId::Float => "float",
                LonghandId::FontKerning => "font-kerning",
                LonghandId::FontOpticalSizing => "font-optical-sizing",
                LonghandId::FontStretch => "font-stretch",
                LonghandId::FontStyle => "font-style",
                LonghandId::FontSynthesis => "font-synthesis",
                LonghandId::FontVariantCaps => "font-variant-caps",
                LonghandId::FontVariantPosition => "font-variant-position",
                LonghandId::FontWeight => "font-weight",
                LonghandId::GridAutoFlow => "grid-auto-flow",
                LonghandId::Hyphens => "hyphens",
                LonghandId::ImageOrientation => "image-orientation",
                LonghandId::ImageRendering => "image-rendering",
                LonghandId::ImeMode => "ime-mode",
                LonghandId::InitialLetter => "initial-letter",
                LonghandId::Isolation => "isolation",
                LonghandId::JustifyContent => "justify-content",
                LonghandId::JustifyItems => "justify-items",
                LonghandId::JustifySelf => "justify-self",
                LonghandId::ListStylePosition => "list-style-position",
                LonghandId::MaskType => "mask-type",
                LonghandId::MixBlendMode => "mix-blend-mode",
                LonghandId::MozAppearance => "-moz-appearance",
                LonghandId::MozBoxAlign => "-moz-box-align",
                LonghandId::MozBoxDirection => "-moz-box-direction",
                LonghandId::MozBoxOrient => "-moz-box-orient",
                LonghandId::MozBoxPack => "-moz-box-pack",
                LonghandId::MozControlCharacterVisibility => "-moz-control-character-visibility",
                LonghandId::MozFloatEdge => "-moz-float-edge",
                LonghandId::MozForceBrokenImageIcon => "-moz-force-broken-image-icon",
                LonghandId::MozMathDisplay => "-moz-math-display",
                LonghandId::MozMathVariant => "-moz-math-variant",
                LonghandId::MozMinFontSizeRatio => "-moz-min-font-size-ratio",
                LonghandId::MozOrient => "-moz-orient",
                LonghandId::MozOsxFontSmoothing => "-moz-osx-font-smoothing",
                LonghandId::MozScriptLevel => "-moz-script-level",
                LonghandId::MozScriptMinSize => "-moz-script-min-size",
                LonghandId::MozScriptSizeMultiplier => "-moz-script-size-multiplier",
                LonghandId::MozStackSizing => "-moz-stack-sizing",
                LonghandId::MozTextSizeAdjust => "-moz-text-size-adjust",
                LonghandId::MozTopLayer => "-moz-top-layer",
                LonghandId::MozUserFocus => "-moz-user-focus",
                LonghandId::MozUserInput => "-moz-user-input",
                LonghandId::MozUserModify => "-moz-user-modify",
                LonghandId::MozUserSelect => "-moz-user-select",
                LonghandId::MozWindowDragging => "-moz-window-dragging",
                LonghandId::MozWindowShadow => "-moz-window-shadow",
                LonghandId::ObjectFit => "object-fit",
                LonghandId::OutlineStyle => "outline-style",
                LonghandId::OverflowWrap => "overflow-wrap",
                LonghandId::OverflowX => "overflow-x",
                LonghandId::PageBreakAfter => "page-break-after",
                LonghandId::PageBreakBefore => "page-break-before",
                LonghandId::PageBreakInside => "page-break-inside",
                LonghandId::PaintOrder => "paint-order",
                LonghandId::PointerEvents => "pointer-events",
                LonghandId::Position => "position",
                LonghandId::Resize => "resize",
                LonghandId::RubyAlign => "ruby-align",
                LonghandId::RubyPosition => "ruby-position",
                LonghandId::ScrollBehavior => "scroll-behavior",
                LonghandId::ShapeRendering => "shape-rendering",
                LonghandId::StrokeLinecap => "stroke-linecap",
                LonghandId::StrokeLinejoin => "stroke-linejoin",
                LonghandId::TableLayout => "table-layout",
                LonghandId::TextAlignLast => "text-align-last",
                LonghandId::TextAnchor => "text-anchor",
                LonghandId::TextCombineUpright => "text-combine-upright",
                LonghandId::TextDecorationLine => "text-decoration-line",
                LonghandId::TextDecorationStyle => "text-decoration-style",
                LonghandId::TextJustify => "text-justify",
                LonghandId::TextOrientation => "text-orientation",
                LonghandId::TextRendering => "text-rendering",
                LonghandId::TextTransform => "text-transform",
                LonghandId::TouchAction => "touch-action",
                LonghandId::TransformBox => "transform-box",
                LonghandId::TransformStyle => "transform-style",
                LonghandId::UnicodeBidi => "unicode-bidi",
                LonghandId::VectorEffect => "vector-effect",
                LonghandId::Visibility => "visibility",
                LonghandId::WhiteSpace => "white-space",
                LonghandId::WordBreak => "word-break",
                LonghandId::WritingMode => "writing-mode",
                LonghandId::XSpan => "-x-span",
                LonghandId::XTextZoom => "-x-text-zoom",
                LonghandId::ZIndex => "z-index",
                LonghandId::MozBoxOrdinalGroup => "-moz-box-ordinal-group",
                LonghandId::Order => "order",
                LonghandId::OverscrollBehaviorX => "overscroll-behavior-x",
                LonghandId::OverscrollBehaviorY => "overscroll-behavior-y",
                LonghandId::ScrollSnapTypeX => "scroll-snap-type-x",
                LonghandId::ScrollSnapTypeY => "scroll-snap-type-y",
                LonghandId::FlexGrow => "flex-grow",
                LonghandId::FlexShrink => "flex-shrink",
                LonghandId::MozBoxFlex => "-moz-box-flex",
                LonghandId::FloodOpacity => "flood-opacity",
                LonghandId::MozWindowOpacity => "-moz-window-opacity",
                LonghandId::Opacity => "opacity",
                LonghandId::ShapeImageThreshold => "shape-image-threshold",
                LonghandId::StopOpacity => "stop-opacity",
                LonghandId::BorderBlockEndStyle => "border-block-end-style",
                LonghandId::BorderBlockStartStyle => "border-block-start-style",
                LonghandId::BorderBottomStyle => "border-bottom-style",
                LonghandId::BorderInlineEndStyle => "border-inline-end-style",
                LonghandId::BorderInlineStartStyle => "border-inline-start-style",
                LonghandId::BorderLeftStyle => "border-left-style",
                LonghandId::BorderRightStyle => "border-right-style",
                LonghandId::BorderTopStyle => "border-top-style",
                LonghandId::AnimationDelay => "animation-delay",
                LonghandId::AnimationDirection => "animation-direction",
                LonghandId::AnimationDuration => "animation-duration",
                LonghandId::AnimationFillMode => "animation-fill-mode",
                LonghandId::AnimationIterationCount => "animation-iteration-count",
                LonghandId::AnimationName => "animation-name",
                LonghandId::AnimationPlayState => "animation-play-state",
                LonghandId::AnimationTimingFunction => "animation-timing-function",
                LonghandId::BackgroundAttachment => "background-attachment",
                LonghandId::BackgroundBlendMode => "background-blend-mode",
                LonghandId::BackgroundClip => "background-clip",
                LonghandId::BackgroundImage => "background-image",
                LonghandId::BackgroundOrigin => "background-origin",
                LonghandId::BackgroundPositionX => "background-position-x",
                LonghandId::BackgroundPositionY => "background-position-y",
                LonghandId::BackgroundRepeat => "background-repeat",
                LonghandId::BackgroundSize => "background-size",
                LonghandId::BorderImageOutset => "border-image-outset",
                LonghandId::BorderImageSlice => "border-image-slice",
                LonghandId::BorderImageSource => "border-image-source",
                LonghandId::BorderImageWidth => "border-image-width",
                LonghandId::BorderSpacing => "border-spacing",
                LonghandId::BoxShadow => "box-shadow",
                LonghandId::CaretColor => "caret-color",
                LonghandId::ClipPath => "clip-path",
                LonghandId::Color => "color",
                LonghandId::ColumnGap => "column-gap",
                LonghandId::ColumnWidth => "column-width",
                LonghandId::Content => "content",
                LonghandId::CounterIncrement => "counter-increment",
                LonghandId::CounterReset => "counter-reset",
                LonghandId::Cursor => "cursor",
                LonghandId::Display => "display",
                LonghandId::Filter => "filter",
                LonghandId::FontFamily => "font-family",
                LonghandId::FontFeatureSettings => "font-feature-settings",
                LonghandId::FontLanguageOverride => "font-language-override",
                LonghandId::FontSize => "font-size",
                LonghandId::FontSizeAdjust => "font-size-adjust",
                LonghandId::FontVariantAlternates => "font-variant-alternates",
                LonghandId::FontVariantEastAsian => "font-variant-east-asian",
                LonghandId::FontVariantLigatures => "font-variant-ligatures",
                LonghandId::FontVariantNumeric => "font-variant-numeric",
                LonghandId::FontVariationSettings => "font-variation-settings",
                LonghandId::GridTemplateAreas => "grid-template-areas",
                LonghandId::LetterSpacing => "letter-spacing",
                LonghandId::LineHeight => "line-height",
                LonghandId::ListStyleImage => "list-style-image",
                LonghandId::ListStyleType => "list-style-type",
                LonghandId::MaskClip => "mask-clip",
                LonghandId::MaskComposite => "mask-composite",
                LonghandId::MaskImage => "mask-image",
                LonghandId::MaskMode => "mask-mode",
                LonghandId::MaskOrigin => "mask-origin",
                LonghandId::MaskPositionX => "mask-position-x",
                LonghandId::MaskPositionY => "mask-position-y",
                LonghandId::MaskRepeat => "mask-repeat",
                LonghandId::MaskSize => "mask-size",
                LonghandId::MozContextProperties => "-moz-context-properties",
                LonghandId::MozTabSize => "-moz-tab-size",
                LonghandId::OutlineOffset => "outline-offset",
                LonghandId::OverflowY => "overflow-y",
                LonghandId::Perspective => "perspective",
                LonghandId::PerspectiveOrigin => "perspective-origin",
                LonghandId::Quotes => "quotes",
                LonghandId::Rotate => "rotate",
                LonghandId::Scale => "scale",
                LonghandId::ScrollSnapCoordinate => "scroll-snap-coordinate",
                LonghandId::ShapeOutside => "shape-outside",
                LonghandId::StrokeDasharray => "stroke-dasharray",
                LonghandId::StrokeDashoffset => "stroke-dashoffset",
                LonghandId::StrokeMiterlimit => "stroke-miterlimit",
                LonghandId::StrokeWidth => "stroke-width",
                LonghandId::TextAlign => "text-align",
                LonghandId::TextEmphasisPosition => "text-emphasis-position",
                LonghandId::TextEmphasisStyle => "text-emphasis-style",
                LonghandId::TextIndent => "text-indent",
                LonghandId::TextOverflow => "text-overflow",
                LonghandId::TextShadow => "text-shadow",
                LonghandId::TransitionDelay => "transition-delay",
                LonghandId::TransitionDuration => "transition-duration",
                LonghandId::TransitionProperty => "transition-property",
                LonghandId::TransitionTimingFunction => "transition-timing-function",
                LonghandId::Translate => "translate",
                LonghandId::VerticalAlign => "vertical-align",
                LonghandId::WillChange => "will-change",
                LonghandId::WordSpacing => "word-spacing",
                LonghandId::XLang => "-x-lang",
                LonghandId::OverflowClipBoxBlock => "overflow-clip-box-block",
                LonghandId::OverflowClipBoxInline => "overflow-clip-box-inline",
                LonghandId::FillOpacity => "fill-opacity",
                LonghandId::StrokeOpacity => "stroke-opacity",
                LonghandId::ScrollSnapPointsX => "scroll-snap-points-x",
                LonghandId::ScrollSnapPointsY => "scroll-snap-points-y",
                LonghandId::MozWindowTransform => "-moz-window-transform",
                LonghandId::Transform => "transform",
                LonghandId::Clip => "clip",
                LonghandId::MozImageRegion => "-moz-image-region",
                LonghandId::GridTemplateColumns => "grid-template-columns",
                LonghandId::GridTemplateRows => "grid-template-rows",
                LonghandId::ObjectPosition => "object-position",
                LonghandId::ScrollSnapDestination => "scroll-snap-destination",
                LonghandId::Fill => "fill",
                LonghandId::Stroke => "stroke",
                LonghandId::GridAutoColumns => "grid-auto-columns",
                LonghandId::GridAutoRows => "grid-auto-rows",
                LonghandId::MozWindowTransformOrigin => "-moz-window-transform-origin",
                LonghandId::TransformOrigin => "transform-origin",
                LonghandId::MaxBlockSize => "max-block-size",
                LonghandId::MaxHeight => "max-height",
                LonghandId::MaxInlineSize => "max-inline-size",
                LonghandId::MaxWidth => "max-width",
                LonghandId::FloodColor => "flood-color",
                LonghandId::LightingColor => "lighting-color",
                LonghandId::MozFontSmoothingBackgroundColor => "-moz-font-smoothing-background-color",
                LonghandId::StopColor => "stop-color",
                LonghandId::MarkerEnd => "marker-end",
                LonghandId::MarkerMid => "marker-mid",
                LonghandId::MarkerStart => "marker-start",
                LonghandId::MozBinding => "-moz-binding",
                LonghandId::GridColumnEnd => "grid-column-end",
                LonghandId::GridColumnStart => "grid-column-start",
                LonghandId::GridRowEnd => "grid-row-end",
                LonghandId::GridRowStart => "grid-row-start",
                LonghandId::BorderBottomLeftRadius => "border-bottom-left-radius",
                LonghandId::BorderBottomRightRadius => "border-bottom-right-radius",
                LonghandId::BorderTopLeftRadius => "border-top-left-radius",
                LonghandId::BorderTopRightRadius => "border-top-right-radius",
                LonghandId::MozOutlineRadiusBottomleft => "-moz-outline-radius-bottomleft",
                LonghandId::MozOutlineRadiusBottomright => "-moz-outline-radius-bottomright",
                LonghandId::MozOutlineRadiusTopleft => "-moz-outline-radius-topleft",
                LonghandId::MozOutlineRadiusTopright => "-moz-outline-radius-topright",
                LonghandId::BlockSize => "block-size",
                LonghandId::FlexBasis => "flex-basis",
                LonghandId::Height => "height",
                LonghandId::InlineSize => "inline-size",
                LonghandId::MinBlockSize => "min-block-size",
                LonghandId::MinHeight => "min-height",
                LonghandId::MinInlineSize => "min-inline-size",
                LonghandId::MinWidth => "min-width",
                LonghandId::Width => "width",
                LonghandId::GridColumnGap => "grid-column-gap",
                LonghandId::GridRowGap => "grid-row-gap",
                LonghandId::PaddingBlockEnd => "padding-block-end",
                LonghandId::PaddingBlockStart => "padding-block-start",
                LonghandId::PaddingBottom => "padding-bottom",
                LonghandId::PaddingInlineEnd => "padding-inline-end",
                LonghandId::PaddingInlineStart => "padding-inline-start",
                LonghandId::PaddingLeft => "padding-left",
                LonghandId::PaddingRight => "padding-right",
                LonghandId::PaddingTop => "padding-top",
                LonghandId::BorderBlockEndWidth => "border-block-end-width",
                LonghandId::BorderBlockStartWidth => "border-block-start-width",
                LonghandId::BorderBottomWidth => "border-bottom-width",
                LonghandId::BorderInlineEndWidth => "border-inline-end-width",
                LonghandId::BorderInlineStartWidth => "border-inline-start-width",
                LonghandId::BorderLeftWidth => "border-left-width",
                LonghandId::BorderRightWidth => "border-right-width",
                LonghandId::BorderTopWidth => "border-top-width",
                LonghandId::ColumnRuleWidth => "column-rule-width",
                LonghandId::OutlineWidth => "outline-width",
                LonghandId::WebkitTextStrokeWidth => "-webkit-text-stroke-width",
                LonghandId::BackgroundColor => "background-color",
                LonghandId::BorderBlockEndColor => "border-block-end-color",
                LonghandId::BorderBlockStartColor => "border-block-start-color",
                LonghandId::BorderBottomColor => "border-bottom-color",
                LonghandId::BorderInlineEndColor => "border-inline-end-color",
                LonghandId::BorderInlineStartColor => "border-inline-start-color",
                LonghandId::BorderLeftColor => "border-left-color",
                LonghandId::BorderRightColor => "border-right-color",
                LonghandId::BorderTopColor => "border-top-color",
                LonghandId::ColumnRuleColor => "column-rule-color",
                LonghandId::OutlineColor => "outline-color",
                LonghandId::TextDecorationColor => "text-decoration-color",
                LonghandId::TextEmphasisColor => "text-emphasis-color",
                LonghandId::WebkitTextFillColor => "-webkit-text-fill-color",
                LonghandId::WebkitTextStrokeColor => "-webkit-text-stroke-color",
                LonghandId::Bottom => "bottom",
                LonghandId::Left => "left",
                LonghandId::MarginBlockEnd => "margin-block-end",
                LonghandId::MarginBlockStart => "margin-block-start",
                LonghandId::MarginBottom => "margin-bottom",
                LonghandId::MarginInlineEnd => "margin-inline-end",
                LonghandId::MarginInlineStart => "margin-inline-start",
                LonghandId::MarginLeft => "margin-left",
                LonghandId::MarginRight => "margin-right",
                LonghandId::MarginTop => "margin-top",
                LonghandId::OffsetBlockEnd => "offset-block-end",
                LonghandId::OffsetBlockStart => "offset-block-start",
                LonghandId::OffsetInlineEnd => "offset-inline-end",
                LonghandId::OffsetInlineStart => "offset-inline-start",
                LonghandId::Right => "right",
                LonghandId::Top => "top",
        }
    }

    fn inherited(&self) -> bool {
        
static INHERITED: LonghandIdSet = LonghandIdSet {
    
    storage: [0xfc683d10, 0x7b90103b, 0x9dd9841d, 0x2f07, 0x54000000, 0x803dff90, 0x980bfc21, 0xe801841, 0x0, 0x380040, 0x0]
};

        INHERITED.contains(*self)
    }

    fn shorthands(&self) -> NonCustomPropertyIterator<ShorthandId> {
        // first generate longhand to shorthands lookup map
        //
        // NOTE(emilio): This currently doesn't exclude the "all" shorthand. It
        // could potentially do so, which would speed up serialization
        // algorithms and what not, I guess.
        

        // based on lookup results for each longhand, create result arrays
            static ALIGN_CONTENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::PlaceContent,
            ];
            static ALIGN_ITEMS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::PlaceItems,
            ];
            static ALIGN_SELF: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::PlaceSelf,
            ];
            static BACKFACE_VISIBILITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static BORDER_COLLAPSE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static BORDER_IMAGE_REPEAT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderImage,
            ];
            static BOX_DECORATION_BREAK: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static BOX_SIZING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CAPTION_SIDE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CLEAR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CLIP_RULE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLOR_ADJUST: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLOR_INTERPOLATION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLOR_INTERPOLATION_FILTERS: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLUMN_COUNT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Columns,
            ];
            static COLUMN_FILL: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLUMN_RULE_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ColumnRule,
            ];
            static COLUMN_SPAN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CONTAIN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static DIRECTION: &'static [ShorthandId] = &[
            ];
            static DOMINANT_BASELINE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static EMPTY_CELLS: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FILL_RULE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FLEX_DIRECTION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::FlexFlow,
            ];
            static FLEX_WRAP: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::FlexFlow,
            ];
            static FLOAT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FONT_KERNING: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_OPTICAL_SIZING: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_STRETCH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_SYNTHESIS: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FONT_VARIANT_CAPS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ];
            static FONT_VARIANT_POSITION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ];
            static FONT_WEIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static GRID_AUTO_FLOW: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Grid,
            ];
            static HYPHENS: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static IMAGE_ORIENTATION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static IMAGE_RENDERING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static IME_MODE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static INITIAL_LETTER: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static ISOLATION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static JUSTIFY_CONTENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::PlaceContent,
            ];
            static JUSTIFY_ITEMS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::PlaceItems,
            ];
            static JUSTIFY_SELF: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::PlaceSelf,
            ];
            static LIST_STYLE_POSITION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ListStyle,
            ];
            static MASK_TYPE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MIX_BLEND_MODE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_APPEARANCE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_BOX_ALIGN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_BOX_DIRECTION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_BOX_ORIENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_BOX_PACK: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_CONTROL_CHARACTER_VISIBILITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_FLOAT_EDGE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_FORCE_BROKEN_IMAGE_ICON: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_MATH_DISPLAY: &'static [ShorthandId] = &[
            ];
            static _MOZ_MATH_VARIANT: &'static [ShorthandId] = &[
            ];
            static _MOZ_MIN_FONT_SIZE_RATIO: &'static [ShorthandId] = &[
            ];
            static _MOZ_ORIENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_OSX_FONT_SMOOTHING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_SCRIPT_LEVEL: &'static [ShorthandId] = &[
            ];
            static _MOZ_SCRIPT_MIN_SIZE: &'static [ShorthandId] = &[
            ];
            static _MOZ_SCRIPT_SIZE_MULTIPLIER: &'static [ShorthandId] = &[
            ];
            static _MOZ_STACK_SIZING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_TEXT_SIZE_ADJUST: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_TOP_LAYER: &'static [ShorthandId] = &[
            ];
            static _MOZ_USER_FOCUS: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_USER_INPUT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_USER_MODIFY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_USER_SELECT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_WINDOW_DRAGGING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_WINDOW_SHADOW: &'static [ShorthandId] = &[
            ];
            static OBJECT_FIT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OUTLINE_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Outline,
            ];
            static OVERFLOW_WRAP: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OVERFLOW_X: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Overflow,
            ];
            static PAGE_BREAK_AFTER: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PAGE_BREAK_BEFORE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PAGE_BREAK_INSIDE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PAINT_ORDER: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static POINTER_EVENTS: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static POSITION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static RESIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static RUBY_ALIGN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static RUBY_POSITION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SCROLL_BEHAVIOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SHAPE_RENDERING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE_LINECAP: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE_LINEJOIN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TABLE_LAYOUT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_ALIGN_LAST: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_ANCHOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_COMBINE_UPRIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_DECORATION_LINE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::TextDecoration,
            ];
            static TEXT_DECORATION_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::TextDecoration,
            ];
            static TEXT_JUSTIFY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_ORIENTATION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_RENDERING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_TRANSFORM: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TOUCH_ACTION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TRANSFORM_BOX: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TRANSFORM_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static UNICODE_BIDI: &'static [ShorthandId] = &[
            ];
            static VECTOR_EFFECT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static VISIBILITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static WHITE_SPACE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static WORD_BREAK: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static WRITING_MODE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _X_SPAN: &'static [ShorthandId] = &[
            ];
            static _X_TEXT_ZOOM: &'static [ShorthandId] = &[
            ];
            static Z_INDEX: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_BOX_ORDINAL_GROUP: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static ORDER: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OVERSCROLL_BEHAVIOR_X: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::OverscrollBehavior,
            ];
            static OVERSCROLL_BEHAVIOR_Y: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::OverscrollBehavior,
            ];
            static SCROLL_SNAP_TYPE_X: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ScrollSnapType,
            ];
            static SCROLL_SNAP_TYPE_Y: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ScrollSnapType,
            ];
            static FLEX_GROW: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Flex,
            ];
            static FLEX_SHRINK: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Flex,
            ];
            static _MOZ_BOX_FLEX: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FLOOD_OPACITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_WINDOW_OPACITY: &'static [ShorthandId] = &[
            ];
            static OPACITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SHAPE_IMAGE_THRESHOLD: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STOP_OPACITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static BORDER_BLOCK_END_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderBlockEnd,
            ];
            static BORDER_BLOCK_START_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderBlockStart,
            ];
            static BORDER_BOTTOM_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderStyle,
                    ShorthandId::BorderBottom,
            ];
            static BORDER_INLINE_END_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderInlineEnd,
            ];
            static BORDER_INLINE_START_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderInlineStart,
            ];
            static BORDER_LEFT_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderStyle,
                    ShorthandId::BorderLeft,
            ];
            static BORDER_RIGHT_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderStyle,
                    ShorthandId::BorderRight,
            ];
            static BORDER_TOP_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderStyle,
                    ShorthandId::BorderTop,
            ];
            static ANIMATION_DELAY: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static ANIMATION_DIRECTION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static ANIMATION_DURATION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static ANIMATION_FILL_MODE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static ANIMATION_ITERATION_COUNT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static ANIMATION_NAME: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static ANIMATION_PLAY_STATE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static ANIMATION_TIMING_FUNCTION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static BACKGROUND_ATTACHMENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ];
            static BACKGROUND_BLEND_MODE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static BACKGROUND_CLIP: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ];
            static BACKGROUND_IMAGE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ];
            static BACKGROUND_ORIGIN: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ];
            static BACKGROUND_POSITION_X: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
                    ShorthandId::BackgroundPosition,
            ];
            static BACKGROUND_POSITION_Y: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
                    ShorthandId::BackgroundPosition,
            ];
            static BACKGROUND_REPEAT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ];
            static BACKGROUND_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ];
            static BORDER_IMAGE_OUTSET: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderImage,
            ];
            static BORDER_IMAGE_SLICE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderImage,
            ];
            static BORDER_IMAGE_SOURCE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderImage,
            ];
            static BORDER_IMAGE_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderImage,
            ];
            static BORDER_SPACING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static BOX_SHADOW: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CARET_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CLIP_PATH: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLUMN_GAP: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLUMN_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Columns,
            ];
            static CONTENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COUNTER_INCREMENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COUNTER_RESET: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CURSOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static DISPLAY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FILTER: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FONT_FAMILY: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_FEATURE_SETTINGS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_LANGUAGE_OVERRIDE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_SIZE_ADJUST: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_VARIANT_ALTERNATES: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ];
            static FONT_VARIANT_EAST_ASIAN: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ];
            static FONT_VARIANT_LIGATURES: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ];
            static FONT_VARIANT_NUMERIC: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ];
            static FONT_VARIATION_SETTINGS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static GRID_TEMPLATE_AREAS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Grid,
                    ShorthandId::GridTemplate,
            ];
            static LETTER_SPACING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static LINE_HEIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static LIST_STYLE_IMAGE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ListStyle,
            ];
            static LIST_STYLE_TYPE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ListStyle,
            ];
            static MASK_CLIP: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ];
            static MASK_COMPOSITE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ];
            static MASK_IMAGE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ];
            static MASK_MODE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ];
            static MASK_ORIGIN: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ];
            static MASK_POSITION_X: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
                    ShorthandId::MaskPosition,
            ];
            static MASK_POSITION_Y: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
                    ShorthandId::MaskPosition,
            ];
            static MASK_REPEAT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ];
            static MASK_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ];
            static _MOZ_CONTEXT_PROPERTIES: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_TAB_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OUTLINE_OFFSET: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OVERFLOW_Y: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Overflow,
            ];
            static PERSPECTIVE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PERSPECTIVE_ORIGIN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static QUOTES: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static ROTATE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SCALE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SCROLL_SNAP_COORDINATE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SHAPE_OUTSIDE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE_DASHARRAY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE_DASHOFFSET: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE_MITERLIMIT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_ALIGN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_EMPHASIS_POSITION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_EMPHASIS_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::TextEmphasis,
            ];
            static TEXT_INDENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_OVERFLOW: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_SHADOW: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TRANSITION_DELAY: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Transition,
            ];
            static TRANSITION_DURATION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Transition,
            ];
            static TRANSITION_PROPERTY: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Transition,
            ];
            static TRANSITION_TIMING_FUNCTION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Transition,
            ];
            static TRANSLATE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static VERTICAL_ALIGN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static WILL_CHANGE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static WORD_SPACING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _X_LANG: &'static [ShorthandId] = &[
            ];
            static OVERFLOW_CLIP_BOX_BLOCK: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::OverflowClipBox,
            ];
            static OVERFLOW_CLIP_BOX_INLINE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::OverflowClipBox,
            ];
            static FILL_OPACITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE_OPACITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SCROLL_SNAP_POINTS_X: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SCROLL_SNAP_POINTS_Y: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_WINDOW_TRANSFORM: &'static [ShorthandId] = &[
            ];
            static TRANSFORM: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CLIP: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_IMAGE_REGION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static GRID_TEMPLATE_COLUMNS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Grid,
                    ShorthandId::GridTemplate,
            ];
            static GRID_TEMPLATE_ROWS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Grid,
                    ShorthandId::GridTemplate,
            ];
            static OBJECT_POSITION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SCROLL_SNAP_DESTINATION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FILL: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static GRID_AUTO_COLUMNS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Grid,
            ];
            static GRID_AUTO_ROWS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Grid,
            ];
            static _MOZ_WINDOW_TRANSFORM_ORIGIN: &'static [ShorthandId] = &[
            ];
            static TRANSFORM_ORIGIN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MAX_BLOCK_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MAX_HEIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MAX_INLINE_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MAX_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FLOOD_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static LIGHTING_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_FONT_SMOOTHING_BACKGROUND_COLOR: &'static [ShorthandId] = &[
            ];
            static STOP_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MARKER_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Marker,
            ];
            static MARKER_MID: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Marker,
            ];
            static MARKER_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Marker,
            ];
            static _MOZ_BINDING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static GRID_COLUMN_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::GridArea,
                    ShorthandId::GridColumn,
            ];
            static GRID_COLUMN_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::GridArea,
                    ShorthandId::GridColumn,
            ];
            static GRID_ROW_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::GridArea,
                    ShorthandId::GridRow,
            ];
            static GRID_ROW_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::GridArea,
                    ShorthandId::GridRow,
            ];
            static BORDER_BOTTOM_LEFT_RADIUS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderRadius,
            ];
            static BORDER_BOTTOM_RIGHT_RADIUS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderRadius,
            ];
            static BORDER_TOP_LEFT_RADIUS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderRadius,
            ];
            static BORDER_TOP_RIGHT_RADIUS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderRadius,
            ];
            static _MOZ_OUTLINE_RADIUS_BOTTOMLEFT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::MozOutlineRadius,
            ];
            static _MOZ_OUTLINE_RADIUS_BOTTOMRIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::MozOutlineRadius,
            ];
            static _MOZ_OUTLINE_RADIUS_TOPLEFT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::MozOutlineRadius,
            ];
            static _MOZ_OUTLINE_RADIUS_TOPRIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::MozOutlineRadius,
            ];
            static BLOCK_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FLEX_BASIS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Flex,
            ];
            static HEIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static INLINE_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MIN_BLOCK_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MIN_HEIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MIN_INLINE_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MIN_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static GRID_COLUMN_GAP: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::GridGap,
            ];
            static GRID_ROW_GAP: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::GridGap,
            ];
            static PADDING_BLOCK_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PADDING_BLOCK_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PADDING_BOTTOM: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Padding,
            ];
            static PADDING_INLINE_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PADDING_INLINE_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PADDING_LEFT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Padding,
            ];
            static PADDING_RIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Padding,
            ];
            static PADDING_TOP: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Padding,
            ];
            static BORDER_BLOCK_END_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderBlockEnd,
            ];
            static BORDER_BLOCK_START_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderBlockStart,
            ];
            static BORDER_BOTTOM_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderWidth,
                    ShorthandId::BorderBottom,
            ];
            static BORDER_INLINE_END_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderInlineEnd,
            ];
            static BORDER_INLINE_START_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderInlineStart,
            ];
            static BORDER_LEFT_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderWidth,
                    ShorthandId::BorderLeft,
            ];
            static BORDER_RIGHT_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderWidth,
                    ShorthandId::BorderRight,
            ];
            static BORDER_TOP_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderWidth,
                    ShorthandId::BorderTop,
            ];
            static COLUMN_RULE_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ColumnRule,
            ];
            static OUTLINE_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Outline,
            ];
            static _WEBKIT_TEXT_STROKE_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::WebkitTextStroke,
            ];
            static BACKGROUND_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ];
            static BORDER_BLOCK_END_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderBlockEnd,
            ];
            static BORDER_BLOCK_START_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderBlockStart,
            ];
            static BORDER_BOTTOM_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderColor,
                    ShorthandId::BorderBottom,
            ];
            static BORDER_INLINE_END_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderInlineEnd,
            ];
            static BORDER_INLINE_START_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderInlineStart,
            ];
            static BORDER_LEFT_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderColor,
                    ShorthandId::BorderLeft,
            ];
            static BORDER_RIGHT_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderColor,
                    ShorthandId::BorderRight,
            ];
            static BORDER_TOP_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderColor,
                    ShorthandId::BorderTop,
            ];
            static COLUMN_RULE_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ColumnRule,
            ];
            static OUTLINE_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Outline,
            ];
            static TEXT_DECORATION_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::TextDecoration,
            ];
            static TEXT_EMPHASIS_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::TextEmphasis,
            ];
            static _WEBKIT_TEXT_FILL_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _WEBKIT_TEXT_STROKE_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::WebkitTextStroke,
            ];
            static BOTTOM: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static LEFT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MARGIN_BLOCK_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MARGIN_BLOCK_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MARGIN_BOTTOM: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Margin,
            ];
            static MARGIN_INLINE_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MARGIN_INLINE_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MARGIN_LEFT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Margin,
            ];
            static MARGIN_RIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Margin,
            ];
            static MARGIN_TOP: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Margin,
            ];
            static OFFSET_BLOCK_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OFFSET_BLOCK_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OFFSET_INLINE_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OFFSET_INLINE_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static RIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TOP: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];

        NonCustomPropertyIterator {
            filter: NonCustomPropertyId::from(*self).enabled_for_all_content(),
            iter: match *self {
                    LonghandId::AlignContent => ALIGN_CONTENT,
                    LonghandId::AlignItems => ALIGN_ITEMS,
                    LonghandId::AlignSelf => ALIGN_SELF,
                    LonghandId::BackfaceVisibility => BACKFACE_VISIBILITY,
                    LonghandId::BorderCollapse => BORDER_COLLAPSE,
                    LonghandId::BorderImageRepeat => BORDER_IMAGE_REPEAT,
                    LonghandId::BoxDecorationBreak => BOX_DECORATION_BREAK,
                    LonghandId::BoxSizing => BOX_SIZING,
                    LonghandId::CaptionSide => CAPTION_SIDE,
                    LonghandId::Clear => CLEAR,
                    LonghandId::ClipRule => CLIP_RULE,
                    LonghandId::ColorAdjust => COLOR_ADJUST,
                    LonghandId::ColorInterpolation => COLOR_INTERPOLATION,
                    LonghandId::ColorInterpolationFilters => COLOR_INTERPOLATION_FILTERS,
                    LonghandId::ColumnCount => COLUMN_COUNT,
                    LonghandId::ColumnFill => COLUMN_FILL,
                    LonghandId::ColumnRuleStyle => COLUMN_RULE_STYLE,
                    LonghandId::ColumnSpan => COLUMN_SPAN,
                    LonghandId::Contain => CONTAIN,
                    LonghandId::Direction => DIRECTION,
                    LonghandId::DominantBaseline => DOMINANT_BASELINE,
                    LonghandId::EmptyCells => EMPTY_CELLS,
                    LonghandId::FillRule => FILL_RULE,
                    LonghandId::FlexDirection => FLEX_DIRECTION,
                    LonghandId::FlexWrap => FLEX_WRAP,
                    LonghandId::Float => FLOAT,
                    LonghandId::FontKerning => FONT_KERNING,
                    LonghandId::FontOpticalSizing => FONT_OPTICAL_SIZING,
                    LonghandId::FontStretch => FONT_STRETCH,
                    LonghandId::FontStyle => FONT_STYLE,
                    LonghandId::FontSynthesis => FONT_SYNTHESIS,
                    LonghandId::FontVariantCaps => FONT_VARIANT_CAPS,
                    LonghandId::FontVariantPosition => FONT_VARIANT_POSITION,
                    LonghandId::FontWeight => FONT_WEIGHT,
                    LonghandId::GridAutoFlow => GRID_AUTO_FLOW,
                    LonghandId::Hyphens => HYPHENS,
                    LonghandId::ImageOrientation => IMAGE_ORIENTATION,
                    LonghandId::ImageRendering => IMAGE_RENDERING,
                    LonghandId::ImeMode => IME_MODE,
                    LonghandId::InitialLetter => INITIAL_LETTER,
                    LonghandId::Isolation => ISOLATION,
                    LonghandId::JustifyContent => JUSTIFY_CONTENT,
                    LonghandId::JustifyItems => JUSTIFY_ITEMS,
                    LonghandId::JustifySelf => JUSTIFY_SELF,
                    LonghandId::ListStylePosition => LIST_STYLE_POSITION,
                    LonghandId::MaskType => MASK_TYPE,
                    LonghandId::MixBlendMode => MIX_BLEND_MODE,
                    LonghandId::MozAppearance => _MOZ_APPEARANCE,
                    LonghandId::MozBoxAlign => _MOZ_BOX_ALIGN,
                    LonghandId::MozBoxDirection => _MOZ_BOX_DIRECTION,
                    LonghandId::MozBoxOrient => _MOZ_BOX_ORIENT,
                    LonghandId::MozBoxPack => _MOZ_BOX_PACK,
                    LonghandId::MozControlCharacterVisibility => _MOZ_CONTROL_CHARACTER_VISIBILITY,
                    LonghandId::MozFloatEdge => _MOZ_FLOAT_EDGE,
                    LonghandId::MozForceBrokenImageIcon => _MOZ_FORCE_BROKEN_IMAGE_ICON,
                    LonghandId::MozMathDisplay => _MOZ_MATH_DISPLAY,
                    LonghandId::MozMathVariant => _MOZ_MATH_VARIANT,
                    LonghandId::MozMinFontSizeRatio => _MOZ_MIN_FONT_SIZE_RATIO,
                    LonghandId::MozOrient => _MOZ_ORIENT,
                    LonghandId::MozOsxFontSmoothing => _MOZ_OSX_FONT_SMOOTHING,
                    LonghandId::MozScriptLevel => _MOZ_SCRIPT_LEVEL,
                    LonghandId::MozScriptMinSize => _MOZ_SCRIPT_MIN_SIZE,
                    LonghandId::MozScriptSizeMultiplier => _MOZ_SCRIPT_SIZE_MULTIPLIER,
                    LonghandId::MozStackSizing => _MOZ_STACK_SIZING,
                    LonghandId::MozTextSizeAdjust => _MOZ_TEXT_SIZE_ADJUST,
                    LonghandId::MozTopLayer => _MOZ_TOP_LAYER,
                    LonghandId::MozUserFocus => _MOZ_USER_FOCUS,
                    LonghandId::MozUserInput => _MOZ_USER_INPUT,
                    LonghandId::MozUserModify => _MOZ_USER_MODIFY,
                    LonghandId::MozUserSelect => _MOZ_USER_SELECT,
                    LonghandId::MozWindowDragging => _MOZ_WINDOW_DRAGGING,
                    LonghandId::MozWindowShadow => _MOZ_WINDOW_SHADOW,
                    LonghandId::ObjectFit => OBJECT_FIT,
                    LonghandId::OutlineStyle => OUTLINE_STYLE,
                    LonghandId::OverflowWrap => OVERFLOW_WRAP,
                    LonghandId::OverflowX => OVERFLOW_X,
                    LonghandId::PageBreakAfter => PAGE_BREAK_AFTER,
                    LonghandId::PageBreakBefore => PAGE_BREAK_BEFORE,
                    LonghandId::PageBreakInside => PAGE_BREAK_INSIDE,
                    LonghandId::PaintOrder => PAINT_ORDER,
                    LonghandId::PointerEvents => POINTER_EVENTS,
                    LonghandId::Position => POSITION,
                    LonghandId::Resize => RESIZE,
                    LonghandId::RubyAlign => RUBY_ALIGN,
                    LonghandId::RubyPosition => RUBY_POSITION,
                    LonghandId::ScrollBehavior => SCROLL_BEHAVIOR,
                    LonghandId::ShapeRendering => SHAPE_RENDERING,
                    LonghandId::StrokeLinecap => STROKE_LINECAP,
                    LonghandId::StrokeLinejoin => STROKE_LINEJOIN,
                    LonghandId::TableLayout => TABLE_LAYOUT,
                    LonghandId::TextAlignLast => TEXT_ALIGN_LAST,
                    LonghandId::TextAnchor => TEXT_ANCHOR,
                    LonghandId::TextCombineUpright => TEXT_COMBINE_UPRIGHT,
                    LonghandId::TextDecorationLine => TEXT_DECORATION_LINE,
                    LonghandId::TextDecorationStyle => TEXT_DECORATION_STYLE,
                    LonghandId::TextJustify => TEXT_JUSTIFY,
                    LonghandId::TextOrientation => TEXT_ORIENTATION,
                    LonghandId::TextRendering => TEXT_RENDERING,
                    LonghandId::TextTransform => TEXT_TRANSFORM,
                    LonghandId::TouchAction => TOUCH_ACTION,
                    LonghandId::TransformBox => TRANSFORM_BOX,
                    LonghandId::TransformStyle => TRANSFORM_STYLE,
                    LonghandId::UnicodeBidi => UNICODE_BIDI,
                    LonghandId::VectorEffect => VECTOR_EFFECT,
                    LonghandId::Visibility => VISIBILITY,
                    LonghandId::WhiteSpace => WHITE_SPACE,
                    LonghandId::WordBreak => WORD_BREAK,
                    LonghandId::WritingMode => WRITING_MODE,
                    LonghandId::XSpan => _X_SPAN,
                    LonghandId::XTextZoom => _X_TEXT_ZOOM,
                    LonghandId::ZIndex => Z_INDEX,
                    LonghandId::MozBoxOrdinalGroup => _MOZ_BOX_ORDINAL_GROUP,
                    LonghandId::Order => ORDER,
                    LonghandId::OverscrollBehaviorX => OVERSCROLL_BEHAVIOR_X,
                    LonghandId::OverscrollBehaviorY => OVERSCROLL_BEHAVIOR_Y,
                    LonghandId::ScrollSnapTypeX => SCROLL_SNAP_TYPE_X,
                    LonghandId::ScrollSnapTypeY => SCROLL_SNAP_TYPE_Y,
                    LonghandId::FlexGrow => FLEX_GROW,
                    LonghandId::FlexShrink => FLEX_SHRINK,
                    LonghandId::MozBoxFlex => _MOZ_BOX_FLEX,
                    LonghandId::FloodOpacity => FLOOD_OPACITY,
                    LonghandId::MozWindowOpacity => _MOZ_WINDOW_OPACITY,
                    LonghandId::Opacity => OPACITY,
                    LonghandId::ShapeImageThreshold => SHAPE_IMAGE_THRESHOLD,
                    LonghandId::StopOpacity => STOP_OPACITY,
                    LonghandId::BorderBlockEndStyle => BORDER_BLOCK_END_STYLE,
                    LonghandId::BorderBlockStartStyle => BORDER_BLOCK_START_STYLE,
                    LonghandId::BorderBottomStyle => BORDER_BOTTOM_STYLE,
                    LonghandId::BorderInlineEndStyle => BORDER_INLINE_END_STYLE,
                    LonghandId::BorderInlineStartStyle => BORDER_INLINE_START_STYLE,
                    LonghandId::BorderLeftStyle => BORDER_LEFT_STYLE,
                    LonghandId::BorderRightStyle => BORDER_RIGHT_STYLE,
                    LonghandId::BorderTopStyle => BORDER_TOP_STYLE,
                    LonghandId::AnimationDelay => ANIMATION_DELAY,
                    LonghandId::AnimationDirection => ANIMATION_DIRECTION,
                    LonghandId::AnimationDuration => ANIMATION_DURATION,
                    LonghandId::AnimationFillMode => ANIMATION_FILL_MODE,
                    LonghandId::AnimationIterationCount => ANIMATION_ITERATION_COUNT,
                    LonghandId::AnimationName => ANIMATION_NAME,
                    LonghandId::AnimationPlayState => ANIMATION_PLAY_STATE,
                    LonghandId::AnimationTimingFunction => ANIMATION_TIMING_FUNCTION,
                    LonghandId::BackgroundAttachment => BACKGROUND_ATTACHMENT,
                    LonghandId::BackgroundBlendMode => BACKGROUND_BLEND_MODE,
                    LonghandId::BackgroundClip => BACKGROUND_CLIP,
                    LonghandId::BackgroundImage => BACKGROUND_IMAGE,
                    LonghandId::BackgroundOrigin => BACKGROUND_ORIGIN,
                    LonghandId::BackgroundPositionX => BACKGROUND_POSITION_X,
                    LonghandId::BackgroundPositionY => BACKGROUND_POSITION_Y,
                    LonghandId::BackgroundRepeat => BACKGROUND_REPEAT,
                    LonghandId::BackgroundSize => BACKGROUND_SIZE,
                    LonghandId::BorderImageOutset => BORDER_IMAGE_OUTSET,
                    LonghandId::BorderImageSlice => BORDER_IMAGE_SLICE,
                    LonghandId::BorderImageSource => BORDER_IMAGE_SOURCE,
                    LonghandId::BorderImageWidth => BORDER_IMAGE_WIDTH,
                    LonghandId::BorderSpacing => BORDER_SPACING,
                    LonghandId::BoxShadow => BOX_SHADOW,
                    LonghandId::CaretColor => CARET_COLOR,
                    LonghandId::ClipPath => CLIP_PATH,
                    LonghandId::Color => COLOR,
                    LonghandId::ColumnGap => COLUMN_GAP,
                    LonghandId::ColumnWidth => COLUMN_WIDTH,
                    LonghandId::Content => CONTENT,
                    LonghandId::CounterIncrement => COUNTER_INCREMENT,
                    LonghandId::CounterReset => COUNTER_RESET,
                    LonghandId::Cursor => CURSOR,
                    LonghandId::Display => DISPLAY,
                    LonghandId::Filter => FILTER,
                    LonghandId::FontFamily => FONT_FAMILY,
                    LonghandId::FontFeatureSettings => FONT_FEATURE_SETTINGS,
                    LonghandId::FontLanguageOverride => FONT_LANGUAGE_OVERRIDE,
                    LonghandId::FontSize => FONT_SIZE,
                    LonghandId::FontSizeAdjust => FONT_SIZE_ADJUST,
                    LonghandId::FontVariantAlternates => FONT_VARIANT_ALTERNATES,
                    LonghandId::FontVariantEastAsian => FONT_VARIANT_EAST_ASIAN,
                    LonghandId::FontVariantLigatures => FONT_VARIANT_LIGATURES,
                    LonghandId::FontVariantNumeric => FONT_VARIANT_NUMERIC,
                    LonghandId::FontVariationSettings => FONT_VARIATION_SETTINGS,
                    LonghandId::GridTemplateAreas => GRID_TEMPLATE_AREAS,
                    LonghandId::LetterSpacing => LETTER_SPACING,
                    LonghandId::LineHeight => LINE_HEIGHT,
                    LonghandId::ListStyleImage => LIST_STYLE_IMAGE,
                    LonghandId::ListStyleType => LIST_STYLE_TYPE,
                    LonghandId::MaskClip => MASK_CLIP,
                    LonghandId::MaskComposite => MASK_COMPOSITE,
                    LonghandId::MaskImage => MASK_IMAGE,
                    LonghandId::MaskMode => MASK_MODE,
                    LonghandId::MaskOrigin => MASK_ORIGIN,
                    LonghandId::MaskPositionX => MASK_POSITION_X,
                    LonghandId::MaskPositionY => MASK_POSITION_Y,
                    LonghandId::MaskRepeat => MASK_REPEAT,
                    LonghandId::MaskSize => MASK_SIZE,
                    LonghandId::MozContextProperties => _MOZ_CONTEXT_PROPERTIES,
                    LonghandId::MozTabSize => _MOZ_TAB_SIZE,
                    LonghandId::OutlineOffset => OUTLINE_OFFSET,
                    LonghandId::OverflowY => OVERFLOW_Y,
                    LonghandId::Perspective => PERSPECTIVE,
                    LonghandId::PerspectiveOrigin => PERSPECTIVE_ORIGIN,
                    LonghandId::Quotes => QUOTES,
                    LonghandId::Rotate => ROTATE,
                    LonghandId::Scale => SCALE,
                    LonghandId::ScrollSnapCoordinate => SCROLL_SNAP_COORDINATE,
                    LonghandId::ShapeOutside => SHAPE_OUTSIDE,
                    LonghandId::StrokeDasharray => STROKE_DASHARRAY,
                    LonghandId::StrokeDashoffset => STROKE_DASHOFFSET,
                    LonghandId::StrokeMiterlimit => STROKE_MITERLIMIT,
                    LonghandId::StrokeWidth => STROKE_WIDTH,
                    LonghandId::TextAlign => TEXT_ALIGN,
                    LonghandId::TextEmphasisPosition => TEXT_EMPHASIS_POSITION,
                    LonghandId::TextEmphasisStyle => TEXT_EMPHASIS_STYLE,
                    LonghandId::TextIndent => TEXT_INDENT,
                    LonghandId::TextOverflow => TEXT_OVERFLOW,
                    LonghandId::TextShadow => TEXT_SHADOW,
                    LonghandId::TransitionDelay => TRANSITION_DELAY,
                    LonghandId::TransitionDuration => TRANSITION_DURATION,
                    LonghandId::TransitionProperty => TRANSITION_PROPERTY,
                    LonghandId::TransitionTimingFunction => TRANSITION_TIMING_FUNCTION,
                    LonghandId::Translate => TRANSLATE,
                    LonghandId::VerticalAlign => VERTICAL_ALIGN,
                    LonghandId::WillChange => WILL_CHANGE,
                    LonghandId::WordSpacing => WORD_SPACING,
                    LonghandId::XLang => _X_LANG,
                    LonghandId::OverflowClipBoxBlock => OVERFLOW_CLIP_BOX_BLOCK,
                    LonghandId::OverflowClipBoxInline => OVERFLOW_CLIP_BOX_INLINE,
                    LonghandId::FillOpacity => FILL_OPACITY,
                    LonghandId::StrokeOpacity => STROKE_OPACITY,
                    LonghandId::ScrollSnapPointsX => SCROLL_SNAP_POINTS_X,
                    LonghandId::ScrollSnapPointsY => SCROLL_SNAP_POINTS_Y,
                    LonghandId::MozWindowTransform => _MOZ_WINDOW_TRANSFORM,
                    LonghandId::Transform => TRANSFORM,
                    LonghandId::Clip => CLIP,
                    LonghandId::MozImageRegion => _MOZ_IMAGE_REGION,
                    LonghandId::GridTemplateColumns => GRID_TEMPLATE_COLUMNS,
                    LonghandId::GridTemplateRows => GRID_TEMPLATE_ROWS,
                    LonghandId::ObjectPosition => OBJECT_POSITION,
                    LonghandId::ScrollSnapDestination => SCROLL_SNAP_DESTINATION,
                    LonghandId::Fill => FILL,
                    LonghandId::Stroke => STROKE,
                    LonghandId::GridAutoColumns => GRID_AUTO_COLUMNS,
                    LonghandId::GridAutoRows => GRID_AUTO_ROWS,
                    LonghandId::MozWindowTransformOrigin => _MOZ_WINDOW_TRANSFORM_ORIGIN,
                    LonghandId::TransformOrigin => TRANSFORM_ORIGIN,
                    LonghandId::MaxBlockSize => MAX_BLOCK_SIZE,
                    LonghandId::MaxHeight => MAX_HEIGHT,
                    LonghandId::MaxInlineSize => MAX_INLINE_SIZE,
                    LonghandId::MaxWidth => MAX_WIDTH,
                    LonghandId::FloodColor => FLOOD_COLOR,
                    LonghandId::LightingColor => LIGHTING_COLOR,
                    LonghandId::MozFontSmoothingBackgroundColor => _MOZ_FONT_SMOOTHING_BACKGROUND_COLOR,
                    LonghandId::StopColor => STOP_COLOR,
                    LonghandId::MarkerEnd => MARKER_END,
                    LonghandId::MarkerMid => MARKER_MID,
                    LonghandId::MarkerStart => MARKER_START,
                    LonghandId::MozBinding => _MOZ_BINDING,
                    LonghandId::GridColumnEnd => GRID_COLUMN_END,
                    LonghandId::GridColumnStart => GRID_COLUMN_START,
                    LonghandId::GridRowEnd => GRID_ROW_END,
                    LonghandId::GridRowStart => GRID_ROW_START,
                    LonghandId::BorderBottomLeftRadius => BORDER_BOTTOM_LEFT_RADIUS,
                    LonghandId::BorderBottomRightRadius => BORDER_BOTTOM_RIGHT_RADIUS,
                    LonghandId::BorderTopLeftRadius => BORDER_TOP_LEFT_RADIUS,
                    LonghandId::BorderTopRightRadius => BORDER_TOP_RIGHT_RADIUS,
                    LonghandId::MozOutlineRadiusBottomleft => _MOZ_OUTLINE_RADIUS_BOTTOMLEFT,
                    LonghandId::MozOutlineRadiusBottomright => _MOZ_OUTLINE_RADIUS_BOTTOMRIGHT,
                    LonghandId::MozOutlineRadiusTopleft => _MOZ_OUTLINE_RADIUS_TOPLEFT,
                    LonghandId::MozOutlineRadiusTopright => _MOZ_OUTLINE_RADIUS_TOPRIGHT,
                    LonghandId::BlockSize => BLOCK_SIZE,
                    LonghandId::FlexBasis => FLEX_BASIS,
                    LonghandId::Height => HEIGHT,
                    LonghandId::InlineSize => INLINE_SIZE,
                    LonghandId::MinBlockSize => MIN_BLOCK_SIZE,
                    LonghandId::MinHeight => MIN_HEIGHT,
                    LonghandId::MinInlineSize => MIN_INLINE_SIZE,
                    LonghandId::MinWidth => MIN_WIDTH,
                    LonghandId::Width => WIDTH,
                    LonghandId::GridColumnGap => GRID_COLUMN_GAP,
                    LonghandId::GridRowGap => GRID_ROW_GAP,
                    LonghandId::PaddingBlockEnd => PADDING_BLOCK_END,
                    LonghandId::PaddingBlockStart => PADDING_BLOCK_START,
                    LonghandId::PaddingBottom => PADDING_BOTTOM,
                    LonghandId::PaddingInlineEnd => PADDING_INLINE_END,
                    LonghandId::PaddingInlineStart => PADDING_INLINE_START,
                    LonghandId::PaddingLeft => PADDING_LEFT,
                    LonghandId::PaddingRight => PADDING_RIGHT,
                    LonghandId::PaddingTop => PADDING_TOP,
                    LonghandId::BorderBlockEndWidth => BORDER_BLOCK_END_WIDTH,
                    LonghandId::BorderBlockStartWidth => BORDER_BLOCK_START_WIDTH,
                    LonghandId::BorderBottomWidth => BORDER_BOTTOM_WIDTH,
                    LonghandId::BorderInlineEndWidth => BORDER_INLINE_END_WIDTH,
                    LonghandId::BorderInlineStartWidth => BORDER_INLINE_START_WIDTH,
                    LonghandId::BorderLeftWidth => BORDER_LEFT_WIDTH,
                    LonghandId::BorderRightWidth => BORDER_RIGHT_WIDTH,
                    LonghandId::BorderTopWidth => BORDER_TOP_WIDTH,
                    LonghandId::ColumnRuleWidth => COLUMN_RULE_WIDTH,
                    LonghandId::OutlineWidth => OUTLINE_WIDTH,
                    LonghandId::WebkitTextStrokeWidth => _WEBKIT_TEXT_STROKE_WIDTH,
                    LonghandId::BackgroundColor => BACKGROUND_COLOR,
                    LonghandId::BorderBlockEndColor => BORDER_BLOCK_END_COLOR,
                    LonghandId::BorderBlockStartColor => BORDER_BLOCK_START_COLOR,
                    LonghandId::BorderBottomColor => BORDER_BOTTOM_COLOR,
                    LonghandId::BorderInlineEndColor => BORDER_INLINE_END_COLOR,
                    LonghandId::BorderInlineStartColor => BORDER_INLINE_START_COLOR,
                    LonghandId::BorderLeftColor => BORDER_LEFT_COLOR,
                    LonghandId::BorderRightColor => BORDER_RIGHT_COLOR,
                    LonghandId::BorderTopColor => BORDER_TOP_COLOR,
                    LonghandId::ColumnRuleColor => COLUMN_RULE_COLOR,
                    LonghandId::OutlineColor => OUTLINE_COLOR,
                    LonghandId::TextDecorationColor => TEXT_DECORATION_COLOR,
                    LonghandId::TextEmphasisColor => TEXT_EMPHASIS_COLOR,
                    LonghandId::WebkitTextFillColor => _WEBKIT_TEXT_FILL_COLOR,
                    LonghandId::WebkitTextStrokeColor => _WEBKIT_TEXT_STROKE_COLOR,
                    LonghandId::Bottom => BOTTOM,
                    LonghandId::Left => LEFT,
                    LonghandId::MarginBlockEnd => MARGIN_BLOCK_END,
                    LonghandId::MarginBlockStart => MARGIN_BLOCK_START,
                    LonghandId::MarginBottom => MARGIN_BOTTOM,
                    LonghandId::MarginInlineEnd => MARGIN_INLINE_END,
                    LonghandId::MarginInlineStart => MARGIN_INLINE_START,
                    LonghandId::MarginLeft => MARGIN_LEFT,
                    LonghandId::MarginRight => MARGIN_RIGHT,
                    LonghandId::MarginTop => MARGIN_TOP,
                    LonghandId::OffsetBlockEnd => OFFSET_BLOCK_END,
                    LonghandId::OffsetBlockStart => OFFSET_BLOCK_START,
                    LonghandId::OffsetInlineEnd => OFFSET_INLINE_END,
                    LonghandId::OffsetInlineStart => OFFSET_INLINE_START,
                    LonghandId::Right => RIGHT,
                    LonghandId::Top => TOP,
            }.iter(),
        }
    }

    fn parse_value<'i, 't>(
        &self,
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<PropertyDeclaration, ParseError<'i>> {
        match *self {
                LonghandId::AlignContent => {
                    longhands::align_content::parse_declared(context, input)
                }
                LonghandId::AlignItems => {
                    longhands::align_items::parse_declared(context, input)
                }
                LonghandId::AlignSelf => {
                    longhands::align_self::parse_declared(context, input)
                }
                LonghandId::BackfaceVisibility => {
                    longhands::backface_visibility::parse_declared(context, input)
                }
                LonghandId::BorderCollapse => {
                    longhands::border_collapse::parse_declared(context, input)
                }
                LonghandId::BorderImageRepeat => {
                    longhands::border_image_repeat::parse_declared(context, input)
                }
                LonghandId::BoxDecorationBreak => {
                    longhands::box_decoration_break::parse_declared(context, input)
                }
                LonghandId::BoxSizing => {
                    longhands::box_sizing::parse_declared(context, input)
                }
                LonghandId::CaptionSide => {
                    longhands::caption_side::parse_declared(context, input)
                }
                LonghandId::Clear => {
                    longhands::clear::parse_declared(context, input)
                }
                LonghandId::ClipRule => {
                    longhands::clip_rule::parse_declared(context, input)
                }
                LonghandId::ColorAdjust => {
                    longhands::color_adjust::parse_declared(context, input)
                }
                LonghandId::ColorInterpolation => {
                    longhands::color_interpolation::parse_declared(context, input)
                }
                LonghandId::ColorInterpolationFilters => {
                    longhands::color_interpolation_filters::parse_declared(context, input)
                }
                LonghandId::ColumnCount => {
                    longhands::column_count::parse_declared(context, input)
                }
                LonghandId::ColumnFill => {
                    longhands::column_fill::parse_declared(context, input)
                }
                LonghandId::ColumnRuleStyle => {
                    longhands::column_rule_style::parse_declared(context, input)
                }
                LonghandId::ColumnSpan => {
                    longhands::column_span::parse_declared(context, input)
                }
                LonghandId::Contain => {
                    longhands::contain::parse_declared(context, input)
                }
                LonghandId::Direction => {
                    longhands::direction::parse_declared(context, input)
                }
                LonghandId::DominantBaseline => {
                    longhands::dominant_baseline::parse_declared(context, input)
                }
                LonghandId::EmptyCells => {
                    longhands::empty_cells::parse_declared(context, input)
                }
                LonghandId::FillRule => {
                    longhands::fill_rule::parse_declared(context, input)
                }
                LonghandId::FlexDirection => {
                    longhands::flex_direction::parse_declared(context, input)
                }
                LonghandId::FlexWrap => {
                    longhands::flex_wrap::parse_declared(context, input)
                }
                LonghandId::Float => {
                    longhands::float::parse_declared(context, input)
                }
                LonghandId::FontKerning => {
                    longhands::font_kerning::parse_declared(context, input)
                }
                LonghandId::FontOpticalSizing => {
                    longhands::font_optical_sizing::parse_declared(context, input)
                }
                LonghandId::FontStretch => {
                    longhands::font_stretch::parse_declared(context, input)
                }
                LonghandId::FontStyle => {
                    longhands::font_style::parse_declared(context, input)
                }
                LonghandId::FontSynthesis => {
                    longhands::font_synthesis::parse_declared(context, input)
                }
                LonghandId::FontVariantCaps => {
                    longhands::font_variant_caps::parse_declared(context, input)
                }
                LonghandId::FontVariantPosition => {
                    longhands::font_variant_position::parse_declared(context, input)
                }
                LonghandId::FontWeight => {
                    longhands::font_weight::parse_declared(context, input)
                }
                LonghandId::GridAutoFlow => {
                    longhands::grid_auto_flow::parse_declared(context, input)
                }
                LonghandId::Hyphens => {
                    longhands::hyphens::parse_declared(context, input)
                }
                LonghandId::ImageOrientation => {
                    longhands::image_orientation::parse_declared(context, input)
                }
                LonghandId::ImageRendering => {
                    longhands::image_rendering::parse_declared(context, input)
                }
                LonghandId::ImeMode => {
                    longhands::ime_mode::parse_declared(context, input)
                }
                LonghandId::InitialLetter => {
                    longhands::initial_letter::parse_declared(context, input)
                }
                LonghandId::Isolation => {
                    longhands::isolation::parse_declared(context, input)
                }
                LonghandId::JustifyContent => {
                    longhands::justify_content::parse_declared(context, input)
                }
                LonghandId::JustifyItems => {
                    longhands::justify_items::parse_declared(context, input)
                }
                LonghandId::JustifySelf => {
                    longhands::justify_self::parse_declared(context, input)
                }
                LonghandId::ListStylePosition => {
                    longhands::list_style_position::parse_declared(context, input)
                }
                LonghandId::MaskType => {
                    longhands::mask_type::parse_declared(context, input)
                }
                LonghandId::MixBlendMode => {
                    longhands::mix_blend_mode::parse_declared(context, input)
                }
                LonghandId::MozAppearance => {
                    longhands::_moz_appearance::parse_declared(context, input)
                }
                LonghandId::MozBoxAlign => {
                    longhands::_moz_box_align::parse_declared(context, input)
                }
                LonghandId::MozBoxDirection => {
                    longhands::_moz_box_direction::parse_declared(context, input)
                }
                LonghandId::MozBoxOrient => {
                    longhands::_moz_box_orient::parse_declared(context, input)
                }
                LonghandId::MozBoxPack => {
                    longhands::_moz_box_pack::parse_declared(context, input)
                }
                LonghandId::MozControlCharacterVisibility => {
                    longhands::_moz_control_character_visibility::parse_declared(context, input)
                }
                LonghandId::MozFloatEdge => {
                    longhands::_moz_float_edge::parse_declared(context, input)
                }
                LonghandId::MozForceBrokenImageIcon => {
                    longhands::_moz_force_broken_image_icon::parse_declared(context, input)
                }
                LonghandId::MozMathDisplay => {
                    longhands::_moz_math_display::parse_declared(context, input)
                }
                LonghandId::MozMathVariant => {
                    longhands::_moz_math_variant::parse_declared(context, input)
                }
                LonghandId::MozMinFontSizeRatio => {
                    longhands::_moz_min_font_size_ratio::parse_declared(context, input)
                }
                LonghandId::MozOrient => {
                    longhands::_moz_orient::parse_declared(context, input)
                }
                LonghandId::MozOsxFontSmoothing => {
                    longhands::_moz_osx_font_smoothing::parse_declared(context, input)
                }
                LonghandId::MozScriptLevel => {
                    longhands::_moz_script_level::parse_declared(context, input)
                }
                LonghandId::MozScriptMinSize => {
                    longhands::_moz_script_min_size::parse_declared(context, input)
                }
                LonghandId::MozScriptSizeMultiplier => {
                    longhands::_moz_script_size_multiplier::parse_declared(context, input)
                }
                LonghandId::MozStackSizing => {
                    longhands::_moz_stack_sizing::parse_declared(context, input)
                }
                LonghandId::MozTextSizeAdjust => {
                    longhands::_moz_text_size_adjust::parse_declared(context, input)
                }
                LonghandId::MozTopLayer => {
                    longhands::_moz_top_layer::parse_declared(context, input)
                }
                LonghandId::MozUserFocus => {
                    longhands::_moz_user_focus::parse_declared(context, input)
                }
                LonghandId::MozUserInput => {
                    longhands::_moz_user_input::parse_declared(context, input)
                }
                LonghandId::MozUserModify => {
                    longhands::_moz_user_modify::parse_declared(context, input)
                }
                LonghandId::MozUserSelect => {
                    longhands::_moz_user_select::parse_declared(context, input)
                }
                LonghandId::MozWindowDragging => {
                    longhands::_moz_window_dragging::parse_declared(context, input)
                }
                LonghandId::MozWindowShadow => {
                    longhands::_moz_window_shadow::parse_declared(context, input)
                }
                LonghandId::ObjectFit => {
                    longhands::object_fit::parse_declared(context, input)
                }
                LonghandId::OutlineStyle => {
                    longhands::outline_style::parse_declared(context, input)
                }
                LonghandId::OverflowWrap => {
                    longhands::overflow_wrap::parse_declared(context, input)
                }
                LonghandId::OverflowX => {
                    longhands::overflow_x::parse_declared(context, input)
                }
                LonghandId::PageBreakAfter => {
                    longhands::page_break_after::parse_declared(context, input)
                }
                LonghandId::PageBreakBefore => {
                    longhands::page_break_before::parse_declared(context, input)
                }
                LonghandId::PageBreakInside => {
                    longhands::page_break_inside::parse_declared(context, input)
                }
                LonghandId::PaintOrder => {
                    longhands::paint_order::parse_declared(context, input)
                }
                LonghandId::PointerEvents => {
                    longhands::pointer_events::parse_declared(context, input)
                }
                LonghandId::Position => {
                    longhands::position::parse_declared(context, input)
                }
                LonghandId::Resize => {
                    longhands::resize::parse_declared(context, input)
                }
                LonghandId::RubyAlign => {
                    longhands::ruby_align::parse_declared(context, input)
                }
                LonghandId::RubyPosition => {
                    longhands::ruby_position::parse_declared(context, input)
                }
                LonghandId::ScrollBehavior => {
                    longhands::scroll_behavior::parse_declared(context, input)
                }
                LonghandId::ShapeRendering => {
                    longhands::shape_rendering::parse_declared(context, input)
                }
                LonghandId::StrokeLinecap => {
                    longhands::stroke_linecap::parse_declared(context, input)
                }
                LonghandId::StrokeLinejoin => {
                    longhands::stroke_linejoin::parse_declared(context, input)
                }
                LonghandId::TableLayout => {
                    longhands::table_layout::parse_declared(context, input)
                }
                LonghandId::TextAlignLast => {
                    longhands::text_align_last::parse_declared(context, input)
                }
                LonghandId::TextAnchor => {
                    longhands::text_anchor::parse_declared(context, input)
                }
                LonghandId::TextCombineUpright => {
                    longhands::text_combine_upright::parse_declared(context, input)
                }
                LonghandId::TextDecorationLine => {
                    longhands::text_decoration_line::parse_declared(context, input)
                }
                LonghandId::TextDecorationStyle => {
                    longhands::text_decoration_style::parse_declared(context, input)
                }
                LonghandId::TextJustify => {
                    longhands::text_justify::parse_declared(context, input)
                }
                LonghandId::TextOrientation => {
                    longhands::text_orientation::parse_declared(context, input)
                }
                LonghandId::TextRendering => {
                    longhands::text_rendering::parse_declared(context, input)
                }
                LonghandId::TextTransform => {
                    longhands::text_transform::parse_declared(context, input)
                }
                LonghandId::TouchAction => {
                    longhands::touch_action::parse_declared(context, input)
                }
                LonghandId::TransformBox => {
                    longhands::transform_box::parse_declared(context, input)
                }
                LonghandId::TransformStyle => {
                    longhands::transform_style::parse_declared(context, input)
                }
                LonghandId::UnicodeBidi => {
                    longhands::unicode_bidi::parse_declared(context, input)
                }
                LonghandId::VectorEffect => {
                    longhands::vector_effect::parse_declared(context, input)
                }
                LonghandId::Visibility => {
                    longhands::visibility::parse_declared(context, input)
                }
                LonghandId::WhiteSpace => {
                    longhands::white_space::parse_declared(context, input)
                }
                LonghandId::WordBreak => {
                    longhands::word_break::parse_declared(context, input)
                }
                LonghandId::WritingMode => {
                    longhands::writing_mode::parse_declared(context, input)
                }
                LonghandId::XSpan => {
                    longhands::_x_span::parse_declared(context, input)
                }
                LonghandId::XTextZoom => {
                    longhands::_x_text_zoom::parse_declared(context, input)
                }
                LonghandId::ZIndex => {
                    longhands::z_index::parse_declared(context, input)
                }
                LonghandId::MozBoxOrdinalGroup => {
                    longhands::_moz_box_ordinal_group::parse_declared(context, input)
                }
                LonghandId::Order => {
                    longhands::order::parse_declared(context, input)
                }
                LonghandId::OverscrollBehaviorX => {
                    longhands::overscroll_behavior_x::parse_declared(context, input)
                }
                LonghandId::OverscrollBehaviorY => {
                    longhands::overscroll_behavior_y::parse_declared(context, input)
                }
                LonghandId::ScrollSnapTypeX => {
                    longhands::scroll_snap_type_x::parse_declared(context, input)
                }
                LonghandId::ScrollSnapTypeY => {
                    longhands::scroll_snap_type_y::parse_declared(context, input)
                }
                LonghandId::FlexGrow => {
                    longhands::flex_grow::parse_declared(context, input)
                }
                LonghandId::FlexShrink => {
                    longhands::flex_shrink::parse_declared(context, input)
                }
                LonghandId::MozBoxFlex => {
                    longhands::_moz_box_flex::parse_declared(context, input)
                }
                LonghandId::FloodOpacity => {
                    longhands::flood_opacity::parse_declared(context, input)
                }
                LonghandId::MozWindowOpacity => {
                    longhands::_moz_window_opacity::parse_declared(context, input)
                }
                LonghandId::Opacity => {
                    longhands::opacity::parse_declared(context, input)
                }
                LonghandId::ShapeImageThreshold => {
                    longhands::shape_image_threshold::parse_declared(context, input)
                }
                LonghandId::StopOpacity => {
                    longhands::stop_opacity::parse_declared(context, input)
                }
                LonghandId::BorderBlockEndStyle => {
                    longhands::border_block_end_style::parse_declared(context, input)
                }
                LonghandId::BorderBlockStartStyle => {
                    longhands::border_block_start_style::parse_declared(context, input)
                }
                LonghandId::BorderBottomStyle => {
                    longhands::border_bottom_style::parse_declared(context, input)
                }
                LonghandId::BorderInlineEndStyle => {
                    longhands::border_inline_end_style::parse_declared(context, input)
                }
                LonghandId::BorderInlineStartStyle => {
                    longhands::border_inline_start_style::parse_declared(context, input)
                }
                LonghandId::BorderLeftStyle => {
                    longhands::border_left_style::parse_declared(context, input)
                }
                LonghandId::BorderRightStyle => {
                    longhands::border_right_style::parse_declared(context, input)
                }
                LonghandId::BorderTopStyle => {
                    longhands::border_top_style::parse_declared(context, input)
                }
                LonghandId::AnimationDelay => {
                    longhands::animation_delay::parse_declared(context, input)
                }
                LonghandId::AnimationDirection => {
                    longhands::animation_direction::parse_declared(context, input)
                }
                LonghandId::AnimationDuration => {
                    longhands::animation_duration::parse_declared(context, input)
                }
                LonghandId::AnimationFillMode => {
                    longhands::animation_fill_mode::parse_declared(context, input)
                }
                LonghandId::AnimationIterationCount => {
                    longhands::animation_iteration_count::parse_declared(context, input)
                }
                LonghandId::AnimationName => {
                    longhands::animation_name::parse_declared(context, input)
                }
                LonghandId::AnimationPlayState => {
                    longhands::animation_play_state::parse_declared(context, input)
                }
                LonghandId::AnimationTimingFunction => {
                    longhands::animation_timing_function::parse_declared(context, input)
                }
                LonghandId::BackgroundAttachment => {
                    longhands::background_attachment::parse_declared(context, input)
                }
                LonghandId::BackgroundBlendMode => {
                    longhands::background_blend_mode::parse_declared(context, input)
                }
                LonghandId::BackgroundClip => {
                    longhands::background_clip::parse_declared(context, input)
                }
                LonghandId::BackgroundImage => {
                    longhands::background_image::parse_declared(context, input)
                }
                LonghandId::BackgroundOrigin => {
                    longhands::background_origin::parse_declared(context, input)
                }
                LonghandId::BackgroundPositionX => {
                    longhands::background_position_x::parse_declared(context, input)
                }
                LonghandId::BackgroundPositionY => {
                    longhands::background_position_y::parse_declared(context, input)
                }
                LonghandId::BackgroundRepeat => {
                    longhands::background_repeat::parse_declared(context, input)
                }
                LonghandId::BackgroundSize => {
                    longhands::background_size::parse_declared(context, input)
                }
                LonghandId::BorderImageOutset => {
                    longhands::border_image_outset::parse_declared(context, input)
                }
                LonghandId::BorderImageSlice => {
                    longhands::border_image_slice::parse_declared(context, input)
                }
                LonghandId::BorderImageSource => {
                    longhands::border_image_source::parse_declared(context, input)
                }
                LonghandId::BorderImageWidth => {
                    longhands::border_image_width::parse_declared(context, input)
                }
                LonghandId::BorderSpacing => {
                    longhands::border_spacing::parse_declared(context, input)
                }
                LonghandId::BoxShadow => {
                    longhands::box_shadow::parse_declared(context, input)
                }
                LonghandId::CaretColor => {
                    longhands::caret_color::parse_declared(context, input)
                }
                LonghandId::ClipPath => {
                    longhands::clip_path::parse_declared(context, input)
                }
                LonghandId::Color => {
                    longhands::color::parse_declared(context, input)
                }
                LonghandId::ColumnGap => {
                    longhands::column_gap::parse_declared(context, input)
                }
                LonghandId::ColumnWidth => {
                    longhands::column_width::parse_declared(context, input)
                }
                LonghandId::Content => {
                    longhands::content::parse_declared(context, input)
                }
                LonghandId::CounterIncrement => {
                    longhands::counter_increment::parse_declared(context, input)
                }
                LonghandId::CounterReset => {
                    longhands::counter_reset::parse_declared(context, input)
                }
                LonghandId::Cursor => {
                    longhands::cursor::parse_declared(context, input)
                }
                LonghandId::Display => {
                    longhands::display::parse_declared(context, input)
                }
                LonghandId::Filter => {
                    longhands::filter::parse_declared(context, input)
                }
                LonghandId::FontFamily => {
                    longhands::font_family::parse_declared(context, input)
                }
                LonghandId::FontFeatureSettings => {
                    longhands::font_feature_settings::parse_declared(context, input)
                }
                LonghandId::FontLanguageOverride => {
                    longhands::font_language_override::parse_declared(context, input)
                }
                LonghandId::FontSize => {
                    longhands::font_size::parse_declared(context, input)
                }
                LonghandId::FontSizeAdjust => {
                    longhands::font_size_adjust::parse_declared(context, input)
                }
                LonghandId::FontVariantAlternates => {
                    longhands::font_variant_alternates::parse_declared(context, input)
                }
                LonghandId::FontVariantEastAsian => {
                    longhands::font_variant_east_asian::parse_declared(context, input)
                }
                LonghandId::FontVariantLigatures => {
                    longhands::font_variant_ligatures::parse_declared(context, input)
                }
                LonghandId::FontVariantNumeric => {
                    longhands::font_variant_numeric::parse_declared(context, input)
                }
                LonghandId::FontVariationSettings => {
                    longhands::font_variation_settings::parse_declared(context, input)
                }
                LonghandId::GridTemplateAreas => {
                    longhands::grid_template_areas::parse_declared(context, input)
                }
                LonghandId::LetterSpacing => {
                    longhands::letter_spacing::parse_declared(context, input)
                }
                LonghandId::LineHeight => {
                    longhands::line_height::parse_declared(context, input)
                }
                LonghandId::ListStyleImage => {
                    longhands::list_style_image::parse_declared(context, input)
                }
                LonghandId::ListStyleType => {
                    longhands::list_style_type::parse_declared(context, input)
                }
                LonghandId::MaskClip => {
                    longhands::mask_clip::parse_declared(context, input)
                }
                LonghandId::MaskComposite => {
                    longhands::mask_composite::parse_declared(context, input)
                }
                LonghandId::MaskImage => {
                    longhands::mask_image::parse_declared(context, input)
                }
                LonghandId::MaskMode => {
                    longhands::mask_mode::parse_declared(context, input)
                }
                LonghandId::MaskOrigin => {
                    longhands::mask_origin::parse_declared(context, input)
                }
                LonghandId::MaskPositionX => {
                    longhands::mask_position_x::parse_declared(context, input)
                }
                LonghandId::MaskPositionY => {
                    longhands::mask_position_y::parse_declared(context, input)
                }
                LonghandId::MaskRepeat => {
                    longhands::mask_repeat::parse_declared(context, input)
                }
                LonghandId::MaskSize => {
                    longhands::mask_size::parse_declared(context, input)
                }
                LonghandId::MozContextProperties => {
                    longhands::_moz_context_properties::parse_declared(context, input)
                }
                LonghandId::MozTabSize => {
                    longhands::_moz_tab_size::parse_declared(context, input)
                }
                LonghandId::OutlineOffset => {
                    longhands::outline_offset::parse_declared(context, input)
                }
                LonghandId::OverflowY => {
                    longhands::overflow_y::parse_declared(context, input)
                }
                LonghandId::Perspective => {
                    longhands::perspective::parse_declared(context, input)
                }
                LonghandId::PerspectiveOrigin => {
                    longhands::perspective_origin::parse_declared(context, input)
                }
                LonghandId::Quotes => {
                    longhands::quotes::parse_declared(context, input)
                }
                LonghandId::Rotate => {
                    longhands::rotate::parse_declared(context, input)
                }
                LonghandId::Scale => {
                    longhands::scale::parse_declared(context, input)
                }
                LonghandId::ScrollSnapCoordinate => {
                    longhands::scroll_snap_coordinate::parse_declared(context, input)
                }
                LonghandId::ShapeOutside => {
                    longhands::shape_outside::parse_declared(context, input)
                }
                LonghandId::StrokeDasharray => {
                    longhands::stroke_dasharray::parse_declared(context, input)
                }
                LonghandId::StrokeDashoffset => {
                    longhands::stroke_dashoffset::parse_declared(context, input)
                }
                LonghandId::StrokeMiterlimit => {
                    longhands::stroke_miterlimit::parse_declared(context, input)
                }
                LonghandId::StrokeWidth => {
                    longhands::stroke_width::parse_declared(context, input)
                }
                LonghandId::TextAlign => {
                    longhands::text_align::parse_declared(context, input)
                }
                LonghandId::TextEmphasisPosition => {
                    longhands::text_emphasis_position::parse_declared(context, input)
                }
                LonghandId::TextEmphasisStyle => {
                    longhands::text_emphasis_style::parse_declared(context, input)
                }
                LonghandId::TextIndent => {
                    longhands::text_indent::parse_declared(context, input)
                }
                LonghandId::TextOverflow => {
                    longhands::text_overflow::parse_declared(context, input)
                }
                LonghandId::TextShadow => {
                    longhands::text_shadow::parse_declared(context, input)
                }
                LonghandId::TransitionDelay => {
                    longhands::transition_delay::parse_declared(context, input)
                }
                LonghandId::TransitionDuration => {
                    longhands::transition_duration::parse_declared(context, input)
                }
                LonghandId::TransitionProperty => {
                    longhands::transition_property::parse_declared(context, input)
                }
                LonghandId::TransitionTimingFunction => {
                    longhands::transition_timing_function::parse_declared(context, input)
                }
                LonghandId::Translate => {
                    longhands::translate::parse_declared(context, input)
                }
                LonghandId::VerticalAlign => {
                    longhands::vertical_align::parse_declared(context, input)
                }
                LonghandId::WillChange => {
                    longhands::will_change::parse_declared(context, input)
                }
                LonghandId::WordSpacing => {
                    longhands::word_spacing::parse_declared(context, input)
                }
                LonghandId::XLang => {
                    longhands::_x_lang::parse_declared(context, input)
                }
                LonghandId::OverflowClipBoxBlock => {
                    longhands::overflow_clip_box_block::parse_declared(context, input)
                }
                LonghandId::OverflowClipBoxInline => {
                    longhands::overflow_clip_box_inline::parse_declared(context, input)
                }
                LonghandId::FillOpacity => {
                    longhands::fill_opacity::parse_declared(context, input)
                }
                LonghandId::StrokeOpacity => {
                    longhands::stroke_opacity::parse_declared(context, input)
                }
                LonghandId::ScrollSnapPointsX => {
                    longhands::scroll_snap_points_x::parse_declared(context, input)
                }
                LonghandId::ScrollSnapPointsY => {
                    longhands::scroll_snap_points_y::parse_declared(context, input)
                }
                LonghandId::MozWindowTransform => {
                    longhands::_moz_window_transform::parse_declared(context, input)
                }
                LonghandId::Transform => {
                    longhands::transform::parse_declared(context, input)
                }
                LonghandId::Clip => {
                    longhands::clip::parse_declared(context, input)
                }
                LonghandId::MozImageRegion => {
                    longhands::_moz_image_region::parse_declared(context, input)
                }
                LonghandId::GridTemplateColumns => {
                    longhands::grid_template_columns::parse_declared(context, input)
                }
                LonghandId::GridTemplateRows => {
                    longhands::grid_template_rows::parse_declared(context, input)
                }
                LonghandId::ObjectPosition => {
                    longhands::object_position::parse_declared(context, input)
                }
                LonghandId::ScrollSnapDestination => {
                    longhands::scroll_snap_destination::parse_declared(context, input)
                }
                LonghandId::Fill => {
                    longhands::fill::parse_declared(context, input)
                }
                LonghandId::Stroke => {
                    longhands::stroke::parse_declared(context, input)
                }
                LonghandId::GridAutoColumns => {
                    longhands::grid_auto_columns::parse_declared(context, input)
                }
                LonghandId::GridAutoRows => {
                    longhands::grid_auto_rows::parse_declared(context, input)
                }
                LonghandId::MozWindowTransformOrigin => {
                    longhands::_moz_window_transform_origin::parse_declared(context, input)
                }
                LonghandId::TransformOrigin => {
                    longhands::transform_origin::parse_declared(context, input)
                }
                LonghandId::MaxBlockSize => {
                    longhands::max_block_size::parse_declared(context, input)
                }
                LonghandId::MaxHeight => {
                    longhands::max_height::parse_declared(context, input)
                }
                LonghandId::MaxInlineSize => {
                    longhands::max_inline_size::parse_declared(context, input)
                }
                LonghandId::MaxWidth => {
                    longhands::max_width::parse_declared(context, input)
                }
                LonghandId::FloodColor => {
                    longhands::flood_color::parse_declared(context, input)
                }
                LonghandId::LightingColor => {
                    longhands::lighting_color::parse_declared(context, input)
                }
                LonghandId::MozFontSmoothingBackgroundColor => {
                    longhands::_moz_font_smoothing_background_color::parse_declared(context, input)
                }
                LonghandId::StopColor => {
                    longhands::stop_color::parse_declared(context, input)
                }
                LonghandId::MarkerEnd => {
                    longhands::marker_end::parse_declared(context, input)
                }
                LonghandId::MarkerMid => {
                    longhands::marker_mid::parse_declared(context, input)
                }
                LonghandId::MarkerStart => {
                    longhands::marker_start::parse_declared(context, input)
                }
                LonghandId::MozBinding => {
                    longhands::_moz_binding::parse_declared(context, input)
                }
                LonghandId::GridColumnEnd => {
                    longhands::grid_column_end::parse_declared(context, input)
                }
                LonghandId::GridColumnStart => {
                    longhands::grid_column_start::parse_declared(context, input)
                }
                LonghandId::GridRowEnd => {
                    longhands::grid_row_end::parse_declared(context, input)
                }
                LonghandId::GridRowStart => {
                    longhands::grid_row_start::parse_declared(context, input)
                }
                LonghandId::BorderBottomLeftRadius => {
                    longhands::border_bottom_left_radius::parse_declared(context, input)
                }
                LonghandId::BorderBottomRightRadius => {
                    longhands::border_bottom_right_radius::parse_declared(context, input)
                }
                LonghandId::BorderTopLeftRadius => {
                    longhands::border_top_left_radius::parse_declared(context, input)
                }
                LonghandId::BorderTopRightRadius => {
                    longhands::border_top_right_radius::parse_declared(context, input)
                }
                LonghandId::MozOutlineRadiusBottomleft => {
                    longhands::_moz_outline_radius_bottomleft::parse_declared(context, input)
                }
                LonghandId::MozOutlineRadiusBottomright => {
                    longhands::_moz_outline_radius_bottomright::parse_declared(context, input)
                }
                LonghandId::MozOutlineRadiusTopleft => {
                    longhands::_moz_outline_radius_topleft::parse_declared(context, input)
                }
                LonghandId::MozOutlineRadiusTopright => {
                    longhands::_moz_outline_radius_topright::parse_declared(context, input)
                }
                LonghandId::BlockSize => {
                    longhands::block_size::parse_declared(context, input)
                }
                LonghandId::FlexBasis => {
                    longhands::flex_basis::parse_declared(context, input)
                }
                LonghandId::Height => {
                    longhands::height::parse_declared(context, input)
                }
                LonghandId::InlineSize => {
                    longhands::inline_size::parse_declared(context, input)
                }
                LonghandId::MinBlockSize => {
                    longhands::min_block_size::parse_declared(context, input)
                }
                LonghandId::MinHeight => {
                    longhands::min_height::parse_declared(context, input)
                }
                LonghandId::MinInlineSize => {
                    longhands::min_inline_size::parse_declared(context, input)
                }
                LonghandId::MinWidth => {
                    longhands::min_width::parse_declared(context, input)
                }
                LonghandId::Width => {
                    longhands::width::parse_declared(context, input)
                }
                LonghandId::GridColumnGap => {
                    longhands::grid_column_gap::parse_declared(context, input)
                }
                LonghandId::GridRowGap => {
                    longhands::grid_row_gap::parse_declared(context, input)
                }
                LonghandId::PaddingBlockEnd => {
                    longhands::padding_block_end::parse_declared(context, input)
                }
                LonghandId::PaddingBlockStart => {
                    longhands::padding_block_start::parse_declared(context, input)
                }
                LonghandId::PaddingBottom => {
                    longhands::padding_bottom::parse_declared(context, input)
                }
                LonghandId::PaddingInlineEnd => {
                    longhands::padding_inline_end::parse_declared(context, input)
                }
                LonghandId::PaddingInlineStart => {
                    longhands::padding_inline_start::parse_declared(context, input)
                }
                LonghandId::PaddingLeft => {
                    longhands::padding_left::parse_declared(context, input)
                }
                LonghandId::PaddingRight => {
                    longhands::padding_right::parse_declared(context, input)
                }
                LonghandId::PaddingTop => {
                    longhands::padding_top::parse_declared(context, input)
                }
                LonghandId::BorderBlockEndWidth => {
                    longhands::border_block_end_width::parse_declared(context, input)
                }
                LonghandId::BorderBlockStartWidth => {
                    longhands::border_block_start_width::parse_declared(context, input)
                }
                LonghandId::BorderBottomWidth => {
                    longhands::border_bottom_width::parse_declared(context, input)
                }
                LonghandId::BorderInlineEndWidth => {
                    longhands::border_inline_end_width::parse_declared(context, input)
                }
                LonghandId::BorderInlineStartWidth => {
                    longhands::border_inline_start_width::parse_declared(context, input)
                }
                LonghandId::BorderLeftWidth => {
                    longhands::border_left_width::parse_declared(context, input)
                }
                LonghandId::BorderRightWidth => {
                    longhands::border_right_width::parse_declared(context, input)
                }
                LonghandId::BorderTopWidth => {
                    longhands::border_top_width::parse_declared(context, input)
                }
                LonghandId::ColumnRuleWidth => {
                    longhands::column_rule_width::parse_declared(context, input)
                }
                LonghandId::OutlineWidth => {
                    longhands::outline_width::parse_declared(context, input)
                }
                LonghandId::WebkitTextStrokeWidth => {
                    longhands::_webkit_text_stroke_width::parse_declared(context, input)
                }
                LonghandId::BackgroundColor => {
                    longhands::background_color::parse_declared(context, input)
                }
                LonghandId::BorderBlockEndColor => {
                    longhands::border_block_end_color::parse_declared(context, input)
                }
                LonghandId::BorderBlockStartColor => {
                    longhands::border_block_start_color::parse_declared(context, input)
                }
                LonghandId::BorderBottomColor => {
                    longhands::border_bottom_color::parse_declared(context, input)
                }
                LonghandId::BorderInlineEndColor => {
                    longhands::border_inline_end_color::parse_declared(context, input)
                }
                LonghandId::BorderInlineStartColor => {
                    longhands::border_inline_start_color::parse_declared(context, input)
                }
                LonghandId::BorderLeftColor => {
                    longhands::border_left_color::parse_declared(context, input)
                }
                LonghandId::BorderRightColor => {
                    longhands::border_right_color::parse_declared(context, input)
                }
                LonghandId::BorderTopColor => {
                    longhands::border_top_color::parse_declared(context, input)
                }
                LonghandId::ColumnRuleColor => {
                    longhands::column_rule_color::parse_declared(context, input)
                }
                LonghandId::OutlineColor => {
                    longhands::outline_color::parse_declared(context, input)
                }
                LonghandId::TextDecorationColor => {
                    longhands::text_decoration_color::parse_declared(context, input)
                }
                LonghandId::TextEmphasisColor => {
                    longhands::text_emphasis_color::parse_declared(context, input)
                }
                LonghandId::WebkitTextFillColor => {
                    longhands::_webkit_text_fill_color::parse_declared(context, input)
                }
                LonghandId::WebkitTextStrokeColor => {
                    longhands::_webkit_text_stroke_color::parse_declared(context, input)
                }
                LonghandId::Bottom => {
                    longhands::bottom::parse_declared(context, input)
                }
                LonghandId::Left => {
                    longhands::left::parse_declared(context, input)
                }
                LonghandId::MarginBlockEnd => {
                    longhands::margin_block_end::parse_declared(context, input)
                }
                LonghandId::MarginBlockStart => {
                    longhands::margin_block_start::parse_declared(context, input)
                }
                LonghandId::MarginBottom => {
                    longhands::margin_bottom::parse_declared(context, input)
                }
                LonghandId::MarginInlineEnd => {
                    longhands::margin_inline_end::parse_declared(context, input)
                }
                LonghandId::MarginInlineStart => {
                    longhands::margin_inline_start::parse_declared(context, input)
                }
                LonghandId::MarginLeft => {
                    longhands::margin_left::parse_declared(context, input)
                }
                LonghandId::MarginRight => {
                    longhands::margin_right::parse_declared(context, input)
                }
                LonghandId::MarginTop => {
                    longhands::margin_top::parse_declared(context, input)
                }
                LonghandId::OffsetBlockEnd => {
                    longhands::offset_block_end::parse_declared(context, input)
                }
                LonghandId::OffsetBlockStart => {
                    longhands::offset_block_start::parse_declared(context, input)
                }
                LonghandId::OffsetInlineEnd => {
                    longhands::offset_inline_end::parse_declared(context, input)
                }
                LonghandId::OffsetInlineStart => {
                    longhands::offset_inline_start::parse_declared(context, input)
                }
                LonghandId::Right => {
                    longhands::right::parse_declared(context, input)
                }
                LonghandId::Top => {
                    longhands::top::parse_declared(context, input)
                }
        }
    }

    /// Returns whether this property is animatable.
    pub fn is_animatable(self) -> bool {
        match self {
            LonghandId::AlignContent => {
                true
            }
            LonghandId::AlignItems => {
                true
            }
            LonghandId::AlignSelf => {
                true
            }
            LonghandId::BackfaceVisibility => {
                true
            }
            LonghandId::BorderCollapse => {
                true
            }
            LonghandId::BorderImageRepeat => {
                true
            }
            LonghandId::BoxDecorationBreak => {
                true
            }
            LonghandId::BoxSizing => {
                true
            }
            LonghandId::CaptionSide => {
                true
            }
            LonghandId::Clear => {
                true
            }
            LonghandId::ClipRule => {
                true
            }
            LonghandId::ColorAdjust => {
                true
            }
            LonghandId::ColorInterpolation => {
                true
            }
            LonghandId::ColorInterpolationFilters => {
                true
            }
            LonghandId::ColumnCount => {
                true
            }
            LonghandId::ColumnFill => {
                true
            }
            LonghandId::ColumnRuleStyle => {
                true
            }
            LonghandId::ColumnSpan => {
                true
            }
            LonghandId::Contain => {
                true
            }
            LonghandId::Direction => {
                true
            }
            LonghandId::DominantBaseline => {
                true
            }
            LonghandId::EmptyCells => {
                true
            }
            LonghandId::FillRule => {
                true
            }
            LonghandId::FlexDirection => {
                true
            }
            LonghandId::FlexWrap => {
                true
            }
            LonghandId::Float => {
                true
            }
            LonghandId::FontKerning => {
                true
            }
            LonghandId::FontOpticalSizing => {
                true
            }
            LonghandId::FontStretch => {
                true
            }
            LonghandId::FontStyle => {
                true
            }
            LonghandId::FontSynthesis => {
                true
            }
            LonghandId::FontVariantCaps => {
                true
            }
            LonghandId::FontVariantPosition => {
                true
            }
            LonghandId::FontWeight => {
                true
            }
            LonghandId::GridAutoFlow => {
                true
            }
            LonghandId::Hyphens => {
                true
            }
            LonghandId::ImageOrientation => {
                true
            }
            LonghandId::ImageRendering => {
                true
            }
            LonghandId::ImeMode => {
                true
            }
            LonghandId::InitialLetter => {
                true
            }
            LonghandId::Isolation => {
                true
            }
            LonghandId::JustifyContent => {
                true
            }
            LonghandId::JustifyItems => {
                true
            }
            LonghandId::JustifySelf => {
                true
            }
            LonghandId::ListStylePosition => {
                true
            }
            LonghandId::MaskType => {
                true
            }
            LonghandId::MixBlendMode => {
                true
            }
            LonghandId::MozAppearance => {
                true
            }
            LonghandId::MozBoxAlign => {
                true
            }
            LonghandId::MozBoxDirection => {
                true
            }
            LonghandId::MozBoxOrient => {
                true
            }
            LonghandId::MozBoxPack => {
                true
            }
            LonghandId::MozControlCharacterVisibility => {
                false
            }
            LonghandId::MozFloatEdge => {
                true
            }
            LonghandId::MozForceBrokenImageIcon => {
                true
            }
            LonghandId::MozMathDisplay => {
                false
            }
            LonghandId::MozMathVariant => {
                false
            }
            LonghandId::MozMinFontSizeRatio => {
                false
            }
            LonghandId::MozOrient => {
                true
            }
            LonghandId::MozOsxFontSmoothing => {
                true
            }
            LonghandId::MozScriptLevel => {
                false
            }
            LonghandId::MozScriptMinSize => {
                false
            }
            LonghandId::MozScriptSizeMultiplier => {
                false
            }
            LonghandId::MozStackSizing => {
                true
            }
            LonghandId::MozTextSizeAdjust => {
                true
            }
            LonghandId::MozTopLayer => {
                false
            }
            LonghandId::MozUserFocus => {
                true
            }
            LonghandId::MozUserInput => {
                true
            }
            LonghandId::MozUserModify => {
                true
            }
            LonghandId::MozUserSelect => {
                true
            }
            LonghandId::MozWindowDragging => {
                true
            }
            LonghandId::MozWindowShadow => {
                true
            }
            LonghandId::ObjectFit => {
                true
            }
            LonghandId::OutlineStyle => {
                true
            }
            LonghandId::OverflowWrap => {
                true
            }
            LonghandId::OverflowX => {
                true
            }
            LonghandId::PageBreakAfter => {
                true
            }
            LonghandId::PageBreakBefore => {
                true
            }
            LonghandId::PageBreakInside => {
                true
            }
            LonghandId::PaintOrder => {
                true
            }
            LonghandId::PointerEvents => {
                true
            }
            LonghandId::Position => {
                true
            }
            LonghandId::Resize => {
                true
            }
            LonghandId::RubyAlign => {
                true
            }
            LonghandId::RubyPosition => {
                true
            }
            LonghandId::ScrollBehavior => {
                true
            }
            LonghandId::ShapeRendering => {
                true
            }
            LonghandId::StrokeLinecap => {
                true
            }
            LonghandId::StrokeLinejoin => {
                true
            }
            LonghandId::TableLayout => {
                true
            }
            LonghandId::TextAlignLast => {
                true
            }
            LonghandId::TextAnchor => {
                true
            }
            LonghandId::TextCombineUpright => {
                true
            }
            LonghandId::TextDecorationLine => {
                true
            }
            LonghandId::TextDecorationStyle => {
                true
            }
            LonghandId::TextJustify => {
                true
            }
            LonghandId::TextOrientation => {
                true
            }
            LonghandId::TextRendering => {
                true
            }
            LonghandId::TextTransform => {
                true
            }
            LonghandId::TouchAction => {
                true
            }
            LonghandId::TransformBox => {
                true
            }
            LonghandId::TransformStyle => {
                true
            }
            LonghandId::UnicodeBidi => {
                true
            }
            LonghandId::VectorEffect => {
                true
            }
            LonghandId::Visibility => {
                true
            }
            LonghandId::WhiteSpace => {
                true
            }
            LonghandId::WordBreak => {
                true
            }
            LonghandId::WritingMode => {
                true
            }
            LonghandId::XSpan => {
                false
            }
            LonghandId::XTextZoom => {
                false
            }
            LonghandId::ZIndex => {
                true
            }
            LonghandId::MozBoxOrdinalGroup => {
                true
            }
            LonghandId::Order => {
                true
            }
            LonghandId::OverscrollBehaviorX => {
                true
            }
            LonghandId::OverscrollBehaviorY => {
                true
            }
            LonghandId::ScrollSnapTypeX => {
                true
            }
            LonghandId::ScrollSnapTypeY => {
                true
            }
            LonghandId::FlexGrow => {
                true
            }
            LonghandId::FlexShrink => {
                true
            }
            LonghandId::MozBoxFlex => {
                true
            }
            LonghandId::FloodOpacity => {
                true
            }
            LonghandId::MozWindowOpacity => {
                true
            }
            LonghandId::Opacity => {
                true
            }
            LonghandId::ShapeImageThreshold => {
                true
            }
            LonghandId::StopOpacity => {
                true
            }
            LonghandId::BorderBlockEndStyle => {
                false
            }
            LonghandId::BorderBlockStartStyle => {
                false
            }
            LonghandId::BorderBottomStyle => {
                true
            }
            LonghandId::BorderInlineEndStyle => {
                false
            }
            LonghandId::BorderInlineStartStyle => {
                false
            }
            LonghandId::BorderLeftStyle => {
                true
            }
            LonghandId::BorderRightStyle => {
                true
            }
            LonghandId::BorderTopStyle => {
                true
            }
            LonghandId::AnimationDelay => {
                false
            }
            LonghandId::AnimationDirection => {
                false
            }
            LonghandId::AnimationDuration => {
                false
            }
            LonghandId::AnimationFillMode => {
                false
            }
            LonghandId::AnimationIterationCount => {
                false
            }
            LonghandId::AnimationName => {
                false
            }
            LonghandId::AnimationPlayState => {
                false
            }
            LonghandId::AnimationTimingFunction => {
                false
            }
            LonghandId::BackgroundAttachment => {
                true
            }
            LonghandId::BackgroundBlendMode => {
                true
            }
            LonghandId::BackgroundClip => {
                true
            }
            LonghandId::BackgroundImage => {
                true
            }
            LonghandId::BackgroundOrigin => {
                true
            }
            LonghandId::BackgroundPositionX => {
                true
            }
            LonghandId::BackgroundPositionY => {
                true
            }
            LonghandId::BackgroundRepeat => {
                true
            }
            LonghandId::BackgroundSize => {
                true
            }
            LonghandId::BorderImageOutset => {
                true
            }
            LonghandId::BorderImageSlice => {
                true
            }
            LonghandId::BorderImageSource => {
                true
            }
            LonghandId::BorderImageWidth => {
                true
            }
            LonghandId::BorderSpacing => {
                true
            }
            LonghandId::BoxShadow => {
                true
            }
            LonghandId::CaretColor => {
                true
            }
            LonghandId::ClipPath => {
                true
            }
            LonghandId::Color => {
                true
            }
            LonghandId::ColumnGap => {
                true
            }
            LonghandId::ColumnWidth => {
                true
            }
            LonghandId::Content => {
                true
            }
            LonghandId::CounterIncrement => {
                true
            }
            LonghandId::CounterReset => {
                true
            }
            LonghandId::Cursor => {
                true
            }
            LonghandId::Display => {
                true
            }
            LonghandId::Filter => {
                true
            }
            LonghandId::FontFamily => {
                true
            }
            LonghandId::FontFeatureSettings => {
                true
            }
            LonghandId::FontLanguageOverride => {
                true
            }
            LonghandId::FontSize => {
                true
            }
            LonghandId::FontSizeAdjust => {
                true
            }
            LonghandId::FontVariantAlternates => {
                true
            }
            LonghandId::FontVariantEastAsian => {
                true
            }
            LonghandId::FontVariantLigatures => {
                true
            }
            LonghandId::FontVariantNumeric => {
                true
            }
            LonghandId::FontVariationSettings => {
                true
            }
            LonghandId::GridTemplateAreas => {
                true
            }
            LonghandId::LetterSpacing => {
                true
            }
            LonghandId::LineHeight => {
                true
            }
            LonghandId::ListStyleImage => {
                true
            }
            LonghandId::ListStyleType => {
                true
            }
            LonghandId::MaskClip => {
                true
            }
            LonghandId::MaskComposite => {
                true
            }
            LonghandId::MaskImage => {
                true
            }
            LonghandId::MaskMode => {
                true
            }
            LonghandId::MaskOrigin => {
                true
            }
            LonghandId::MaskPositionX => {
                true
            }
            LonghandId::MaskPositionY => {
                true
            }
            LonghandId::MaskRepeat => {
                true
            }
            LonghandId::MaskSize => {
                true
            }
            LonghandId::MozContextProperties => {
                false
            }
            LonghandId::MozTabSize => {
                true
            }
            LonghandId::OutlineOffset => {
                true
            }
            LonghandId::OverflowY => {
                true
            }
            LonghandId::Perspective => {
                true
            }
            LonghandId::PerspectiveOrigin => {
                true
            }
            LonghandId::Quotes => {
                true
            }
            LonghandId::Rotate => {
                true
            }
            LonghandId::Scale => {
                true
            }
            LonghandId::ScrollSnapCoordinate => {
                true
            }
            LonghandId::ShapeOutside => {
                true
            }
            LonghandId::StrokeDasharray => {
                true
            }
            LonghandId::StrokeDashoffset => {
                true
            }
            LonghandId::StrokeMiterlimit => {
                true
            }
            LonghandId::StrokeWidth => {
                true
            }
            LonghandId::TextAlign => {
                true
            }
            LonghandId::TextEmphasisPosition => {
                true
            }
            LonghandId::TextEmphasisStyle => {
                true
            }
            LonghandId::TextIndent => {
                true
            }
            LonghandId::TextOverflow => {
                true
            }
            LonghandId::TextShadow => {
                true
            }
            LonghandId::TransitionDelay => {
                false
            }
            LonghandId::TransitionDuration => {
                false
            }
            LonghandId::TransitionProperty => {
                false
            }
            LonghandId::TransitionTimingFunction => {
                false
            }
            LonghandId::Translate => {
                true
            }
            LonghandId::VerticalAlign => {
                true
            }
            LonghandId::WillChange => {
                true
            }
            LonghandId::WordSpacing => {
                true
            }
            LonghandId::XLang => {
                false
            }
            LonghandId::OverflowClipBoxBlock => {
                true
            }
            LonghandId::OverflowClipBoxInline => {
                true
            }
            LonghandId::FillOpacity => {
                true
            }
            LonghandId::StrokeOpacity => {
                true
            }
            LonghandId::ScrollSnapPointsX => {
                true
            }
            LonghandId::ScrollSnapPointsY => {
                true
            }
            LonghandId::MozWindowTransform => {
                true
            }
            LonghandId::Transform => {
                true
            }
            LonghandId::Clip => {
                true
            }
            LonghandId::MozImageRegion => {
                true
            }
            LonghandId::GridTemplateColumns => {
                true
            }
            LonghandId::GridTemplateRows => {
                true
            }
            LonghandId::ObjectPosition => {
                true
            }
            LonghandId::ScrollSnapDestination => {
                true
            }
            LonghandId::Fill => {
                true
            }
            LonghandId::Stroke => {
                true
            }
            LonghandId::GridAutoColumns => {
                true
            }
            LonghandId::GridAutoRows => {
                true
            }
            LonghandId::MozWindowTransformOrigin => {
                true
            }
            LonghandId::TransformOrigin => {
                true
            }
            LonghandId::MaxBlockSize => {
                false
            }
            LonghandId::MaxHeight => {
                true
            }
            LonghandId::MaxInlineSize => {
                false
            }
            LonghandId::MaxWidth => {
                true
            }
            LonghandId::FloodColor => {
                true
            }
            LonghandId::LightingColor => {
                true
            }
            LonghandId::MozFontSmoothingBackgroundColor => {
                true
            }
            LonghandId::StopColor => {
                true
            }
            LonghandId::MarkerEnd => {
                true
            }
            LonghandId::MarkerMid => {
                true
            }
            LonghandId::MarkerStart => {
                true
            }
            LonghandId::MozBinding => {
                false
            }
            LonghandId::GridColumnEnd => {
                true
            }
            LonghandId::GridColumnStart => {
                true
            }
            LonghandId::GridRowEnd => {
                true
            }
            LonghandId::GridRowStart => {
                true
            }
            LonghandId::BorderBottomLeftRadius => {
                true
            }
            LonghandId::BorderBottomRightRadius => {
                true
            }
            LonghandId::BorderTopLeftRadius => {
                true
            }
            LonghandId::BorderTopRightRadius => {
                true
            }
            LonghandId::MozOutlineRadiusBottomleft => {
                true
            }
            LonghandId::MozOutlineRadiusBottomright => {
                true
            }
            LonghandId::MozOutlineRadiusTopleft => {
                true
            }
            LonghandId::MozOutlineRadiusTopright => {
                true
            }
            LonghandId::BlockSize => {
                false
            }
            LonghandId::FlexBasis => {
                true
            }
            LonghandId::Height => {
                true
            }
            LonghandId::InlineSize => {
                false
            }
            LonghandId::MinBlockSize => {
                false
            }
            LonghandId::MinHeight => {
                true
            }
            LonghandId::MinInlineSize => {
                false
            }
            LonghandId::MinWidth => {
                true
            }
            LonghandId::Width => {
                true
            }
            LonghandId::GridColumnGap => {
                true
            }
            LonghandId::GridRowGap => {
                true
            }
            LonghandId::PaddingBlockEnd => {
                false
            }
            LonghandId::PaddingBlockStart => {
                false
            }
            LonghandId::PaddingBottom => {
                true
            }
            LonghandId::PaddingInlineEnd => {
                false
            }
            LonghandId::PaddingInlineStart => {
                false
            }
            LonghandId::PaddingLeft => {
                true
            }
            LonghandId::PaddingRight => {
                true
            }
            LonghandId::PaddingTop => {
                true
            }
            LonghandId::BorderBlockEndWidth => {
                false
            }
            LonghandId::BorderBlockStartWidth => {
                false
            }
            LonghandId::BorderBottomWidth => {
                true
            }
            LonghandId::BorderInlineEndWidth => {
                false
            }
            LonghandId::BorderInlineStartWidth => {
                false
            }
            LonghandId::BorderLeftWidth => {
                true
            }
            LonghandId::BorderRightWidth => {
                true
            }
            LonghandId::BorderTopWidth => {
                true
            }
            LonghandId::ColumnRuleWidth => {
                true
            }
            LonghandId::OutlineWidth => {
                true
            }
            LonghandId::WebkitTextStrokeWidth => {
                true
            }
            LonghandId::BackgroundColor => {
                true
            }
            LonghandId::BorderBlockEndColor => {
                false
            }
            LonghandId::BorderBlockStartColor => {
                false
            }
            LonghandId::BorderBottomColor => {
                true
            }
            LonghandId::BorderInlineEndColor => {
                false
            }
            LonghandId::BorderInlineStartColor => {
                false
            }
            LonghandId::BorderLeftColor => {
                true
            }
            LonghandId::BorderRightColor => {
                true
            }
            LonghandId::BorderTopColor => {
                true
            }
            LonghandId::ColumnRuleColor => {
                true
            }
            LonghandId::OutlineColor => {
                true
            }
            LonghandId::TextDecorationColor => {
                true
            }
            LonghandId::TextEmphasisColor => {
                true
            }
            LonghandId::WebkitTextFillColor => {
                true
            }
            LonghandId::WebkitTextStrokeColor => {
                true
            }
            LonghandId::Bottom => {
                true
            }
            LonghandId::Left => {
                true
            }
            LonghandId::MarginBlockEnd => {
                false
            }
            LonghandId::MarginBlockStart => {
                false
            }
            LonghandId::MarginBottom => {
                true
            }
            LonghandId::MarginInlineEnd => {
                false
            }
            LonghandId::MarginInlineStart => {
                false
            }
            LonghandId::MarginLeft => {
                true
            }
            LonghandId::MarginRight => {
                true
            }
            LonghandId::MarginTop => {
                true
            }
            LonghandId::OffsetBlockEnd => {
                false
            }
            LonghandId::OffsetBlockStart => {
                false
            }
            LonghandId::OffsetInlineEnd => {
                false
            }
            LonghandId::OffsetInlineStart => {
                false
            }
            LonghandId::Right => {
                true
            }
            LonghandId::Top => {
                true
            }
        }
    }

    /// Returns whether this property is animatable in a discrete way.
    pub fn is_discrete_animatable(self) -> bool {
        match self {
            LonghandId::AlignContent => {
                true
            }
            LonghandId::AlignItems => {
                true
            }
            LonghandId::AlignSelf => {
                true
            }
            LonghandId::BackfaceVisibility => {
                true
            }
            LonghandId::BorderCollapse => {
                true
            }
            LonghandId::BorderImageRepeat => {
                true
            }
            LonghandId::BoxDecorationBreak => {
                true
            }
            LonghandId::BoxSizing => {
                true
            }
            LonghandId::CaptionSide => {
                true
            }
            LonghandId::Clear => {
                true
            }
            LonghandId::ClipRule => {
                true
            }
            LonghandId::ColorAdjust => {
                true
            }
            LonghandId::ColorInterpolation => {
                true
            }
            LonghandId::ColorInterpolationFilters => {
                true
            }
            LonghandId::ColumnCount => {
                false
            }
            LonghandId::ColumnFill => {
                true
            }
            LonghandId::ColumnRuleStyle => {
                true
            }
            LonghandId::ColumnSpan => {
                true
            }
            LonghandId::Contain => {
                true
            }
            LonghandId::Direction => {
                true
            }
            LonghandId::DominantBaseline => {
                true
            }
            LonghandId::EmptyCells => {
                true
            }
            LonghandId::FillRule => {
                true
            }
            LonghandId::FlexDirection => {
                true
            }
            LonghandId::FlexWrap => {
                true
            }
            LonghandId::Float => {
                true
            }
            LonghandId::FontKerning => {
                true
            }
            LonghandId::FontOpticalSizing => {
                true
            }
            LonghandId::FontStretch => {
                false
            }
            LonghandId::FontStyle => {
                true
            }
            LonghandId::FontSynthesis => {
                true
            }
            LonghandId::FontVariantCaps => {
                true
            }
            LonghandId::FontVariantPosition => {
                true
            }
            LonghandId::FontWeight => {
                false
            }
            LonghandId::GridAutoFlow => {
                true
            }
            LonghandId::Hyphens => {
                true
            }
            LonghandId::ImageOrientation => {
                true
            }
            LonghandId::ImageRendering => {
                true
            }
            LonghandId::ImeMode => {
                true
            }
            LonghandId::InitialLetter => {
                true
            }
            LonghandId::Isolation => {
                true
            }
            LonghandId::JustifyContent => {
                true
            }
            LonghandId::JustifyItems => {
                true
            }
            LonghandId::JustifySelf => {
                true
            }
            LonghandId::ListStylePosition => {
                true
            }
            LonghandId::MaskType => {
                true
            }
            LonghandId::MixBlendMode => {
                true
            }
            LonghandId::MozAppearance => {
                true
            }
            LonghandId::MozBoxAlign => {
                true
            }
            LonghandId::MozBoxDirection => {
                true
            }
            LonghandId::MozBoxOrient => {
                true
            }
            LonghandId::MozBoxPack => {
                true
            }
            LonghandId::MozControlCharacterVisibility => {
                false
            }
            LonghandId::MozFloatEdge => {
                true
            }
            LonghandId::MozForceBrokenImageIcon => {
                true
            }
            LonghandId::MozMathDisplay => {
                false
            }
            LonghandId::MozMathVariant => {
                false
            }
            LonghandId::MozMinFontSizeRatio => {
                false
            }
            LonghandId::MozOrient => {
                true
            }
            LonghandId::MozOsxFontSmoothing => {
                true
            }
            LonghandId::MozScriptLevel => {
                false
            }
            LonghandId::MozScriptMinSize => {
                false
            }
            LonghandId::MozScriptSizeMultiplier => {
                false
            }
            LonghandId::MozStackSizing => {
                true
            }
            LonghandId::MozTextSizeAdjust => {
                true
            }
            LonghandId::MozTopLayer => {
                false
            }
            LonghandId::MozUserFocus => {
                true
            }
            LonghandId::MozUserInput => {
                true
            }
            LonghandId::MozUserModify => {
                true
            }
            LonghandId::MozUserSelect => {
                true
            }
            LonghandId::MozWindowDragging => {
                true
            }
            LonghandId::MozWindowShadow => {
                true
            }
            LonghandId::ObjectFit => {
                true
            }
            LonghandId::OutlineStyle => {
                true
            }
            LonghandId::OverflowWrap => {
                true
            }
            LonghandId::OverflowX => {
                true
            }
            LonghandId::PageBreakAfter => {
                true
            }
            LonghandId::PageBreakBefore => {
                true
            }
            LonghandId::PageBreakInside => {
                true
            }
            LonghandId::PaintOrder => {
                true
            }
            LonghandId::PointerEvents => {
                true
            }
            LonghandId::Position => {
                true
            }
            LonghandId::Resize => {
                true
            }
            LonghandId::RubyAlign => {
                true
            }
            LonghandId::RubyPosition => {
                true
            }
            LonghandId::ScrollBehavior => {
                true
            }
            LonghandId::ShapeRendering => {
                true
            }
            LonghandId::StrokeLinecap => {
                true
            }
            LonghandId::StrokeLinejoin => {
                true
            }
            LonghandId::TableLayout => {
                true
            }
            LonghandId::TextAlignLast => {
                true
            }
            LonghandId::TextAnchor => {
                true
            }
            LonghandId::TextCombineUpright => {
                true
            }
            LonghandId::TextDecorationLine => {
                true
            }
            LonghandId::TextDecorationStyle => {
                true
            }
            LonghandId::TextJustify => {
                true
            }
            LonghandId::TextOrientation => {
                true
            }
            LonghandId::TextRendering => {
                true
            }
            LonghandId::TextTransform => {
                true
            }
            LonghandId::TouchAction => {
                true
            }
            LonghandId::TransformBox => {
                true
            }
            LonghandId::TransformStyle => {
                true
            }
            LonghandId::UnicodeBidi => {
                true
            }
            LonghandId::VectorEffect => {
                true
            }
            LonghandId::Visibility => {
                false
            }
            LonghandId::WhiteSpace => {
                true
            }
            LonghandId::WordBreak => {
                true
            }
            LonghandId::WritingMode => {
                true
            }
            LonghandId::XSpan => {
                false
            }
            LonghandId::XTextZoom => {
                false
            }
            LonghandId::ZIndex => {
                false
            }
            LonghandId::MozBoxOrdinalGroup => {
                true
            }
            LonghandId::Order => {
                false
            }
            LonghandId::OverscrollBehaviorX => {
                true
            }
            LonghandId::OverscrollBehaviorY => {
                true
            }
            LonghandId::ScrollSnapTypeX => {
                true
            }
            LonghandId::ScrollSnapTypeY => {
                true
            }
            LonghandId::FlexGrow => {
                false
            }
            LonghandId::FlexShrink => {
                false
            }
            LonghandId::MozBoxFlex => {
                false
            }
            LonghandId::FloodOpacity => {
                false
            }
            LonghandId::MozWindowOpacity => {
                false
            }
            LonghandId::Opacity => {
                false
            }
            LonghandId::ShapeImageThreshold => {
                false
            }
            LonghandId::StopOpacity => {
                false
            }
            LonghandId::BorderBlockEndStyle => {
                false
            }
            LonghandId::BorderBlockStartStyle => {
                false
            }
            LonghandId::BorderBottomStyle => {
                true
            }
            LonghandId::BorderInlineEndStyle => {
                false
            }
            LonghandId::BorderInlineStartStyle => {
                false
            }
            LonghandId::BorderLeftStyle => {
                true
            }
            LonghandId::BorderRightStyle => {
                true
            }
            LonghandId::BorderTopStyle => {
                true
            }
            LonghandId::AnimationDelay => {
                false
            }
            LonghandId::AnimationDirection => {
                false
            }
            LonghandId::AnimationDuration => {
                false
            }
            LonghandId::AnimationFillMode => {
                false
            }
            LonghandId::AnimationIterationCount => {
                false
            }
            LonghandId::AnimationName => {
                false
            }
            LonghandId::AnimationPlayState => {
                false
            }
            LonghandId::AnimationTimingFunction => {
                false
            }
            LonghandId::BackgroundAttachment => {
                true
            }
            LonghandId::BackgroundBlendMode => {
                true
            }
            LonghandId::BackgroundClip => {
                true
            }
            LonghandId::BackgroundImage => {
                true
            }
            LonghandId::BackgroundOrigin => {
                true
            }
            LonghandId::BackgroundPositionX => {
                false
            }
            LonghandId::BackgroundPositionY => {
                false
            }
            LonghandId::BackgroundRepeat => {
                true
            }
            LonghandId::BackgroundSize => {
                false
            }
            LonghandId::BorderImageOutset => {
                true
            }
            LonghandId::BorderImageSlice => {
                true
            }
            LonghandId::BorderImageSource => {
                true
            }
            LonghandId::BorderImageWidth => {
                true
            }
            LonghandId::BorderSpacing => {
                false
            }
            LonghandId::BoxShadow => {
                false
            }
            LonghandId::CaretColor => {
                false
            }
            LonghandId::ClipPath => {
                false
            }
            LonghandId::Color => {
                false
            }
            LonghandId::ColumnGap => {
                false
            }
            LonghandId::ColumnWidth => {
                false
            }
            LonghandId::Content => {
                true
            }
            LonghandId::CounterIncrement => {
                true
            }
            LonghandId::CounterReset => {
                true
            }
            LonghandId::Cursor => {
                true
            }
            LonghandId::Display => {
                true
            }
            LonghandId::Filter => {
                false
            }
            LonghandId::FontFamily => {
                true
            }
            LonghandId::FontFeatureSettings => {
                true
            }
            LonghandId::FontLanguageOverride => {
                true
            }
            LonghandId::FontSize => {
                false
            }
            LonghandId::FontSizeAdjust => {
                false
            }
            LonghandId::FontVariantAlternates => {
                true
            }
            LonghandId::FontVariantEastAsian => {
                true
            }
            LonghandId::FontVariantLigatures => {
                true
            }
            LonghandId::FontVariantNumeric => {
                true
            }
            LonghandId::FontVariationSettings => {
                false
            }
            LonghandId::GridTemplateAreas => {
                true
            }
            LonghandId::LetterSpacing => {
                false
            }
            LonghandId::LineHeight => {
                false
            }
            LonghandId::ListStyleImage => {
                true
            }
            LonghandId::ListStyleType => {
                true
            }
            LonghandId::MaskClip => {
                true
            }
            LonghandId::MaskComposite => {
                true
            }
            LonghandId::MaskImage => {
                true
            }
            LonghandId::MaskMode => {
                true
            }
            LonghandId::MaskOrigin => {
                true
            }
            LonghandId::MaskPositionX => {
                false
            }
            LonghandId::MaskPositionY => {
                false
            }
            LonghandId::MaskRepeat => {
                true
            }
            LonghandId::MaskSize => {
                false
            }
            LonghandId::MozContextProperties => {
                false
            }
            LonghandId::MozTabSize => {
                false
            }
            LonghandId::OutlineOffset => {
                false
            }
            LonghandId::OverflowY => {
                true
            }
            LonghandId::Perspective => {
                false
            }
            LonghandId::PerspectiveOrigin => {
                false
            }
            LonghandId::Quotes => {
                true
            }
            LonghandId::Rotate => {
                false
            }
            LonghandId::Scale => {
                false
            }
            LonghandId::ScrollSnapCoordinate => {
                true
            }
            LonghandId::ShapeOutside => {
                false
            }
            LonghandId::StrokeDasharray => {
                false
            }
            LonghandId::StrokeDashoffset => {
                false
            }
            LonghandId::StrokeMiterlimit => {
                false
            }
            LonghandId::StrokeWidth => {
                false
            }
            LonghandId::TextAlign => {
                true
            }
            LonghandId::TextEmphasisPosition => {
                true
            }
            LonghandId::TextEmphasisStyle => {
                true
            }
            LonghandId::TextIndent => {
                false
            }
            LonghandId::TextOverflow => {
                true
            }
            LonghandId::TextShadow => {
                false
            }
            LonghandId::TransitionDelay => {
                false
            }
            LonghandId::TransitionDuration => {
                false
            }
            LonghandId::TransitionProperty => {
                false
            }
            LonghandId::TransitionTimingFunction => {
                false
            }
            LonghandId::Translate => {
                false
            }
            LonghandId::VerticalAlign => {
                false
            }
            LonghandId::WillChange => {
                true
            }
            LonghandId::WordSpacing => {
                false
            }
            LonghandId::XLang => {
                false
            }
            LonghandId::OverflowClipBoxBlock => {
                true
            }
            LonghandId::OverflowClipBoxInline => {
                true
            }
            LonghandId::FillOpacity => {
                false
            }
            LonghandId::StrokeOpacity => {
                false
            }
            LonghandId::ScrollSnapPointsX => {
                true
            }
            LonghandId::ScrollSnapPointsY => {
                true
            }
            LonghandId::MozWindowTransform => {
                false
            }
            LonghandId::Transform => {
                false
            }
            LonghandId::Clip => {
                false
            }
            LonghandId::MozImageRegion => {
                false
            }
            LonghandId::GridTemplateColumns => {
                true
            }
            LonghandId::GridTemplateRows => {
                true
            }
            LonghandId::ObjectPosition => {
                false
            }
            LonghandId::ScrollSnapDestination => {
                true
            }
            LonghandId::Fill => {
                false
            }
            LonghandId::Stroke => {
                false
            }
            LonghandId::GridAutoColumns => {
                true
            }
            LonghandId::GridAutoRows => {
                true
            }
            LonghandId::MozWindowTransformOrigin => {
                false
            }
            LonghandId::TransformOrigin => {
                false
            }
            LonghandId::MaxBlockSize => {
                false
            }
            LonghandId::MaxHeight => {
                false
            }
            LonghandId::MaxInlineSize => {
                false
            }
            LonghandId::MaxWidth => {
                false
            }
            LonghandId::FloodColor => {
                false
            }
            LonghandId::LightingColor => {
                false
            }
            LonghandId::MozFontSmoothingBackgroundColor => {
                false
            }
            LonghandId::StopColor => {
                false
            }
            LonghandId::MarkerEnd => {
                true
            }
            LonghandId::MarkerMid => {
                true
            }
            LonghandId::MarkerStart => {
                true
            }
            LonghandId::MozBinding => {
                false
            }
            LonghandId::GridColumnEnd => {
                true
            }
            LonghandId::GridColumnStart => {
                true
            }
            LonghandId::GridRowEnd => {
                true
            }
            LonghandId::GridRowStart => {
                true
            }
            LonghandId::BorderBottomLeftRadius => {
                false
            }
            LonghandId::BorderBottomRightRadius => {
                false
            }
            LonghandId::BorderTopLeftRadius => {
                false
            }
            LonghandId::BorderTopRightRadius => {
                false
            }
            LonghandId::MozOutlineRadiusBottomleft => {
                false
            }
            LonghandId::MozOutlineRadiusBottomright => {
                false
            }
            LonghandId::MozOutlineRadiusTopleft => {
                false
            }
            LonghandId::MozOutlineRadiusTopright => {
                false
            }
            LonghandId::BlockSize => {
                false
            }
            LonghandId::FlexBasis => {
                false
            }
            LonghandId::Height => {
                false
            }
            LonghandId::InlineSize => {
                false
            }
            LonghandId::MinBlockSize => {
                false
            }
            LonghandId::MinHeight => {
                false
            }
            LonghandId::MinInlineSize => {
                false
            }
            LonghandId::MinWidth => {
                false
            }
            LonghandId::Width => {
                false
            }
            LonghandId::GridColumnGap => {
                false
            }
            LonghandId::GridRowGap => {
                false
            }
            LonghandId::PaddingBlockEnd => {
                false
            }
            LonghandId::PaddingBlockStart => {
                false
            }
            LonghandId::PaddingBottom => {
                false
            }
            LonghandId::PaddingInlineEnd => {
                false
            }
            LonghandId::PaddingInlineStart => {
                false
            }
            LonghandId::PaddingLeft => {
                false
            }
            LonghandId::PaddingRight => {
                false
            }
            LonghandId::PaddingTop => {
                false
            }
            LonghandId::BorderBlockEndWidth => {
                false
            }
            LonghandId::BorderBlockStartWidth => {
                false
            }
            LonghandId::BorderBottomWidth => {
                false
            }
            LonghandId::BorderInlineEndWidth => {
                false
            }
            LonghandId::BorderInlineStartWidth => {
                false
            }
            LonghandId::BorderLeftWidth => {
                false
            }
            LonghandId::BorderRightWidth => {
                false
            }
            LonghandId::BorderTopWidth => {
                false
            }
            LonghandId::ColumnRuleWidth => {
                false
            }
            LonghandId::OutlineWidth => {
                false
            }
            LonghandId::WebkitTextStrokeWidth => {
                true
            }
            LonghandId::BackgroundColor => {
                false
            }
            LonghandId::BorderBlockEndColor => {
                false
            }
            LonghandId::BorderBlockStartColor => {
                false
            }
            LonghandId::BorderBottomColor => {
                false
            }
            LonghandId::BorderInlineEndColor => {
                false
            }
            LonghandId::BorderInlineStartColor => {
                false
            }
            LonghandId::BorderLeftColor => {
                false
            }
            LonghandId::BorderRightColor => {
                false
            }
            LonghandId::BorderTopColor => {
                false
            }
            LonghandId::ColumnRuleColor => {
                false
            }
            LonghandId::OutlineColor => {
                false
            }
            LonghandId::TextDecorationColor => {
                false
            }
            LonghandId::TextEmphasisColor => {
                false
            }
            LonghandId::WebkitTextFillColor => {
                false
            }
            LonghandId::WebkitTextStrokeColor => {
                false
            }
            LonghandId::Bottom => {
                false
            }
            LonghandId::Left => {
                false
            }
            LonghandId::MarginBlockEnd => {
                false
            }
            LonghandId::MarginBlockStart => {
                false
            }
            LonghandId::MarginBottom => {
                false
            }
            LonghandId::MarginInlineEnd => {
                false
            }
            LonghandId::MarginInlineStart => {
                false
            }
            LonghandId::MarginLeft => {
                false
            }
            LonghandId::MarginRight => {
                false
            }
            LonghandId::MarginTop => {
                false
            }
            LonghandId::OffsetBlockEnd => {
                false
            }
            LonghandId::OffsetBlockStart => {
                false
            }
            LonghandId::OffsetInlineEnd => {
                false
            }
            LonghandId::OffsetInlineStart => {
                false
            }
            LonghandId::Right => {
                false
            }
            LonghandId::Top => {
                false
            }
        }
    }

    /// Converts from a LonghandId to an adequate nsCSSPropertyID.
    #[cfg(feature = "gecko")]
    #[inline]
    pub fn to_nscsspropertyid(self) -> nsCSSPropertyID {
        NonCustomPropertyId::from(self).to_nscsspropertyid()
    }

    #[cfg(feature = "gecko")]
    #[allow(non_upper_case_globals)]
    /// Returns a longhand id from Gecko's nsCSSPropertyID.
    pub fn from_nscsspropertyid(id: nsCSSPropertyID) -> Result<Self, ()> {
        match PropertyId::from_nscsspropertyid(id) {
            Ok(PropertyId::Longhand(id)) |
            Ok(PropertyId::LonghandAlias(id, _)) => Ok(id),
            _ => Err(()),
        }
    }

    /// If this is a logical property, return the corresponding physical one in the given writing mode.
    /// Otherwise, return unchanged.
    pub fn to_physical(&self, wm: WritingMode) -> Self {
        match *self {
                    LonghandId::BorderBlockEndStyle => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopStyle
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftStyle
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomStyle
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightStyle
                            
                }
        }

                    }
                    LonghandId::BorderBlockStartStyle => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopStyle
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftStyle
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomStyle
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightStyle
                            
                }
        }

                    }
                    LonghandId::BorderInlineEndStyle => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopStyle
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftStyle
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomStyle
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightStyle
                            
                }
        }

                    }
                    LonghandId::BorderInlineStartStyle => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopStyle
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftStyle
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomStyle
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightStyle
                            
                }
        }

                    }
                    LonghandId::MaxBlockSize => {
                        
    
        
        if wm.is_vertical() {
            
                                LonghandId::MaxWidth
                            
        } else {
            
                                LonghandId::MaxHeight
                            
        }

                    }
                    LonghandId::MaxInlineSize => {
                        
    
        
        if wm.is_vertical() {
            
                                LonghandId::MaxHeight
                            
        } else {
            
                                LonghandId::MaxWidth
                            
        }

                    }
                    LonghandId::BlockSize => {
                        
    
        
        if wm.is_vertical() {
            
                                LonghandId::Width
                            
        } else {
            
                                LonghandId::Height
                            
        }

                    }
                    LonghandId::InlineSize => {
                        
    
        
        if wm.is_vertical() {
            
                                LonghandId::Height
                            
        } else {
            
                                LonghandId::Width
                            
        }

                    }
                    LonghandId::MinBlockSize => {
                        
    
        
        if wm.is_vertical() {
            
                                LonghandId::MinWidth
                            
        } else {
            
                                LonghandId::MinHeight
                            
        }

                    }
                    LonghandId::MinInlineSize => {
                        
    
        
        if wm.is_vertical() {
            
                                LonghandId::MinHeight
                            
        } else {
            
                                LonghandId::MinWidth
                            
        }

                    }
                    LonghandId::PaddingBlockEnd => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::PaddingTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::PaddingLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::PaddingBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::PaddingRight
                            
                }
        }

                    }
                    LonghandId::PaddingBlockStart => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::PaddingTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::PaddingLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::PaddingBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::PaddingRight
                            
                }
        }

                    }
                    LonghandId::PaddingInlineEnd => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::PaddingTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::PaddingLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::PaddingBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::PaddingRight
                            
                }
        }

                    }
                    LonghandId::PaddingInlineStart => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::PaddingTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::PaddingLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::PaddingBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::PaddingRight
                            
                }
        }

                    }
                    LonghandId::BorderBlockEndWidth => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopWidth
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftWidth
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomWidth
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightWidth
                            
                }
        }

                    }
                    LonghandId::BorderBlockStartWidth => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopWidth
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftWidth
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomWidth
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightWidth
                            
                }
        }

                    }
                    LonghandId::BorderInlineEndWidth => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopWidth
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftWidth
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomWidth
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightWidth
                            
                }
        }

                    }
                    LonghandId::BorderInlineStartWidth => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopWidth
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftWidth
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomWidth
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightWidth
                            
                }
        }

                    }
                    LonghandId::BorderBlockEndColor => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopColor
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftColor
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomColor
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightColor
                            
                }
        }

                    }
                    LonghandId::BorderBlockStartColor => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopColor
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftColor
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomColor
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightColor
                            
                }
        }

                    }
                    LonghandId::BorderInlineEndColor => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopColor
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftColor
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomColor
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightColor
                            
                }
        }

                    }
                    LonghandId::BorderInlineStartColor => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopColor
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftColor
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomColor
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightColor
                            
                }
        }

                    }
                    LonghandId::MarginBlockEnd => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::MarginTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::MarginLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::MarginBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::MarginRight
                            
                }
        }

                    }
                    LonghandId::MarginBlockStart => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::MarginTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::MarginLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::MarginBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::MarginRight
                            
                }
        }

                    }
                    LonghandId::MarginInlineEnd => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::MarginTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::MarginLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::MarginBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::MarginRight
                            
                }
        }

                    }
                    LonghandId::MarginInlineStart => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::MarginTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::MarginLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::MarginBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::MarginRight
                            
                }
        }

                    }
                    LonghandId::OffsetBlockEnd => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::Top
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::Left
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::Bottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::Right
                            
                }
        }

                    }
                    LonghandId::OffsetBlockStart => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::Top
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::Left
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::Bottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::Right
                            
                }
        }

                    }
                    LonghandId::OffsetInlineEnd => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::Top
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::Left
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::Bottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::Right
                            
                }
        }

                    }
                    LonghandId::OffsetInlineStart => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::Top
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::Left
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::Bottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::Right
                            
                }
        }

                    }
            _ => *self
        }
    }

    /// Returns PropertyFlags for given longhand property.
    pub fn flags(&self) -> PropertyFlags {
        match *self {
                LonghandId::AlignContent =>
                    PropertyFlags::empty(),
                LonghandId::AlignItems =>
                    PropertyFlags::empty(),
                LonghandId::AlignSelf =>
                    PropertyFlags::empty(),
                LonghandId::BackfaceVisibility =>
                    PropertyFlags::empty(),
                LonghandId::BorderCollapse =>
                    PropertyFlags::empty(),
                LonghandId::BorderImageRepeat =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BoxDecorationBreak =>
                    PropertyFlags::empty(),
                LonghandId::BoxSizing =>
                    PropertyFlags::empty(),
                LonghandId::CaptionSide =>
                    PropertyFlags::empty(),
                LonghandId::Clear =>
                    PropertyFlags::empty(),
                LonghandId::ClipRule =>
                    PropertyFlags::empty(),
                LonghandId::ColorAdjust =>
                    PropertyFlags::empty(),
                LonghandId::ColorInterpolation =>
                    PropertyFlags::empty(),
                LonghandId::ColorInterpolationFilters =>
                    PropertyFlags::empty(),
                LonghandId::ColumnCount =>
                    PropertyFlags::empty(),
                LonghandId::ColumnFill =>
                    PropertyFlags::empty(),
                LonghandId::ColumnRuleStyle =>
                    PropertyFlags::empty(),
                LonghandId::ColumnSpan =>
                    PropertyFlags::empty(),
                LonghandId::Contain =>
                        PropertyFlags::FIXPOS_CB |
                    PropertyFlags::empty(),
                LonghandId::Direction =>
                    PropertyFlags::empty(),
                LonghandId::DominantBaseline =>
                    PropertyFlags::empty(),
                LonghandId::EmptyCells =>
                    PropertyFlags::empty(),
                LonghandId::FillRule =>
                    PropertyFlags::empty(),
                LonghandId::FlexDirection =>
                    PropertyFlags::empty(),
                LonghandId::FlexWrap =>
                    PropertyFlags::empty(),
                LonghandId::Float =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::FontKerning =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontOpticalSizing =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontStretch =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontSynthesis =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontVariantCaps =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontVariantPosition =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontWeight =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::GridAutoFlow =>
                    PropertyFlags::empty(),
                LonghandId::Hyphens =>
                    PropertyFlags::empty(),
                LonghandId::ImageOrientation =>
                    PropertyFlags::empty(),
                LonghandId::ImageRendering =>
                    PropertyFlags::empty(),
                LonghandId::ImeMode =>
                    PropertyFlags::empty(),
                LonghandId::InitialLetter =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::Isolation =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                    PropertyFlags::empty(),
                LonghandId::JustifyContent =>
                    PropertyFlags::empty(),
                LonghandId::JustifyItems =>
                    PropertyFlags::empty(),
                LonghandId::JustifySelf =>
                    PropertyFlags::empty(),
                LonghandId::ListStylePosition =>
                    PropertyFlags::empty(),
                LonghandId::MaskType =>
                    PropertyFlags::empty(),
                LonghandId::MixBlendMode =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                    PropertyFlags::empty(),
                LonghandId::MozAppearance =>
                    PropertyFlags::empty(),
                LonghandId::MozBoxAlign =>
                    PropertyFlags::empty(),
                LonghandId::MozBoxDirection =>
                    PropertyFlags::empty(),
                LonghandId::MozBoxOrient =>
                    PropertyFlags::empty(),
                LonghandId::MozBoxPack =>
                    PropertyFlags::empty(),
                LonghandId::MozControlCharacterVisibility =>
                    PropertyFlags::empty(),
                LonghandId::MozFloatEdge =>
                    PropertyFlags::empty(),
                LonghandId::MozForceBrokenImageIcon =>
                    PropertyFlags::empty(),
                LonghandId::MozMathDisplay =>
                    PropertyFlags::empty(),
                LonghandId::MozMathVariant =>
                    PropertyFlags::empty(),
                LonghandId::MozMinFontSizeRatio =>
                    PropertyFlags::empty(),
                LonghandId::MozOrient =>
                    PropertyFlags::empty(),
                LonghandId::MozOsxFontSmoothing =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::MozScriptLevel =>
                    PropertyFlags::empty(),
                LonghandId::MozScriptMinSize =>
                    PropertyFlags::empty(),
                LonghandId::MozScriptSizeMultiplier =>
                    PropertyFlags::empty(),
                LonghandId::MozStackSizing =>
                    PropertyFlags::empty(),
                LonghandId::MozTextSizeAdjust =>
                    PropertyFlags::empty(),
                LonghandId::MozTopLayer =>
                    PropertyFlags::empty(),
                LonghandId::MozUserFocus =>
                    PropertyFlags::empty(),
                LonghandId::MozUserInput =>
                    PropertyFlags::empty(),
                LonghandId::MozUserModify =>
                    PropertyFlags::empty(),
                LonghandId::MozUserSelect =>
                    PropertyFlags::empty(),
                LonghandId::MozWindowDragging =>
                    PropertyFlags::empty(),
                LonghandId::MozWindowShadow =>
                    PropertyFlags::empty(),
                LonghandId::ObjectFit =>
                    PropertyFlags::empty(),
                LonghandId::OutlineStyle =>
                    PropertyFlags::empty(),
                LonghandId::OverflowWrap =>
                    PropertyFlags::empty(),
                LonghandId::OverflowX =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::PageBreakAfter =>
                    PropertyFlags::empty(),
                LonghandId::PageBreakBefore =>
                    PropertyFlags::empty(),
                LonghandId::PageBreakInside =>
                    PropertyFlags::empty(),
                LonghandId::PaintOrder =>
                    PropertyFlags::empty(),
                LonghandId::PointerEvents =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::Position =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                        PropertyFlags::ABSPOS_CB |
                    PropertyFlags::empty(),
                LonghandId::Resize =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::RubyAlign =>
                    PropertyFlags::empty(),
                LonghandId::RubyPosition =>
                    PropertyFlags::empty(),
                LonghandId::ScrollBehavior =>
                    PropertyFlags::empty(),
                LonghandId::ShapeRendering =>
                    PropertyFlags::empty(),
                LonghandId::StrokeLinecap =>
                    PropertyFlags::empty(),
                LonghandId::StrokeLinejoin =>
                    PropertyFlags::empty(),
                LonghandId::TableLayout =>
                    PropertyFlags::empty(),
                LonghandId::TextAlignLast =>
                    PropertyFlags::empty(),
                LonghandId::TextAnchor =>
                    PropertyFlags::empty(),
                LonghandId::TextCombineUpright =>
                    PropertyFlags::empty(),
                LonghandId::TextDecorationLine =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::TextDecorationStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::TextJustify =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::TextOrientation =>
                    PropertyFlags::empty(),
                LonghandId::TextRendering =>
                    PropertyFlags::empty(),
                LonghandId::TextTransform =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::TouchAction =>
                    PropertyFlags::empty(),
                LonghandId::TransformBox =>
                    PropertyFlags::empty(),
                LonghandId::TransformStyle =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                        PropertyFlags::FIXPOS_CB |
                    PropertyFlags::empty(),
                LonghandId::UnicodeBidi =>
                    PropertyFlags::empty(),
                LonghandId::VectorEffect =>
                    PropertyFlags::empty(),
                LonghandId::Visibility =>
                    PropertyFlags::empty(),
                LonghandId::WhiteSpace =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::WordBreak =>
                    PropertyFlags::empty(),
                LonghandId::WritingMode =>
                    PropertyFlags::empty(),
                LonghandId::XSpan =>
                    PropertyFlags::empty(),
                LonghandId::XTextZoom =>
                    PropertyFlags::empty(),
                LonghandId::ZIndex =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                    PropertyFlags::empty(),
                LonghandId::MozBoxOrdinalGroup =>
                    PropertyFlags::empty(),
                LonghandId::Order =>
                    PropertyFlags::empty(),
                LonghandId::OverscrollBehaviorX =>
                    PropertyFlags::empty(),
                LonghandId::OverscrollBehaviorY =>
                    PropertyFlags::empty(),
                LonghandId::ScrollSnapTypeX =>
                    PropertyFlags::empty(),
                LonghandId::ScrollSnapTypeY =>
                    PropertyFlags::empty(),
                LonghandId::FlexGrow =>
                    PropertyFlags::empty(),
                LonghandId::FlexShrink =>
                    PropertyFlags::empty(),
                LonghandId::MozBoxFlex =>
                    PropertyFlags::empty(),
                LonghandId::FloodOpacity =>
                    PropertyFlags::empty(),
                LonghandId::MozWindowOpacity =>
                    PropertyFlags::empty(),
                LonghandId::Opacity =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::ShapeImageThreshold =>
                    PropertyFlags::empty(),
                LonghandId::StopOpacity =>
                    PropertyFlags::empty(),
                LonghandId::BorderBlockEndStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBlockStartStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBottomStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderInlineEndStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderInlineStartStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderLeftStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderRightStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderTopStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::AnimationDelay =>
                    PropertyFlags::empty(),
                LonghandId::AnimationDirection =>
                    PropertyFlags::empty(),
                LonghandId::AnimationDuration =>
                    PropertyFlags::empty(),
                LonghandId::AnimationFillMode =>
                    PropertyFlags::empty(),
                LonghandId::AnimationIterationCount =>
                    PropertyFlags::empty(),
                LonghandId::AnimationName =>
                    PropertyFlags::empty(),
                LonghandId::AnimationPlayState =>
                    PropertyFlags::empty(),
                LonghandId::AnimationTimingFunction =>
                    PropertyFlags::empty(),
                LonghandId::BackgroundAttachment =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundBlendMode =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundClip =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundImage =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundOrigin =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundPositionX =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundPositionY =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundRepeat =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundSize =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BorderImageOutset =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderImageSlice =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderImageSource =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderImageWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderSpacing =>
                    PropertyFlags::empty(),
                LonghandId::BoxShadow =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::CaretColor =>
                    PropertyFlags::empty(),
                LonghandId::ClipPath =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                    PropertyFlags::empty(),
                LonghandId::Color =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::ColumnGap =>
                    PropertyFlags::empty(),
                LonghandId::ColumnWidth =>
                    PropertyFlags::empty(),
                LonghandId::Content =>
                    PropertyFlags::empty(),
                LonghandId::CounterIncrement =>
                    PropertyFlags::empty(),
                LonghandId::CounterReset =>
                    PropertyFlags::empty(),
                LonghandId::Cursor =>
                    PropertyFlags::empty(),
                LonghandId::Display =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::Filter =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                        PropertyFlags::FIXPOS_CB |
                    PropertyFlags::empty(),
                LonghandId::FontFamily =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontFeatureSettings =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontLanguageOverride =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontSize =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontSizeAdjust =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontVariantAlternates =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontVariantEastAsian =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontVariantLigatures =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontVariantNumeric =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontVariationSettings =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::GridTemplateAreas =>
                    PropertyFlags::empty(),
                LonghandId::LetterSpacing =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::LineHeight =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::ListStyleImage =>
                    PropertyFlags::empty(),
                LonghandId::ListStyleType =>
                    PropertyFlags::empty(),
                LonghandId::MaskClip =>
                    PropertyFlags::empty(),
                LonghandId::MaskComposite =>
                    PropertyFlags::empty(),
                LonghandId::MaskImage =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                    PropertyFlags::empty(),
                LonghandId::MaskMode =>
                    PropertyFlags::empty(),
                LonghandId::MaskOrigin =>
                    PropertyFlags::empty(),
                LonghandId::MaskPositionX =>
                    PropertyFlags::empty(),
                LonghandId::MaskPositionY =>
                    PropertyFlags::empty(),
                LonghandId::MaskRepeat =>
                    PropertyFlags::empty(),
                LonghandId::MaskSize =>
                    PropertyFlags::empty(),
                LonghandId::MozContextProperties =>
                    PropertyFlags::empty(),
                LonghandId::MozTabSize =>
                    PropertyFlags::empty(),
                LonghandId::OutlineOffset =>
                    PropertyFlags::empty(),
                LonghandId::OverflowY =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::Perspective =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                        PropertyFlags::FIXPOS_CB |
                    PropertyFlags::empty(),
                LonghandId::PerspectiveOrigin =>
                    PropertyFlags::empty(),
                LonghandId::Quotes =>
                    PropertyFlags::empty(),
                LonghandId::Rotate =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                        PropertyFlags::FIXPOS_CB |
                    PropertyFlags::empty(),
                LonghandId::Scale =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                        PropertyFlags::FIXPOS_CB |
                    PropertyFlags::empty(),
                LonghandId::ScrollSnapCoordinate =>
                    PropertyFlags::empty(),
                LonghandId::ShapeOutside =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::StrokeDasharray =>
                    PropertyFlags::empty(),
                LonghandId::StrokeDashoffset =>
                    PropertyFlags::empty(),
                LonghandId::StrokeMiterlimit =>
                    PropertyFlags::empty(),
                LonghandId::StrokeWidth =>
                    PropertyFlags::empty(),
                LonghandId::TextAlign =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::TextEmphasisPosition =>
                    PropertyFlags::empty(),
                LonghandId::TextEmphasisStyle =>
                    PropertyFlags::empty(),
                LonghandId::TextIndent =>
                    PropertyFlags::empty(),
                LonghandId::TextOverflow =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::TextShadow =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::TransitionDelay =>
                    PropertyFlags::empty(),
                LonghandId::TransitionDuration =>
                    PropertyFlags::empty(),
                LonghandId::TransitionProperty =>
                    PropertyFlags::empty(),
                LonghandId::TransitionTimingFunction =>
                    PropertyFlags::empty(),
                LonghandId::Translate =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                        PropertyFlags::FIXPOS_CB |
                    PropertyFlags::empty(),
                LonghandId::VerticalAlign =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::WillChange =>
                    PropertyFlags::empty(),
                LonghandId::WordSpacing =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::XLang =>
                    PropertyFlags::empty(),
                LonghandId::OverflowClipBoxBlock =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::OverflowClipBoxInline =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FillOpacity =>
                    PropertyFlags::empty(),
                LonghandId::StrokeOpacity =>
                    PropertyFlags::empty(),
                LonghandId::ScrollSnapPointsX =>
                    PropertyFlags::empty(),
                LonghandId::ScrollSnapPointsY =>
                    PropertyFlags::empty(),
                LonghandId::MozWindowTransform =>
                    PropertyFlags::empty(),
                LonghandId::Transform =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                        PropertyFlags::FIXPOS_CB |
                    PropertyFlags::empty(),
                LonghandId::Clip =>
                    PropertyFlags::empty(),
                LonghandId::MozImageRegion =>
                    PropertyFlags::empty(),
                LonghandId::GridTemplateColumns =>
                    PropertyFlags::empty(),
                LonghandId::GridTemplateRows =>
                    PropertyFlags::empty(),
                LonghandId::ObjectPosition =>
                    PropertyFlags::empty(),
                LonghandId::ScrollSnapDestination =>
                    PropertyFlags::empty(),
                LonghandId::Fill =>
                    PropertyFlags::empty(),
                LonghandId::Stroke =>
                    PropertyFlags::empty(),
                LonghandId::GridAutoColumns =>
                    PropertyFlags::empty(),
                LonghandId::GridAutoRows =>
                    PropertyFlags::empty(),
                LonghandId::MozWindowTransformOrigin =>
                    PropertyFlags::empty(),
                LonghandId::TransformOrigin =>
                    PropertyFlags::empty(),
                LonghandId::MaxBlockSize =>
                    PropertyFlags::empty(),
                LonghandId::MaxHeight =>
                    PropertyFlags::empty(),
                LonghandId::MaxInlineSize =>
                    PropertyFlags::empty(),
                LonghandId::MaxWidth =>
                    PropertyFlags::empty(),
                LonghandId::FloodColor =>
                    PropertyFlags::empty(),
                LonghandId::LightingColor =>
                    PropertyFlags::empty(),
                LonghandId::MozFontSmoothingBackgroundColor =>
                    PropertyFlags::empty(),
                LonghandId::StopColor =>
                    PropertyFlags::empty(),
                LonghandId::MarkerEnd =>
                    PropertyFlags::empty(),
                LonghandId::MarkerMid =>
                    PropertyFlags::empty(),
                LonghandId::MarkerStart =>
                    PropertyFlags::empty(),
                LonghandId::MozBinding =>
                    PropertyFlags::empty(),
                LonghandId::GridColumnEnd =>
                    PropertyFlags::empty(),
                LonghandId::GridColumnStart =>
                    PropertyFlags::empty(),
                LonghandId::GridRowEnd =>
                    PropertyFlags::empty(),
                LonghandId::GridRowStart =>
                    PropertyFlags::empty(),
                LonghandId::BorderBottomLeftRadius =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBottomRightRadius =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderTopLeftRadius =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderTopRightRadius =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MozOutlineRadiusBottomleft =>
                    PropertyFlags::empty(),
                LonghandId::MozOutlineRadiusBottomright =>
                    PropertyFlags::empty(),
                LonghandId::MozOutlineRadiusTopleft =>
                    PropertyFlags::empty(),
                LonghandId::MozOutlineRadiusTopright =>
                    PropertyFlags::empty(),
                LonghandId::BlockSize =>
                    PropertyFlags::empty(),
                LonghandId::FlexBasis =>
                    PropertyFlags::empty(),
                LonghandId::Height =>
                    PropertyFlags::empty(),
                LonghandId::InlineSize =>
                    PropertyFlags::empty(),
                LonghandId::MinBlockSize =>
                    PropertyFlags::empty(),
                LonghandId::MinHeight =>
                    PropertyFlags::empty(),
                LonghandId::MinInlineSize =>
                    PropertyFlags::empty(),
                LonghandId::MinWidth =>
                    PropertyFlags::empty(),
                LonghandId::Width =>
                    PropertyFlags::empty(),
                LonghandId::GridColumnGap =>
                    PropertyFlags::empty(),
                LonghandId::GridRowGap =>
                    PropertyFlags::empty(),
                LonghandId::PaddingBlockEnd =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::PaddingBlockStart =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::PaddingBottom =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::PaddingInlineEnd =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::PaddingInlineStart =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::PaddingLeft =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::PaddingRight =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::PaddingTop =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BorderBlockEndWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBlockStartWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBottomWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderInlineEndWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderInlineStartWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderLeftWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderRightWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderTopWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::ColumnRuleWidth =>
                    PropertyFlags::empty(),
                LonghandId::OutlineWidth =>
                    PropertyFlags::empty(),
                LonghandId::WebkitTextStrokeWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BorderBlockEndColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBlockStartColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBottomColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderInlineEndColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderInlineStartColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderLeftColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderRightColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderTopColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::ColumnRuleColor =>
                    PropertyFlags::empty(),
                LonghandId::OutlineColor =>
                    PropertyFlags::empty(),
                LonghandId::TextDecorationColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::TextEmphasisColor =>
                    PropertyFlags::empty(),
                LonghandId::WebkitTextFillColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::WebkitTextStrokeColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::Bottom =>
                    PropertyFlags::empty(),
                LonghandId::Left =>
                    PropertyFlags::empty(),
                LonghandId::MarginBlockEnd =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MarginBlockStart =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MarginBottom =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MarginInlineEnd =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MarginInlineStart =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MarginLeft =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MarginRight =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MarginTop =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::OffsetBlockEnd =>
                    PropertyFlags::empty(),
                LonghandId::OffsetBlockStart =>
                    PropertyFlags::empty(),
                LonghandId::OffsetInlineEnd =>
                    PropertyFlags::empty(),
                LonghandId::OffsetInlineStart =>
                    PropertyFlags::empty(),
                LonghandId::Right =>
                    PropertyFlags::empty(),
                LonghandId::Top =>
                    PropertyFlags::empty(),
        }
    }

    /// Only a few properties are allowed to depend on the visited state of
    /// links. When cascading visited styles, we can save time by only
    /// processing these properties.
    fn is_visited_dependent(&self) -> bool {
        matches!(*self,
            LonghandId::ColumnRuleColor |
            LonghandId::TextEmphasisColor |
            LonghandId::WebkitTextFillColor |
            LonghandId::WebkitTextStrokeColor |
            LonghandId::TextDecorationColor |
            LonghandId::Fill |
            LonghandId::Stroke |
            LonghandId::CaretColor |
            LonghandId::Color |
            LonghandId::BackgroundColor |
            LonghandId::BorderTopColor |
            LonghandId::BorderRightColor |
            LonghandId::BorderBottomColor |
            LonghandId::BorderLeftColor |
            LonghandId::OutlineColor
        )
    }

    /// Returns true if the property is one that is ignored when document
    /// colors are disabled.
    fn is_ignored_when_document_colors_disabled(
        &self,
        cascade_level: CascadeLevel,
        pseudo: Option<&PseudoElement>,
    ) -> bool {
        let is_ua_or_user_rule = matches!(
            cascade_level,
            CascadeLevel::UANormal |
            CascadeLevel::UserNormal |
            CascadeLevel::UserImportant |
            CascadeLevel::UAImportant
        );

        if is_ua_or_user_rule {
            return false;
        }

        let is_style_attribute = matches!(
            cascade_level,
            CascadeLevel::StyleAttributeNormal |
            CascadeLevel::StyleAttributeImportant
        );
        // Don't override colors on pseudo-element's style attributes. The
        // background-color on ::-moz-color-swatch is an example. Those are set
        // as an author style (via the style attribute), but it's pretty
        // important for it to show up for obvious reasons :)
        if pseudo.is_some() && is_style_attribute {
            return false;
        }

        matches!(*self,
            LonghandId::BackgroundImage | LonghandId::BoxShadow | LonghandId::CaretColor | LonghandId::Color | LonghandId::TextShadow | LonghandId::BackgroundColor | LonghandId::BorderBlockEndColor | LonghandId::BorderBlockStartColor | LonghandId::BorderBottomColor | LonghandId::BorderInlineEndColor | LonghandId::BorderInlineStartColor | LonghandId::BorderLeftColor | LonghandId::BorderRightColor | LonghandId::BorderTopColor | LonghandId::ColumnRuleColor | LonghandId::OutlineColor | LonghandId::TextDecorationColor | LonghandId::TextEmphasisColor | LonghandId::WebkitTextFillColor | LonghandId::WebkitTextStrokeColor
        )
    }

    /// The computed value of some properties depends on the (sometimes
    /// computed) value of *other* properties.
    ///
    /// So we classify properties into "early" and "other", such that the only
    /// dependencies can be from "other" to "early".
    ///
    /// Unfortunately, it’s not easy to check that this classification is
    /// correct.
    fn is_early_property(&self) -> bool {
        matches!(*self,

            // Needed to properly compute the writing mode, to resolve logical
            // properties, and similar stuff. In this block instead of along
            // `WritingMode` and `Direction` just for convenience, since it's
            // Gecko-only (for now at least).
            //
            // see WritingMode::new.
            LonghandId::TextOrientation |

            // Needed to properly compute the zoomed font-size.
            //
            // FIXME(emilio): This could probably just be a cascade flag like
            // IN_SVG_SUBTREE or such, and we could nuke this property.
            LonghandId::XTextZoom |

            // Needed to do font-size computation in a language-dependent way.
            LonghandId::XLang |
            // Needed for ruby to respect language-dependent min-font-size
            // preferences properly, see bug 1165538.
            LonghandId::MozMinFontSizeRatio |

            // Needed to do font-size for MathML. :(
            LonghandId::MozScriptLevel |

            // Needed to compute font-relative lengths correctly.
            LonghandId::FontSize |
            LonghandId::FontFamily |

            // Needed to resolve currentcolor at computed value time properly.
            //
            // FIXME(emilio): All the properties should be moved to currentcolor
            // as a computed-value (and thus resolving it at used-value time).
            //
            // This would allow this property to go away from this list.
            LonghandId::Color |

            // FIXME(emilio): There's no reason for this afaict, nuke it.
            LonghandId::TextDecorationLine |

            // Needed to properly compute the writing mode, to resolve logical
            // properties, and similar stuff.
            LonghandId::WritingMode |
            LonghandId::Direction
        )
    }

    /// Whether computed values of this property lossily convert any complex
    /// colors into RGBA colors.
    ///
    /// In Gecko, there are some properties still that compute currentcolor
    /// down to an RGBA color at computed value time, instead of as
    /// `StyleComplexColor`s. For these properties, we must return `false`,
    /// so that we correctly avoid caching style data in the rule tree.
    pub fn stores_complex_colors_lossily(&self) -> bool {
        matches!(*self,
            LonghandId::FloodColor |
            LonghandId::LightingColor |
            LonghandId::MozFontSmoothingBackgroundColor |
            LonghandId::StopColor |
            LonghandId::BackgroundImage |
            LonghandId::BorderImageSource |
            LonghandId::BoxShadow |
            LonghandId::MaskImage |
            LonghandId::TextShadow
        )
    }
}

/// An iterator over all the property ids that are enabled for a given
/// shorthand, if that shorthand is enabled for all content too.
pub struct NonCustomPropertyIterator<Item: 'static> {
    filter: bool,
    iter: ::std::slice::Iter<'static, Item>,
}

impl<Item> Iterator for NonCustomPropertyIterator<Item>
where
    Item: 'static + Copy + Into<NonCustomPropertyId>,
{
    type Item = Item;

    fn next(&mut self) -> Option<Self::Item> {
        loop {
            let id = *self.iter.next()?;
            if !self.filter || id.into().enabled_for_all_content() {
                return Some(id)
            }
        }
    }
}

/// An identifier for a given shorthand property.
#[derive(Clone, Copy, Debug, Eq, Hash, MallocSizeOf, PartialEq)]
pub enum ShorthandId {
        /// background
        Background,
        /// background-position
        BackgroundPosition,
        /// border-color
        BorderColor,
        /// border-style
        BorderStyle,
        /// border-width
        BorderWidth,
        /// border-top
        BorderTop,
        /// border-left
        BorderLeft,
        /// border-bottom
        BorderBottom,
        /// border-right
        BorderRight,
        /// border-block-start
        BorderBlockStart,
        /// border-block-end
        BorderBlockEnd,
        /// border-inline-start
        BorderInlineStart,
        /// border-inline-end
        BorderInlineEnd,
        /// border
        Border,
        /// border-radius
        BorderRadius,
        /// border-image
        BorderImage,
        /// overflow
        Overflow,
        /// overflow-clip-box
        OverflowClipBox,
        /// transition
        Transition,
        /// animation
        Animation,
        /// scroll-snap-type
        ScrollSnapType,
        /// overscroll-behavior
        OverscrollBehavior,
        /// columns
        Columns,
        /// column-rule
        ColumnRule,
        /// font
        Font,
        /// font-variant
        FontVariant,
        /// text-emphasis
        TextEmphasis,
        /// -webkit-text-stroke
        WebkitTextStroke,
        /// list-style
        ListStyle,
        /// margin
        Margin,
        /// mask
        Mask,
        /// mask-position
        MaskPosition,
        /// outline
        Outline,
        /// -moz-outline-radius
        MozOutlineRadius,
        /// padding
        Padding,
        /// flex-flow
        FlexFlow,
        /// flex
        Flex,
        /// grid-gap
        GridGap,
        /// grid-row
        GridRow,
        /// grid-column
        GridColumn,
        /// grid-area
        GridArea,
        /// grid-template
        GridTemplate,
        /// grid
        Grid,
        /// place-content
        PlaceContent,
        /// place-self
        PlaceSelf,
        /// place-items
        PlaceItems,
        /// marker
        Marker,
        /// text-decoration
        TextDecoration,
        /// all
        All,
}

impl ToCss for ShorthandId {
    #[inline]
    fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
    where
        W: Write,
    {
        dest.write_str(self.name())
    }
}

impl ShorthandId {
    /// Get the name for this shorthand property.
    pub fn name(&self) -> &'static str {
        match *self {
                ShorthandId::Background => "background",
                ShorthandId::BackgroundPosition => "background-position",
                ShorthandId::BorderColor => "border-color",
                ShorthandId::BorderStyle => "border-style",
                ShorthandId::BorderWidth => "border-width",
                ShorthandId::BorderTop => "border-top",
                ShorthandId::BorderLeft => "border-left",
                ShorthandId::BorderBottom => "border-bottom",
                ShorthandId::BorderRight => "border-right",
                ShorthandId::BorderBlockStart => "border-block-start",
                ShorthandId::BorderBlockEnd => "border-block-end",
                ShorthandId::BorderInlineStart => "border-inline-start",
                ShorthandId::BorderInlineEnd => "border-inline-end",
                ShorthandId::Border => "border",
                ShorthandId::BorderRadius => "border-radius",
                ShorthandId::BorderImage => "border-image",
                ShorthandId::Overflow => "overflow",
                ShorthandId::OverflowClipBox => "overflow-clip-box",
                ShorthandId::Transition => "transition",
                ShorthandId::Animation => "animation",
                ShorthandId::ScrollSnapType => "scroll-snap-type",
                ShorthandId::OverscrollBehavior => "overscroll-behavior",
                ShorthandId::Columns => "columns",
                ShorthandId::ColumnRule => "column-rule",
                ShorthandId::Font => "font",
                ShorthandId::FontVariant => "font-variant",
                ShorthandId::TextEmphasis => "text-emphasis",
                ShorthandId::WebkitTextStroke => "-webkit-text-stroke",
                ShorthandId::ListStyle => "list-style",
                ShorthandId::Margin => "margin",
                ShorthandId::Mask => "mask",
                ShorthandId::MaskPosition => "mask-position",
                ShorthandId::Outline => "outline",
                ShorthandId::MozOutlineRadius => "-moz-outline-radius",
                ShorthandId::Padding => "padding",
                ShorthandId::FlexFlow => "flex-flow",
                ShorthandId::Flex => "flex",
                ShorthandId::GridGap => "grid-gap",
                ShorthandId::GridRow => "grid-row",
                ShorthandId::GridColumn => "grid-column",
                ShorthandId::GridArea => "grid-area",
                ShorthandId::GridTemplate => "grid-template",
                ShorthandId::Grid => "grid",
                ShorthandId::PlaceContent => "place-content",
                ShorthandId::PlaceSelf => "place-self",
                ShorthandId::PlaceItems => "place-items",
                ShorthandId::Marker => "marker",
                ShorthandId::TextDecoration => "text-decoration",
                ShorthandId::All => "all",
        }
    }

    /// Converts from a ShorthandId to an adequate nsCSSPropertyID.
    #[cfg(feature = "gecko")]
    #[inline]
    pub fn to_nscsspropertyid(self) -> nsCSSPropertyID {
        NonCustomPropertyId::from(self).to_nscsspropertyid()
    }

    /// Get the longhand ids that form this shorthand.
    pub fn longhands(&self) -> NonCustomPropertyIterator<LonghandId> {
            static BACKGROUND: &'static [LonghandId] = &[
                    LonghandId::BackgroundColor,
                    LonghandId::BackgroundPositionX,
                    LonghandId::BackgroundPositionY,
                    LonghandId::BackgroundRepeat,
                    LonghandId::BackgroundAttachment,
                    LonghandId::BackgroundImage,
                    LonghandId::BackgroundSize,
                    LonghandId::BackgroundOrigin,
                    LonghandId::BackgroundClip,
            ];
            static BACKGROUND_POSITION: &'static [LonghandId] = &[
                    LonghandId::BackgroundPositionX,
                    LonghandId::BackgroundPositionY,
            ];
            static BORDER_COLOR: &'static [LonghandId] = &[
                    LonghandId::BorderTopColor,
                    LonghandId::BorderRightColor,
                    LonghandId::BorderBottomColor,
                    LonghandId::BorderLeftColor,
            ];
            static BORDER_STYLE: &'static [LonghandId] = &[
                    LonghandId::BorderTopStyle,
                    LonghandId::BorderRightStyle,
                    LonghandId::BorderBottomStyle,
                    LonghandId::BorderLeftStyle,
            ];
            static BORDER_WIDTH: &'static [LonghandId] = &[
                    LonghandId::BorderTopWidth,
                    LonghandId::BorderLeftWidth,
                    LonghandId::BorderBottomWidth,
                    LonghandId::BorderRightWidth,
            ];
            static BORDER_TOP: &'static [LonghandId] = &[
                    LonghandId::BorderTopColor,
                    LonghandId::BorderTopStyle,
                    LonghandId::BorderTopWidth,
            ];
            static BORDER_LEFT: &'static [LonghandId] = &[
                    LonghandId::BorderLeftColor,
                    LonghandId::BorderLeftStyle,
                    LonghandId::BorderLeftWidth,
            ];
            static BORDER_BOTTOM: &'static [LonghandId] = &[
                    LonghandId::BorderBottomColor,
                    LonghandId::BorderBottomStyle,
                    LonghandId::BorderBottomWidth,
            ];
            static BORDER_RIGHT: &'static [LonghandId] = &[
                    LonghandId::BorderRightColor,
                    LonghandId::BorderRightStyle,
                    LonghandId::BorderRightWidth,
            ];
            static BORDER_BLOCK_START: &'static [LonghandId] = &[
                    LonghandId::BorderBlockStartColor,
                    LonghandId::BorderBlockStartStyle,
                    LonghandId::BorderBlockStartWidth,
            ];
            static BORDER_BLOCK_END: &'static [LonghandId] = &[
                    LonghandId::BorderBlockEndColor,
                    LonghandId::BorderBlockEndStyle,
                    LonghandId::BorderBlockEndWidth,
            ];
            static BORDER_INLINE_START: &'static [LonghandId] = &[
                    LonghandId::BorderInlineStartColor,
                    LonghandId::BorderInlineStartStyle,
                    LonghandId::BorderInlineStartWidth,
            ];
            static BORDER_INLINE_END: &'static [LonghandId] = &[
                    LonghandId::BorderInlineEndColor,
                    LonghandId::BorderInlineEndStyle,
                    LonghandId::BorderInlineEndWidth,
            ];
            static BORDER: &'static [LonghandId] = &[
                    LonghandId::BorderTopColor,
                    LonghandId::BorderTopStyle,
                    LonghandId::BorderTopWidth,
                    LonghandId::BorderLeftColor,
                    LonghandId::BorderLeftStyle,
                    LonghandId::BorderLeftWidth,
                    LonghandId::BorderBottomColor,
                    LonghandId::BorderBottomStyle,
                    LonghandId::BorderBottomWidth,
                    LonghandId::BorderRightColor,
                    LonghandId::BorderRightStyle,
                    LonghandId::BorderRightWidth,
                    LonghandId::BorderImageOutset,
                    LonghandId::BorderImageRepeat,
                    LonghandId::BorderImageSlice,
                    LonghandId::BorderImageSource,
                    LonghandId::BorderImageWidth,
            ];
            static BORDER_RADIUS: &'static [LonghandId] = &[
                    LonghandId::BorderTopLeftRadius,
                    LonghandId::BorderTopRightRadius,
                    LonghandId::BorderBottomRightRadius,
                    LonghandId::BorderBottomLeftRadius,
            ];
            static BORDER_IMAGE: &'static [LonghandId] = &[
                    LonghandId::BorderImageOutset,
                    LonghandId::BorderImageRepeat,
                    LonghandId::BorderImageSlice,
                    LonghandId::BorderImageSource,
                    LonghandId::BorderImageWidth,
            ];
            static OVERFLOW: &'static [LonghandId] = &[
                    LonghandId::OverflowX,
                    LonghandId::OverflowY,
            ];
            static OVERFLOW_CLIP_BOX: &'static [LonghandId] = &[
                    LonghandId::OverflowClipBoxBlock,
                    LonghandId::OverflowClipBoxInline,
            ];
            static TRANSITION: &'static [LonghandId] = &[
                    LonghandId::TransitionProperty,
                    LonghandId::TransitionDuration,
                    LonghandId::TransitionTimingFunction,
                    LonghandId::TransitionDelay,
            ];
            static ANIMATION: &'static [LonghandId] = &[
                    LonghandId::AnimationName,
                    LonghandId::AnimationDuration,
                    LonghandId::AnimationTimingFunction,
                    LonghandId::AnimationDelay,
                    LonghandId::AnimationIterationCount,
                    LonghandId::AnimationDirection,
                    LonghandId::AnimationFillMode,
                    LonghandId::AnimationPlayState,
            ];
            static SCROLL_SNAP_TYPE: &'static [LonghandId] = &[
                    LonghandId::ScrollSnapTypeX,
                    LonghandId::ScrollSnapTypeY,
            ];
            static OVERSCROLL_BEHAVIOR: &'static [LonghandId] = &[
                    LonghandId::OverscrollBehaviorX,
                    LonghandId::OverscrollBehaviorY,
            ];
            static COLUMNS: &'static [LonghandId] = &[
                    LonghandId::ColumnWidth,
                    LonghandId::ColumnCount,
            ];
            static COLUMN_RULE: &'static [LonghandId] = &[
                    LonghandId::ColumnRuleWidth,
                    LonghandId::ColumnRuleStyle,
                    LonghandId::ColumnRuleColor,
            ];
            static FONT: &'static [LonghandId] = &[
                    LonghandId::FontStyle,
                    LonghandId::FontVariantCaps,
                    LonghandId::FontWeight,
                    LonghandId::FontStretch,
                    LonghandId::FontSize,
                    LonghandId::LineHeight,
                    LonghandId::FontFamily,
                    LonghandId::FontSizeAdjust,
                    LonghandId::FontKerning,
                    LonghandId::FontOpticalSizing,
                    LonghandId::FontVariantAlternates,
                    LonghandId::FontVariantEastAsian,
                    LonghandId::FontVariantLigatures,
                    LonghandId::FontVariantNumeric,
                    LonghandId::FontVariantPosition,
                    LonghandId::FontLanguageOverride,
                    LonghandId::FontFeatureSettings,
                    LonghandId::FontVariationSettings,
            ];
            static FONT_VARIANT: &'static [LonghandId] = &[
                    LonghandId::FontVariantCaps,
                    LonghandId::FontVariantAlternates,
                    LonghandId::FontVariantEastAsian,
                    LonghandId::FontVariantLigatures,
                    LonghandId::FontVariantNumeric,
                    LonghandId::FontVariantPosition,
            ];
            static TEXT_EMPHASIS: &'static [LonghandId] = &[
                    LonghandId::TextEmphasisStyle,
                    LonghandId::TextEmphasisColor,
            ];
            static _WEBKIT_TEXT_STROKE: &'static [LonghandId] = &[
                    LonghandId::WebkitTextStrokeWidth,
                    LonghandId::WebkitTextStrokeColor,
            ];
            static LIST_STYLE: &'static [LonghandId] = &[
                    LonghandId::ListStylePosition,
                    LonghandId::ListStyleImage,
                    LonghandId::ListStyleType,
            ];
            static MARGIN: &'static [LonghandId] = &[
                    LonghandId::MarginTop,
                    LonghandId::MarginRight,
                    LonghandId::MarginBottom,
                    LonghandId::MarginLeft,
            ];
            static MASK: &'static [LonghandId] = &[
                    LonghandId::MaskMode,
                    LonghandId::MaskRepeat,
                    LonghandId::MaskClip,
                    LonghandId::MaskOrigin,
                    LonghandId::MaskComposite,
                    LonghandId::MaskPositionX,
                    LonghandId::MaskPositionY,
                    LonghandId::MaskSize,
                    LonghandId::MaskImage,
            ];
            static MASK_POSITION: &'static [LonghandId] = &[
                    LonghandId::MaskPositionX,
                    LonghandId::MaskPositionY,
            ];
            static OUTLINE: &'static [LonghandId] = &[
                    LonghandId::OutlineWidth,
                    LonghandId::OutlineStyle,
                    LonghandId::OutlineColor,
            ];
            static _MOZ_OUTLINE_RADIUS: &'static [LonghandId] = &[
                    LonghandId::MozOutlineRadiusTopleft,
                    LonghandId::MozOutlineRadiusTopright,
                    LonghandId::MozOutlineRadiusBottomright,
                    LonghandId::MozOutlineRadiusBottomleft,
            ];
            static PADDING: &'static [LonghandId] = &[
                    LonghandId::PaddingTop,
                    LonghandId::PaddingRight,
                    LonghandId::PaddingBottom,
                    LonghandId::PaddingLeft,
            ];
            static FLEX_FLOW: &'static [LonghandId] = &[
                    LonghandId::FlexDirection,
                    LonghandId::FlexWrap,
            ];
            static FLEX: &'static [LonghandId] = &[
                    LonghandId::FlexGrow,
                    LonghandId::FlexShrink,
                    LonghandId::FlexBasis,
            ];
            static GRID_GAP: &'static [LonghandId] = &[
                    LonghandId::GridRowGap,
                    LonghandId::GridColumnGap,
            ];
            static GRID_ROW: &'static [LonghandId] = &[
                    LonghandId::GridRowStart,
                    LonghandId::GridRowEnd,
            ];
            static GRID_COLUMN: &'static [LonghandId] = &[
                    LonghandId::GridColumnStart,
                    LonghandId::GridColumnEnd,
            ];
            static GRID_AREA: &'static [LonghandId] = &[
                    LonghandId::GridRowStart,
                    LonghandId::GridRowEnd,
                    LonghandId::GridColumnStart,
                    LonghandId::GridColumnEnd,
            ];
            static GRID_TEMPLATE: &'static [LonghandId] = &[
                    LonghandId::GridTemplateRows,
                    LonghandId::GridTemplateColumns,
                    LonghandId::GridTemplateAreas,
            ];
            static GRID: &'static [LonghandId] = &[
                    LonghandId::GridTemplateRows,
                    LonghandId::GridTemplateColumns,
                    LonghandId::GridTemplateAreas,
                    LonghandId::GridAutoRows,
                    LonghandId::GridAutoColumns,
                    LonghandId::GridAutoFlow,
            ];
            static PLACE_CONTENT: &'static [LonghandId] = &[
                    LonghandId::AlignContent,
                    LonghandId::JustifyContent,
            ];
            static PLACE_SELF: &'static [LonghandId] = &[
                    LonghandId::AlignSelf,
                    LonghandId::JustifySelf,
            ];
            static PLACE_ITEMS: &'static [LonghandId] = &[
                    LonghandId::AlignItems,
                    LonghandId::JustifyItems,
            ];
            static MARKER: &'static [LonghandId] = &[
                    LonghandId::MarkerStart,
                    LonghandId::MarkerEnd,
                    LonghandId::MarkerMid,
            ];
            static TEXT_DECORATION: &'static [LonghandId] = &[
                    LonghandId::TextDecorationLine,
                    LonghandId::TextDecorationStyle,
                    LonghandId::TextDecorationColor,
            ];
            static ALL: &'static [LonghandId] = &[
                    LonghandId::BorderBlockStartColor,
                    LonghandId::BorderBlockStartStyle,
                    LonghandId::BorderBlockStartWidth,
                    LonghandId::BorderBlockEndColor,
                    LonghandId::BorderBlockEndStyle,
                    LonghandId::BorderBlockEndWidth,
                    LonghandId::BorderInlineStartColor,
                    LonghandId::BorderInlineStartStyle,
                    LonghandId::BorderInlineStartWidth,
                    LonghandId::BorderInlineEndColor,
                    LonghandId::BorderInlineEndStyle,
                    LonghandId::BorderInlineEndWidth,
                    LonghandId::MarginBlockStart,
                    LonghandId::MarginBlockEnd,
                    LonghandId::MarginInlineStart,
                    LonghandId::MarginInlineEnd,
                    LonghandId::PaddingBlockStart,
                    LonghandId::PaddingBlockEnd,
                    LonghandId::PaddingInlineStart,
                    LonghandId::PaddingInlineEnd,
                    LonghandId::OffsetBlockStart,
                    LonghandId::OffsetBlockEnd,
                    LonghandId::OffsetInlineStart,
                    LonghandId::OffsetInlineEnd,
                    LonghandId::BlockSize,
                    LonghandId::MinBlockSize,
                    LonghandId::MaxBlockSize,
                    LonghandId::InlineSize,
                    LonghandId::MinInlineSize,
                    LonghandId::MaxInlineSize,
                    LonghandId::BackgroundColor,
                    LonghandId::BackgroundImage,
                    LonghandId::BackgroundPositionX,
                    LonghandId::BackgroundPositionY,
                    LonghandId::BackgroundRepeat,
                    LonghandId::BackgroundAttachment,
                    LonghandId::BackgroundClip,
                    LonghandId::BackgroundOrigin,
                    LonghandId::BackgroundSize,
                    LonghandId::BackgroundBlendMode,
                    LonghandId::BorderTopColor,
                    LonghandId::BorderTopStyle,
                    LonghandId::BorderTopWidth,
                    LonghandId::BorderLeftColor,
                    LonghandId::BorderLeftStyle,
                    LonghandId::BorderLeftWidth,
                    LonghandId::BorderBottomColor,
                    LonghandId::BorderBottomStyle,
                    LonghandId::BorderBottomWidth,
                    LonghandId::BorderRightColor,
                    LonghandId::BorderRightStyle,
                    LonghandId::BorderRightWidth,
                    LonghandId::BorderTopLeftRadius,
                    LonghandId::BorderTopRightRadius,
                    LonghandId::BorderBottomRightRadius,
                    LonghandId::BorderBottomLeftRadius,
                    LonghandId::BoxDecorationBreak,
                    LonghandId::MozFloatEdge,
                    LonghandId::BorderImageSource,
                    LonghandId::BorderImageOutset,
                    LonghandId::BorderImageRepeat,
                    LonghandId::BorderImageWidth,
                    LonghandId::BorderImageSlice,
                    LonghandId::Display,
                    LonghandId::Position,
                    LonghandId::Float,
                    LonghandId::Clear,
                    LonghandId::VerticalAlign,
                    LonghandId::OverflowClipBoxInline,
                    LonghandId::OverflowClipBoxBlock,
                    LonghandId::OverflowX,
                    LonghandId::OverflowY,
                    LonghandId::TransitionDuration,
                    LonghandId::TransitionTimingFunction,
                    LonghandId::TransitionProperty,
                    LonghandId::TransitionDelay,
                    LonghandId::AnimationName,
                    LonghandId::AnimationDuration,
                    LonghandId::AnimationTimingFunction,
                    LonghandId::AnimationIterationCount,
                    LonghandId::AnimationDirection,
                    LonghandId::AnimationPlayState,
                    LonghandId::AnimationFillMode,
                    LonghandId::AnimationDelay,
                    LonghandId::ScrollSnapPointsX,
                    LonghandId::ScrollSnapPointsY,
                    LonghandId::ScrollSnapDestination,
                    LonghandId::ScrollSnapCoordinate,
                    LonghandId::Transform,
                    LonghandId::Rotate,
                    LonghandId::Scale,
                    LonghandId::Translate,
                    LonghandId::ScrollBehavior,
                    LonghandId::ScrollSnapTypeX,
                    LonghandId::ScrollSnapTypeY,
                    LonghandId::OverscrollBehaviorX,
                    LonghandId::OverscrollBehaviorY,
                    LonghandId::Isolation,
                    LonghandId::PageBreakAfter,
                    LonghandId::PageBreakBefore,
                    LonghandId::PageBreakInside,
                    LonghandId::Resize,
                    LonghandId::Perspective,
                    LonghandId::PerspectiveOrigin,
                    LonghandId::BackfaceVisibility,
                    LonghandId::TransformBox,
                    LonghandId::TransformStyle,
                    LonghandId::TransformOrigin,
                    LonghandId::Contain,
                    LonghandId::MozAppearance,
                    LonghandId::MozBinding,
                    LonghandId::MozOrient,
                    LonghandId::WillChange,
                    LonghandId::ShapeImageThreshold,
                    LonghandId::ShapeOutside,
                    LonghandId::TouchAction,
                    LonghandId::Color,
                    LonghandId::ColumnWidth,
                    LonghandId::ColumnCount,
                    LonghandId::ColumnGap,
                    LonghandId::ColumnFill,
                    LonghandId::ColumnRuleWidth,
                    LonghandId::ColumnRuleColor,
                    LonghandId::ColumnSpan,
                    LonghandId::ColumnRuleStyle,
                    LonghandId::Content,
                    LonghandId::CounterIncrement,
                    LonghandId::CounterReset,
                    LonghandId::Opacity,
                    LonghandId::BoxShadow,
                    LonghandId::Clip,
                    LonghandId::Filter,
                    LonghandId::MixBlendMode,
                    LonghandId::FontFamily,
                    LonghandId::FontStyle,
                    LonghandId::FontVariantCaps,
                    LonghandId::FontWeight,
                    LonghandId::FontSize,
                    LonghandId::FontSizeAdjust,
                    LonghandId::FontSynthesis,
                    LonghandId::FontStretch,
                    LonghandId::FontKerning,
                    LonghandId::FontVariantAlternates,
                    LonghandId::FontVariantEastAsian,
                    LonghandId::FontVariantLigatures,
                    LonghandId::FontVariantNumeric,
                    LonghandId::FontVariantPosition,
                    LonghandId::FontFeatureSettings,
                    LonghandId::FontVariationSettings,
                    LonghandId::FontLanguageOverride,
                    LonghandId::FontOpticalSizing,
                    LonghandId::MozOsxFontSmoothing,
                    LonghandId::Visibility,
                    LonghandId::WritingMode,
                    LonghandId::TextOrientation,
                    LonghandId::ColorAdjust,
                    LonghandId::ImageRendering,
                    LonghandId::ImageOrientation,
                    LonghandId::BorderCollapse,
                    LonghandId::EmptyCells,
                    LonghandId::CaptionSide,
                    LonghandId::BorderSpacing,
                    LonghandId::LineHeight,
                    LonghandId::TextTransform,
                    LonghandId::Hyphens,
                    LonghandId::MozTextSizeAdjust,
                    LonghandId::TextIndent,
                    LonghandId::OverflowWrap,
                    LonghandId::WordBreak,
                    LonghandId::TextJustify,
                    LonghandId::TextAlignLast,
                    LonghandId::TextAlign,
                    LonghandId::LetterSpacing,
                    LonghandId::WordSpacing,
                    LonghandId::WhiteSpace,
                    LonghandId::TextShadow,
                    LonghandId::TextEmphasisStyle,
                    LonghandId::TextEmphasisPosition,
                    LonghandId::TextEmphasisColor,
                    LonghandId::MozTabSize,
                    LonghandId::WebkitTextFillColor,
                    LonghandId::WebkitTextStrokeColor,
                    LonghandId::WebkitTextStrokeWidth,
                    LonghandId::RubyAlign,
                    LonghandId::RubyPosition,
                    LonghandId::TextCombineUpright,
                    LonghandId::TextRendering,
                    LonghandId::MozControlCharacterVisibility,
                    LonghandId::ListStylePosition,
                    LonghandId::ListStyleType,
                    LonghandId::ListStyleImage,
                    LonghandId::Quotes,
                    LonghandId::MozImageRegion,
                    LonghandId::MarginTop,
                    LonghandId::MarginLeft,
                    LonghandId::MarginBottom,
                    LonghandId::MarginRight,
                    LonghandId::OutlineColor,
                    LonghandId::OutlineStyle,
                    LonghandId::OutlineWidth,
                    LonghandId::MozOutlineRadiusTopleft,
                    LonghandId::MozOutlineRadiusTopright,
                    LonghandId::MozOutlineRadiusBottomright,
                    LonghandId::MozOutlineRadiusBottomleft,
                    LonghandId::OutlineOffset,
                    LonghandId::PaddingTop,
                    LonghandId::PaddingLeft,
                    LonghandId::PaddingBottom,
                    LonghandId::PaddingRight,
                    LonghandId::Cursor,
                    LonghandId::PointerEvents,
                    LonghandId::MozUserInput,
                    LonghandId::MozUserModify,
                    LonghandId::MozUserFocus,
                    LonghandId::CaretColor,
                    LonghandId::Top,
                    LonghandId::Left,
                    LonghandId::Bottom,
                    LonghandId::Right,
                    LonghandId::ZIndex,
                    LonghandId::FlexDirection,
                    LonghandId::FlexWrap,
                    LonghandId::JustifyContent,
                    LonghandId::AlignContent,
                    LonghandId::AlignItems,
                    LonghandId::JustifyItems,
                    LonghandId::FlexGrow,
                    LonghandId::FlexShrink,
                    LonghandId::AlignSelf,
                    LonghandId::JustifySelf,
                    LonghandId::Order,
                    LonghandId::FlexBasis,
                    LonghandId::Width,
                    LonghandId::MinWidth,
                    LonghandId::MaxWidth,
                    LonghandId::Height,
                    LonghandId::MinHeight,
                    LonghandId::MaxHeight,
                    LonghandId::BoxSizing,
                    LonghandId::ObjectFit,
                    LonghandId::ObjectPosition,
                    LonghandId::GridRowGap,
                    LonghandId::GridRowStart,
                    LonghandId::GridRowEnd,
                    LonghandId::GridAutoRows,
                    LonghandId::GridTemplateRows,
                    LonghandId::GridColumnGap,
                    LonghandId::GridColumnStart,
                    LonghandId::GridColumnEnd,
                    LonghandId::GridAutoColumns,
                    LonghandId::GridTemplateColumns,
                    LonghandId::GridAutoFlow,
                    LonghandId::GridTemplateAreas,
                    LonghandId::TableLayout,
                    LonghandId::TextOverflow,
                    LonghandId::TextDecorationLine,
                    LonghandId::TextDecorationStyle,
                    LonghandId::TextDecorationColor,
                    LonghandId::InitialLetter,
                    LonghandId::ImeMode,
                    LonghandId::MozUserSelect,
                    LonghandId::MozWindowDragging,
                    LonghandId::MozForceBrokenImageIcon,
                    LonghandId::TextAnchor,
                    LonghandId::ColorInterpolation,
                    LonghandId::ColorInterpolationFilters,
                    LonghandId::Fill,
                    LonghandId::FillOpacity,
                    LonghandId::FillRule,
                    LonghandId::ShapeRendering,
                    LonghandId::Stroke,
                    LonghandId::StrokeWidth,
                    LonghandId::StrokeLinecap,
                    LonghandId::StrokeLinejoin,
                    LonghandId::StrokeMiterlimit,
                    LonghandId::StrokeOpacity,
                    LonghandId::StrokeDasharray,
                    LonghandId::StrokeDashoffset,
                    LonghandId::ClipRule,
                    LonghandId::MarkerStart,
                    LonghandId::MarkerMid,
                    LonghandId::MarkerEnd,
                    LonghandId::PaintOrder,
                    LonghandId::MozContextProperties,
                    LonghandId::DominantBaseline,
                    LonghandId::VectorEffect,
                    LonghandId::StopColor,
                    LonghandId::StopOpacity,
                    LonghandId::FloodColor,
                    LonghandId::FloodOpacity,
                    LonghandId::LightingColor,
                    LonghandId::MaskType,
                    LonghandId::ClipPath,
                    LonghandId::MaskMode,
                    LonghandId::MaskRepeat,
                    LonghandId::MaskPositionX,
                    LonghandId::MaskPositionY,
                    LonghandId::MaskClip,
                    LonghandId::MaskOrigin,
                    LonghandId::MaskSize,
                    LonghandId::MaskComposite,
                    LonghandId::MaskImage,
                    LonghandId::MozBoxAlign,
                    LonghandId::MozBoxDirection,
                    LonghandId::MozBoxFlex,
                    LonghandId::MozBoxOrient,
                    LonghandId::MozBoxPack,
                    LonghandId::MozStackSizing,
                    LonghandId::MozBoxOrdinalGroup,
            ];
        NonCustomPropertyIterator {
            filter: NonCustomPropertyId::from(*self).enabled_for_all_content(),
            iter: match *self {
                    ShorthandId::Background => BACKGROUND,
                    ShorthandId::BackgroundPosition => BACKGROUND_POSITION,
                    ShorthandId::BorderColor => BORDER_COLOR,
                    ShorthandId::BorderStyle => BORDER_STYLE,
                    ShorthandId::BorderWidth => BORDER_WIDTH,
                    ShorthandId::BorderTop => BORDER_TOP,
                    ShorthandId::BorderLeft => BORDER_LEFT,
                    ShorthandId::BorderBottom => BORDER_BOTTOM,
                    ShorthandId::BorderRight => BORDER_RIGHT,
                    ShorthandId::BorderBlockStart => BORDER_BLOCK_START,
                    ShorthandId::BorderBlockEnd => BORDER_BLOCK_END,
                    ShorthandId::BorderInlineStart => BORDER_INLINE_START,
                    ShorthandId::BorderInlineEnd => BORDER_INLINE_END,
                    ShorthandId::Border => BORDER,
                    ShorthandId::BorderRadius => BORDER_RADIUS,
                    ShorthandId::BorderImage => BORDER_IMAGE,
                    ShorthandId::Overflow => OVERFLOW,
                    ShorthandId::OverflowClipBox => OVERFLOW_CLIP_BOX,
                    ShorthandId::Transition => TRANSITION,
                    ShorthandId::Animation => ANIMATION,
                    ShorthandId::ScrollSnapType => SCROLL_SNAP_TYPE,
                    ShorthandId::OverscrollBehavior => OVERSCROLL_BEHAVIOR,
                    ShorthandId::Columns => COLUMNS,
                    ShorthandId::ColumnRule => COLUMN_RULE,
                    ShorthandId::Font => FONT,
                    ShorthandId::FontVariant => FONT_VARIANT,
                    ShorthandId::TextEmphasis => TEXT_EMPHASIS,
                    ShorthandId::WebkitTextStroke => _WEBKIT_TEXT_STROKE,
                    ShorthandId::ListStyle => LIST_STYLE,
                    ShorthandId::Margin => MARGIN,
                    ShorthandId::Mask => MASK,
                    ShorthandId::MaskPosition => MASK_POSITION,
                    ShorthandId::Outline => OUTLINE,
                    ShorthandId::MozOutlineRadius => _MOZ_OUTLINE_RADIUS,
                    ShorthandId::Padding => PADDING,
                    ShorthandId::FlexFlow => FLEX_FLOW,
                    ShorthandId::Flex => FLEX,
                    ShorthandId::GridGap => GRID_GAP,
                    ShorthandId::GridRow => GRID_ROW,
                    ShorthandId::GridColumn => GRID_COLUMN,
                    ShorthandId::GridArea => GRID_AREA,
                    ShorthandId::GridTemplate => GRID_TEMPLATE,
                    ShorthandId::Grid => GRID,
                    ShorthandId::PlaceContent => PLACE_CONTENT,
                    ShorthandId::PlaceSelf => PLACE_SELF,
                    ShorthandId::PlaceItems => PLACE_ITEMS,
                    ShorthandId::Marker => MARKER,
                    ShorthandId::TextDecoration => TEXT_DECORATION,
                    ShorthandId::All => ALL,
            }.iter()
        }
    }

    /// Try to serialize the given declarations as this shorthand.
    ///
    /// Returns an error if writing to the stream fails, or if the declarations
    /// do not map to a shorthand.
    pub fn longhands_to_css<'a, W, I>(
        &self,
        declarations: I,
        dest: &mut CssWriter<W>,
    ) -> fmt::Result
    where
        W: Write,
        I: Iterator<Item=&'a PropertyDeclaration>,
    {
        match *self {
            ShorthandId::All => {
                // No need to try to serialize the declarations as the 'all'
                // shorthand, since it only accepts CSS-wide keywords (and
                // variable references), which will be handled in
                // get_shorthand_appendable_value.
                Err(fmt::Error)
            }
                ShorthandId::Background => {
                    match shorthands::background::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BackgroundPosition => {
                    match shorthands::background_position::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderColor => {
                    match shorthands::border_color::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderStyle => {
                    match shorthands::border_style::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderWidth => {
                    match shorthands::border_width::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderTop => {
                    match shorthands::border_top::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderLeft => {
                    match shorthands::border_left::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderBottom => {
                    match shorthands::border_bottom::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderRight => {
                    match shorthands::border_right::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderBlockStart => {
                    match shorthands::border_block_start::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderBlockEnd => {
                    match shorthands::border_block_end::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderInlineStart => {
                    match shorthands::border_inline_start::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderInlineEnd => {
                    match shorthands::border_inline_end::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Border => {
                    match shorthands::border::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderRadius => {
                    match shorthands::border_radius::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderImage => {
                    match shorthands::border_image::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Overflow => {
                    match shorthands::overflow::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::OverflowClipBox => {
                    match shorthands::overflow_clip_box::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Transition => {
                    match shorthands::transition::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Animation => {
                    match shorthands::animation::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::ScrollSnapType => {
                    match shorthands::scroll_snap_type::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::OverscrollBehavior => {
                    match shorthands::overscroll_behavior::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Columns => {
                    match shorthands::columns::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::ColumnRule => {
                    match shorthands::column_rule::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Font => {
                    match shorthands::font::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::FontVariant => {
                    match shorthands::font_variant::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::TextEmphasis => {
                    match shorthands::text_emphasis::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::WebkitTextStroke => {
                    match shorthands::_webkit_text_stroke::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::ListStyle => {
                    match shorthands::list_style::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Margin => {
                    match shorthands::margin::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Mask => {
                    match shorthands::mask::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::MaskPosition => {
                    match shorthands::mask_position::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Outline => {
                    match shorthands::outline::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::MozOutlineRadius => {
                    match shorthands::_moz_outline_radius::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Padding => {
                    match shorthands::padding::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::FlexFlow => {
                    match shorthands::flex_flow::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Flex => {
                    match shorthands::flex::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::GridGap => {
                    match shorthands::grid_gap::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::GridRow => {
                    match shorthands::grid_row::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::GridColumn => {
                    match shorthands::grid_column::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::GridArea => {
                    match shorthands::grid_area::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::GridTemplate => {
                    match shorthands::grid_template::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Grid => {
                    match shorthands::grid::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::PlaceContent => {
                    match shorthands::place_content::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::PlaceSelf => {
                    match shorthands::place_self::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::PlaceItems => {
                    match shorthands::place_items::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Marker => {
                    match shorthands::marker::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::TextDecoration => {
                    match shorthands::text_decoration::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
        }
    }

    /// Finds and returns an appendable value for the given declarations.
    ///
    /// Returns the optional appendable value.
    pub fn get_shorthand_appendable_value<'a, I>(
        self,
        declarations: I,
    ) -> Option<AppendableValue<'a, I::IntoIter>>
    where
        I: IntoIterator<Item=&'a PropertyDeclaration>,
        I::IntoIter: Clone,
    {
        let declarations = declarations.into_iter();

        // Only cloning iterators (a few pointers each) not declarations.
        let mut declarations2 = declarations.clone();
        let mut declarations3 = declarations.clone();

        let first_declaration = declarations2.next()?;

        // https://drafts.csswg.org/css-variables/#variables-in-shorthands
        if let Some(css) = first_declaration.with_variables_from_shorthand(self) {
            if declarations2.all(|d| d.with_variables_from_shorthand(self) == Some(css)) {
               return Some(AppendableValue::Css {
                   css: CssStringBorrow::from(css),
                   with_variables: true,
               });
            }
            return None;
        }

        // Check whether they are all the same CSS-wide keyword.
        if let Some(keyword) = first_declaration.get_css_wide_keyword() {
            if declarations2.all(|d| d.get_css_wide_keyword() == Some(keyword)) {
                return Some(AppendableValue::Css {
                    css: CssStringBorrow::from(keyword.to_str()),
                    with_variables: false,
                });
            }
            return None;
        }

        // Check whether all declarations can be serialized as part of shorthand.
        if declarations3.all(|d| d.may_serialize_as_part_of_shorthand()) {
            return Some(AppendableValue::DeclarationsForShorthand(self, declarations));
        }

        None
    }

    /// Returns PropertyFlags for given shorthand property.
    pub fn flags(&self) -> PropertyFlags {
        match *self {
                ShorthandId::Background =>
                    PropertyFlags::empty(),
                ShorthandId::BackgroundPosition =>
                    PropertyFlags::empty(),
                ShorthandId::BorderColor =>
                    PropertyFlags::empty(),
                ShorthandId::BorderStyle =>
                    PropertyFlags::empty(),
                ShorthandId::BorderWidth =>
                    PropertyFlags::empty(),
                ShorthandId::BorderTop =>
                    PropertyFlags::empty(),
                ShorthandId::BorderLeft =>
                    PropertyFlags::empty(),
                ShorthandId::BorderBottom =>
                    PropertyFlags::empty(),
                ShorthandId::BorderRight =>
                    PropertyFlags::empty(),
                ShorthandId::BorderBlockStart =>
                    PropertyFlags::empty(),
                ShorthandId::BorderBlockEnd =>
                    PropertyFlags::empty(),
                ShorthandId::BorderInlineStart =>
                    PropertyFlags::empty(),
                ShorthandId::BorderInlineEnd =>
                    PropertyFlags::empty(),
                ShorthandId::Border =>
                    PropertyFlags::empty(),
                ShorthandId::BorderRadius =>
                    PropertyFlags::empty(),
                ShorthandId::BorderImage =>
                    PropertyFlags::empty(),
                ShorthandId::Overflow =>
                    PropertyFlags::empty(),
                ShorthandId::OverflowClipBox =>
                    PropertyFlags::empty(),
                ShorthandId::Transition =>
                    PropertyFlags::empty(),
                ShorthandId::Animation =>
                    PropertyFlags::empty(),
                ShorthandId::ScrollSnapType =>
                    PropertyFlags::empty(),
                ShorthandId::OverscrollBehavior =>
                    PropertyFlags::empty(),
                ShorthandId::Columns =>
                    PropertyFlags::empty(),
                ShorthandId::ColumnRule =>
                    PropertyFlags::empty(),
                ShorthandId::Font =>
                    PropertyFlags::empty(),
                ShorthandId::FontVariant =>
                    PropertyFlags::empty(),
                ShorthandId::TextEmphasis =>
                    PropertyFlags::empty(),
                ShorthandId::WebkitTextStroke =>
                    PropertyFlags::empty(),
                ShorthandId::ListStyle =>
                    PropertyFlags::empty(),
                ShorthandId::Margin =>
                    PropertyFlags::empty(),
                ShorthandId::Mask =>
                    PropertyFlags::empty(),
                ShorthandId::MaskPosition =>
                    PropertyFlags::empty(),
                ShorthandId::Outline =>
                    PropertyFlags::empty(),
                ShorthandId::MozOutlineRadius =>
                    PropertyFlags::empty(),
                ShorthandId::Padding =>
                    PropertyFlags::empty(),
                ShorthandId::FlexFlow =>
                    PropertyFlags::empty(),
                ShorthandId::Flex =>
                    PropertyFlags::empty(),
                ShorthandId::GridGap =>
                    PropertyFlags::empty(),
                ShorthandId::GridRow =>
                    PropertyFlags::empty(),
                ShorthandId::GridColumn =>
                    PropertyFlags::empty(),
                ShorthandId::GridArea =>
                    PropertyFlags::empty(),
                ShorthandId::GridTemplate =>
                    PropertyFlags::empty(),
                ShorthandId::Grid =>
                    PropertyFlags::empty(),
                ShorthandId::PlaceContent =>
                    PropertyFlags::empty(),
                ShorthandId::PlaceSelf =>
                    PropertyFlags::empty(),
                ShorthandId::PlaceItems =>
                    PropertyFlags::empty(),
                ShorthandId::Marker =>
                    PropertyFlags::empty(),
                ShorthandId::TextDecoration =>
                    PropertyFlags::empty(),
                ShorthandId::All =>
                    PropertyFlags::empty(),
        }
    }

    fn parse_into<'i, 't>(
        &self,
        declarations: &mut SourcePropertyDeclaration,
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<(), ParseError<'i>> {
        match *self {
                ShorthandId::Background => {
                    shorthands::background::parse_into(declarations, context, input)
                }
                ShorthandId::BackgroundPosition => {
                    shorthands::background_position::parse_into(declarations, context, input)
                }
                ShorthandId::BorderColor => {
                    shorthands::border_color::parse_into(declarations, context, input)
                }
                ShorthandId::BorderStyle => {
                    shorthands::border_style::parse_into(declarations, context, input)
                }
                ShorthandId::BorderWidth => {
                    shorthands::border_width::parse_into(declarations, context, input)
                }
                ShorthandId::BorderTop => {
                    shorthands::border_top::parse_into(declarations, context, input)
                }
                ShorthandId::BorderLeft => {
                    shorthands::border_left::parse_into(declarations, context, input)
                }
                ShorthandId::BorderBottom => {
                    shorthands::border_bottom::parse_into(declarations, context, input)
                }
                ShorthandId::BorderRight => {
                    shorthands::border_right::parse_into(declarations, context, input)
                }
                ShorthandId::BorderBlockStart => {
                    shorthands::border_block_start::parse_into(declarations, context, input)
                }
                ShorthandId::BorderBlockEnd => {
                    shorthands::border_block_end::parse_into(declarations, context, input)
                }
                ShorthandId::BorderInlineStart => {
                    shorthands::border_inline_start::parse_into(declarations, context, input)
                }
                ShorthandId::BorderInlineEnd => {
                    shorthands::border_inline_end::parse_into(declarations, context, input)
                }
                ShorthandId::Border => {
                    shorthands::border::parse_into(declarations, context, input)
                }
                ShorthandId::BorderRadius => {
                    shorthands::border_radius::parse_into(declarations, context, input)
                }
                ShorthandId::BorderImage => {
                    shorthands::border_image::parse_into(declarations, context, input)
                }
                ShorthandId::Overflow => {
                    shorthands::overflow::parse_into(declarations, context, input)
                }
                ShorthandId::OverflowClipBox => {
                    shorthands::overflow_clip_box::parse_into(declarations, context, input)
                }
                ShorthandId::Transition => {
                    shorthands::transition::parse_into(declarations, context, input)
                }
                ShorthandId::Animation => {
                    shorthands::animation::parse_into(declarations, context, input)
                }
                ShorthandId::ScrollSnapType => {
                    shorthands::scroll_snap_type::parse_into(declarations, context, input)
                }
                ShorthandId::OverscrollBehavior => {
                    shorthands::overscroll_behavior::parse_into(declarations, context, input)
                }
                ShorthandId::Columns => {
                    shorthands::columns::parse_into(declarations, context, input)
                }
                ShorthandId::ColumnRule => {
                    shorthands::column_rule::parse_into(declarations, context, input)
                }
                ShorthandId::Font => {
                    shorthands::font::parse_into(declarations, context, input)
                }
                ShorthandId::FontVariant => {
                    shorthands::font_variant::parse_into(declarations, context, input)
                }
                ShorthandId::TextEmphasis => {
                    shorthands::text_emphasis::parse_into(declarations, context, input)
                }
                ShorthandId::WebkitTextStroke => {
                    shorthands::_webkit_text_stroke::parse_into(declarations, context, input)
                }
                ShorthandId::ListStyle => {
                    shorthands::list_style::parse_into(declarations, context, input)
                }
                ShorthandId::Margin => {
                    shorthands::margin::parse_into(declarations, context, input)
                }
                ShorthandId::Mask => {
                    shorthands::mask::parse_into(declarations, context, input)
                }
                ShorthandId::MaskPosition => {
                    shorthands::mask_position::parse_into(declarations, context, input)
                }
                ShorthandId::Outline => {
                    shorthands::outline::parse_into(declarations, context, input)
                }
                ShorthandId::MozOutlineRadius => {
                    shorthands::_moz_outline_radius::parse_into(declarations, context, input)
                }
                ShorthandId::Padding => {
                    shorthands::padding::parse_into(declarations, context, input)
                }
                ShorthandId::FlexFlow => {
                    shorthands::flex_flow::parse_into(declarations, context, input)
                }
                ShorthandId::Flex => {
                    shorthands::flex::parse_into(declarations, context, input)
                }
                ShorthandId::GridGap => {
                    shorthands::grid_gap::parse_into(declarations, context, input)
                }
                ShorthandId::GridRow => {
                    shorthands::grid_row::parse_into(declarations, context, input)
                }
                ShorthandId::GridColumn => {
                    shorthands::grid_column::parse_into(declarations, context, input)
                }
                ShorthandId::GridArea => {
                    shorthands::grid_area::parse_into(declarations, context, input)
                }
                ShorthandId::GridTemplate => {
                    shorthands::grid_template::parse_into(declarations, context, input)
                }
                ShorthandId::Grid => {
                    shorthands::grid::parse_into(declarations, context, input)
                }
                ShorthandId::PlaceContent => {
                    shorthands::place_content::parse_into(declarations, context, input)
                }
                ShorthandId::PlaceSelf => {
                    shorthands::place_self::parse_into(declarations, context, input)
                }
                ShorthandId::PlaceItems => {
                    shorthands::place_items::parse_into(declarations, context, input)
                }
                ShorthandId::Marker => {
                    shorthands::marker::parse_into(declarations, context, input)
                }
                ShorthandId::TextDecoration => {
                    shorthands::text_decoration::parse_into(declarations, context, input)
                }
            // 'all' accepts no value other than CSS-wide keywords
            ShorthandId::All => Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }
}

/// Servo's representation of a declared value for a given `T`, which is the
/// declared value for that property.
#[derive(Clone, Debug, Eq, PartialEq)]
pub enum DeclaredValue<'a, T: 'a> {
    /// A known specified value from the stylesheet.
    Value(&'a T),
    /// An unparsed value that contains `var()` functions.
    WithVariables(&'a Arc<UnparsedValue>),
    /// An CSS-wide keyword.
    CSSWideKeyword(CSSWideKeyword),
}

/// A variant of DeclaredValue that owns its data. This separation exists so
/// that PropertyDeclaration can avoid embedding a DeclaredValue (and its
/// extra discriminant word) and synthesize dependent DeclaredValues for
/// PropertyDeclaration instances as needed.
#[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
#[derive(Clone, Debug, Eq, PartialEq, ToCss)]
pub enum DeclaredValueOwned<T> {
    /// A known specified value from the stylesheet.
    Value(T),
    /// An unparsed value that contains `var()` functions.
    WithVariables(
        #[cfg_attr(feature = "gecko", ignore_malloc_size_of = "XXX: how to handle this?")]
        Arc<UnparsedValue>
    ),
    /// An CSS-wide keyword.
    CSSWideKeyword(CSSWideKeyword),
}

impl<T> DeclaredValueOwned<T> {
    /// Creates a dependent DeclaredValue from this DeclaredValueOwned.
    fn borrow(&self) -> DeclaredValue<T> {
        match *self {
            DeclaredValueOwned::Value(ref v) => DeclaredValue::Value(v),
            DeclaredValueOwned::WithVariables(ref v) => DeclaredValue::WithVariables(v),
            DeclaredValueOwned::CSSWideKeyword(v) => DeclaredValue::CSSWideKeyword(v),
        }
    }
}

/// An unparsed property value that contains `var()` functions.
#[derive(Debug, Eq, PartialEq)]
pub struct UnparsedValue {
    /// The css serialization for this value.
    css: String,
    /// The first token type for this serialization.
    first_token_type: TokenSerializationType,
    /// The url data for resolving url values.
    url_data: UrlExtraData,
    /// The shorthand this came from.
    from_shorthand: Option<ShorthandId>,
}

impl ToCss for UnparsedValue {
    fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
    where
        W: Write,
    {
        // https://drafts.csswg.org/css-variables/#variables-in-shorthands
        if self.from_shorthand.is_none() {
            dest.write_str(&*self.css)?;
        }
        Ok(())
    }
}

impl UnparsedValue {
    fn substitute_variables(
        &self,
        longhand_id: LonghandId,
        custom_properties: Option<&Arc<::custom_properties::CustomPropertiesMap>>,
        quirks_mode: QuirksMode,
    ) -> PropertyDeclaration {
        ::custom_properties::substitute(&self.css, self.first_token_type, custom_properties)
        .ok()
        .and_then(|css| {
            // As of this writing, only the base URL is used for property
            // values.
            let context = ParserContext::new(
                Origin::Author,
                &self.url_data,
                None,
                ParsingMode::DEFAULT,
                quirks_mode,
            );

            let mut input = ParserInput::new(&css);
            Parser::new(&mut input).parse_entirely(|input| {
                match self.from_shorthand {
                    None => longhand_id.parse_value(&context, input),
                    Some(ShorthandId::All) => {
                        // No need to parse the 'all' shorthand as anything other than a CSS-wide
                        // keyword, after variable substitution.
                        Err(input.new_custom_error(SelectorParseErrorKind::UnexpectedIdent("all".into())))
                    }
                        Some(ShorthandId::Background) => {
                            shorthands::background::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BackgroundColor => {
                                            PropertyDeclaration::BackgroundColor(
                                                longhands.background_color
                                            )
                                        }
                                        LonghandId::BackgroundPositionX => {
                                            PropertyDeclaration::BackgroundPositionX(
                                                longhands.background_position_x
                                            )
                                        }
                                        LonghandId::BackgroundPositionY => {
                                            PropertyDeclaration::BackgroundPositionY(
                                                longhands.background_position_y
                                            )
                                        }
                                        LonghandId::BackgroundRepeat => {
                                            PropertyDeclaration::BackgroundRepeat(
                                                longhands.background_repeat
                                            )
                                        }
                                        LonghandId::BackgroundAttachment => {
                                            PropertyDeclaration::BackgroundAttachment(
                                                longhands.background_attachment
                                            )
                                        }
                                        LonghandId::BackgroundImage => {
                                            PropertyDeclaration::BackgroundImage(
                                                longhands.background_image
                                            )
                                        }
                                        LonghandId::BackgroundSize => {
                                            PropertyDeclaration::BackgroundSize(
                                                longhands.background_size
                                            )
                                        }
                                        LonghandId::BackgroundOrigin => {
                                            PropertyDeclaration::BackgroundOrigin(
                                                longhands.background_origin
                                            )
                                        }
                                        LonghandId::BackgroundClip => {
                                            PropertyDeclaration::BackgroundClip(
                                                longhands.background_clip
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BackgroundPosition) => {
                            shorthands::background_position::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BackgroundPositionX => {
                                            PropertyDeclaration::BackgroundPositionX(
                                                longhands.background_position_x
                                            )
                                        }
                                        LonghandId::BackgroundPositionY => {
                                            PropertyDeclaration::BackgroundPositionY(
                                                longhands.background_position_y
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderColor) => {
                            shorthands::border_color::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderTopColor => {
                                            PropertyDeclaration::BorderTopColor(
                                                longhands.border_top_color
                                            )
                                        }
                                        LonghandId::BorderRightColor => {
                                            PropertyDeclaration::BorderRightColor(
                                                longhands.border_right_color
                                            )
                                        }
                                        LonghandId::BorderBottomColor => {
                                            PropertyDeclaration::BorderBottomColor(
                                                longhands.border_bottom_color
                                            )
                                        }
                                        LonghandId::BorderLeftColor => {
                                            PropertyDeclaration::BorderLeftColor(
                                                longhands.border_left_color
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderStyle) => {
                            shorthands::border_style::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderTopStyle => {
                                            PropertyDeclaration::BorderTopStyle(
                                                longhands.border_top_style
                                            )
                                        }
                                        LonghandId::BorderRightStyle => {
                                            PropertyDeclaration::BorderRightStyle(
                                                longhands.border_right_style
                                            )
                                        }
                                        LonghandId::BorderBottomStyle => {
                                            PropertyDeclaration::BorderBottomStyle(
                                                longhands.border_bottom_style
                                            )
                                        }
                                        LonghandId::BorderLeftStyle => {
                                            PropertyDeclaration::BorderLeftStyle(
                                                longhands.border_left_style
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderWidth) => {
                            shorthands::border_width::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderTopWidth => {
                                            PropertyDeclaration::BorderTopWidth(
                                                longhands.border_top_width
                                            )
                                        }
                                        LonghandId::BorderLeftWidth => {
                                            PropertyDeclaration::BorderLeftWidth(
                                                longhands.border_left_width
                                            )
                                        }
                                        LonghandId::BorderBottomWidth => {
                                            PropertyDeclaration::BorderBottomWidth(
                                                longhands.border_bottom_width
                                            )
                                        }
                                        LonghandId::BorderRightWidth => {
                                            PropertyDeclaration::BorderRightWidth(
                                                longhands.border_right_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderTop) => {
                            shorthands::border_top::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderTopColor => {
                                            PropertyDeclaration::BorderTopColor(
                                                longhands.border_top_color
                                            )
                                        }
                                        LonghandId::BorderTopStyle => {
                                            PropertyDeclaration::BorderTopStyle(
                                                longhands.border_top_style
                                            )
                                        }
                                        LonghandId::BorderTopWidth => {
                                            PropertyDeclaration::BorderTopWidth(
                                                longhands.border_top_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderLeft) => {
                            shorthands::border_left::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderLeftColor => {
                                            PropertyDeclaration::BorderLeftColor(
                                                longhands.border_left_color
                                            )
                                        }
                                        LonghandId::BorderLeftStyle => {
                                            PropertyDeclaration::BorderLeftStyle(
                                                longhands.border_left_style
                                            )
                                        }
                                        LonghandId::BorderLeftWidth => {
                                            PropertyDeclaration::BorderLeftWidth(
                                                longhands.border_left_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderBottom) => {
                            shorthands::border_bottom::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderBottomColor => {
                                            PropertyDeclaration::BorderBottomColor(
                                                longhands.border_bottom_color
                                            )
                                        }
                                        LonghandId::BorderBottomStyle => {
                                            PropertyDeclaration::BorderBottomStyle(
                                                longhands.border_bottom_style
                                            )
                                        }
                                        LonghandId::BorderBottomWidth => {
                                            PropertyDeclaration::BorderBottomWidth(
                                                longhands.border_bottom_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderRight) => {
                            shorthands::border_right::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderRightColor => {
                                            PropertyDeclaration::BorderRightColor(
                                                longhands.border_right_color
                                            )
                                        }
                                        LonghandId::BorderRightStyle => {
                                            PropertyDeclaration::BorderRightStyle(
                                                longhands.border_right_style
                                            )
                                        }
                                        LonghandId::BorderRightWidth => {
                                            PropertyDeclaration::BorderRightWidth(
                                                longhands.border_right_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderBlockStart) => {
                            shorthands::border_block_start::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderBlockStartColor => {
                                            PropertyDeclaration::BorderBlockStartColor(
                                                longhands.border_block_start_color
                                            )
                                        }
                                        LonghandId::BorderBlockStartStyle => {
                                            PropertyDeclaration::BorderBlockStartStyle(
                                                longhands.border_block_start_style
                                            )
                                        }
                                        LonghandId::BorderBlockStartWidth => {
                                            PropertyDeclaration::BorderBlockStartWidth(
                                                longhands.border_block_start_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderBlockEnd) => {
                            shorthands::border_block_end::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderBlockEndColor => {
                                            PropertyDeclaration::BorderBlockEndColor(
                                                longhands.border_block_end_color
                                            )
                                        }
                                        LonghandId::BorderBlockEndStyle => {
                                            PropertyDeclaration::BorderBlockEndStyle(
                                                longhands.border_block_end_style
                                            )
                                        }
                                        LonghandId::BorderBlockEndWidth => {
                                            PropertyDeclaration::BorderBlockEndWidth(
                                                longhands.border_block_end_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderInlineStart) => {
                            shorthands::border_inline_start::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderInlineStartColor => {
                                            PropertyDeclaration::BorderInlineStartColor(
                                                longhands.border_inline_start_color
                                            )
                                        }
                                        LonghandId::BorderInlineStartStyle => {
                                            PropertyDeclaration::BorderInlineStartStyle(
                                                longhands.border_inline_start_style
                                            )
                                        }
                                        LonghandId::BorderInlineStartWidth => {
                                            PropertyDeclaration::BorderInlineStartWidth(
                                                longhands.border_inline_start_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderInlineEnd) => {
                            shorthands::border_inline_end::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderInlineEndColor => {
                                            PropertyDeclaration::BorderInlineEndColor(
                                                longhands.border_inline_end_color
                                            )
                                        }
                                        LonghandId::BorderInlineEndStyle => {
                                            PropertyDeclaration::BorderInlineEndStyle(
                                                longhands.border_inline_end_style
                                            )
                                        }
                                        LonghandId::BorderInlineEndWidth => {
                                            PropertyDeclaration::BorderInlineEndWidth(
                                                longhands.border_inline_end_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Border) => {
                            shorthands::border::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderTopColor => {
                                            PropertyDeclaration::BorderTopColor(
                                                longhands.border_top_color
                                            )
                                        }
                                        LonghandId::BorderTopStyle => {
                                            PropertyDeclaration::BorderTopStyle(
                                                longhands.border_top_style
                                            )
                                        }
                                        LonghandId::BorderTopWidth => {
                                            PropertyDeclaration::BorderTopWidth(
                                                longhands.border_top_width
                                            )
                                        }
                                        LonghandId::BorderLeftColor => {
                                            PropertyDeclaration::BorderLeftColor(
                                                longhands.border_left_color
                                            )
                                        }
                                        LonghandId::BorderLeftStyle => {
                                            PropertyDeclaration::BorderLeftStyle(
                                                longhands.border_left_style
                                            )
                                        }
                                        LonghandId::BorderLeftWidth => {
                                            PropertyDeclaration::BorderLeftWidth(
                                                longhands.border_left_width
                                            )
                                        }
                                        LonghandId::BorderBottomColor => {
                                            PropertyDeclaration::BorderBottomColor(
                                                longhands.border_bottom_color
                                            )
                                        }
                                        LonghandId::BorderBottomStyle => {
                                            PropertyDeclaration::BorderBottomStyle(
                                                longhands.border_bottom_style
                                            )
                                        }
                                        LonghandId::BorderBottomWidth => {
                                            PropertyDeclaration::BorderBottomWidth(
                                                longhands.border_bottom_width
                                            )
                                        }
                                        LonghandId::BorderRightColor => {
                                            PropertyDeclaration::BorderRightColor(
                                                longhands.border_right_color
                                            )
                                        }
                                        LonghandId::BorderRightStyle => {
                                            PropertyDeclaration::BorderRightStyle(
                                                longhands.border_right_style
                                            )
                                        }
                                        LonghandId::BorderRightWidth => {
                                            PropertyDeclaration::BorderRightWidth(
                                                longhands.border_right_width
                                            )
                                        }
                                        LonghandId::BorderImageOutset => {
                                            PropertyDeclaration::BorderImageOutset(
                                                longhands.border_image_outset
                                            )
                                        }
                                        LonghandId::BorderImageRepeat => {
                                            PropertyDeclaration::BorderImageRepeat(
                                                longhands.border_image_repeat
                                            )
                                        }
                                        LonghandId::BorderImageSlice => {
                                            PropertyDeclaration::BorderImageSlice(
                                                longhands.border_image_slice
                                            )
                                        }
                                        LonghandId::BorderImageSource => {
                                            PropertyDeclaration::BorderImageSource(
                                                longhands.border_image_source
                                            )
                                        }
                                        LonghandId::BorderImageWidth => {
                                            PropertyDeclaration::BorderImageWidth(
                                                longhands.border_image_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderRadius) => {
                            shorthands::border_radius::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderTopLeftRadius => {
                                            PropertyDeclaration::BorderTopLeftRadius(
                                                longhands.border_top_left_radius
                                            )
                                        }
                                        LonghandId::BorderTopRightRadius => {
                                            PropertyDeclaration::BorderTopRightRadius(
                                                longhands.border_top_right_radius
                                            )
                                        }
                                        LonghandId::BorderBottomRightRadius => {
                                            PropertyDeclaration::BorderBottomRightRadius(
                                                longhands.border_bottom_right_radius
                                            )
                                        }
                                        LonghandId::BorderBottomLeftRadius => {
                                            PropertyDeclaration::BorderBottomLeftRadius(
                                                longhands.border_bottom_left_radius
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderImage) => {
                            shorthands::border_image::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderImageOutset => {
                                            PropertyDeclaration::BorderImageOutset(
                                                longhands.border_image_outset
                                            )
                                        }
                                        LonghandId::BorderImageRepeat => {
                                            PropertyDeclaration::BorderImageRepeat(
                                                longhands.border_image_repeat
                                            )
                                        }
                                        LonghandId::BorderImageSlice => {
                                            PropertyDeclaration::BorderImageSlice(
                                                longhands.border_image_slice
                                            )
                                        }
                                        LonghandId::BorderImageSource => {
                                            PropertyDeclaration::BorderImageSource(
                                                longhands.border_image_source
                                            )
                                        }
                                        LonghandId::BorderImageWidth => {
                                            PropertyDeclaration::BorderImageWidth(
                                                longhands.border_image_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Overflow) => {
                            shorthands::overflow::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::OverflowX => {
                                            PropertyDeclaration::OverflowX(
                                                longhands.overflow_x
                                            )
                                        }
                                        LonghandId::OverflowY => {
                                            PropertyDeclaration::OverflowY(
                                                longhands.overflow_y
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::OverflowClipBox) => {
                            shorthands::overflow_clip_box::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::OverflowClipBoxBlock => {
                                            PropertyDeclaration::OverflowClipBoxBlock(
                                                longhands.overflow_clip_box_block
                                            )
                                        }
                                        LonghandId::OverflowClipBoxInline => {
                                            PropertyDeclaration::OverflowClipBoxInline(
                                                longhands.overflow_clip_box_inline
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Transition) => {
                            shorthands::transition::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::TransitionProperty => {
                                            PropertyDeclaration::TransitionProperty(
                                                longhands.transition_property
                                            )
                                        }
                                        LonghandId::TransitionDuration => {
                                            PropertyDeclaration::TransitionDuration(
                                                longhands.transition_duration
                                            )
                                        }
                                        LonghandId::TransitionTimingFunction => {
                                            PropertyDeclaration::TransitionTimingFunction(
                                                longhands.transition_timing_function
                                            )
                                        }
                                        LonghandId::TransitionDelay => {
                                            PropertyDeclaration::TransitionDelay(
                                                longhands.transition_delay
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Animation) => {
                            shorthands::animation::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::AnimationName => {
                                            PropertyDeclaration::AnimationName(
                                                longhands.animation_name
                                            )
                                        }
                                        LonghandId::AnimationDuration => {
                                            PropertyDeclaration::AnimationDuration(
                                                longhands.animation_duration
                                            )
                                        }
                                        LonghandId::AnimationTimingFunction => {
                                            PropertyDeclaration::AnimationTimingFunction(
                                                longhands.animation_timing_function
                                            )
                                        }
                                        LonghandId::AnimationDelay => {
                                            PropertyDeclaration::AnimationDelay(
                                                longhands.animation_delay
                                            )
                                        }
                                        LonghandId::AnimationIterationCount => {
                                            PropertyDeclaration::AnimationIterationCount(
                                                longhands.animation_iteration_count
                                            )
                                        }
                                        LonghandId::AnimationDirection => {
                                            PropertyDeclaration::AnimationDirection(
                                                longhands.animation_direction
                                            )
                                        }
                                        LonghandId::AnimationFillMode => {
                                            PropertyDeclaration::AnimationFillMode(
                                                longhands.animation_fill_mode
                                            )
                                        }
                                        LonghandId::AnimationPlayState => {
                                            PropertyDeclaration::AnimationPlayState(
                                                longhands.animation_play_state
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::ScrollSnapType) => {
                            shorthands::scroll_snap_type::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::ScrollSnapTypeX => {
                                            PropertyDeclaration::ScrollSnapTypeX(
                                                longhands.scroll_snap_type_x
                                            )
                                        }
                                        LonghandId::ScrollSnapTypeY => {
                                            PropertyDeclaration::ScrollSnapTypeY(
                                                longhands.scroll_snap_type_y
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::OverscrollBehavior) => {
                            shorthands::overscroll_behavior::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::OverscrollBehaviorX => {
                                            PropertyDeclaration::OverscrollBehaviorX(
                                                longhands.overscroll_behavior_x
                                            )
                                        }
                                        LonghandId::OverscrollBehaviorY => {
                                            PropertyDeclaration::OverscrollBehaviorY(
                                                longhands.overscroll_behavior_y
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Columns) => {
                            shorthands::columns::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::ColumnWidth => {
                                            PropertyDeclaration::ColumnWidth(
                                                longhands.column_width
                                            )
                                        }
                                        LonghandId::ColumnCount => {
                                            PropertyDeclaration::ColumnCount(
                                                longhands.column_count
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::ColumnRule) => {
                            shorthands::column_rule::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::ColumnRuleWidth => {
                                            PropertyDeclaration::ColumnRuleWidth(
                                                longhands.column_rule_width
                                            )
                                        }
                                        LonghandId::ColumnRuleStyle => {
                                            PropertyDeclaration::ColumnRuleStyle(
                                                longhands.column_rule_style
                                            )
                                        }
                                        LonghandId::ColumnRuleColor => {
                                            PropertyDeclaration::ColumnRuleColor(
                                                longhands.column_rule_color
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Font) => {
                            shorthands::font::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::FontStyle => {
                                            PropertyDeclaration::FontStyle(
                                                longhands.font_style
                                            )
                                        }
                                        LonghandId::FontVariantCaps => {
                                            PropertyDeclaration::FontVariantCaps(
                                                longhands.font_variant_caps
                                            )
                                        }
                                        LonghandId::FontWeight => {
                                            PropertyDeclaration::FontWeight(
                                                longhands.font_weight
                                            )
                                        }
                                        LonghandId::FontStretch => {
                                            PropertyDeclaration::FontStretch(
                                                longhands.font_stretch
                                            )
                                        }
                                        LonghandId::FontSize => {
                                            PropertyDeclaration::FontSize(
                                                longhands.font_size
                                            )
                                        }
                                        LonghandId::LineHeight => {
                                            PropertyDeclaration::LineHeight(
                                                longhands.line_height
                                            )
                                        }
                                        LonghandId::FontFamily => {
                                            PropertyDeclaration::FontFamily(
                                                longhands.font_family
                                            )
                                        }
                                        LonghandId::FontSizeAdjust => {
                                            PropertyDeclaration::FontSizeAdjust(
                                                longhands.font_size_adjust
                                            )
                                        }
                                        LonghandId::FontKerning => {
                                            PropertyDeclaration::FontKerning(
                                                longhands.font_kerning
                                            )
                                        }
                                        LonghandId::FontOpticalSizing => {
                                            PropertyDeclaration::FontOpticalSizing(
                                                longhands.font_optical_sizing
                                            )
                                        }
                                        LonghandId::FontVariantAlternates => {
                                            PropertyDeclaration::FontVariantAlternates(
                                                longhands.font_variant_alternates
                                            )
                                        }
                                        LonghandId::FontVariantEastAsian => {
                                            PropertyDeclaration::FontVariantEastAsian(
                                                longhands.font_variant_east_asian
                                            )
                                        }
                                        LonghandId::FontVariantLigatures => {
                                            PropertyDeclaration::FontVariantLigatures(
                                                longhands.font_variant_ligatures
                                            )
                                        }
                                        LonghandId::FontVariantNumeric => {
                                            PropertyDeclaration::FontVariantNumeric(
                                                longhands.font_variant_numeric
                                            )
                                        }
                                        LonghandId::FontVariantPosition => {
                                            PropertyDeclaration::FontVariantPosition(
                                                longhands.font_variant_position
                                            )
                                        }
                                        LonghandId::FontLanguageOverride => {
                                            PropertyDeclaration::FontLanguageOverride(
                                                longhands.font_language_override
                                            )
                                        }
                                        LonghandId::FontFeatureSettings => {
                                            PropertyDeclaration::FontFeatureSettings(
                                                longhands.font_feature_settings
                                            )
                                        }
                                        LonghandId::FontVariationSettings => {
                                            PropertyDeclaration::FontVariationSettings(
                                                longhands.font_variation_settings
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::FontVariant) => {
                            shorthands::font_variant::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::FontVariantCaps => {
                                            PropertyDeclaration::FontVariantCaps(
                                                longhands.font_variant_caps
                                            )
                                        }
                                        LonghandId::FontVariantAlternates => {
                                            PropertyDeclaration::FontVariantAlternates(
                                                longhands.font_variant_alternates
                                            )
                                        }
                                        LonghandId::FontVariantEastAsian => {
                                            PropertyDeclaration::FontVariantEastAsian(
                                                longhands.font_variant_east_asian
                                            )
                                        }
                                        LonghandId::FontVariantLigatures => {
                                            PropertyDeclaration::FontVariantLigatures(
                                                longhands.font_variant_ligatures
                                            )
                                        }
                                        LonghandId::FontVariantNumeric => {
                                            PropertyDeclaration::FontVariantNumeric(
                                                longhands.font_variant_numeric
                                            )
                                        }
                                        LonghandId::FontVariantPosition => {
                                            PropertyDeclaration::FontVariantPosition(
                                                longhands.font_variant_position
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::TextEmphasis) => {
                            shorthands::text_emphasis::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::TextEmphasisStyle => {
                                            PropertyDeclaration::TextEmphasisStyle(
                                                longhands.text_emphasis_style
                                            )
                                        }
                                        LonghandId::TextEmphasisColor => {
                                            PropertyDeclaration::TextEmphasisColor(
                                                longhands.text_emphasis_color
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::WebkitTextStroke) => {
                            shorthands::_webkit_text_stroke::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::WebkitTextStrokeWidth => {
                                            PropertyDeclaration::WebkitTextStrokeWidth(
                                                longhands._webkit_text_stroke_width
                                            )
                                        }
                                        LonghandId::WebkitTextStrokeColor => {
                                            PropertyDeclaration::WebkitTextStrokeColor(
                                                longhands._webkit_text_stroke_color
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::ListStyle) => {
                            shorthands::list_style::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::ListStylePosition => {
                                            PropertyDeclaration::ListStylePosition(
                                                longhands.list_style_position
                                            )
                                        }
                                        LonghandId::ListStyleImage => {
                                            PropertyDeclaration::ListStyleImage(
                                                longhands.list_style_image
                                            )
                                        }
                                        LonghandId::ListStyleType => {
                                            PropertyDeclaration::ListStyleType(
                                                longhands.list_style_type
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Margin) => {
                            shorthands::margin::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::MarginTop => {
                                            PropertyDeclaration::MarginTop(
                                                longhands.margin_top
                                            )
                                        }
                                        LonghandId::MarginRight => {
                                            PropertyDeclaration::MarginRight(
                                                longhands.margin_right
                                            )
                                        }
                                        LonghandId::MarginBottom => {
                                            PropertyDeclaration::MarginBottom(
                                                longhands.margin_bottom
                                            )
                                        }
                                        LonghandId::MarginLeft => {
                                            PropertyDeclaration::MarginLeft(
                                                longhands.margin_left
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Mask) => {
                            shorthands::mask::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::MaskMode => {
                                            PropertyDeclaration::MaskMode(
                                                longhands.mask_mode
                                            )
                                        }
                                        LonghandId::MaskRepeat => {
                                            PropertyDeclaration::MaskRepeat(
                                                longhands.mask_repeat
                                            )
                                        }
                                        LonghandId::MaskClip => {
                                            PropertyDeclaration::MaskClip(
                                                longhands.mask_clip
                                            )
                                        }
                                        LonghandId::MaskOrigin => {
                                            PropertyDeclaration::MaskOrigin(
                                                longhands.mask_origin
                                            )
                                        }
                                        LonghandId::MaskComposite => {
                                            PropertyDeclaration::MaskComposite(
                                                longhands.mask_composite
                                            )
                                        }
                                        LonghandId::MaskPositionX => {
                                            PropertyDeclaration::MaskPositionX(
                                                longhands.mask_position_x
                                            )
                                        }
                                        LonghandId::MaskPositionY => {
                                            PropertyDeclaration::MaskPositionY(
                                                longhands.mask_position_y
                                            )
                                        }
                                        LonghandId::MaskSize => {
                                            PropertyDeclaration::MaskSize(
                                                longhands.mask_size
                                            )
                                        }
                                        LonghandId::MaskImage => {
                                            PropertyDeclaration::MaskImage(
                                                longhands.mask_image
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::MaskPosition) => {
                            shorthands::mask_position::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::MaskPositionX => {
                                            PropertyDeclaration::MaskPositionX(
                                                longhands.mask_position_x
                                            )
                                        }
                                        LonghandId::MaskPositionY => {
                                            PropertyDeclaration::MaskPositionY(
                                                longhands.mask_position_y
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Outline) => {
                            shorthands::outline::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::OutlineWidth => {
                                            PropertyDeclaration::OutlineWidth(
                                                longhands.outline_width
                                            )
                                        }
                                        LonghandId::OutlineStyle => {
                                            PropertyDeclaration::OutlineStyle(
                                                longhands.outline_style
                                            )
                                        }
                                        LonghandId::OutlineColor => {
                                            PropertyDeclaration::OutlineColor(
                                                longhands.outline_color
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::MozOutlineRadius) => {
                            shorthands::_moz_outline_radius::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::MozOutlineRadiusTopleft => {
                                            PropertyDeclaration::MozOutlineRadiusTopleft(
                                                longhands._moz_outline_radius_topleft
                                            )
                                        }
                                        LonghandId::MozOutlineRadiusTopright => {
                                            PropertyDeclaration::MozOutlineRadiusTopright(
                                                longhands._moz_outline_radius_topright
                                            )
                                        }
                                        LonghandId::MozOutlineRadiusBottomright => {
                                            PropertyDeclaration::MozOutlineRadiusBottomright(
                                                longhands._moz_outline_radius_bottomright
                                            )
                                        }
                                        LonghandId::MozOutlineRadiusBottomleft => {
                                            PropertyDeclaration::MozOutlineRadiusBottomleft(
                                                longhands._moz_outline_radius_bottomleft
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Padding) => {
                            shorthands::padding::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::PaddingTop => {
                                            PropertyDeclaration::PaddingTop(
                                                longhands.padding_top
                                            )
                                        }
                                        LonghandId::PaddingRight => {
                                            PropertyDeclaration::PaddingRight(
                                                longhands.padding_right
                                            )
                                        }
                                        LonghandId::PaddingBottom => {
                                            PropertyDeclaration::PaddingBottom(
                                                longhands.padding_bottom
                                            )
                                        }
                                        LonghandId::PaddingLeft => {
                                            PropertyDeclaration::PaddingLeft(
                                                longhands.padding_left
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::FlexFlow) => {
                            shorthands::flex_flow::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::FlexDirection => {
                                            PropertyDeclaration::FlexDirection(
                                                longhands.flex_direction
                                            )
                                        }
                                        LonghandId::FlexWrap => {
                                            PropertyDeclaration::FlexWrap(
                                                longhands.flex_wrap
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Flex) => {
                            shorthands::flex::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::FlexGrow => {
                                            PropertyDeclaration::FlexGrow(
                                                longhands.flex_grow
                                            )
                                        }
                                        LonghandId::FlexShrink => {
                                            PropertyDeclaration::FlexShrink(
                                                longhands.flex_shrink
                                            )
                                        }
                                        LonghandId::FlexBasis => {
                                            PropertyDeclaration::FlexBasis(
                                                longhands.flex_basis
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::GridGap) => {
                            shorthands::grid_gap::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::GridRowGap => {
                                            PropertyDeclaration::GridRowGap(
                                                longhands.grid_row_gap
                                            )
                                        }
                                        LonghandId::GridColumnGap => {
                                            PropertyDeclaration::GridColumnGap(
                                                longhands.grid_column_gap
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::GridRow) => {
                            shorthands::grid_row::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::GridRowStart => {
                                            PropertyDeclaration::GridRowStart(
                                                longhands.grid_row_start
                                            )
                                        }
                                        LonghandId::GridRowEnd => {
                                            PropertyDeclaration::GridRowEnd(
                                                longhands.grid_row_end
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::GridColumn) => {
                            shorthands::grid_column::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::GridColumnStart => {
                                            PropertyDeclaration::GridColumnStart(
                                                longhands.grid_column_start
                                            )
                                        }
                                        LonghandId::GridColumnEnd => {
                                            PropertyDeclaration::GridColumnEnd(
                                                longhands.grid_column_end
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::GridArea) => {
                            shorthands::grid_area::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::GridRowStart => {
                                            PropertyDeclaration::GridRowStart(
                                                longhands.grid_row_start
                                            )
                                        }
                                        LonghandId::GridRowEnd => {
                                            PropertyDeclaration::GridRowEnd(
                                                longhands.grid_row_end
                                            )
                                        }
                                        LonghandId::GridColumnStart => {
                                            PropertyDeclaration::GridColumnStart(
                                                longhands.grid_column_start
                                            )
                                        }
                                        LonghandId::GridColumnEnd => {
                                            PropertyDeclaration::GridColumnEnd(
                                                longhands.grid_column_end
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::GridTemplate) => {
                            shorthands::grid_template::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::GridTemplateRows => {
                                            PropertyDeclaration::GridTemplateRows(
                                                longhands.grid_template_rows
                                            )
                                        }
                                        LonghandId::GridTemplateColumns => {
                                            PropertyDeclaration::GridTemplateColumns(
                                                longhands.grid_template_columns
                                            )
                                        }
                                        LonghandId::GridTemplateAreas => {
                                            PropertyDeclaration::GridTemplateAreas(
                                                longhands.grid_template_areas
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Grid) => {
                            shorthands::grid::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::GridTemplateRows => {
                                            PropertyDeclaration::GridTemplateRows(
                                                longhands.grid_template_rows
                                            )
                                        }
                                        LonghandId::GridTemplateColumns => {
                                            PropertyDeclaration::GridTemplateColumns(
                                                longhands.grid_template_columns
                                            )
                                        }
                                        LonghandId::GridTemplateAreas => {
                                            PropertyDeclaration::GridTemplateAreas(
                                                longhands.grid_template_areas
                                            )
                                        }
                                        LonghandId::GridAutoRows => {
                                            PropertyDeclaration::GridAutoRows(
                                                longhands.grid_auto_rows
                                            )
                                        }
                                        LonghandId::GridAutoColumns => {
                                            PropertyDeclaration::GridAutoColumns(
                                                longhands.grid_auto_columns
                                            )
                                        }
                                        LonghandId::GridAutoFlow => {
                                            PropertyDeclaration::GridAutoFlow(
                                                longhands.grid_auto_flow
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::PlaceContent) => {
                            shorthands::place_content::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::AlignContent => {
                                            PropertyDeclaration::AlignContent(
                                                longhands.align_content
                                            )
                                        }
                                        LonghandId::JustifyContent => {
                                            PropertyDeclaration::JustifyContent(
                                                longhands.justify_content
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::PlaceSelf) => {
                            shorthands::place_self::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::AlignSelf => {
                                            PropertyDeclaration::AlignSelf(
                                                longhands.align_self
                                            )
                                        }
                                        LonghandId::JustifySelf => {
                                            PropertyDeclaration::JustifySelf(
                                                longhands.justify_self
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::PlaceItems) => {
                            shorthands::place_items::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::AlignItems => {
                                            PropertyDeclaration::AlignItems(
                                                longhands.align_items
                                            )
                                        }
                                        LonghandId::JustifyItems => {
                                            PropertyDeclaration::JustifyItems(
                                                longhands.justify_items
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Marker) => {
                            shorthands::marker::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::MarkerStart => {
                                            PropertyDeclaration::MarkerStart(
                                                longhands.marker_start
                                            )
                                        }
                                        LonghandId::MarkerEnd => {
                                            PropertyDeclaration::MarkerEnd(
                                                longhands.marker_end
                                            )
                                        }
                                        LonghandId::MarkerMid => {
                                            PropertyDeclaration::MarkerMid(
                                                longhands.marker_mid
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::TextDecoration) => {
                            shorthands::text_decoration::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::TextDecorationLine => {
                                            PropertyDeclaration::TextDecorationLine(
                                                longhands.text_decoration_line
                                            )
                                        }
                                        LonghandId::TextDecorationStyle => {
                                            PropertyDeclaration::TextDecorationStyle(
                                                longhands.text_decoration_style
                                            )
                                        }
                                        LonghandId::TextDecorationColor => {
                                            PropertyDeclaration::TextDecorationColor(
                                                longhands.text_decoration_color
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                }
            })
            .ok()
        })
        .unwrap_or_else(|| {
            // Invalid at computed-value time.
            let keyword = if longhand_id.inherited() {
                CSSWideKeyword::Inherit
            } else {
                CSSWideKeyword::Initial
            };
            PropertyDeclaration::CSSWideKeyword(WideKeywordDeclaration {
                id: longhand_id,
                keyword,
        })
        })
    }
}

/// An identifier for a given property declaration, which can be either a
/// longhand or a custom property.
#[derive(Clone, Copy, PartialEq)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub enum PropertyDeclarationId<'a> {
    /// A longhand.
    Longhand(LonghandId),
    /// A custom property declaration.
    Custom(&'a ::custom_properties::Name),
}

impl<'a> ToCss for PropertyDeclarationId<'a> {
    fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
    where
        W: Write,
    {
        match *self {
            PropertyDeclarationId::Longhand(id) => dest.write_str(id.name()),
            PropertyDeclarationId::Custom(_) => {
                serialize_identifier(&self.name(), dest)
            }
        }
    }
}

impl<'a> PropertyDeclarationId<'a> {
    /// Whether a given declaration id is either the same as `other`, or a
    /// longhand of it.
    pub fn is_or_is_longhand_of(&self, other: &PropertyId) -> bool {
        match *self {
            PropertyDeclarationId::Longhand(id) => {
                match *other {
                    PropertyId::Longhand(other_id) |
                    PropertyId::LonghandAlias(other_id, _) => id == other_id,
                    PropertyId::Shorthand(shorthand) |
                    PropertyId::ShorthandAlias(shorthand, _) => self.is_longhand_of(shorthand),
                    PropertyId::Custom(_) => false,
                }
            }
            PropertyDeclarationId::Custom(name) => {
                matches!(*other, PropertyId::Custom(ref other_name) if name == other_name)
            }
        }
    }

    /// Whether a given declaration id is a longhand belonging to this
    /// shorthand.
    pub fn is_longhand_of(&self, shorthand: ShorthandId) -> bool {
        match *self {
            PropertyDeclarationId::Longhand(ref id) => id.shorthands().any(|s| s == shorthand),
            _ => false,
        }
    }

    /// Returns the name of the property without CSS escaping.
    pub fn name(&self) -> Cow<'static, str> {
        match *self {
            PropertyDeclarationId::Longhand(id) => id.name().into(),
            PropertyDeclarationId::Custom(name) => {
                let mut s = String::new();
                write!(&mut s, "--{}", name).unwrap();
                s.into()
            }
        }
    }
}

/// Servo's representation of a CSS property, that is, either a longhand, a
/// shorthand, or a custom property.
#[derive(Clone, Eq, PartialEq)]
pub enum PropertyId {
    /// A longhand property.
    Longhand(LonghandId),
    /// A shorthand property.
    Shorthand(ShorthandId),
    /// An alias for a longhand property.
    LonghandAlias(LonghandId, AliasId),
    /// An alias for a shorthand property.
    ShorthandAlias(ShorthandId, AliasId),
    /// A custom property.
    Custom(::custom_properties::Name),
}

impl fmt::Debug for PropertyId {
    fn fmt(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
        self.to_css(&mut CssWriter::new(formatter))
    }
}

impl ToCss for PropertyId {
    fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
    where
        W: Write,
    {
        match *self {
            PropertyId::Longhand(id) => dest.write_str(id.name()),
            PropertyId::Shorthand(id) => dest.write_str(id.name()),
            PropertyId::LonghandAlias(id, _) => dest.write_str(id.name()),
            PropertyId::ShorthandAlias(id, _) => dest.write_str(id.name()),
            PropertyId::Custom(_) => {
                serialize_identifier(&self.name(), dest)
            }
        }
    }
}

impl PropertyId {
    /// Return the longhand id that this property id represents.
    #[inline]
    pub fn longhand_id(&self) -> Option<LonghandId> {
        Some(match *self {
            PropertyId::Longhand(id) => id,
            PropertyId::LonghandAlias(id, _) => id,
            _ => return None,
        })
    }

    /// Returns a given property from the string `s`.
    ///
    /// Returns Err(()) for unknown non-custom properties.
    pub fn parse(property_name: &str) -> Result<Self, ()> {
        // FIXME(https://github.com/rust-lang/rust/issues/33156): remove this
        // enum and use PropertyId when stable Rust allows destructors in
        // statics.
        //
        // ShorthandAlias is not used in the Servo build.
        // That's why we need to allow dead_code.
        #[allow(dead_code)]
        pub enum StaticId {
            Longhand(LonghandId),
            Shorthand(ShorthandId),
            LonghandAlias(LonghandId, AliasId),
            ShorthandAlias(ShorthandId, AliasId),
        }
        ascii_case_insensitive_phf_map! {
            static_id -> StaticId = {
                        "align-content" => StaticId::Longhand(LonghandId::AlignContent),
                            "-webkit-align-content" => {
                                StaticId::LonghandAlias(LonghandId::AlignContent,
                                                       AliasId::WebkitAlignContent)
                            },
                        "align-items" => StaticId::Longhand(LonghandId::AlignItems),
                            "-webkit-align-items" => {
                                StaticId::LonghandAlias(LonghandId::AlignItems,
                                                       AliasId::WebkitAlignItems)
                            },
                        "align-self" => StaticId::Longhand(LonghandId::AlignSelf),
                            "-webkit-align-self" => {
                                StaticId::LonghandAlias(LonghandId::AlignSelf,
                                                       AliasId::WebkitAlignSelf)
                            },
                        "backface-visibility" => StaticId::Longhand(LonghandId::BackfaceVisibility),
                            "-moz-backface-visibility" => {
                                StaticId::LonghandAlias(LonghandId::BackfaceVisibility,
                                                       AliasId::MozBackfaceVisibility)
                            },
                            "-webkit-backface-visibility" => {
                                StaticId::LonghandAlias(LonghandId::BackfaceVisibility,
                                                       AliasId::WebkitBackfaceVisibility)
                            },
                        "border-collapse" => StaticId::Longhand(LonghandId::BorderCollapse),
                        "border-image-repeat" => StaticId::Longhand(LonghandId::BorderImageRepeat),
                        "box-decoration-break" => StaticId::Longhand(LonghandId::BoxDecorationBreak),
                        "box-sizing" => StaticId::Longhand(LonghandId::BoxSizing),
                            "-moz-box-sizing" => {
                                StaticId::LonghandAlias(LonghandId::BoxSizing,
                                                       AliasId::MozBoxSizing)
                            },
                            "-webkit-box-sizing" => {
                                StaticId::LonghandAlias(LonghandId::BoxSizing,
                                                       AliasId::WebkitBoxSizing)
                            },
                        "caption-side" => StaticId::Longhand(LonghandId::CaptionSide),
                        "clear" => StaticId::Longhand(LonghandId::Clear),
                        "clip-rule" => StaticId::Longhand(LonghandId::ClipRule),
                        "color-adjust" => StaticId::Longhand(LonghandId::ColorAdjust),
                        "color-interpolation" => StaticId::Longhand(LonghandId::ColorInterpolation),
                        "color-interpolation-filters" => StaticId::Longhand(LonghandId::ColorInterpolationFilters),
                        "column-count" => StaticId::Longhand(LonghandId::ColumnCount),
                            "-moz-column-count" => {
                                StaticId::LonghandAlias(LonghandId::ColumnCount,
                                                       AliasId::MozColumnCount)
                            },
                        "column-fill" => StaticId::Longhand(LonghandId::ColumnFill),
                            "-moz-column-fill" => {
                                StaticId::LonghandAlias(LonghandId::ColumnFill,
                                                       AliasId::MozColumnFill)
                            },
                        "column-rule-style" => StaticId::Longhand(LonghandId::ColumnRuleStyle),
                            "-moz-column-rule-style" => {
                                StaticId::LonghandAlias(LonghandId::ColumnRuleStyle,
                                                       AliasId::MozColumnRuleStyle)
                            },
                        "column-span" => StaticId::Longhand(LonghandId::ColumnSpan),
                            "-moz-column-span" => {
                                StaticId::LonghandAlias(LonghandId::ColumnSpan,
                                                       AliasId::MozColumnSpan)
                            },
                        "contain" => StaticId::Longhand(LonghandId::Contain),
                        "direction" => StaticId::Longhand(LonghandId::Direction),
                        "dominant-baseline" => StaticId::Longhand(LonghandId::DominantBaseline),
                        "empty-cells" => StaticId::Longhand(LonghandId::EmptyCells),
                        "fill-rule" => StaticId::Longhand(LonghandId::FillRule),
                        "flex-direction" => StaticId::Longhand(LonghandId::FlexDirection),
                            "-webkit-flex-direction" => {
                                StaticId::LonghandAlias(LonghandId::FlexDirection,
                                                       AliasId::WebkitFlexDirection)
                            },
                        "flex-wrap" => StaticId::Longhand(LonghandId::FlexWrap),
                            "-webkit-flex-wrap" => {
                                StaticId::LonghandAlias(LonghandId::FlexWrap,
                                                       AliasId::WebkitFlexWrap)
                            },
                        "float" => StaticId::Longhand(LonghandId::Float),
                        "font-kerning" => StaticId::Longhand(LonghandId::FontKerning),
                        "font-optical-sizing" => StaticId::Longhand(LonghandId::FontOpticalSizing),
                        "font-stretch" => StaticId::Longhand(LonghandId::FontStretch),
                        "font-style" => StaticId::Longhand(LonghandId::FontStyle),
                        "font-synthesis" => StaticId::Longhand(LonghandId::FontSynthesis),
                        "font-variant-caps" => StaticId::Longhand(LonghandId::FontVariantCaps),
                        "font-variant-position" => StaticId::Longhand(LonghandId::FontVariantPosition),
                        "font-weight" => StaticId::Longhand(LonghandId::FontWeight),
                        "grid-auto-flow" => StaticId::Longhand(LonghandId::GridAutoFlow),
                        "hyphens" => StaticId::Longhand(LonghandId::Hyphens),
                            "-moz-hyphens" => {
                                StaticId::LonghandAlias(LonghandId::Hyphens,
                                                       AliasId::MozHyphens)
                            },
                        "image-orientation" => StaticId::Longhand(LonghandId::ImageOrientation),
                        "image-rendering" => StaticId::Longhand(LonghandId::ImageRendering),
                        "ime-mode" => StaticId::Longhand(LonghandId::ImeMode),
                        "initial-letter" => StaticId::Longhand(LonghandId::InitialLetter),
                        "isolation" => StaticId::Longhand(LonghandId::Isolation),
                        "justify-content" => StaticId::Longhand(LonghandId::JustifyContent),
                            "-webkit-justify-content" => {
                                StaticId::LonghandAlias(LonghandId::JustifyContent,
                                                       AliasId::WebkitJustifyContent)
                            },
                        "justify-items" => StaticId::Longhand(LonghandId::JustifyItems),
                        "justify-self" => StaticId::Longhand(LonghandId::JustifySelf),
                        "list-style-position" => StaticId::Longhand(LonghandId::ListStylePosition),
                        "mask-type" => StaticId::Longhand(LonghandId::MaskType),
                        "mix-blend-mode" => StaticId::Longhand(LonghandId::MixBlendMode),
                        "-moz-appearance" => StaticId::Longhand(LonghandId::MozAppearance),
                        "-moz-box-align" => StaticId::Longhand(LonghandId::MozBoxAlign),
                            "-webkit-box-align" => {
                                StaticId::LonghandAlias(LonghandId::MozBoxAlign,
                                                       AliasId::WebkitBoxAlign)
                            },
                        "-moz-box-direction" => StaticId::Longhand(LonghandId::MozBoxDirection),
                            "-webkit-box-direction" => {
                                StaticId::LonghandAlias(LonghandId::MozBoxDirection,
                                                       AliasId::WebkitBoxDirection)
                            },
                        "-moz-box-orient" => StaticId::Longhand(LonghandId::MozBoxOrient),
                            "-webkit-box-orient" => {
                                StaticId::LonghandAlias(LonghandId::MozBoxOrient,
                                                       AliasId::WebkitBoxOrient)
                            },
                        "-moz-box-pack" => StaticId::Longhand(LonghandId::MozBoxPack),
                            "-webkit-box-pack" => {
                                StaticId::LonghandAlias(LonghandId::MozBoxPack,
                                                       AliasId::WebkitBoxPack)
                            },
                        "-moz-control-character-visibility" => StaticId::Longhand(LonghandId::MozControlCharacterVisibility),
                        "-moz-float-edge" => StaticId::Longhand(LonghandId::MozFloatEdge),
                        "-moz-force-broken-image-icon" => StaticId::Longhand(LonghandId::MozForceBrokenImageIcon),
                        "-moz-math-display" => StaticId::Longhand(LonghandId::MozMathDisplay),
                        "-moz-math-variant" => StaticId::Longhand(LonghandId::MozMathVariant),
                        "-moz-min-font-size-ratio" => StaticId::Longhand(LonghandId::MozMinFontSizeRatio),
                        "-moz-orient" => StaticId::Longhand(LonghandId::MozOrient),
                        "-moz-osx-font-smoothing" => StaticId::Longhand(LonghandId::MozOsxFontSmoothing),
                        "-moz-script-level" => StaticId::Longhand(LonghandId::MozScriptLevel),
                        "-moz-script-min-size" => StaticId::Longhand(LonghandId::MozScriptMinSize),
                        "-moz-script-size-multiplier" => StaticId::Longhand(LonghandId::MozScriptSizeMultiplier),
                        "-moz-stack-sizing" => StaticId::Longhand(LonghandId::MozStackSizing),
                        "-moz-text-size-adjust" => StaticId::Longhand(LonghandId::MozTextSizeAdjust),
                            "-webkit-text-size-adjust" => {
                                StaticId::LonghandAlias(LonghandId::MozTextSizeAdjust,
                                                       AliasId::WebkitTextSizeAdjust)
                            },
                        "-moz-top-layer" => StaticId::Longhand(LonghandId::MozTopLayer),
                        "-moz-user-focus" => StaticId::Longhand(LonghandId::MozUserFocus),
                        "-moz-user-input" => StaticId::Longhand(LonghandId::MozUserInput),
                        "-moz-user-modify" => StaticId::Longhand(LonghandId::MozUserModify),
                        "-moz-user-select" => StaticId::Longhand(LonghandId::MozUserSelect),
                            "-webkit-user-select" => {
                                StaticId::LonghandAlias(LonghandId::MozUserSelect,
                                                       AliasId::WebkitUserSelect)
                            },
                        "-moz-window-dragging" => StaticId::Longhand(LonghandId::MozWindowDragging),
                        "-moz-window-shadow" => StaticId::Longhand(LonghandId::MozWindowShadow),
                        "object-fit" => StaticId::Longhand(LonghandId::ObjectFit),
                        "outline-style" => StaticId::Longhand(LonghandId::OutlineStyle),
                        "overflow-wrap" => StaticId::Longhand(LonghandId::OverflowWrap),
                            "word-wrap" => {
                                StaticId::LonghandAlias(LonghandId::OverflowWrap,
                                                       AliasId::WordWrap)
                            },
                        "overflow-x" => StaticId::Longhand(LonghandId::OverflowX),
                        "page-break-after" => StaticId::Longhand(LonghandId::PageBreakAfter),
                        "page-break-before" => StaticId::Longhand(LonghandId::PageBreakBefore),
                        "page-break-inside" => StaticId::Longhand(LonghandId::PageBreakInside),
                        "paint-order" => StaticId::Longhand(LonghandId::PaintOrder),
                        "pointer-events" => StaticId::Longhand(LonghandId::PointerEvents),
                        "position" => StaticId::Longhand(LonghandId::Position),
                        "resize" => StaticId::Longhand(LonghandId::Resize),
                        "ruby-align" => StaticId::Longhand(LonghandId::RubyAlign),
                        "ruby-position" => StaticId::Longhand(LonghandId::RubyPosition),
                        "scroll-behavior" => StaticId::Longhand(LonghandId::ScrollBehavior),
                        "shape-rendering" => StaticId::Longhand(LonghandId::ShapeRendering),
                        "stroke-linecap" => StaticId::Longhand(LonghandId::StrokeLinecap),
                        "stroke-linejoin" => StaticId::Longhand(LonghandId::StrokeLinejoin),
                        "table-layout" => StaticId::Longhand(LonghandId::TableLayout),
                        "text-align-last" => StaticId::Longhand(LonghandId::TextAlignLast),
                        "text-anchor" => StaticId::Longhand(LonghandId::TextAnchor),
                        "text-combine-upright" => StaticId::Longhand(LonghandId::TextCombineUpright),
                        "text-decoration-line" => StaticId::Longhand(LonghandId::TextDecorationLine),
                        "text-decoration-style" => StaticId::Longhand(LonghandId::TextDecorationStyle),
                        "text-justify" => StaticId::Longhand(LonghandId::TextJustify),
                        "text-orientation" => StaticId::Longhand(LonghandId::TextOrientation),
                        "text-rendering" => StaticId::Longhand(LonghandId::TextRendering),
                        "text-transform" => StaticId::Longhand(LonghandId::TextTransform),
                        "touch-action" => StaticId::Longhand(LonghandId::TouchAction),
                        "transform-box" => StaticId::Longhand(LonghandId::TransformBox),
                        "transform-style" => StaticId::Longhand(LonghandId::TransformStyle),
                            "-moz-transform-style" => {
                                StaticId::LonghandAlias(LonghandId::TransformStyle,
                                                       AliasId::MozTransformStyle)
                            },
                            "-webkit-transform-style" => {
                                StaticId::LonghandAlias(LonghandId::TransformStyle,
                                                       AliasId::WebkitTransformStyle)
                            },
                        "unicode-bidi" => StaticId::Longhand(LonghandId::UnicodeBidi),
                        "vector-effect" => StaticId::Longhand(LonghandId::VectorEffect),
                        "visibility" => StaticId::Longhand(LonghandId::Visibility),
                        "white-space" => StaticId::Longhand(LonghandId::WhiteSpace),
                        "word-break" => StaticId::Longhand(LonghandId::WordBreak),
                        "writing-mode" => StaticId::Longhand(LonghandId::WritingMode),
                        "-x-span" => StaticId::Longhand(LonghandId::XSpan),
                        "-x-text-zoom" => StaticId::Longhand(LonghandId::XTextZoom),
                        "z-index" => StaticId::Longhand(LonghandId::ZIndex),
                        "-moz-box-ordinal-group" => StaticId::Longhand(LonghandId::MozBoxOrdinalGroup),
                            "-webkit-box-ordinal-group" => {
                                StaticId::LonghandAlias(LonghandId::MozBoxOrdinalGroup,
                                                       AliasId::WebkitBoxOrdinalGroup)
                            },
                        "order" => StaticId::Longhand(LonghandId::Order),
                            "-webkit-order" => {
                                StaticId::LonghandAlias(LonghandId::Order,
                                                       AliasId::WebkitOrder)
                            },
                        "overscroll-behavior-x" => StaticId::Longhand(LonghandId::OverscrollBehaviorX),
                        "overscroll-behavior-y" => StaticId::Longhand(LonghandId::OverscrollBehaviorY),
                        "scroll-snap-type-x" => StaticId::Longhand(LonghandId::ScrollSnapTypeX),
                        "scroll-snap-type-y" => StaticId::Longhand(LonghandId::ScrollSnapTypeY),
                        "flex-grow" => StaticId::Longhand(LonghandId::FlexGrow),
                            "-webkit-flex-grow" => {
                                StaticId::LonghandAlias(LonghandId::FlexGrow,
                                                       AliasId::WebkitFlexGrow)
                            },
                        "flex-shrink" => StaticId::Longhand(LonghandId::FlexShrink),
                            "-webkit-flex-shrink" => {
                                StaticId::LonghandAlias(LonghandId::FlexShrink,
                                                       AliasId::WebkitFlexShrink)
                            },
                        "-moz-box-flex" => StaticId::Longhand(LonghandId::MozBoxFlex),
                            "-webkit-box-flex" => {
                                StaticId::LonghandAlias(LonghandId::MozBoxFlex,
                                                       AliasId::WebkitBoxFlex)
                            },
                        "flood-opacity" => StaticId::Longhand(LonghandId::FloodOpacity),
                        "-moz-window-opacity" => StaticId::Longhand(LonghandId::MozWindowOpacity),
                        "opacity" => StaticId::Longhand(LonghandId::Opacity),
                        "shape-image-threshold" => StaticId::Longhand(LonghandId::ShapeImageThreshold),
                        "stop-opacity" => StaticId::Longhand(LonghandId::StopOpacity),
                        "border-block-end-style" => StaticId::Longhand(LonghandId::BorderBlockEndStyle),
                        "border-block-start-style" => StaticId::Longhand(LonghandId::BorderBlockStartStyle),
                        "border-bottom-style" => StaticId::Longhand(LonghandId::BorderBottomStyle),
                        "border-inline-end-style" => StaticId::Longhand(LonghandId::BorderInlineEndStyle),
                            "-moz-border-end-style" => {
                                StaticId::LonghandAlias(LonghandId::BorderInlineEndStyle,
                                                       AliasId::MozBorderEndStyle)
                            },
                        "border-inline-start-style" => StaticId::Longhand(LonghandId::BorderInlineStartStyle),
                            "-moz-border-start-style" => {
                                StaticId::LonghandAlias(LonghandId::BorderInlineStartStyle,
                                                       AliasId::MozBorderStartStyle)
                            },
                        "border-left-style" => StaticId::Longhand(LonghandId::BorderLeftStyle),
                        "border-right-style" => StaticId::Longhand(LonghandId::BorderRightStyle),
                        "border-top-style" => StaticId::Longhand(LonghandId::BorderTopStyle),
                        "animation-delay" => StaticId::Longhand(LonghandId::AnimationDelay),
                            "-moz-animation-delay" => {
                                StaticId::LonghandAlias(LonghandId::AnimationDelay,
                                                       AliasId::MozAnimationDelay)
                            },
                            "-webkit-animation-delay" => {
                                StaticId::LonghandAlias(LonghandId::AnimationDelay,
                                                       AliasId::WebkitAnimationDelay)
                            },
                        "animation-direction" => StaticId::Longhand(LonghandId::AnimationDirection),
                            "-moz-animation-direction" => {
                                StaticId::LonghandAlias(LonghandId::AnimationDirection,
                                                       AliasId::MozAnimationDirection)
                            },
                            "-webkit-animation-direction" => {
                                StaticId::LonghandAlias(LonghandId::AnimationDirection,
                                                       AliasId::WebkitAnimationDirection)
                            },
                        "animation-duration" => StaticId::Longhand(LonghandId::AnimationDuration),
                            "-moz-animation-duration" => {
                                StaticId::LonghandAlias(LonghandId::AnimationDuration,
                                                       AliasId::MozAnimationDuration)
                            },
                            "-webkit-animation-duration" => {
                                StaticId::LonghandAlias(LonghandId::AnimationDuration,
                                                       AliasId::WebkitAnimationDuration)
                            },
                        "animation-fill-mode" => StaticId::Longhand(LonghandId::AnimationFillMode),
                            "-moz-animation-fill-mode" => {
                                StaticId::LonghandAlias(LonghandId::AnimationFillMode,
                                                       AliasId::MozAnimationFillMode)
                            },
                            "-webkit-animation-fill-mode" => {
                                StaticId::LonghandAlias(LonghandId::AnimationFillMode,
                                                       AliasId::WebkitAnimationFillMode)
                            },
                        "animation-iteration-count" => StaticId::Longhand(LonghandId::AnimationIterationCount),
                            "-moz-animation-iteration-count" => {
                                StaticId::LonghandAlias(LonghandId::AnimationIterationCount,
                                                       AliasId::MozAnimationIterationCount)
                            },
                            "-webkit-animation-iteration-count" => {
                                StaticId::LonghandAlias(LonghandId::AnimationIterationCount,
                                                       AliasId::WebkitAnimationIterationCount)
                            },
                        "animation-name" => StaticId::Longhand(LonghandId::AnimationName),
                            "-moz-animation-name" => {
                                StaticId::LonghandAlias(LonghandId::AnimationName,
                                                       AliasId::MozAnimationName)
                            },
                            "-webkit-animation-name" => {
                                StaticId::LonghandAlias(LonghandId::AnimationName,
                                                       AliasId::WebkitAnimationName)
                            },
                        "animation-play-state" => StaticId::Longhand(LonghandId::AnimationPlayState),
                            "-moz-animation-play-state" => {
                                StaticId::LonghandAlias(LonghandId::AnimationPlayState,
                                                       AliasId::MozAnimationPlayState)
                            },
                            "-webkit-animation-play-state" => {
                                StaticId::LonghandAlias(LonghandId::AnimationPlayState,
                                                       AliasId::WebkitAnimationPlayState)
                            },
                        "animation-timing-function" => StaticId::Longhand(LonghandId::AnimationTimingFunction),
                            "-moz-animation-timing-function" => {
                                StaticId::LonghandAlias(LonghandId::AnimationTimingFunction,
                                                       AliasId::MozAnimationTimingFunction)
                            },
                            "-webkit-animation-timing-function" => {
                                StaticId::LonghandAlias(LonghandId::AnimationTimingFunction,
                                                       AliasId::WebkitAnimationTimingFunction)
                            },
                        "background-attachment" => StaticId::Longhand(LonghandId::BackgroundAttachment),
                        "background-blend-mode" => StaticId::Longhand(LonghandId::BackgroundBlendMode),
                        "background-clip" => StaticId::Longhand(LonghandId::BackgroundClip),
                            "-webkit-background-clip" => {
                                StaticId::LonghandAlias(LonghandId::BackgroundClip,
                                                       AliasId::WebkitBackgroundClip)
                            },
                        "background-image" => StaticId::Longhand(LonghandId::BackgroundImage),
                        "background-origin" => StaticId::Longhand(LonghandId::BackgroundOrigin),
                            "-webkit-background-origin" => {
                                StaticId::LonghandAlias(LonghandId::BackgroundOrigin,
                                                       AliasId::WebkitBackgroundOrigin)
                            },
                        "background-position-x" => StaticId::Longhand(LonghandId::BackgroundPositionX),
                        "background-position-y" => StaticId::Longhand(LonghandId::BackgroundPositionY),
                        "background-repeat" => StaticId::Longhand(LonghandId::BackgroundRepeat),
                        "background-size" => StaticId::Longhand(LonghandId::BackgroundSize),
                            "-webkit-background-size" => {
                                StaticId::LonghandAlias(LonghandId::BackgroundSize,
                                                       AliasId::WebkitBackgroundSize)
                            },
                        "border-image-outset" => StaticId::Longhand(LonghandId::BorderImageOutset),
                        "border-image-slice" => StaticId::Longhand(LonghandId::BorderImageSlice),
                        "border-image-source" => StaticId::Longhand(LonghandId::BorderImageSource),
                        "border-image-width" => StaticId::Longhand(LonghandId::BorderImageWidth),
                        "border-spacing" => StaticId::Longhand(LonghandId::BorderSpacing),
                        "box-shadow" => StaticId::Longhand(LonghandId::BoxShadow),
                            "-webkit-box-shadow" => {
                                StaticId::LonghandAlias(LonghandId::BoxShadow,
                                                       AliasId::WebkitBoxShadow)
                            },
                        "caret-color" => StaticId::Longhand(LonghandId::CaretColor),
                        "clip-path" => StaticId::Longhand(LonghandId::ClipPath),
                        "color" => StaticId::Longhand(LonghandId::Color),
                        "column-gap" => StaticId::Longhand(LonghandId::ColumnGap),
                            "-moz-column-gap" => {
                                StaticId::LonghandAlias(LonghandId::ColumnGap,
                                                       AliasId::MozColumnGap)
                            },
                        "column-width" => StaticId::Longhand(LonghandId::ColumnWidth),
                            "-moz-column-width" => {
                                StaticId::LonghandAlias(LonghandId::ColumnWidth,
                                                       AliasId::MozColumnWidth)
                            },
                        "content" => StaticId::Longhand(LonghandId::Content),
                        "counter-increment" => StaticId::Longhand(LonghandId::CounterIncrement),
                        "counter-reset" => StaticId::Longhand(LonghandId::CounterReset),
                        "cursor" => StaticId::Longhand(LonghandId::Cursor),
                        "display" => StaticId::Longhand(LonghandId::Display),
                        "filter" => StaticId::Longhand(LonghandId::Filter),
                            "-webkit-filter" => {
                                StaticId::LonghandAlias(LonghandId::Filter,
                                                       AliasId::WebkitFilter)
                            },
                        "font-family" => StaticId::Longhand(LonghandId::FontFamily),
                        "font-feature-settings" => StaticId::Longhand(LonghandId::FontFeatureSettings),
                            "-moz-font-feature-settings" => {
                                StaticId::LonghandAlias(LonghandId::FontFeatureSettings,
                                                       AliasId::MozFontFeatureSettings)
                            },
                        "font-language-override" => StaticId::Longhand(LonghandId::FontLanguageOverride),
                            "-moz-font-language-override" => {
                                StaticId::LonghandAlias(LonghandId::FontLanguageOverride,
                                                       AliasId::MozFontLanguageOverride)
                            },
                        "font-size" => StaticId::Longhand(LonghandId::FontSize),
                        "font-size-adjust" => StaticId::Longhand(LonghandId::FontSizeAdjust),
                        "font-variant-alternates" => StaticId::Longhand(LonghandId::FontVariantAlternates),
                        "font-variant-east-asian" => StaticId::Longhand(LonghandId::FontVariantEastAsian),
                        "font-variant-ligatures" => StaticId::Longhand(LonghandId::FontVariantLigatures),
                        "font-variant-numeric" => StaticId::Longhand(LonghandId::FontVariantNumeric),
                        "font-variation-settings" => StaticId::Longhand(LonghandId::FontVariationSettings),
                        "grid-template-areas" => StaticId::Longhand(LonghandId::GridTemplateAreas),
                        "letter-spacing" => StaticId::Longhand(LonghandId::LetterSpacing),
                        "line-height" => StaticId::Longhand(LonghandId::LineHeight),
                        "list-style-image" => StaticId::Longhand(LonghandId::ListStyleImage),
                        "list-style-type" => StaticId::Longhand(LonghandId::ListStyleType),
                        "mask-clip" => StaticId::Longhand(LonghandId::MaskClip),
                            "-webkit-mask-clip" => {
                                StaticId::LonghandAlias(LonghandId::MaskClip,
                                                       AliasId::WebkitMaskClip)
                            },
                        "mask-composite" => StaticId::Longhand(LonghandId::MaskComposite),
                            "-webkit-mask-composite" => {
                                StaticId::LonghandAlias(LonghandId::MaskComposite,
                                                       AliasId::WebkitMaskComposite)
                            },
                        "mask-image" => StaticId::Longhand(LonghandId::MaskImage),
                            "-webkit-mask-image" => {
                                StaticId::LonghandAlias(LonghandId::MaskImage,
                                                       AliasId::WebkitMaskImage)
                            },
                        "mask-mode" => StaticId::Longhand(LonghandId::MaskMode),
                        "mask-origin" => StaticId::Longhand(LonghandId::MaskOrigin),
                            "-webkit-mask-origin" => {
                                StaticId::LonghandAlias(LonghandId::MaskOrigin,
                                                       AliasId::WebkitMaskOrigin)
                            },
                        "mask-position-x" => StaticId::Longhand(LonghandId::MaskPositionX),
                            "-webkit-mask-position-x" => {
                                StaticId::LonghandAlias(LonghandId::MaskPositionX,
                                                       AliasId::WebkitMaskPositionX)
                            },
                        "mask-position-y" => StaticId::Longhand(LonghandId::MaskPositionY),
                            "-webkit-mask-position-y" => {
                                StaticId::LonghandAlias(LonghandId::MaskPositionY,
                                                       AliasId::WebkitMaskPositionY)
                            },
                        "mask-repeat" => StaticId::Longhand(LonghandId::MaskRepeat),
                            "-webkit-mask-repeat" => {
                                StaticId::LonghandAlias(LonghandId::MaskRepeat,
                                                       AliasId::WebkitMaskRepeat)
                            },
                        "mask-size" => StaticId::Longhand(LonghandId::MaskSize),
                            "-webkit-mask-size" => {
                                StaticId::LonghandAlias(LonghandId::MaskSize,
                                                       AliasId::WebkitMaskSize)
                            },
                        "-moz-context-properties" => StaticId::Longhand(LonghandId::MozContextProperties),
                        "-moz-tab-size" => StaticId::Longhand(LonghandId::MozTabSize),
                        "outline-offset" => StaticId::Longhand(LonghandId::OutlineOffset),
                        "overflow-y" => StaticId::Longhand(LonghandId::OverflowY),
                        "perspective" => StaticId::Longhand(LonghandId::Perspective),
                            "-moz-perspective" => {
                                StaticId::LonghandAlias(LonghandId::Perspective,
                                                       AliasId::MozPerspective)
                            },
                            "-webkit-perspective" => {
                                StaticId::LonghandAlias(LonghandId::Perspective,
                                                       AliasId::WebkitPerspective)
                            },
                        "perspective-origin" => StaticId::Longhand(LonghandId::PerspectiveOrigin),
                            "-moz-perspective-origin" => {
                                StaticId::LonghandAlias(LonghandId::PerspectiveOrigin,
                                                       AliasId::MozPerspectiveOrigin)
                            },
                            "-webkit-perspective-origin" => {
                                StaticId::LonghandAlias(LonghandId::PerspectiveOrigin,
                                                       AliasId::WebkitPerspectiveOrigin)
                            },
                        "quotes" => StaticId::Longhand(LonghandId::Quotes),
                        "rotate" => StaticId::Longhand(LonghandId::Rotate),
                        "scale" => StaticId::Longhand(LonghandId::Scale),
                        "scroll-snap-coordinate" => StaticId::Longhand(LonghandId::ScrollSnapCoordinate),
                        "shape-outside" => StaticId::Longhand(LonghandId::ShapeOutside),
                        "stroke-dasharray" => StaticId::Longhand(LonghandId::StrokeDasharray),
                        "stroke-dashoffset" => StaticId::Longhand(LonghandId::StrokeDashoffset),
                        "stroke-miterlimit" => StaticId::Longhand(LonghandId::StrokeMiterlimit),
                        "stroke-width" => StaticId::Longhand(LonghandId::StrokeWidth),
                        "text-align" => StaticId::Longhand(LonghandId::TextAlign),
                        "text-emphasis-position" => StaticId::Longhand(LonghandId::TextEmphasisPosition),
                        "text-emphasis-style" => StaticId::Longhand(LonghandId::TextEmphasisStyle),
                        "text-indent" => StaticId::Longhand(LonghandId::TextIndent),
                        "text-overflow" => StaticId::Longhand(LonghandId::TextOverflow),
                        "text-shadow" => StaticId::Longhand(LonghandId::TextShadow),
                        "transition-delay" => StaticId::Longhand(LonghandId::TransitionDelay),
                            "-moz-transition-delay" => {
                                StaticId::LonghandAlias(LonghandId::TransitionDelay,
                                                       AliasId::MozTransitionDelay)
                            },
                            "-webkit-transition-delay" => {
                                StaticId::LonghandAlias(LonghandId::TransitionDelay,
                                                       AliasId::WebkitTransitionDelay)
                            },
                        "transition-duration" => StaticId::Longhand(LonghandId::TransitionDuration),
                            "-moz-transition-duration" => {
                                StaticId::LonghandAlias(LonghandId::TransitionDuration,
                                                       AliasId::MozTransitionDuration)
                            },
                            "-webkit-transition-duration" => {
                                StaticId::LonghandAlias(LonghandId::TransitionDuration,
                                                       AliasId::WebkitTransitionDuration)
                            },
                        "transition-property" => StaticId::Longhand(LonghandId::TransitionProperty),
                            "-moz-transition-property" => {
                                StaticId::LonghandAlias(LonghandId::TransitionProperty,
                                                       AliasId::MozTransitionProperty)
                            },
                            "-webkit-transition-property" => {
                                StaticId::LonghandAlias(LonghandId::TransitionProperty,
                                                       AliasId::WebkitTransitionProperty)
                            },
                        "transition-timing-function" => StaticId::Longhand(LonghandId::TransitionTimingFunction),
                            "-moz-transition-timing-function" => {
                                StaticId::LonghandAlias(LonghandId::TransitionTimingFunction,
                                                       AliasId::MozTransitionTimingFunction)
                            },
                            "-webkit-transition-timing-function" => {
                                StaticId::LonghandAlias(LonghandId::TransitionTimingFunction,
                                                       AliasId::WebkitTransitionTimingFunction)
                            },
                        "translate" => StaticId::Longhand(LonghandId::Translate),
                        "vertical-align" => StaticId::Longhand(LonghandId::VerticalAlign),
                        "will-change" => StaticId::Longhand(LonghandId::WillChange),
                        "word-spacing" => StaticId::Longhand(LonghandId::WordSpacing),
                        "-x-lang" => StaticId::Longhand(LonghandId::XLang),
                        "overflow-clip-box-block" => StaticId::Longhand(LonghandId::OverflowClipBoxBlock),
                        "overflow-clip-box-inline" => StaticId::Longhand(LonghandId::OverflowClipBoxInline),
                        "fill-opacity" => StaticId::Longhand(LonghandId::FillOpacity),
                        "stroke-opacity" => StaticId::Longhand(LonghandId::StrokeOpacity),
                        "scroll-snap-points-x" => StaticId::Longhand(LonghandId::ScrollSnapPointsX),
                        "scroll-snap-points-y" => StaticId::Longhand(LonghandId::ScrollSnapPointsY),
                        "-moz-window-transform" => StaticId::Longhand(LonghandId::MozWindowTransform),
                        "transform" => StaticId::Longhand(LonghandId::Transform),
                            "-webkit-transform" => {
                                StaticId::LonghandAlias(LonghandId::Transform,
                                                       AliasId::WebkitTransform)
                            },
                            "-moz-transform" => {
                                StaticId::LonghandAlias(LonghandId::Transform,
                                                       AliasId::MozTransform)
                            },
                        "clip" => StaticId::Longhand(LonghandId::Clip),
                        "-moz-image-region" => StaticId::Longhand(LonghandId::MozImageRegion),
                        "grid-template-columns" => StaticId::Longhand(LonghandId::GridTemplateColumns),
                        "grid-template-rows" => StaticId::Longhand(LonghandId::GridTemplateRows),
                        "object-position" => StaticId::Longhand(LonghandId::ObjectPosition),
                        "scroll-snap-destination" => StaticId::Longhand(LonghandId::ScrollSnapDestination),
                        "fill" => StaticId::Longhand(LonghandId::Fill),
                        "stroke" => StaticId::Longhand(LonghandId::Stroke),
                        "grid-auto-columns" => StaticId::Longhand(LonghandId::GridAutoColumns),
                        "grid-auto-rows" => StaticId::Longhand(LonghandId::GridAutoRows),
                        "-moz-window-transform-origin" => StaticId::Longhand(LonghandId::MozWindowTransformOrigin),
                        "transform-origin" => StaticId::Longhand(LonghandId::TransformOrigin),
                            "-moz-transform-origin" => {
                                StaticId::LonghandAlias(LonghandId::TransformOrigin,
                                                       AliasId::MozTransformOrigin)
                            },
                            "-webkit-transform-origin" => {
                                StaticId::LonghandAlias(LonghandId::TransformOrigin,
                                                       AliasId::WebkitTransformOrigin)
                            },
                        "max-block-size" => StaticId::Longhand(LonghandId::MaxBlockSize),
                        "max-height" => StaticId::Longhand(LonghandId::MaxHeight),
                        "max-inline-size" => StaticId::Longhand(LonghandId::MaxInlineSize),
                        "max-width" => StaticId::Longhand(LonghandId::MaxWidth),
                        "flood-color" => StaticId::Longhand(LonghandId::FloodColor),
                        "lighting-color" => StaticId::Longhand(LonghandId::LightingColor),
                        "-moz-font-smoothing-background-color" => StaticId::Longhand(LonghandId::MozFontSmoothingBackgroundColor),
                        "stop-color" => StaticId::Longhand(LonghandId::StopColor),
                        "marker-end" => StaticId::Longhand(LonghandId::MarkerEnd),
                        "marker-mid" => StaticId::Longhand(LonghandId::MarkerMid),
                        "marker-start" => StaticId::Longhand(LonghandId::MarkerStart),
                        "-moz-binding" => StaticId::Longhand(LonghandId::MozBinding),
                        "grid-column-end" => StaticId::Longhand(LonghandId::GridColumnEnd),
                        "grid-column-start" => StaticId::Longhand(LonghandId::GridColumnStart),
                        "grid-row-end" => StaticId::Longhand(LonghandId::GridRowEnd),
                        "grid-row-start" => StaticId::Longhand(LonghandId::GridRowStart),
                        "border-bottom-left-radius" => StaticId::Longhand(LonghandId::BorderBottomLeftRadius),
                            "-webkit-border-bottom-left-radius" => {
                                StaticId::LonghandAlias(LonghandId::BorderBottomLeftRadius,
                                                       AliasId::WebkitBorderBottomLeftRadius)
                            },
                        "border-bottom-right-radius" => StaticId::Longhand(LonghandId::BorderBottomRightRadius),
                            "-webkit-border-bottom-right-radius" => {
                                StaticId::LonghandAlias(LonghandId::BorderBottomRightRadius,
                                                       AliasId::WebkitBorderBottomRightRadius)
                            },
                        "border-top-left-radius" => StaticId::Longhand(LonghandId::BorderTopLeftRadius),
                            "-webkit-border-top-left-radius" => {
                                StaticId::LonghandAlias(LonghandId::BorderTopLeftRadius,
                                                       AliasId::WebkitBorderTopLeftRadius)
                            },
                        "border-top-right-radius" => StaticId::Longhand(LonghandId::BorderTopRightRadius),
                            "-webkit-border-top-right-radius" => {
                                StaticId::LonghandAlias(LonghandId::BorderTopRightRadius,
                                                       AliasId::WebkitBorderTopRightRadius)
                            },
                        "-moz-outline-radius-bottomleft" => StaticId::Longhand(LonghandId::MozOutlineRadiusBottomleft),
                        "-moz-outline-radius-bottomright" => StaticId::Longhand(LonghandId::MozOutlineRadiusBottomright),
                        "-moz-outline-radius-topleft" => StaticId::Longhand(LonghandId::MozOutlineRadiusTopleft),
                        "-moz-outline-radius-topright" => StaticId::Longhand(LonghandId::MozOutlineRadiusTopright),
                        "block-size" => StaticId::Longhand(LonghandId::BlockSize),
                        "flex-basis" => StaticId::Longhand(LonghandId::FlexBasis),
                            "-webkit-flex-basis" => {
                                StaticId::LonghandAlias(LonghandId::FlexBasis,
                                                       AliasId::WebkitFlexBasis)
                            },
                        "height" => StaticId::Longhand(LonghandId::Height),
                        "inline-size" => StaticId::Longhand(LonghandId::InlineSize),
                        "min-block-size" => StaticId::Longhand(LonghandId::MinBlockSize),
                        "min-height" => StaticId::Longhand(LonghandId::MinHeight),
                        "min-inline-size" => StaticId::Longhand(LonghandId::MinInlineSize),
                        "min-width" => StaticId::Longhand(LonghandId::MinWidth),
                        "width" => StaticId::Longhand(LonghandId::Width),
                        "grid-column-gap" => StaticId::Longhand(LonghandId::GridColumnGap),
                        "grid-row-gap" => StaticId::Longhand(LonghandId::GridRowGap),
                        "padding-block-end" => StaticId::Longhand(LonghandId::PaddingBlockEnd),
                        "padding-block-start" => StaticId::Longhand(LonghandId::PaddingBlockStart),
                        "padding-bottom" => StaticId::Longhand(LonghandId::PaddingBottom),
                        "padding-inline-end" => StaticId::Longhand(LonghandId::PaddingInlineEnd),
                            "-moz-padding-end" => {
                                StaticId::LonghandAlias(LonghandId::PaddingInlineEnd,
                                                       AliasId::MozPaddingEnd)
                            },
                        "padding-inline-start" => StaticId::Longhand(LonghandId::PaddingInlineStart),
                            "-moz-padding-start" => {
                                StaticId::LonghandAlias(LonghandId::PaddingInlineStart,
                                                       AliasId::MozPaddingStart)
                            },
                        "padding-left" => StaticId::Longhand(LonghandId::PaddingLeft),
                        "padding-right" => StaticId::Longhand(LonghandId::PaddingRight),
                        "padding-top" => StaticId::Longhand(LonghandId::PaddingTop),
                        "border-block-end-width" => StaticId::Longhand(LonghandId::BorderBlockEndWidth),
                        "border-block-start-width" => StaticId::Longhand(LonghandId::BorderBlockStartWidth),
                        "border-bottom-width" => StaticId::Longhand(LonghandId::BorderBottomWidth),
                        "border-inline-end-width" => StaticId::Longhand(LonghandId::BorderInlineEndWidth),
                            "-moz-border-end-width" => {
                                StaticId::LonghandAlias(LonghandId::BorderInlineEndWidth,
                                                       AliasId::MozBorderEndWidth)
                            },
                        "border-inline-start-width" => StaticId::Longhand(LonghandId::BorderInlineStartWidth),
                            "-moz-border-start-width" => {
                                StaticId::LonghandAlias(LonghandId::BorderInlineStartWidth,
                                                       AliasId::MozBorderStartWidth)
                            },
                        "border-left-width" => StaticId::Longhand(LonghandId::BorderLeftWidth),
                        "border-right-width" => StaticId::Longhand(LonghandId::BorderRightWidth),
                        "border-top-width" => StaticId::Longhand(LonghandId::BorderTopWidth),
                        "column-rule-width" => StaticId::Longhand(LonghandId::ColumnRuleWidth),
                            "-moz-column-rule-width" => {
                                StaticId::LonghandAlias(LonghandId::ColumnRuleWidth,
                                                       AliasId::MozColumnRuleWidth)
                            },
                        "outline-width" => StaticId::Longhand(LonghandId::OutlineWidth),
                        "-webkit-text-stroke-width" => StaticId::Longhand(LonghandId::WebkitTextStrokeWidth),
                        "background-color" => StaticId::Longhand(LonghandId::BackgroundColor),
                        "border-block-end-color" => StaticId::Longhand(LonghandId::BorderBlockEndColor),
                        "border-block-start-color" => StaticId::Longhand(LonghandId::BorderBlockStartColor),
                        "border-bottom-color" => StaticId::Longhand(LonghandId::BorderBottomColor),
                        "border-inline-end-color" => StaticId::Longhand(LonghandId::BorderInlineEndColor),
                            "-moz-border-end-color" => {
                                StaticId::LonghandAlias(LonghandId::BorderInlineEndColor,
                                                       AliasId::MozBorderEndColor)
                            },
                        "border-inline-start-color" => StaticId::Longhand(LonghandId::BorderInlineStartColor),
                            "-moz-border-start-color" => {
                                StaticId::LonghandAlias(LonghandId::BorderInlineStartColor,
                                                       AliasId::MozBorderStartColor)
                            },
                        "border-left-color" => StaticId::Longhand(LonghandId::BorderLeftColor),
                        "border-right-color" => StaticId::Longhand(LonghandId::BorderRightColor),
                        "border-top-color" => StaticId::Longhand(LonghandId::BorderTopColor),
                        "column-rule-color" => StaticId::Longhand(LonghandId::ColumnRuleColor),
                            "-moz-column-rule-color" => {
                                StaticId::LonghandAlias(LonghandId::ColumnRuleColor,
                                                       AliasId::MozColumnRuleColor)
                            },
                        "outline-color" => StaticId::Longhand(LonghandId::OutlineColor),
                        "text-decoration-color" => StaticId::Longhand(LonghandId::TextDecorationColor),
                        "text-emphasis-color" => StaticId::Longhand(LonghandId::TextEmphasisColor),
                        "-webkit-text-fill-color" => StaticId::Longhand(LonghandId::WebkitTextFillColor),
                        "-webkit-text-stroke-color" => StaticId::Longhand(LonghandId::WebkitTextStrokeColor),
                        "bottom" => StaticId::Longhand(LonghandId::Bottom),
                        "left" => StaticId::Longhand(LonghandId::Left),
                        "margin-block-end" => StaticId::Longhand(LonghandId::MarginBlockEnd),
                        "margin-block-start" => StaticId::Longhand(LonghandId::MarginBlockStart),
                        "margin-bottom" => StaticId::Longhand(LonghandId::MarginBottom),
                        "margin-inline-end" => StaticId::Longhand(LonghandId::MarginInlineEnd),
                            "-moz-margin-end" => {
                                StaticId::LonghandAlias(LonghandId::MarginInlineEnd,
                                                       AliasId::MozMarginEnd)
                            },
                        "margin-inline-start" => StaticId::Longhand(LonghandId::MarginInlineStart),
                            "-moz-margin-start" => {
                                StaticId::LonghandAlias(LonghandId::MarginInlineStart,
                                                       AliasId::MozMarginStart)
                            },
                        "margin-left" => StaticId::Longhand(LonghandId::MarginLeft),
                        "margin-right" => StaticId::Longhand(LonghandId::MarginRight),
                        "margin-top" => StaticId::Longhand(LonghandId::MarginTop),
                        "offset-block-end" => StaticId::Longhand(LonghandId::OffsetBlockEnd),
                        "offset-block-start" => StaticId::Longhand(LonghandId::OffsetBlockStart),
                        "offset-inline-end" => StaticId::Longhand(LonghandId::OffsetInlineEnd),
                        "offset-inline-start" => StaticId::Longhand(LonghandId::OffsetInlineStart),
                        "right" => StaticId::Longhand(LonghandId::Right),
                        "top" => StaticId::Longhand(LonghandId::Top),
                        "background" => StaticId::Shorthand(ShorthandId::Background),
                        "background-position" => StaticId::Shorthand(ShorthandId::BackgroundPosition),
                        "border-color" => StaticId::Shorthand(ShorthandId::BorderColor),
                        "border-style" => StaticId::Shorthand(ShorthandId::BorderStyle),
                        "border-width" => StaticId::Shorthand(ShorthandId::BorderWidth),
                        "border-top" => StaticId::Shorthand(ShorthandId::BorderTop),
                        "border-left" => StaticId::Shorthand(ShorthandId::BorderLeft),
                        "border-bottom" => StaticId::Shorthand(ShorthandId::BorderBottom),
                        "border-right" => StaticId::Shorthand(ShorthandId::BorderRight),
                        "border-block-start" => StaticId::Shorthand(ShorthandId::BorderBlockStart),
                        "border-block-end" => StaticId::Shorthand(ShorthandId::BorderBlockEnd),
                        "border-inline-start" => StaticId::Shorthand(ShorthandId::BorderInlineStart),
                            "-moz-border-start" => {
                                StaticId::ShorthandAlias(ShorthandId::BorderInlineStart,
                                                       AliasId::MozBorderStart)
                            },
                        "border-inline-end" => StaticId::Shorthand(ShorthandId::BorderInlineEnd),
                            "-moz-border-end" => {
                                StaticId::ShorthandAlias(ShorthandId::BorderInlineEnd,
                                                       AliasId::MozBorderEnd)
                            },
                        "border" => StaticId::Shorthand(ShorthandId::Border),
                        "border-radius" => StaticId::Shorthand(ShorthandId::BorderRadius),
                            "-webkit-border-radius" => {
                                StaticId::ShorthandAlias(ShorthandId::BorderRadius,
                                                       AliasId::WebkitBorderRadius)
                            },
                        "border-image" => StaticId::Shorthand(ShorthandId::BorderImage),
                            "-moz-border-image" => {
                                StaticId::ShorthandAlias(ShorthandId::BorderImage,
                                                       AliasId::MozBorderImage)
                            },
                            "-webkit-border-image" => {
                                StaticId::ShorthandAlias(ShorthandId::BorderImage,
                                                       AliasId::WebkitBorderImage)
                            },
                        "overflow" => StaticId::Shorthand(ShorthandId::Overflow),
                        "overflow-clip-box" => StaticId::Shorthand(ShorthandId::OverflowClipBox),
                        "transition" => StaticId::Shorthand(ShorthandId::Transition),
                            "-moz-transition" => {
                                StaticId::ShorthandAlias(ShorthandId::Transition,
                                                       AliasId::MozTransition)
                            },
                            "-webkit-transition" => {
                                StaticId::ShorthandAlias(ShorthandId::Transition,
                                                       AliasId::WebkitTransition)
                            },
                        "animation" => StaticId::Shorthand(ShorthandId::Animation),
                            "-moz-animation" => {
                                StaticId::ShorthandAlias(ShorthandId::Animation,
                                                       AliasId::MozAnimation)
                            },
                            "-webkit-animation" => {
                                StaticId::ShorthandAlias(ShorthandId::Animation,
                                                       AliasId::WebkitAnimation)
                            },
                        "scroll-snap-type" => StaticId::Shorthand(ShorthandId::ScrollSnapType),
                        "overscroll-behavior" => StaticId::Shorthand(ShorthandId::OverscrollBehavior),
                        "columns" => StaticId::Shorthand(ShorthandId::Columns),
                            "-moz-columns" => {
                                StaticId::ShorthandAlias(ShorthandId::Columns,
                                                       AliasId::MozColumns)
                            },
                        "column-rule" => StaticId::Shorthand(ShorthandId::ColumnRule),
                            "-moz-column-rule" => {
                                StaticId::ShorthandAlias(ShorthandId::ColumnRule,
                                                       AliasId::MozColumnRule)
                            },
                        "font" => StaticId::Shorthand(ShorthandId::Font),
                        "font-variant" => StaticId::Shorthand(ShorthandId::FontVariant),
                        "text-emphasis" => StaticId::Shorthand(ShorthandId::TextEmphasis),
                        "-webkit-text-stroke" => StaticId::Shorthand(ShorthandId::WebkitTextStroke),
                        "list-style" => StaticId::Shorthand(ShorthandId::ListStyle),
                        "margin" => StaticId::Shorthand(ShorthandId::Margin),
                        "mask" => StaticId::Shorthand(ShorthandId::Mask),
                            "-webkit-mask" => {
                                StaticId::ShorthandAlias(ShorthandId::Mask,
                                                       AliasId::WebkitMask)
                            },
                        "mask-position" => StaticId::Shorthand(ShorthandId::MaskPosition),
                            "-webkit-mask-position" => {
                                StaticId::ShorthandAlias(ShorthandId::MaskPosition,
                                                       AliasId::WebkitMaskPosition)
                            },
                        "outline" => StaticId::Shorthand(ShorthandId::Outline),
                        "-moz-outline-radius" => StaticId::Shorthand(ShorthandId::MozOutlineRadius),
                        "padding" => StaticId::Shorthand(ShorthandId::Padding),
                        "flex-flow" => StaticId::Shorthand(ShorthandId::FlexFlow),
                            "-webkit-flex-flow" => {
                                StaticId::ShorthandAlias(ShorthandId::FlexFlow,
                                                       AliasId::WebkitFlexFlow)
                            },
                        "flex" => StaticId::Shorthand(ShorthandId::Flex),
                            "-webkit-flex" => {
                                StaticId::ShorthandAlias(ShorthandId::Flex,
                                                       AliasId::WebkitFlex)
                            },
                        "grid-gap" => StaticId::Shorthand(ShorthandId::GridGap),
                        "grid-row" => StaticId::Shorthand(ShorthandId::GridRow),
                        "grid-column" => StaticId::Shorthand(ShorthandId::GridColumn),
                        "grid-area" => StaticId::Shorthand(ShorthandId::GridArea),
                        "grid-template" => StaticId::Shorthand(ShorthandId::GridTemplate),
                        "grid" => StaticId::Shorthand(ShorthandId::Grid),
                        "place-content" => StaticId::Shorthand(ShorthandId::PlaceContent),
                        "place-self" => StaticId::Shorthand(ShorthandId::PlaceSelf),
                        "place-items" => StaticId::Shorthand(ShorthandId::PlaceItems),
                        "marker" => StaticId::Shorthand(ShorthandId::Marker),
                        "text-decoration" => StaticId::Shorthand(ShorthandId::TextDecoration),
                        "all" => StaticId::Shorthand(ShorthandId::All),
            }
        }

        Ok(match static_id(property_name) {
            Some(&StaticId::Longhand(id)) => {
                PropertyId::Longhand(id)
            },
            Some(&StaticId::Shorthand(id)) => {
                PropertyId::Shorthand(id)
            },
            Some(&StaticId::LonghandAlias(id, alias)) => {
                PropertyId::LonghandAlias(id, alias)
            },
            Some(&StaticId::ShorthandAlias(id, alias)) => {
                PropertyId::ShorthandAlias(id, alias)
            },
            None => {
                return ::custom_properties::parse_name(property_name).map(|name| {
                    PropertyId::Custom(::custom_properties::Name::from(name))
                })
            },
        })
    }

    /// Returns a property id from Gecko's nsCSSPropertyID.
    #[cfg(feature = "gecko")]
    #[allow(non_upper_case_globals)]
    pub fn from_nscsspropertyid(id: nsCSSPropertyID) -> Result<Self, ()> {
        use gecko_bindings::structs::*;
        match id {
                
    nsCSSPropertyID::eCSSProperty_align_content => {
                    Ok(PropertyId::Longhand(LonghandId::AlignContent))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAlignContent => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AlignContent,
                            AliasId::WebkitAlignContent
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_align_items => {
                    Ok(PropertyId::Longhand(LonghandId::AlignItems))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAlignItems => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AlignItems,
                            AliasId::WebkitAlignItems
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_align_self => {
                    Ok(PropertyId::Longhand(LonghandId::AlignSelf))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAlignSelf => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AlignSelf,
                            AliasId::WebkitAlignSelf
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_backface_visibility => {
                    Ok(PropertyId::Longhand(LonghandId::BackfaceVisibility))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBackfaceVisibility => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BackfaceVisibility,
                            AliasId::MozBackfaceVisibility
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackfaceVisibility => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BackfaceVisibility,
                            AliasId::WebkitBackfaceVisibility
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_collapse => {
                    Ok(PropertyId::Longhand(LonghandId::BorderCollapse))
                }
                
    nsCSSPropertyID::eCSSProperty_border_image_repeat => {
                    Ok(PropertyId::Longhand(LonghandId::BorderImageRepeat))
                }
                
    nsCSSPropertyID::eCSSProperty_box_decoration_break => {
                    Ok(PropertyId::Longhand(LonghandId::BoxDecorationBreak))
                }
                
    nsCSSPropertyID::eCSSProperty_box_sizing => {
                    Ok(PropertyId::Longhand(LonghandId::BoxSizing))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBoxSizing => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BoxSizing,
                            AliasId::MozBoxSizing
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxSizing => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BoxSizing,
                            AliasId::WebkitBoxSizing
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_caption_side => {
                    Ok(PropertyId::Longhand(LonghandId::CaptionSide))
                }
                
    nsCSSPropertyID::eCSSProperty_clear => {
                    Ok(PropertyId::Longhand(LonghandId::Clear))
                }
                
    nsCSSPropertyID::eCSSProperty_clip_rule => {
                    Ok(PropertyId::Longhand(LonghandId::ClipRule))
                }
                
    nsCSSPropertyID::eCSSProperty_color_adjust => {
                    Ok(PropertyId::Longhand(LonghandId::ColorAdjust))
                }
                
    nsCSSPropertyID::eCSSProperty_color_interpolation => {
                    Ok(PropertyId::Longhand(LonghandId::ColorInterpolation))
                }
                
    nsCSSPropertyID::eCSSProperty_color_interpolation_filters => {
                    Ok(PropertyId::Longhand(LonghandId::ColorInterpolationFilters))
                }
                
    nsCSSPropertyID::eCSSProperty_column_count => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnCount))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnCount => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnCount,
                            AliasId::MozColumnCount
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_column_fill => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnFill))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnFill => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnFill,
                            AliasId::MozColumnFill
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_column_rule_style => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnRuleStyle))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRuleStyle => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnRuleStyle,
                            AliasId::MozColumnRuleStyle
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_column_span => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnSpan))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnSpan => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnSpan,
                            AliasId::MozColumnSpan
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_contain => {
                    Ok(PropertyId::Longhand(LonghandId::Contain))
                }
                
    nsCSSPropertyID::eCSSProperty_direction => {
                    Ok(PropertyId::Longhand(LonghandId::Direction))
                }
                
    nsCSSPropertyID::eCSSProperty_dominant_baseline => {
                    Ok(PropertyId::Longhand(LonghandId::DominantBaseline))
                }
                
    nsCSSPropertyID::eCSSProperty_empty_cells => {
                    Ok(PropertyId::Longhand(LonghandId::EmptyCells))
                }
                
    nsCSSPropertyID::eCSSProperty_fill_rule => {
                    Ok(PropertyId::Longhand(LonghandId::FillRule))
                }
                
    nsCSSPropertyID::eCSSProperty_flex_direction => {
                    Ok(PropertyId::Longhand(LonghandId::FlexDirection))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexDirection => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::FlexDirection,
                            AliasId::WebkitFlexDirection
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_flex_wrap => {
                    Ok(PropertyId::Longhand(LonghandId::FlexWrap))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexWrap => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::FlexWrap,
                            AliasId::WebkitFlexWrap
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_float_ => {
                    Ok(PropertyId::Longhand(LonghandId::Float))
                }
                
    nsCSSPropertyID::eCSSProperty_font_kerning => {
                    Ok(PropertyId::Longhand(LonghandId::FontKerning))
                }
                
    nsCSSPropertyID::eCSSProperty_font_optical_sizing => {
                    Ok(PropertyId::Longhand(LonghandId::FontOpticalSizing))
                }
                
    nsCSSPropertyID::eCSSProperty_font_stretch => {
                    Ok(PropertyId::Longhand(LonghandId::FontStretch))
                }
                
    nsCSSPropertyID::eCSSProperty_font_style => {
                    Ok(PropertyId::Longhand(LonghandId::FontStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_font_synthesis => {
                    Ok(PropertyId::Longhand(LonghandId::FontSynthesis))
                }
                
    nsCSSPropertyID::eCSSProperty_font_variant_caps => {
                    Ok(PropertyId::Longhand(LonghandId::FontVariantCaps))
                }
                
    nsCSSPropertyID::eCSSProperty_font_variant_position => {
                    Ok(PropertyId::Longhand(LonghandId::FontVariantPosition))
                }
                
    nsCSSPropertyID::eCSSProperty_font_weight => {
                    Ok(PropertyId::Longhand(LonghandId::FontWeight))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_auto_flow => {
                    Ok(PropertyId::Longhand(LonghandId::GridAutoFlow))
                }
                
    nsCSSPropertyID::eCSSProperty_hyphens => {
                    Ok(PropertyId::Longhand(LonghandId::Hyphens))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozHyphens => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::Hyphens,
                            AliasId::MozHyphens
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_image_orientation => {
                    Ok(PropertyId::Longhand(LonghandId::ImageOrientation))
                }
                
    nsCSSPropertyID::eCSSProperty_image_rendering => {
                    Ok(PropertyId::Longhand(LonghandId::ImageRendering))
                }
                
    nsCSSPropertyID::eCSSProperty_ime_mode => {
                    Ok(PropertyId::Longhand(LonghandId::ImeMode))
                }
                
    nsCSSPropertyID::eCSSProperty_initial_letter => {
                    Ok(PropertyId::Longhand(LonghandId::InitialLetter))
                }
                
    nsCSSPropertyID::eCSSProperty_isolation => {
                    Ok(PropertyId::Longhand(LonghandId::Isolation))
                }
                
    nsCSSPropertyID::eCSSProperty_justify_content => {
                    Ok(PropertyId::Longhand(LonghandId::JustifyContent))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitJustifyContent => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::JustifyContent,
                            AliasId::WebkitJustifyContent
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_justify_items => {
                    Ok(PropertyId::Longhand(LonghandId::JustifyItems))
                }
                
    nsCSSPropertyID::eCSSProperty_justify_self => {
                    Ok(PropertyId::Longhand(LonghandId::JustifySelf))
                }
                
    nsCSSPropertyID::eCSSProperty_list_style_position => {
                    Ok(PropertyId::Longhand(LonghandId::ListStylePosition))
                }
                
    nsCSSPropertyID::eCSSProperty_mask_type => {
                    Ok(PropertyId::Longhand(LonghandId::MaskType))
                }
                
    nsCSSPropertyID::eCSSProperty_mix_blend_mode => {
                    Ok(PropertyId::Longhand(LonghandId::MixBlendMode))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_appearance => {
                    Ok(PropertyId::Longhand(LonghandId::MozAppearance))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_box_align => {
                    Ok(PropertyId::Longhand(LonghandId::MozBoxAlign))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxAlign => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozBoxAlign,
                            AliasId::WebkitBoxAlign
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_box_direction => {
                    Ok(PropertyId::Longhand(LonghandId::MozBoxDirection))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxDirection => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozBoxDirection,
                            AliasId::WebkitBoxDirection
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_box_orient => {
                    Ok(PropertyId::Longhand(LonghandId::MozBoxOrient))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxOrient => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozBoxOrient,
                            AliasId::WebkitBoxOrient
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_box_pack => {
                    Ok(PropertyId::Longhand(LonghandId::MozBoxPack))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxPack => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozBoxPack,
                            AliasId::WebkitBoxPack
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_control_character_visibility => {
                    Ok(PropertyId::Longhand(LonghandId::MozControlCharacterVisibility))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_float_edge => {
                    Ok(PropertyId::Longhand(LonghandId::MozFloatEdge))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_force_broken_image_icon => {
                    Ok(PropertyId::Longhand(LonghandId::MozForceBrokenImageIcon))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_math_display => {
                    Ok(PropertyId::Longhand(LonghandId::MozMathDisplay))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_math_variant => {
                    Ok(PropertyId::Longhand(LonghandId::MozMathVariant))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_min_font_size_ratio => {
                    Ok(PropertyId::Longhand(LonghandId::MozMinFontSizeRatio))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_orient => {
                    Ok(PropertyId::Longhand(LonghandId::MozOrient))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_osx_font_smoothing => {
                    Ok(PropertyId::Longhand(LonghandId::MozOsxFontSmoothing))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_script_level => {
                    Ok(PropertyId::Longhand(LonghandId::MozScriptLevel))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_script_min_size => {
                    Ok(PropertyId::Longhand(LonghandId::MozScriptMinSize))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_script_size_multiplier => {
                    Ok(PropertyId::Longhand(LonghandId::MozScriptSizeMultiplier))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_stack_sizing => {
                    Ok(PropertyId::Longhand(LonghandId::MozStackSizing))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_text_size_adjust => {
                    Ok(PropertyId::Longhand(LonghandId::MozTextSizeAdjust))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTextSizeAdjust => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozTextSizeAdjust,
                            AliasId::WebkitTextSizeAdjust
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_top_layer => {
                    Ok(PropertyId::Longhand(LonghandId::MozTopLayer))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_user_focus => {
                    Ok(PropertyId::Longhand(LonghandId::MozUserFocus))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_user_input => {
                    Ok(PropertyId::Longhand(LonghandId::MozUserInput))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_user_modify => {
                    Ok(PropertyId::Longhand(LonghandId::MozUserModify))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_user_select => {
                    Ok(PropertyId::Longhand(LonghandId::MozUserSelect))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitUserSelect => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozUserSelect,
                            AliasId::WebkitUserSelect
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_window_dragging => {
                    Ok(PropertyId::Longhand(LonghandId::MozWindowDragging))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_window_shadow => {
                    Ok(PropertyId::Longhand(LonghandId::MozWindowShadow))
                }
                
    nsCSSPropertyID::eCSSProperty_object_fit => {
                    Ok(PropertyId::Longhand(LonghandId::ObjectFit))
                }
                
    nsCSSPropertyID::eCSSProperty_outline_style => {
                    Ok(PropertyId::Longhand(LonghandId::OutlineStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_overflow_wrap => {
                    Ok(PropertyId::Longhand(LonghandId::OverflowWrap))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WordWrap => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::OverflowWrap,
                            AliasId::WordWrap
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_overflow_x => {
                    Ok(PropertyId::Longhand(LonghandId::OverflowX))
                }
                
    nsCSSPropertyID::eCSSProperty_page_break_after => {
                    Ok(PropertyId::Longhand(LonghandId::PageBreakAfter))
                }
                
    nsCSSPropertyID::eCSSProperty_page_break_before => {
                    Ok(PropertyId::Longhand(LonghandId::PageBreakBefore))
                }
                
    nsCSSPropertyID::eCSSProperty_page_break_inside => {
                    Ok(PropertyId::Longhand(LonghandId::PageBreakInside))
                }
                
    nsCSSPropertyID::eCSSProperty_paint_order => {
                    Ok(PropertyId::Longhand(LonghandId::PaintOrder))
                }
                
    nsCSSPropertyID::eCSSProperty_pointer_events => {
                    Ok(PropertyId::Longhand(LonghandId::PointerEvents))
                }
                
    nsCSSPropertyID::eCSSProperty_position => {
                    Ok(PropertyId::Longhand(LonghandId::Position))
                }
                
    nsCSSPropertyID::eCSSProperty_resize => {
                    Ok(PropertyId::Longhand(LonghandId::Resize))
                }
                
    nsCSSPropertyID::eCSSProperty_ruby_align => {
                    Ok(PropertyId::Longhand(LonghandId::RubyAlign))
                }
                
    nsCSSPropertyID::eCSSProperty_ruby_position => {
                    Ok(PropertyId::Longhand(LonghandId::RubyPosition))
                }
                
    nsCSSPropertyID::eCSSProperty_scroll_behavior => {
                    Ok(PropertyId::Longhand(LonghandId::ScrollBehavior))
                }
                
    nsCSSPropertyID::eCSSProperty_shape_rendering => {
                    Ok(PropertyId::Longhand(LonghandId::ShapeRendering))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke_linecap => {
                    Ok(PropertyId::Longhand(LonghandId::StrokeLinecap))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke_linejoin => {
                    Ok(PropertyId::Longhand(LonghandId::StrokeLinejoin))
                }
                
    nsCSSPropertyID::eCSSProperty_table_layout => {
                    Ok(PropertyId::Longhand(LonghandId::TableLayout))
                }
                
    nsCSSPropertyID::eCSSProperty_text_align_last => {
                    Ok(PropertyId::Longhand(LonghandId::TextAlignLast))
                }
                
    nsCSSPropertyID::eCSSProperty_text_anchor => {
                    Ok(PropertyId::Longhand(LonghandId::TextAnchor))
                }
                
    nsCSSPropertyID::eCSSProperty_text_combine_upright => {
                    Ok(PropertyId::Longhand(LonghandId::TextCombineUpright))
                }
                
    nsCSSPropertyID::eCSSProperty_text_decoration_line => {
                    Ok(PropertyId::Longhand(LonghandId::TextDecorationLine))
                }
                
    nsCSSPropertyID::eCSSProperty_text_decoration_style => {
                    Ok(PropertyId::Longhand(LonghandId::TextDecorationStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_text_justify => {
                    Ok(PropertyId::Longhand(LonghandId::TextJustify))
                }
                
    nsCSSPropertyID::eCSSProperty_text_orientation => {
                    Ok(PropertyId::Longhand(LonghandId::TextOrientation))
                }
                
    nsCSSPropertyID::eCSSProperty_text_rendering => {
                    Ok(PropertyId::Longhand(LonghandId::TextRendering))
                }
                
    nsCSSPropertyID::eCSSProperty_text_transform => {
                    Ok(PropertyId::Longhand(LonghandId::TextTransform))
                }
                
    nsCSSPropertyID::eCSSProperty_touch_action => {
                    Ok(PropertyId::Longhand(LonghandId::TouchAction))
                }
                
    nsCSSPropertyID::eCSSProperty_transform_box => {
                    Ok(PropertyId::Longhand(LonghandId::TransformBox))
                }
                
    nsCSSPropertyID::eCSSProperty_transform_style => {
                    Ok(PropertyId::Longhand(LonghandId::TransformStyle))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransformStyle => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransformStyle,
                            AliasId::MozTransformStyle
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransformStyle => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransformStyle,
                            AliasId::WebkitTransformStyle
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_unicode_bidi => {
                    Ok(PropertyId::Longhand(LonghandId::UnicodeBidi))
                }
                
    nsCSSPropertyID::eCSSProperty_vector_effect => {
                    Ok(PropertyId::Longhand(LonghandId::VectorEffect))
                }
                
    nsCSSPropertyID::eCSSProperty_visibility => {
                    Ok(PropertyId::Longhand(LonghandId::Visibility))
                }
                
    nsCSSPropertyID::eCSSProperty_white_space => {
                    Ok(PropertyId::Longhand(LonghandId::WhiteSpace))
                }
                
    nsCSSPropertyID::eCSSProperty_word_break => {
                    Ok(PropertyId::Longhand(LonghandId::WordBreak))
                }
                
    nsCSSPropertyID::eCSSProperty_writing_mode => {
                    Ok(PropertyId::Longhand(LonghandId::WritingMode))
                }
                
    nsCSSPropertyID::eCSSProperty__x_span => {
                    Ok(PropertyId::Longhand(LonghandId::XSpan))
                }
                
    nsCSSPropertyID::eCSSProperty__x_text_zoom => {
                    Ok(PropertyId::Longhand(LonghandId::XTextZoom))
                }
                
    nsCSSPropertyID::eCSSProperty_z_index => {
                    Ok(PropertyId::Longhand(LonghandId::ZIndex))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_box_ordinal_group => {
                    Ok(PropertyId::Longhand(LonghandId::MozBoxOrdinalGroup))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxOrdinalGroup => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozBoxOrdinalGroup,
                            AliasId::WebkitBoxOrdinalGroup
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_order => {
                    Ok(PropertyId::Longhand(LonghandId::Order))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitOrder => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::Order,
                            AliasId::WebkitOrder
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_x => {
                    Ok(PropertyId::Longhand(LonghandId::OverscrollBehaviorX))
                }
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_y => {
                    Ok(PropertyId::Longhand(LonghandId::OverscrollBehaviorY))
                }
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_x => {
                    Ok(PropertyId::Longhand(LonghandId::ScrollSnapTypeX))
                }
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_y => {
                    Ok(PropertyId::Longhand(LonghandId::ScrollSnapTypeY))
                }
                
    nsCSSPropertyID::eCSSProperty_flex_grow => {
                    Ok(PropertyId::Longhand(LonghandId::FlexGrow))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexGrow => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::FlexGrow,
                            AliasId::WebkitFlexGrow
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_flex_shrink => {
                    Ok(PropertyId::Longhand(LonghandId::FlexShrink))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexShrink => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::FlexShrink,
                            AliasId::WebkitFlexShrink
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_box_flex => {
                    Ok(PropertyId::Longhand(LonghandId::MozBoxFlex))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxFlex => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozBoxFlex,
                            AliasId::WebkitBoxFlex
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_flood_opacity => {
                    Ok(PropertyId::Longhand(LonghandId::FloodOpacity))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_window_opacity => {
                    Ok(PropertyId::Longhand(LonghandId::MozWindowOpacity))
                }
                
    nsCSSPropertyID::eCSSProperty_opacity => {
                    Ok(PropertyId::Longhand(LonghandId::Opacity))
                }
                
    nsCSSPropertyID::eCSSProperty_shape_image_threshold => {
                    Ok(PropertyId::Longhand(LonghandId::ShapeImageThreshold))
                }
                
    nsCSSPropertyID::eCSSProperty_stop_opacity => {
                    Ok(PropertyId::Longhand(LonghandId::StopOpacity))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_end_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBlockEndStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_start_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBlockStartStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_border_bottom_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBottomStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_border_inline_end_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderInlineEndStyle))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEndStyle => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderInlineEndStyle,
                            AliasId::MozBorderEndStyle
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_inline_start_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderInlineStartStyle))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStartStyle => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderInlineStartStyle,
                            AliasId::MozBorderStartStyle
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_left_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderLeftStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_border_right_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderRightStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_border_top_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderTopStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_animation_delay => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationDelay))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationDelay => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationDelay,
                            AliasId::MozAnimationDelay
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationDelay => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationDelay,
                            AliasId::WebkitAnimationDelay
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation_direction => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationDirection))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationDirection => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationDirection,
                            AliasId::MozAnimationDirection
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationDirection => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationDirection,
                            AliasId::WebkitAnimationDirection
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation_duration => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationDuration))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationDuration => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationDuration,
                            AliasId::MozAnimationDuration
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationDuration => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationDuration,
                            AliasId::WebkitAnimationDuration
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation_fill_mode => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationFillMode))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationFillMode => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationFillMode,
                            AliasId::MozAnimationFillMode
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationFillMode => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationFillMode,
                            AliasId::WebkitAnimationFillMode
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation_iteration_count => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationIterationCount))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationIterationCount => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationIterationCount,
                            AliasId::MozAnimationIterationCount
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationIterationCount => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationIterationCount,
                            AliasId::WebkitAnimationIterationCount
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation_name => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationName))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationName => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationName,
                            AliasId::MozAnimationName
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationName => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationName,
                            AliasId::WebkitAnimationName
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation_play_state => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationPlayState))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationPlayState => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationPlayState,
                            AliasId::MozAnimationPlayState
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationPlayState => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationPlayState,
                            AliasId::WebkitAnimationPlayState
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation_timing_function => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationTimingFunction))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationTimingFunction => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationTimingFunction,
                            AliasId::MozAnimationTimingFunction
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationTimingFunction => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationTimingFunction,
                            AliasId::WebkitAnimationTimingFunction
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_background_attachment => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundAttachment))
                }
                
    nsCSSPropertyID::eCSSProperty_background_blend_mode => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundBlendMode))
                }
                
    nsCSSPropertyID::eCSSProperty_background_clip => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundClip))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackgroundClip => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BackgroundClip,
                            AliasId::WebkitBackgroundClip
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_background_image => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundImage))
                }
                
    nsCSSPropertyID::eCSSProperty_background_origin => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundOrigin))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackgroundOrigin => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BackgroundOrigin,
                            AliasId::WebkitBackgroundOrigin
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_background_position_x => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundPositionX))
                }
                
    nsCSSPropertyID::eCSSProperty_background_position_y => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundPositionY))
                }
                
    nsCSSPropertyID::eCSSProperty_background_repeat => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundRepeat))
                }
                
    nsCSSPropertyID::eCSSProperty_background_size => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundSize))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackgroundSize => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BackgroundSize,
                            AliasId::WebkitBackgroundSize
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_image_outset => {
                    Ok(PropertyId::Longhand(LonghandId::BorderImageOutset))
                }
                
    nsCSSPropertyID::eCSSProperty_border_image_slice => {
                    Ok(PropertyId::Longhand(LonghandId::BorderImageSlice))
                }
                
    nsCSSPropertyID::eCSSProperty_border_image_source => {
                    Ok(PropertyId::Longhand(LonghandId::BorderImageSource))
                }
                
    nsCSSPropertyID::eCSSProperty_border_image_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderImageWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_border_spacing => {
                    Ok(PropertyId::Longhand(LonghandId::BorderSpacing))
                }
                
    nsCSSPropertyID::eCSSProperty_box_shadow => {
                    Ok(PropertyId::Longhand(LonghandId::BoxShadow))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxShadow => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BoxShadow,
                            AliasId::WebkitBoxShadow
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_caret_color => {
                    Ok(PropertyId::Longhand(LonghandId::CaretColor))
                }
                
    nsCSSPropertyID::eCSSProperty_clip_path => {
                    Ok(PropertyId::Longhand(LonghandId::ClipPath))
                }
                
    nsCSSPropertyID::eCSSProperty_color => {
                    Ok(PropertyId::Longhand(LonghandId::Color))
                }
                
    nsCSSPropertyID::eCSSProperty_column_gap => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnGap))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnGap => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnGap,
                            AliasId::MozColumnGap
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_column_width => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnWidth))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnWidth => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnWidth,
                            AliasId::MozColumnWidth
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_content => {
                    Ok(PropertyId::Longhand(LonghandId::Content))
                }
                
    nsCSSPropertyID::eCSSProperty_counter_increment => {
                    Ok(PropertyId::Longhand(LonghandId::CounterIncrement))
                }
                
    nsCSSPropertyID::eCSSProperty_counter_reset => {
                    Ok(PropertyId::Longhand(LonghandId::CounterReset))
                }
                
    nsCSSPropertyID::eCSSProperty_cursor => {
                    Ok(PropertyId::Longhand(LonghandId::Cursor))
                }
                
    nsCSSPropertyID::eCSSProperty_display => {
                    Ok(PropertyId::Longhand(LonghandId::Display))
                }
                
    nsCSSPropertyID::eCSSProperty_filter => {
                    Ok(PropertyId::Longhand(LonghandId::Filter))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFilter => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::Filter,
                            AliasId::WebkitFilter
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_font_family => {
                    Ok(PropertyId::Longhand(LonghandId::FontFamily))
                }
                
    nsCSSPropertyID::eCSSProperty_font_feature_settings => {
                    Ok(PropertyId::Longhand(LonghandId::FontFeatureSettings))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozFontFeatureSettings => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::FontFeatureSettings,
                            AliasId::MozFontFeatureSettings
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_font_language_override => {
                    Ok(PropertyId::Longhand(LonghandId::FontLanguageOverride))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozFontLanguageOverride => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::FontLanguageOverride,
                            AliasId::MozFontLanguageOverride
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_font_size => {
                    Ok(PropertyId::Longhand(LonghandId::FontSize))
                }
                
    nsCSSPropertyID::eCSSProperty_font_size_adjust => {
                    Ok(PropertyId::Longhand(LonghandId::FontSizeAdjust))
                }
                
    nsCSSPropertyID::eCSSProperty_font_variant_alternates => {
                    Ok(PropertyId::Longhand(LonghandId::FontVariantAlternates))
                }
                
    nsCSSPropertyID::eCSSProperty_font_variant_east_asian => {
                    Ok(PropertyId::Longhand(LonghandId::FontVariantEastAsian))
                }
                
    nsCSSPropertyID::eCSSProperty_font_variant_ligatures => {
                    Ok(PropertyId::Longhand(LonghandId::FontVariantLigatures))
                }
                
    nsCSSPropertyID::eCSSProperty_font_variant_numeric => {
                    Ok(PropertyId::Longhand(LonghandId::FontVariantNumeric))
                }
                
    nsCSSPropertyID::eCSSProperty_font_variation_settings => {
                    Ok(PropertyId::Longhand(LonghandId::FontVariationSettings))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_template_areas => {
                    Ok(PropertyId::Longhand(LonghandId::GridTemplateAreas))
                }
                
    nsCSSPropertyID::eCSSProperty_letter_spacing => {
                    Ok(PropertyId::Longhand(LonghandId::LetterSpacing))
                }
                
    nsCSSPropertyID::eCSSProperty_line_height => {
                    Ok(PropertyId::Longhand(LonghandId::LineHeight))
                }
                
    nsCSSPropertyID::eCSSProperty_list_style_image => {
                    Ok(PropertyId::Longhand(LonghandId::ListStyleImage))
                }
                
    nsCSSPropertyID::eCSSProperty_list_style_type => {
                    Ok(PropertyId::Longhand(LonghandId::ListStyleType))
                }
                
    nsCSSPropertyID::eCSSProperty_mask_clip => {
                    Ok(PropertyId::Longhand(LonghandId::MaskClip))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskClip => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskClip,
                            AliasId::WebkitMaskClip
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_composite => {
                    Ok(PropertyId::Longhand(LonghandId::MaskComposite))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskComposite => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskComposite,
                            AliasId::WebkitMaskComposite
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_image => {
                    Ok(PropertyId::Longhand(LonghandId::MaskImage))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskImage => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskImage,
                            AliasId::WebkitMaskImage
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_mode => {
                    Ok(PropertyId::Longhand(LonghandId::MaskMode))
                }
                
    nsCSSPropertyID::eCSSProperty_mask_origin => {
                    Ok(PropertyId::Longhand(LonghandId::MaskOrigin))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskOrigin => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskOrigin,
                            AliasId::WebkitMaskOrigin
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_position_x => {
                    Ok(PropertyId::Longhand(LonghandId::MaskPositionX))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskPositionX => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskPositionX,
                            AliasId::WebkitMaskPositionX
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_position_y => {
                    Ok(PropertyId::Longhand(LonghandId::MaskPositionY))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskPositionY => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskPositionY,
                            AliasId::WebkitMaskPositionY
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_repeat => {
                    Ok(PropertyId::Longhand(LonghandId::MaskRepeat))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskRepeat => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskRepeat,
                            AliasId::WebkitMaskRepeat
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_size => {
                    Ok(PropertyId::Longhand(LonghandId::MaskSize))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskSize => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskSize,
                            AliasId::WebkitMaskSize
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_context_properties => {
                    Ok(PropertyId::Longhand(LonghandId::MozContextProperties))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_tab_size => {
                    Ok(PropertyId::Longhand(LonghandId::MozTabSize))
                }
                
    nsCSSPropertyID::eCSSProperty_outline_offset => {
                    Ok(PropertyId::Longhand(LonghandId::OutlineOffset))
                }
                
    nsCSSPropertyID::eCSSProperty_overflow_y => {
                    Ok(PropertyId::Longhand(LonghandId::OverflowY))
                }
                
    nsCSSPropertyID::eCSSProperty_perspective => {
                    Ok(PropertyId::Longhand(LonghandId::Perspective))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozPerspective => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::Perspective,
                            AliasId::MozPerspective
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitPerspective => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::Perspective,
                            AliasId::WebkitPerspective
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_perspective_origin => {
                    Ok(PropertyId::Longhand(LonghandId::PerspectiveOrigin))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozPerspectiveOrigin => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::PerspectiveOrigin,
                            AliasId::MozPerspectiveOrigin
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitPerspectiveOrigin => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::PerspectiveOrigin,
                            AliasId::WebkitPerspectiveOrigin
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_quotes => {
                    Ok(PropertyId::Longhand(LonghandId::Quotes))
                }
                
    nsCSSPropertyID::eCSSProperty_rotate => {
                    Ok(PropertyId::Longhand(LonghandId::Rotate))
                }
                
    nsCSSPropertyID::eCSSProperty_scale => {
                    Ok(PropertyId::Longhand(LonghandId::Scale))
                }
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_coordinate => {
                    Ok(PropertyId::Longhand(LonghandId::ScrollSnapCoordinate))
                }
                
    nsCSSPropertyID::eCSSProperty_shape_outside => {
                    Ok(PropertyId::Longhand(LonghandId::ShapeOutside))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke_dasharray => {
                    Ok(PropertyId::Longhand(LonghandId::StrokeDasharray))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke_dashoffset => {
                    Ok(PropertyId::Longhand(LonghandId::StrokeDashoffset))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke_miterlimit => {
                    Ok(PropertyId::Longhand(LonghandId::StrokeMiterlimit))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke_width => {
                    Ok(PropertyId::Longhand(LonghandId::StrokeWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_text_align => {
                    Ok(PropertyId::Longhand(LonghandId::TextAlign))
                }
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_position => {
                    Ok(PropertyId::Longhand(LonghandId::TextEmphasisPosition))
                }
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_style => {
                    Ok(PropertyId::Longhand(LonghandId::TextEmphasisStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_text_indent => {
                    Ok(PropertyId::Longhand(LonghandId::TextIndent))
                }
                
    nsCSSPropertyID::eCSSProperty_text_overflow => {
                    Ok(PropertyId::Longhand(LonghandId::TextOverflow))
                }
                
    nsCSSPropertyID::eCSSProperty_text_shadow => {
                    Ok(PropertyId::Longhand(LonghandId::TextShadow))
                }
                
    nsCSSPropertyID::eCSSProperty_transition_delay => {
                    Ok(PropertyId::Longhand(LonghandId::TransitionDelay))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionDelay => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionDelay,
                            AliasId::MozTransitionDelay
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionDelay => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionDelay,
                            AliasId::WebkitTransitionDelay
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_transition_duration => {
                    Ok(PropertyId::Longhand(LonghandId::TransitionDuration))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionDuration => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionDuration,
                            AliasId::MozTransitionDuration
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionDuration => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionDuration,
                            AliasId::WebkitTransitionDuration
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_transition_property => {
                    Ok(PropertyId::Longhand(LonghandId::TransitionProperty))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionProperty => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionProperty,
                            AliasId::MozTransitionProperty
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionProperty => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionProperty,
                            AliasId::WebkitTransitionProperty
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_transition_timing_function => {
                    Ok(PropertyId::Longhand(LonghandId::TransitionTimingFunction))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionTimingFunction => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionTimingFunction,
                            AliasId::MozTransitionTimingFunction
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionTimingFunction => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionTimingFunction,
                            AliasId::WebkitTransitionTimingFunction
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_translate => {
                    Ok(PropertyId::Longhand(LonghandId::Translate))
                }
                
    nsCSSPropertyID::eCSSProperty_vertical_align => {
                    Ok(PropertyId::Longhand(LonghandId::VerticalAlign))
                }
                
    nsCSSPropertyID::eCSSProperty_will_change => {
                    Ok(PropertyId::Longhand(LonghandId::WillChange))
                }
                
    nsCSSPropertyID::eCSSProperty_word_spacing => {
                    Ok(PropertyId::Longhand(LonghandId::WordSpacing))
                }
                
    nsCSSPropertyID::eCSSProperty__x_lang => {
                    Ok(PropertyId::Longhand(LonghandId::XLang))
                }
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_block => {
                    Ok(PropertyId::Longhand(LonghandId::OverflowClipBoxBlock))
                }
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_inline => {
                    Ok(PropertyId::Longhand(LonghandId::OverflowClipBoxInline))
                }
                
    nsCSSPropertyID::eCSSProperty_fill_opacity => {
                    Ok(PropertyId::Longhand(LonghandId::FillOpacity))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke_opacity => {
                    Ok(PropertyId::Longhand(LonghandId::StrokeOpacity))
                }
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_x => {
                    Ok(PropertyId::Longhand(LonghandId::ScrollSnapPointsX))
                }
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_y => {
                    Ok(PropertyId::Longhand(LonghandId::ScrollSnapPointsY))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform => {
                    Ok(PropertyId::Longhand(LonghandId::MozWindowTransform))
                }
                
    nsCSSPropertyID::eCSSProperty_transform => {
                    Ok(PropertyId::Longhand(LonghandId::Transform))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransform => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::Transform,
                            AliasId::WebkitTransform
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransform => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::Transform,
                            AliasId::MozTransform
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_clip => {
                    Ok(PropertyId::Longhand(LonghandId::Clip))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_image_region => {
                    Ok(PropertyId::Longhand(LonghandId::MozImageRegion))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_template_columns => {
                    Ok(PropertyId::Longhand(LonghandId::GridTemplateColumns))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_template_rows => {
                    Ok(PropertyId::Longhand(LonghandId::GridTemplateRows))
                }
                
    nsCSSPropertyID::eCSSProperty_object_position => {
                    Ok(PropertyId::Longhand(LonghandId::ObjectPosition))
                }
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_destination => {
                    Ok(PropertyId::Longhand(LonghandId::ScrollSnapDestination))
                }
                
    nsCSSPropertyID::eCSSProperty_fill => {
                    Ok(PropertyId::Longhand(LonghandId::Fill))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke => {
                    Ok(PropertyId::Longhand(LonghandId::Stroke))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_auto_columns => {
                    Ok(PropertyId::Longhand(LonghandId::GridAutoColumns))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_auto_rows => {
                    Ok(PropertyId::Longhand(LonghandId::GridAutoRows))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform_origin => {
                    Ok(PropertyId::Longhand(LonghandId::MozWindowTransformOrigin))
                }
                
    nsCSSPropertyID::eCSSProperty_transform_origin => {
                    Ok(PropertyId::Longhand(LonghandId::TransformOrigin))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransformOrigin => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransformOrigin,
                            AliasId::MozTransformOrigin
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransformOrigin => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransformOrigin,
                            AliasId::WebkitTransformOrigin
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_max_block_size => {
                    Ok(PropertyId::Longhand(LonghandId::MaxBlockSize))
                }
                
    nsCSSPropertyID::eCSSProperty_max_height => {
                    Ok(PropertyId::Longhand(LonghandId::MaxHeight))
                }
                
    nsCSSPropertyID::eCSSProperty_max_inline_size => {
                    Ok(PropertyId::Longhand(LonghandId::MaxInlineSize))
                }
                
    nsCSSPropertyID::eCSSProperty_max_width => {
                    Ok(PropertyId::Longhand(LonghandId::MaxWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_flood_color => {
                    Ok(PropertyId::Longhand(LonghandId::FloodColor))
                }
                
    nsCSSPropertyID::eCSSProperty_lighting_color => {
                    Ok(PropertyId::Longhand(LonghandId::LightingColor))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_font_smoothing_background_color => {
                    Ok(PropertyId::Longhand(LonghandId::MozFontSmoothingBackgroundColor))
                }
                
    nsCSSPropertyID::eCSSProperty_stop_color => {
                    Ok(PropertyId::Longhand(LonghandId::StopColor))
                }
                
    nsCSSPropertyID::eCSSProperty_marker_end => {
                    Ok(PropertyId::Longhand(LonghandId::MarkerEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_marker_mid => {
                    Ok(PropertyId::Longhand(LonghandId::MarkerMid))
                }
                
    nsCSSPropertyID::eCSSProperty_marker_start => {
                    Ok(PropertyId::Longhand(LonghandId::MarkerStart))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_binding => {
                    Ok(PropertyId::Longhand(LonghandId::MozBinding))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_column_end => {
                    Ok(PropertyId::Longhand(LonghandId::GridColumnEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_column_start => {
                    Ok(PropertyId::Longhand(LonghandId::GridColumnStart))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_row_end => {
                    Ok(PropertyId::Longhand(LonghandId::GridRowEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_row_start => {
                    Ok(PropertyId::Longhand(LonghandId::GridRowStart))
                }
                
    nsCSSPropertyID::eCSSProperty_border_bottom_left_radius => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBottomLeftRadius))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderBottomLeftRadius => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderBottomLeftRadius,
                            AliasId::WebkitBorderBottomLeftRadius
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_bottom_right_radius => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBottomRightRadius))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderBottomRightRadius => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderBottomRightRadius,
                            AliasId::WebkitBorderBottomRightRadius
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_top_left_radius => {
                    Ok(PropertyId::Longhand(LonghandId::BorderTopLeftRadius))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderTopLeftRadius => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderTopLeftRadius,
                            AliasId::WebkitBorderTopLeftRadius
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_top_right_radius => {
                    Ok(PropertyId::Longhand(LonghandId::BorderTopRightRadius))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderTopRightRadius => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderTopRightRadius,
                            AliasId::WebkitBorderTopRightRadius
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomleft => {
                    Ok(PropertyId::Longhand(LonghandId::MozOutlineRadiusBottomleft))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomright => {
                    Ok(PropertyId::Longhand(LonghandId::MozOutlineRadiusBottomright))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topleft => {
                    Ok(PropertyId::Longhand(LonghandId::MozOutlineRadiusTopleft))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topright => {
                    Ok(PropertyId::Longhand(LonghandId::MozOutlineRadiusTopright))
                }
                
    nsCSSPropertyID::eCSSProperty_block_size => {
                    Ok(PropertyId::Longhand(LonghandId::BlockSize))
                }
                
    nsCSSPropertyID::eCSSProperty_flex_basis => {
                    Ok(PropertyId::Longhand(LonghandId::FlexBasis))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexBasis => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::FlexBasis,
                            AliasId::WebkitFlexBasis
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_height => {
                    Ok(PropertyId::Longhand(LonghandId::Height))
                }
                
    nsCSSPropertyID::eCSSProperty_inline_size => {
                    Ok(PropertyId::Longhand(LonghandId::InlineSize))
                }
                
    nsCSSPropertyID::eCSSProperty_min_block_size => {
                    Ok(PropertyId::Longhand(LonghandId::MinBlockSize))
                }
                
    nsCSSPropertyID::eCSSProperty_min_height => {
                    Ok(PropertyId::Longhand(LonghandId::MinHeight))
                }
                
    nsCSSPropertyID::eCSSProperty_min_inline_size => {
                    Ok(PropertyId::Longhand(LonghandId::MinInlineSize))
                }
                
    nsCSSPropertyID::eCSSProperty_min_width => {
                    Ok(PropertyId::Longhand(LonghandId::MinWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_width => {
                    Ok(PropertyId::Longhand(LonghandId::Width))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_column_gap => {
                    Ok(PropertyId::Longhand(LonghandId::GridColumnGap))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_row_gap => {
                    Ok(PropertyId::Longhand(LonghandId::GridRowGap))
                }
                
    nsCSSPropertyID::eCSSProperty_padding_block_end => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingBlockEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_padding_block_start => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingBlockStart))
                }
                
    nsCSSPropertyID::eCSSProperty_padding_bottom => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingBottom))
                }
                
    nsCSSPropertyID::eCSSProperty_padding_inline_end => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingInlineEnd))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozPaddingEnd => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::PaddingInlineEnd,
                            AliasId::MozPaddingEnd
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_padding_inline_start => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingInlineStart))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozPaddingStart => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::PaddingInlineStart,
                            AliasId::MozPaddingStart
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_padding_left => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingLeft))
                }
                
    nsCSSPropertyID::eCSSProperty_padding_right => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingRight))
                }
                
    nsCSSPropertyID::eCSSProperty_padding_top => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingTop))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_end_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBlockEndWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_start_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBlockStartWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_border_bottom_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBottomWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_border_inline_end_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderInlineEndWidth))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEndWidth => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderInlineEndWidth,
                            AliasId::MozBorderEndWidth
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_inline_start_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderInlineStartWidth))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStartWidth => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderInlineStartWidth,
                            AliasId::MozBorderStartWidth
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_left_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderLeftWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_border_right_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderRightWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_border_top_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderTopWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_column_rule_width => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnRuleWidth))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRuleWidth => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnRuleWidth,
                            AliasId::MozColumnRuleWidth
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_outline_width => {
                    Ok(PropertyId::Longhand(LonghandId::OutlineWidth))
                }
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_width => {
                    Ok(PropertyId::Longhand(LonghandId::WebkitTextStrokeWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_background_color => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundColor))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_end_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBlockEndColor))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_start_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBlockStartColor))
                }
                
    nsCSSPropertyID::eCSSProperty_border_bottom_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBottomColor))
                }
                
    nsCSSPropertyID::eCSSProperty_border_inline_end_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderInlineEndColor))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEndColor => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderInlineEndColor,
                            AliasId::MozBorderEndColor
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_inline_start_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderInlineStartColor))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStartColor => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderInlineStartColor,
                            AliasId::MozBorderStartColor
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_left_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderLeftColor))
                }
                
    nsCSSPropertyID::eCSSProperty_border_right_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderRightColor))
                }
                
    nsCSSPropertyID::eCSSProperty_border_top_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderTopColor))
                }
                
    nsCSSPropertyID::eCSSProperty_column_rule_color => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnRuleColor))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRuleColor => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnRuleColor,
                            AliasId::MozColumnRuleColor
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_outline_color => {
                    Ok(PropertyId::Longhand(LonghandId::OutlineColor))
                }
                
    nsCSSPropertyID::eCSSProperty_text_decoration_color => {
                    Ok(PropertyId::Longhand(LonghandId::TextDecorationColor))
                }
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_color => {
                    Ok(PropertyId::Longhand(LonghandId::TextEmphasisColor))
                }
                
    nsCSSPropertyID::eCSSProperty__webkit_text_fill_color => {
                    Ok(PropertyId::Longhand(LonghandId::WebkitTextFillColor))
                }
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_color => {
                    Ok(PropertyId::Longhand(LonghandId::WebkitTextStrokeColor))
                }
                
    nsCSSPropertyID::eCSSProperty_bottom => {
                    Ok(PropertyId::Longhand(LonghandId::Bottom))
                }
                
    nsCSSPropertyID::eCSSProperty_left => {
                    Ok(PropertyId::Longhand(LonghandId::Left))
                }
                
    nsCSSPropertyID::eCSSProperty_margin_block_end => {
                    Ok(PropertyId::Longhand(LonghandId::MarginBlockEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_margin_block_start => {
                    Ok(PropertyId::Longhand(LonghandId::MarginBlockStart))
                }
                
    nsCSSPropertyID::eCSSProperty_margin_bottom => {
                    Ok(PropertyId::Longhand(LonghandId::MarginBottom))
                }
                
    nsCSSPropertyID::eCSSProperty_margin_inline_end => {
                    Ok(PropertyId::Longhand(LonghandId::MarginInlineEnd))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozMarginEnd => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MarginInlineEnd,
                            AliasId::MozMarginEnd
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_margin_inline_start => {
                    Ok(PropertyId::Longhand(LonghandId::MarginInlineStart))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozMarginStart => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MarginInlineStart,
                            AliasId::MozMarginStart
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_margin_left => {
                    Ok(PropertyId::Longhand(LonghandId::MarginLeft))
                }
                
    nsCSSPropertyID::eCSSProperty_margin_right => {
                    Ok(PropertyId::Longhand(LonghandId::MarginRight))
                }
                
    nsCSSPropertyID::eCSSProperty_margin_top => {
                    Ok(PropertyId::Longhand(LonghandId::MarginTop))
                }
                
    nsCSSPropertyID::eCSSProperty_offset_block_end => {
                    Ok(PropertyId::Longhand(LonghandId::OffsetBlockEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_offset_block_start => {
                    Ok(PropertyId::Longhand(LonghandId::OffsetBlockStart))
                }
                
    nsCSSPropertyID::eCSSProperty_offset_inline_end => {
                    Ok(PropertyId::Longhand(LonghandId::OffsetInlineEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_offset_inline_start => {
                    Ok(PropertyId::Longhand(LonghandId::OffsetInlineStart))
                }
                
    nsCSSPropertyID::eCSSProperty_right => {
                    Ok(PropertyId::Longhand(LonghandId::Right))
                }
                
    nsCSSPropertyID::eCSSProperty_top => {
                    Ok(PropertyId::Longhand(LonghandId::Top))
                }
                
    nsCSSPropertyID::eCSSProperty_background => {
                    Ok(PropertyId::Shorthand(ShorthandId::Background))
                }
                
    nsCSSPropertyID::eCSSProperty_background_position => {
                    Ok(PropertyId::Shorthand(ShorthandId::BackgroundPosition))
                }
                
    nsCSSPropertyID::eCSSProperty_border_color => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderColor))
                }
                
    nsCSSPropertyID::eCSSProperty_border_style => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_border_width => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_border_top => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderTop))
                }
                
    nsCSSPropertyID::eCSSProperty_border_left => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderLeft))
                }
                
    nsCSSPropertyID::eCSSProperty_border_bottom => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderBottom))
                }
                
    nsCSSPropertyID::eCSSProperty_border_right => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderRight))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_start => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderBlockStart))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_end => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderBlockEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_border_inline_start => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderInlineStart))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStart => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::BorderInlineStart,
                            AliasId::MozBorderStart
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_inline_end => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderInlineEnd))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEnd => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::BorderInlineEnd,
                            AliasId::MozBorderEnd
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border => {
                    Ok(PropertyId::Shorthand(ShorthandId::Border))
                }
                
    nsCSSPropertyID::eCSSProperty_border_radius => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderRadius))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderRadius => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::BorderRadius,
                            AliasId::WebkitBorderRadius
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_image => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderImage))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderImage => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::BorderImage,
                            AliasId::MozBorderImage
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderImage => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::BorderImage,
                            AliasId::WebkitBorderImage
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_overflow => {
                    Ok(PropertyId::Shorthand(ShorthandId::Overflow))
                }
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box => {
                    Ok(PropertyId::Shorthand(ShorthandId::OverflowClipBox))
                }
                
    nsCSSPropertyID::eCSSProperty_transition => {
                    Ok(PropertyId::Shorthand(ShorthandId::Transition))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransition => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::Transition,
                            AliasId::MozTransition
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransition => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::Transition,
                            AliasId::WebkitTransition
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation => {
                    Ok(PropertyId::Shorthand(ShorthandId::Animation))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimation => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::Animation,
                            AliasId::MozAnimation
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimation => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::Animation,
                            AliasId::WebkitAnimation
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type => {
                    Ok(PropertyId::Shorthand(ShorthandId::ScrollSnapType))
                }
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior => {
                    Ok(PropertyId::Shorthand(ShorthandId::OverscrollBehavior))
                }
                
    nsCSSPropertyID::eCSSProperty_columns => {
                    Ok(PropertyId::Shorthand(ShorthandId::Columns))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumns => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::Columns,
                            AliasId::MozColumns
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_column_rule => {
                    Ok(PropertyId::Shorthand(ShorthandId::ColumnRule))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRule => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::ColumnRule,
                            AliasId::MozColumnRule
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_font => {
                    Ok(PropertyId::Shorthand(ShorthandId::Font))
                }
                
    nsCSSPropertyID::eCSSProperty_font_variant => {
                    Ok(PropertyId::Shorthand(ShorthandId::FontVariant))
                }
                
    nsCSSPropertyID::eCSSProperty_text_emphasis => {
                    Ok(PropertyId::Shorthand(ShorthandId::TextEmphasis))
                }
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke => {
                    Ok(PropertyId::Shorthand(ShorthandId::WebkitTextStroke))
                }
                
    nsCSSPropertyID::eCSSProperty_list_style => {
                    Ok(PropertyId::Shorthand(ShorthandId::ListStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_margin => {
                    Ok(PropertyId::Shorthand(ShorthandId::Margin))
                }
                
    nsCSSPropertyID::eCSSProperty_mask => {
                    Ok(PropertyId::Shorthand(ShorthandId::Mask))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMask => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::Mask,
                            AliasId::WebkitMask
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_position => {
                    Ok(PropertyId::Shorthand(ShorthandId::MaskPosition))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskPosition => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::MaskPosition,
                            AliasId::WebkitMaskPosition
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_outline => {
                    Ok(PropertyId::Shorthand(ShorthandId::Outline))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius => {
                    Ok(PropertyId::Shorthand(ShorthandId::MozOutlineRadius))
                }
                
    nsCSSPropertyID::eCSSProperty_padding => {
                    Ok(PropertyId::Shorthand(ShorthandId::Padding))
                }
                
    nsCSSPropertyID::eCSSProperty_flex_flow => {
                    Ok(PropertyId::Shorthand(ShorthandId::FlexFlow))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexFlow => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::FlexFlow,
                            AliasId::WebkitFlexFlow
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_flex => {
                    Ok(PropertyId::Shorthand(ShorthandId::Flex))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlex => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::Flex,
                            AliasId::WebkitFlex
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_grid_gap => {
                    Ok(PropertyId::Shorthand(ShorthandId::GridGap))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_row => {
                    Ok(PropertyId::Shorthand(ShorthandId::GridRow))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_column => {
                    Ok(PropertyId::Shorthand(ShorthandId::GridColumn))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_area => {
                    Ok(PropertyId::Shorthand(ShorthandId::GridArea))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_template => {
                    Ok(PropertyId::Shorthand(ShorthandId::GridTemplate))
                }
                
    nsCSSPropertyID::eCSSProperty_grid => {
                    Ok(PropertyId::Shorthand(ShorthandId::Grid))
                }
                
    nsCSSPropertyID::eCSSProperty_place_content => {
                    Ok(PropertyId::Shorthand(ShorthandId::PlaceContent))
                }
                
    nsCSSPropertyID::eCSSProperty_place_self => {
                    Ok(PropertyId::Shorthand(ShorthandId::PlaceSelf))
                }
                
    nsCSSPropertyID::eCSSProperty_place_items => {
                    Ok(PropertyId::Shorthand(ShorthandId::PlaceItems))
                }
                
    nsCSSPropertyID::eCSSProperty_marker => {
                    Ok(PropertyId::Shorthand(ShorthandId::Marker))
                }
                
    nsCSSPropertyID::eCSSProperty_text_decoration => {
                    Ok(PropertyId::Shorthand(ShorthandId::TextDecoration))
                }
                
    nsCSSPropertyID::eCSSProperty_all => {
                    Ok(PropertyId::Shorthand(ShorthandId::All))
                }
            _ => Err(())
        }
    }

    /// Given this property id, get it either as a shorthand or as a
    /// `PropertyDeclarationId`.
    pub fn as_shorthand(&self) -> Result<ShorthandId, PropertyDeclarationId> {
        match *self {
            PropertyId::ShorthandAlias(id, _) |
            PropertyId::Shorthand(id) => Ok(id),
            PropertyId::LonghandAlias(id, _) |
            PropertyId::Longhand(id) => Err(PropertyDeclarationId::Longhand(id)),
            PropertyId::Custom(ref name) => Err(PropertyDeclarationId::Custom(name)),
        }
    }

    /// Returns the name of the property without CSS escaping.
    pub fn name(&self) -> Cow<'static, str> {
        match *self {
            PropertyId::ShorthandAlias(id, _) |
            PropertyId::Shorthand(id) => id.name().into(),
            PropertyId::LonghandAlias(id, _) |
            PropertyId::Longhand(id) => id.name().into(),
            PropertyId::Custom(ref name) => {
                let mut s = String::new();
                write!(&mut s, "--{}", name).unwrap();
                s.into()
            }
        }
    }

    fn non_custom_id(&self) -> Option<NonCustomPropertyId> {
        Some(match *self {
            PropertyId::Custom(_) => return None,
            PropertyId::Shorthand(shorthand_id) => shorthand_id.into(),
            PropertyId::Longhand(longhand_id) => longhand_id.into(),
            PropertyId::ShorthandAlias(_, alias_id) => alias_id.into(),
            PropertyId::LonghandAlias(_, alias_id) => alias_id.into(),
        })
    }

    /// Whether the property is enabled for all content regardless of the
    /// stylesheet it was declared on (that is, in practice only checks prefs).
    #[inline]
    pub fn enabled_for_all_content(&self) -> bool {
        let id = match self.non_custom_id() {
            // Custom properties are allowed everywhere
            None => return true,
            Some(id) => id,
        };

        id.enabled_for_all_content()
    }

    fn allowed_in(&self, context: &ParserContext) -> bool {
        let id = match self.non_custom_id() {
            // Custom properties are allowed everywhere
            None => return true,
            Some(id) => id,
        };
        id.allowed_in(context)
    }
}

/// A declaration using a CSS-wide keyword.
#[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
#[derive(Clone, PartialEq, ToCss)]
pub struct WideKeywordDeclaration {
    #[css(skip)]
    id: LonghandId,
    keyword: CSSWideKeyword,
}

/// An unparsed declaration that contains `var()` functions.
#[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
#[derive(Clone, PartialEq, ToCss)]
pub struct VariableDeclaration {
    #[css(skip)]
    id: LonghandId,
    #[cfg_attr(feature = "gecko", ignore_malloc_size_of = "XXX: how to handle this?")]
    value: Arc<UnparsedValue>,
}

/// A custom property declaration with the property name and the declared value.
#[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
#[derive(Clone, PartialEq, ToCss)]
pub struct CustomDeclaration {
    /// The name of the custom property.
    #[css(skip)]
    pub name: ::custom_properties::Name,
    /// The value of the custom property.
    #[cfg_attr(feature = "gecko", ignore_malloc_size_of = "XXX: how to handle this?")]
    pub value: DeclaredValueOwned<Arc<::custom_properties::SpecifiedValue>>,
}

impl fmt::Debug for PropertyDeclaration {
    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
        self.id().to_css(&mut CssWriter::new(f))?;
        f.write_str(": ")?;

        // Because PropertyDeclaration::to_css requires CssStringWriter, we can't write
        // it directly to f, and need to allocate an intermediate string. This is
        // fine for debug-only code.
        let mut s = CssString::new();
        self.to_css(&mut s)?;
        write!(f, "{}", s)
    }
}

impl PropertyDeclaration {
    /// Given a property declaration, return the property declaration id.
    #[inline]
    pub fn id(&self) -> PropertyDeclarationId {
        match *self {
            PropertyDeclaration::Custom(ref declaration) => {
                return PropertyDeclarationId::Custom(&declaration.name)
            }
            PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                return PropertyDeclarationId::Longhand(declaration.id);
            }
            PropertyDeclaration::WithVariables(ref declaration) => {
                return PropertyDeclarationId::Longhand(declaration.id);
            }
            _ => {}
        }
        // This is just fine because PropertyDeclarationId and LonghandId
        // have corresponding discriminants.
        let id = unsafe { *(self as *const _ as *const LonghandId) };
        debug_assert_eq!(id, match *self {
            PropertyDeclaration::AlignContent(..) => LonghandId::AlignContent,
            PropertyDeclaration::AlignItems(..) => LonghandId::AlignItems,
            PropertyDeclaration::AlignSelf(..) => LonghandId::AlignSelf,
            PropertyDeclaration::BackfaceVisibility(..) => LonghandId::BackfaceVisibility,
            PropertyDeclaration::BorderCollapse(..) => LonghandId::BorderCollapse,
            PropertyDeclaration::BorderImageRepeat(..) => LonghandId::BorderImageRepeat,
            PropertyDeclaration::BoxDecorationBreak(..) => LonghandId::BoxDecorationBreak,
            PropertyDeclaration::BoxSizing(..) => LonghandId::BoxSizing,
            PropertyDeclaration::CaptionSide(..) => LonghandId::CaptionSide,
            PropertyDeclaration::Clear(..) => LonghandId::Clear,
            PropertyDeclaration::ClipRule(..) => LonghandId::ClipRule,
            PropertyDeclaration::ColorAdjust(..) => LonghandId::ColorAdjust,
            PropertyDeclaration::ColorInterpolation(..) => LonghandId::ColorInterpolation,
            PropertyDeclaration::ColorInterpolationFilters(..) => LonghandId::ColorInterpolationFilters,
            PropertyDeclaration::ColumnCount(..) => LonghandId::ColumnCount,
            PropertyDeclaration::ColumnFill(..) => LonghandId::ColumnFill,
            PropertyDeclaration::ColumnRuleStyle(..) => LonghandId::ColumnRuleStyle,
            PropertyDeclaration::ColumnSpan(..) => LonghandId::ColumnSpan,
            PropertyDeclaration::Contain(..) => LonghandId::Contain,
            PropertyDeclaration::Direction(..) => LonghandId::Direction,
            PropertyDeclaration::DominantBaseline(..) => LonghandId::DominantBaseline,
            PropertyDeclaration::EmptyCells(..) => LonghandId::EmptyCells,
            PropertyDeclaration::FillRule(..) => LonghandId::FillRule,
            PropertyDeclaration::FlexDirection(..) => LonghandId::FlexDirection,
            PropertyDeclaration::FlexWrap(..) => LonghandId::FlexWrap,
            PropertyDeclaration::Float(..) => LonghandId::Float,
            PropertyDeclaration::FontKerning(..) => LonghandId::FontKerning,
            PropertyDeclaration::FontOpticalSizing(..) => LonghandId::FontOpticalSizing,
            PropertyDeclaration::FontStretch(..) => LonghandId::FontStretch,
            PropertyDeclaration::FontStyle(..) => LonghandId::FontStyle,
            PropertyDeclaration::FontSynthesis(..) => LonghandId::FontSynthesis,
            PropertyDeclaration::FontVariantCaps(..) => LonghandId::FontVariantCaps,
            PropertyDeclaration::FontVariantPosition(..) => LonghandId::FontVariantPosition,
            PropertyDeclaration::FontWeight(..) => LonghandId::FontWeight,
            PropertyDeclaration::GridAutoFlow(..) => LonghandId::GridAutoFlow,
            PropertyDeclaration::Hyphens(..) => LonghandId::Hyphens,
            PropertyDeclaration::ImageOrientation(..) => LonghandId::ImageOrientation,
            PropertyDeclaration::ImageRendering(..) => LonghandId::ImageRendering,
            PropertyDeclaration::ImeMode(..) => LonghandId::ImeMode,
            PropertyDeclaration::InitialLetter(..) => LonghandId::InitialLetter,
            PropertyDeclaration::Isolation(..) => LonghandId::Isolation,
            PropertyDeclaration::JustifyContent(..) => LonghandId::JustifyContent,
            PropertyDeclaration::JustifyItems(..) => LonghandId::JustifyItems,
            PropertyDeclaration::JustifySelf(..) => LonghandId::JustifySelf,
            PropertyDeclaration::ListStylePosition(..) => LonghandId::ListStylePosition,
            PropertyDeclaration::MaskType(..) => LonghandId::MaskType,
            PropertyDeclaration::MixBlendMode(..) => LonghandId::MixBlendMode,
            PropertyDeclaration::MozAppearance(..) => LonghandId::MozAppearance,
            PropertyDeclaration::MozBoxAlign(..) => LonghandId::MozBoxAlign,
            PropertyDeclaration::MozBoxDirection(..) => LonghandId::MozBoxDirection,
            PropertyDeclaration::MozBoxOrient(..) => LonghandId::MozBoxOrient,
            PropertyDeclaration::MozBoxPack(..) => LonghandId::MozBoxPack,
            PropertyDeclaration::MozControlCharacterVisibility(..) => LonghandId::MozControlCharacterVisibility,
            PropertyDeclaration::MozFloatEdge(..) => LonghandId::MozFloatEdge,
            PropertyDeclaration::MozForceBrokenImageIcon(..) => LonghandId::MozForceBrokenImageIcon,
            PropertyDeclaration::MozMathDisplay(..) => LonghandId::MozMathDisplay,
            PropertyDeclaration::MozMathVariant(..) => LonghandId::MozMathVariant,
            PropertyDeclaration::MozMinFontSizeRatio(..) => LonghandId::MozMinFontSizeRatio,
            PropertyDeclaration::MozOrient(..) => LonghandId::MozOrient,
            PropertyDeclaration::MozOsxFontSmoothing(..) => LonghandId::MozOsxFontSmoothing,
            PropertyDeclaration::MozScriptLevel(..) => LonghandId::MozScriptLevel,
            PropertyDeclaration::MozScriptMinSize(..) => LonghandId::MozScriptMinSize,
            PropertyDeclaration::MozScriptSizeMultiplier(..) => LonghandId::MozScriptSizeMultiplier,
            PropertyDeclaration::MozStackSizing(..) => LonghandId::MozStackSizing,
            PropertyDeclaration::MozTextSizeAdjust(..) => LonghandId::MozTextSizeAdjust,
            PropertyDeclaration::MozTopLayer(..) => LonghandId::MozTopLayer,
            PropertyDeclaration::MozUserFocus(..) => LonghandId::MozUserFocus,
            PropertyDeclaration::MozUserInput(..) => LonghandId::MozUserInput,
            PropertyDeclaration::MozUserModify(..) => LonghandId::MozUserModify,
            PropertyDeclaration::MozUserSelect(..) => LonghandId::MozUserSelect,
            PropertyDeclaration::MozWindowDragging(..) => LonghandId::MozWindowDragging,
            PropertyDeclaration::MozWindowShadow(..) => LonghandId::MozWindowShadow,
            PropertyDeclaration::ObjectFit(..) => LonghandId::ObjectFit,
            PropertyDeclaration::OutlineStyle(..) => LonghandId::OutlineStyle,
            PropertyDeclaration::OverflowWrap(..) => LonghandId::OverflowWrap,
            PropertyDeclaration::OverflowX(..) => LonghandId::OverflowX,
            PropertyDeclaration::PageBreakAfter(..) => LonghandId::PageBreakAfter,
            PropertyDeclaration::PageBreakBefore(..) => LonghandId::PageBreakBefore,
            PropertyDeclaration::PageBreakInside(..) => LonghandId::PageBreakInside,
            PropertyDeclaration::PaintOrder(..) => LonghandId::PaintOrder,
            PropertyDeclaration::PointerEvents(..) => LonghandId::PointerEvents,
            PropertyDeclaration::Position(..) => LonghandId::Position,
            PropertyDeclaration::Resize(..) => LonghandId::Resize,
            PropertyDeclaration::RubyAlign(..) => LonghandId::RubyAlign,
            PropertyDeclaration::RubyPosition(..) => LonghandId::RubyPosition,
            PropertyDeclaration::ScrollBehavior(..) => LonghandId::ScrollBehavior,
            PropertyDeclaration::ShapeRendering(..) => LonghandId::ShapeRendering,
            PropertyDeclaration::StrokeLinecap(..) => LonghandId::StrokeLinecap,
            PropertyDeclaration::StrokeLinejoin(..) => LonghandId::StrokeLinejoin,
            PropertyDeclaration::TableLayout(..) => LonghandId::TableLayout,
            PropertyDeclaration::TextAlignLast(..) => LonghandId::TextAlignLast,
            PropertyDeclaration::TextAnchor(..) => LonghandId::TextAnchor,
            PropertyDeclaration::TextCombineUpright(..) => LonghandId::TextCombineUpright,
            PropertyDeclaration::TextDecorationLine(..) => LonghandId::TextDecorationLine,
            PropertyDeclaration::TextDecorationStyle(..) => LonghandId::TextDecorationStyle,
            PropertyDeclaration::TextJustify(..) => LonghandId::TextJustify,
            PropertyDeclaration::TextOrientation(..) => LonghandId::TextOrientation,
            PropertyDeclaration::TextRendering(..) => LonghandId::TextRendering,
            PropertyDeclaration::TextTransform(..) => LonghandId::TextTransform,
            PropertyDeclaration::TouchAction(..) => LonghandId::TouchAction,
            PropertyDeclaration::TransformBox(..) => LonghandId::TransformBox,
            PropertyDeclaration::TransformStyle(..) => LonghandId::TransformStyle,
            PropertyDeclaration::UnicodeBidi(..) => LonghandId::UnicodeBidi,
            PropertyDeclaration::VectorEffect(..) => LonghandId::VectorEffect,
            PropertyDeclaration::Visibility(..) => LonghandId::Visibility,
            PropertyDeclaration::WhiteSpace(..) => LonghandId::WhiteSpace,
            PropertyDeclaration::WordBreak(..) => LonghandId::WordBreak,
            PropertyDeclaration::WritingMode(..) => LonghandId::WritingMode,
            PropertyDeclaration::XSpan(..) => LonghandId::XSpan,
            PropertyDeclaration::XTextZoom(..) => LonghandId::XTextZoom,
            PropertyDeclaration::ZIndex(..) => LonghandId::ZIndex,
            PropertyDeclaration::MozBoxOrdinalGroup(..) => LonghandId::MozBoxOrdinalGroup,
            PropertyDeclaration::Order(..) => LonghandId::Order,
            PropertyDeclaration::OverscrollBehaviorX(..) => LonghandId::OverscrollBehaviorX,
            PropertyDeclaration::OverscrollBehaviorY(..) => LonghandId::OverscrollBehaviorY,
            PropertyDeclaration::ScrollSnapTypeX(..) => LonghandId::ScrollSnapTypeX,
            PropertyDeclaration::ScrollSnapTypeY(..) => LonghandId::ScrollSnapTypeY,
            PropertyDeclaration::FlexGrow(..) => LonghandId::FlexGrow,
            PropertyDeclaration::FlexShrink(..) => LonghandId::FlexShrink,
            PropertyDeclaration::MozBoxFlex(..) => LonghandId::MozBoxFlex,
            PropertyDeclaration::FloodOpacity(..) => LonghandId::FloodOpacity,
            PropertyDeclaration::MozWindowOpacity(..) => LonghandId::MozWindowOpacity,
            PropertyDeclaration::Opacity(..) => LonghandId::Opacity,
            PropertyDeclaration::ShapeImageThreshold(..) => LonghandId::ShapeImageThreshold,
            PropertyDeclaration::StopOpacity(..) => LonghandId::StopOpacity,
            PropertyDeclaration::BorderBlockEndStyle(..) => LonghandId::BorderBlockEndStyle,
            PropertyDeclaration::BorderBlockStartStyle(..) => LonghandId::BorderBlockStartStyle,
            PropertyDeclaration::BorderBottomStyle(..) => LonghandId::BorderBottomStyle,
            PropertyDeclaration::BorderInlineEndStyle(..) => LonghandId::BorderInlineEndStyle,
            PropertyDeclaration::BorderInlineStartStyle(..) => LonghandId::BorderInlineStartStyle,
            PropertyDeclaration::BorderLeftStyle(..) => LonghandId::BorderLeftStyle,
            PropertyDeclaration::BorderRightStyle(..) => LonghandId::BorderRightStyle,
            PropertyDeclaration::BorderTopStyle(..) => LonghandId::BorderTopStyle,
            PropertyDeclaration::AnimationDelay(..) => LonghandId::AnimationDelay,
            PropertyDeclaration::AnimationDirection(..) => LonghandId::AnimationDirection,
            PropertyDeclaration::AnimationDuration(..) => LonghandId::AnimationDuration,
            PropertyDeclaration::AnimationFillMode(..) => LonghandId::AnimationFillMode,
            PropertyDeclaration::AnimationIterationCount(..) => LonghandId::AnimationIterationCount,
            PropertyDeclaration::AnimationName(..) => LonghandId::AnimationName,
            PropertyDeclaration::AnimationPlayState(..) => LonghandId::AnimationPlayState,
            PropertyDeclaration::AnimationTimingFunction(..) => LonghandId::AnimationTimingFunction,
            PropertyDeclaration::BackgroundAttachment(..) => LonghandId::BackgroundAttachment,
            PropertyDeclaration::BackgroundBlendMode(..) => LonghandId::BackgroundBlendMode,
            PropertyDeclaration::BackgroundClip(..) => LonghandId::BackgroundClip,
            PropertyDeclaration::BackgroundImage(..) => LonghandId::BackgroundImage,
            PropertyDeclaration::BackgroundOrigin(..) => LonghandId::BackgroundOrigin,
            PropertyDeclaration::BackgroundPositionX(..) => LonghandId::BackgroundPositionX,
            PropertyDeclaration::BackgroundPositionY(..) => LonghandId::BackgroundPositionY,
            PropertyDeclaration::BackgroundRepeat(..) => LonghandId::BackgroundRepeat,
            PropertyDeclaration::BackgroundSize(..) => LonghandId::BackgroundSize,
            PropertyDeclaration::BorderImageOutset(..) => LonghandId::BorderImageOutset,
            PropertyDeclaration::BorderImageSlice(..) => LonghandId::BorderImageSlice,
            PropertyDeclaration::BorderImageSource(..) => LonghandId::BorderImageSource,
            PropertyDeclaration::BorderImageWidth(..) => LonghandId::BorderImageWidth,
            PropertyDeclaration::BorderSpacing(..) => LonghandId::BorderSpacing,
            PropertyDeclaration::BoxShadow(..) => LonghandId::BoxShadow,
            PropertyDeclaration::CaretColor(..) => LonghandId::CaretColor,
            PropertyDeclaration::ClipPath(..) => LonghandId::ClipPath,
            PropertyDeclaration::Color(..) => LonghandId::Color,
            PropertyDeclaration::ColumnGap(..) => LonghandId::ColumnGap,
            PropertyDeclaration::ColumnWidth(..) => LonghandId::ColumnWidth,
            PropertyDeclaration::Content(..) => LonghandId::Content,
            PropertyDeclaration::CounterIncrement(..) => LonghandId::CounterIncrement,
            PropertyDeclaration::CounterReset(..) => LonghandId::CounterReset,
            PropertyDeclaration::Cursor(..) => LonghandId::Cursor,
            PropertyDeclaration::Display(..) => LonghandId::Display,
            PropertyDeclaration::Filter(..) => LonghandId::Filter,
            PropertyDeclaration::FontFamily(..) => LonghandId::FontFamily,
            PropertyDeclaration::FontFeatureSettings(..) => LonghandId::FontFeatureSettings,
            PropertyDeclaration::FontLanguageOverride(..) => LonghandId::FontLanguageOverride,
            PropertyDeclaration::FontSize(..) => LonghandId::FontSize,
            PropertyDeclaration::FontSizeAdjust(..) => LonghandId::FontSizeAdjust,
            PropertyDeclaration::FontVariantAlternates(..) => LonghandId::FontVariantAlternates,
            PropertyDeclaration::FontVariantEastAsian(..) => LonghandId::FontVariantEastAsian,
            PropertyDeclaration::FontVariantLigatures(..) => LonghandId::FontVariantLigatures,
            PropertyDeclaration::FontVariantNumeric(..) => LonghandId::FontVariantNumeric,
            PropertyDeclaration::FontVariationSettings(..) => LonghandId::FontVariationSettings,
            PropertyDeclaration::GridTemplateAreas(..) => LonghandId::GridTemplateAreas,
            PropertyDeclaration::LetterSpacing(..) => LonghandId::LetterSpacing,
            PropertyDeclaration::LineHeight(..) => LonghandId::LineHeight,
            PropertyDeclaration::ListStyleImage(..) => LonghandId::ListStyleImage,
            PropertyDeclaration::ListStyleType(..) => LonghandId::ListStyleType,
            PropertyDeclaration::MaskClip(..) => LonghandId::MaskClip,
            PropertyDeclaration::MaskComposite(..) => LonghandId::MaskComposite,
            PropertyDeclaration::MaskImage(..) => LonghandId::MaskImage,
            PropertyDeclaration::MaskMode(..) => LonghandId::MaskMode,
            PropertyDeclaration::MaskOrigin(..) => LonghandId::MaskOrigin,
            PropertyDeclaration::MaskPositionX(..) => LonghandId::MaskPositionX,
            PropertyDeclaration::MaskPositionY(..) => LonghandId::MaskPositionY,
            PropertyDeclaration::MaskRepeat(..) => LonghandId::MaskRepeat,
            PropertyDeclaration::MaskSize(..) => LonghandId::MaskSize,
            PropertyDeclaration::MozContextProperties(..) => LonghandId::MozContextProperties,
            PropertyDeclaration::MozTabSize(..) => LonghandId::MozTabSize,
            PropertyDeclaration::OutlineOffset(..) => LonghandId::OutlineOffset,
            PropertyDeclaration::OverflowY(..) => LonghandId::OverflowY,
            PropertyDeclaration::Perspective(..) => LonghandId::Perspective,
            PropertyDeclaration::PerspectiveOrigin(..) => LonghandId::PerspectiveOrigin,
            PropertyDeclaration::Quotes(..) => LonghandId::Quotes,
            PropertyDeclaration::Rotate(..) => LonghandId::Rotate,
            PropertyDeclaration::Scale(..) => LonghandId::Scale,
            PropertyDeclaration::ScrollSnapCoordinate(..) => LonghandId::ScrollSnapCoordinate,
            PropertyDeclaration::ShapeOutside(..) => LonghandId::ShapeOutside,
            PropertyDeclaration::StrokeDasharray(..) => LonghandId::StrokeDasharray,
            PropertyDeclaration::StrokeDashoffset(..) => LonghandId::StrokeDashoffset,
            PropertyDeclaration::StrokeMiterlimit(..) => LonghandId::StrokeMiterlimit,
            PropertyDeclaration::StrokeWidth(..) => LonghandId::StrokeWidth,
            PropertyDeclaration::TextAlign(..) => LonghandId::TextAlign,
            PropertyDeclaration::TextEmphasisPosition(..) => LonghandId::TextEmphasisPosition,
            PropertyDeclaration::TextEmphasisStyle(..) => LonghandId::TextEmphasisStyle,
            PropertyDeclaration::TextIndent(..) => LonghandId::TextIndent,
            PropertyDeclaration::TextOverflow(..) => LonghandId::TextOverflow,
            PropertyDeclaration::TextShadow(..) => LonghandId::TextShadow,
            PropertyDeclaration::TransitionDelay(..) => LonghandId::TransitionDelay,
            PropertyDeclaration::TransitionDuration(..) => LonghandId::TransitionDuration,
            PropertyDeclaration::TransitionProperty(..) => LonghandId::TransitionProperty,
            PropertyDeclaration::TransitionTimingFunction(..) => LonghandId::TransitionTimingFunction,
            PropertyDeclaration::Translate(..) => LonghandId::Translate,
            PropertyDeclaration::VerticalAlign(..) => LonghandId::VerticalAlign,
            PropertyDeclaration::WillChange(..) => LonghandId::WillChange,
            PropertyDeclaration::WordSpacing(..) => LonghandId::WordSpacing,
            PropertyDeclaration::XLang(..) => LonghandId::XLang,
            PropertyDeclaration::OverflowClipBoxBlock(..) => LonghandId::OverflowClipBoxBlock,
            PropertyDeclaration::OverflowClipBoxInline(..) => LonghandId::OverflowClipBoxInline,
            PropertyDeclaration::FillOpacity(..) => LonghandId::FillOpacity,
            PropertyDeclaration::StrokeOpacity(..) => LonghandId::StrokeOpacity,
            PropertyDeclaration::ScrollSnapPointsX(..) => LonghandId::ScrollSnapPointsX,
            PropertyDeclaration::ScrollSnapPointsY(..) => LonghandId::ScrollSnapPointsY,
            PropertyDeclaration::MozWindowTransform(..) => LonghandId::MozWindowTransform,
            PropertyDeclaration::Transform(..) => LonghandId::Transform,
            PropertyDeclaration::Clip(..) => LonghandId::Clip,
            PropertyDeclaration::MozImageRegion(..) => LonghandId::MozImageRegion,
            PropertyDeclaration::GridTemplateColumns(..) => LonghandId::GridTemplateColumns,
            PropertyDeclaration::GridTemplateRows(..) => LonghandId::GridTemplateRows,
            PropertyDeclaration::ObjectPosition(..) => LonghandId::ObjectPosition,
            PropertyDeclaration::ScrollSnapDestination(..) => LonghandId::ScrollSnapDestination,
            PropertyDeclaration::Fill(..) => LonghandId::Fill,
            PropertyDeclaration::Stroke(..) => LonghandId::Stroke,
            PropertyDeclaration::GridAutoColumns(..) => LonghandId::GridAutoColumns,
            PropertyDeclaration::GridAutoRows(..) => LonghandId::GridAutoRows,
            PropertyDeclaration::MozWindowTransformOrigin(..) => LonghandId::MozWindowTransformOrigin,
            PropertyDeclaration::TransformOrigin(..) => LonghandId::TransformOrigin,
            PropertyDeclaration::MaxBlockSize(..) => LonghandId::MaxBlockSize,
            PropertyDeclaration::MaxHeight(..) => LonghandId::MaxHeight,
            PropertyDeclaration::MaxInlineSize(..) => LonghandId::MaxInlineSize,
            PropertyDeclaration::MaxWidth(..) => LonghandId::MaxWidth,
            PropertyDeclaration::FloodColor(..) => LonghandId::FloodColor,
            PropertyDeclaration::LightingColor(..) => LonghandId::LightingColor,
            PropertyDeclaration::MozFontSmoothingBackgroundColor(..) => LonghandId::MozFontSmoothingBackgroundColor,
            PropertyDeclaration::StopColor(..) => LonghandId::StopColor,
            PropertyDeclaration::MarkerEnd(..) => LonghandId::MarkerEnd,
            PropertyDeclaration::MarkerMid(..) => LonghandId::MarkerMid,
            PropertyDeclaration::MarkerStart(..) => LonghandId::MarkerStart,
            PropertyDeclaration::MozBinding(..) => LonghandId::MozBinding,
            PropertyDeclaration::GridColumnEnd(..) => LonghandId::GridColumnEnd,
            PropertyDeclaration::GridColumnStart(..) => LonghandId::GridColumnStart,
            PropertyDeclaration::GridRowEnd(..) => LonghandId::GridRowEnd,
            PropertyDeclaration::GridRowStart(..) => LonghandId::GridRowStart,
            PropertyDeclaration::BorderBottomLeftRadius(..) => LonghandId::BorderBottomLeftRadius,
            PropertyDeclaration::BorderBottomRightRadius(..) => LonghandId::BorderBottomRightRadius,
            PropertyDeclaration::BorderTopLeftRadius(..) => LonghandId::BorderTopLeftRadius,
            PropertyDeclaration::BorderTopRightRadius(..) => LonghandId::BorderTopRightRadius,
            PropertyDeclaration::MozOutlineRadiusBottomleft(..) => LonghandId::MozOutlineRadiusBottomleft,
            PropertyDeclaration::MozOutlineRadiusBottomright(..) => LonghandId::MozOutlineRadiusBottomright,
            PropertyDeclaration::MozOutlineRadiusTopleft(..) => LonghandId::MozOutlineRadiusTopleft,
            PropertyDeclaration::MozOutlineRadiusTopright(..) => LonghandId::MozOutlineRadiusTopright,
            PropertyDeclaration::BlockSize(..) => LonghandId::BlockSize,
            PropertyDeclaration::FlexBasis(..) => LonghandId::FlexBasis,
            PropertyDeclaration::Height(..) => LonghandId::Height,
            PropertyDeclaration::InlineSize(..) => LonghandId::InlineSize,
            PropertyDeclaration::MinBlockSize(..) => LonghandId::MinBlockSize,
            PropertyDeclaration::MinHeight(..) => LonghandId::MinHeight,
            PropertyDeclaration::MinInlineSize(..) => LonghandId::MinInlineSize,
            PropertyDeclaration::MinWidth(..) => LonghandId::MinWidth,
            PropertyDeclaration::Width(..) => LonghandId::Width,
            PropertyDeclaration::GridColumnGap(..) => LonghandId::GridColumnGap,
            PropertyDeclaration::GridRowGap(..) => LonghandId::GridRowGap,
            PropertyDeclaration::PaddingBlockEnd(..) => LonghandId::PaddingBlockEnd,
            PropertyDeclaration::PaddingBlockStart(..) => LonghandId::PaddingBlockStart,
            PropertyDeclaration::PaddingBottom(..) => LonghandId::PaddingBottom,
            PropertyDeclaration::PaddingInlineEnd(..) => LonghandId::PaddingInlineEnd,
            PropertyDeclaration::PaddingInlineStart(..) => LonghandId::PaddingInlineStart,
            PropertyDeclaration::PaddingLeft(..) => LonghandId::PaddingLeft,
            PropertyDeclaration::PaddingRight(..) => LonghandId::PaddingRight,
            PropertyDeclaration::PaddingTop(..) => LonghandId::PaddingTop,
            PropertyDeclaration::BorderBlockEndWidth(..) => LonghandId::BorderBlockEndWidth,
            PropertyDeclaration::BorderBlockStartWidth(..) => LonghandId::BorderBlockStartWidth,
            PropertyDeclaration::BorderBottomWidth(..) => LonghandId::BorderBottomWidth,
            PropertyDeclaration::BorderInlineEndWidth(..) => LonghandId::BorderInlineEndWidth,
            PropertyDeclaration::BorderInlineStartWidth(..) => LonghandId::BorderInlineStartWidth,
            PropertyDeclaration::BorderLeftWidth(..) => LonghandId::BorderLeftWidth,
            PropertyDeclaration::BorderRightWidth(..) => LonghandId::BorderRightWidth,
            PropertyDeclaration::BorderTopWidth(..) => LonghandId::BorderTopWidth,
            PropertyDeclaration::ColumnRuleWidth(..) => LonghandId::ColumnRuleWidth,
            PropertyDeclaration::OutlineWidth(..) => LonghandId::OutlineWidth,
            PropertyDeclaration::WebkitTextStrokeWidth(..) => LonghandId::WebkitTextStrokeWidth,
            PropertyDeclaration::BackgroundColor(..) => LonghandId::BackgroundColor,
            PropertyDeclaration::BorderBlockEndColor(..) => LonghandId::BorderBlockEndColor,
            PropertyDeclaration::BorderBlockStartColor(..) => LonghandId::BorderBlockStartColor,
            PropertyDeclaration::BorderBottomColor(..) => LonghandId::BorderBottomColor,
            PropertyDeclaration::BorderInlineEndColor(..) => LonghandId::BorderInlineEndColor,
            PropertyDeclaration::BorderInlineStartColor(..) => LonghandId::BorderInlineStartColor,
            PropertyDeclaration::BorderLeftColor(..) => LonghandId::BorderLeftColor,
            PropertyDeclaration::BorderRightColor(..) => LonghandId::BorderRightColor,
            PropertyDeclaration::BorderTopColor(..) => LonghandId::BorderTopColor,
            PropertyDeclaration::ColumnRuleColor(..) => LonghandId::ColumnRuleColor,
            PropertyDeclaration::OutlineColor(..) => LonghandId::OutlineColor,
            PropertyDeclaration::TextDecorationColor(..) => LonghandId::TextDecorationColor,
            PropertyDeclaration::TextEmphasisColor(..) => LonghandId::TextEmphasisColor,
            PropertyDeclaration::WebkitTextFillColor(..) => LonghandId::WebkitTextFillColor,
            PropertyDeclaration::WebkitTextStrokeColor(..) => LonghandId::WebkitTextStrokeColor,
            PropertyDeclaration::Bottom(..) => LonghandId::Bottom,
            PropertyDeclaration::Left(..) => LonghandId::Left,
            PropertyDeclaration::MarginBlockEnd(..) => LonghandId::MarginBlockEnd,
            PropertyDeclaration::MarginBlockStart(..) => LonghandId::MarginBlockStart,
            PropertyDeclaration::MarginBottom(..) => LonghandId::MarginBottom,
            PropertyDeclaration::MarginInlineEnd(..) => LonghandId::MarginInlineEnd,
            PropertyDeclaration::MarginInlineStart(..) => LonghandId::MarginInlineStart,
            PropertyDeclaration::MarginLeft(..) => LonghandId::MarginLeft,
            PropertyDeclaration::MarginRight(..) => LonghandId::MarginRight,
            PropertyDeclaration::MarginTop(..) => LonghandId::MarginTop,
            PropertyDeclaration::OffsetBlockEnd(..) => LonghandId::OffsetBlockEnd,
            PropertyDeclaration::OffsetBlockStart(..) => LonghandId::OffsetBlockStart,
            PropertyDeclaration::OffsetInlineEnd(..) => LonghandId::OffsetInlineEnd,
            PropertyDeclaration::OffsetInlineStart(..) => LonghandId::OffsetInlineStart,
            PropertyDeclaration::Right(..) => LonghandId::Right,
            PropertyDeclaration::Top(..) => LonghandId::Top,
            _ => id,
        });
        PropertyDeclarationId::Longhand(id)
    }

    fn with_variables_from_shorthand(&self, shorthand: ShorthandId) -> Option< &str> {
        match *self {
            PropertyDeclaration::WithVariables(ref declaration) => {
                let s = declaration.value.from_shorthand?;
                if s != shorthand {
                    return None;
                }
                Some(&*declaration.value.css)
            },
            _ => None,
        }
    }

    /// Returns a CSS-wide keyword if the declaration's value is one.
    pub fn get_css_wide_keyword(&self) -> Option<CSSWideKeyword> {
        match *self {
            PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                Some(declaration.keyword)
            },
            _ => None,
        }
    }

    /// Returns whether or not the property is set by a system font
    #[cfg(feature = "gecko")]
    pub fn get_system(&self) -> Option<SystemFont> {
        match *self {
                PropertyDeclaration::FontFamily(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontSize(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontStyle(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontVariantCaps(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontStretch(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontKerning(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontVariantPosition(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontWeight(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontSizeAdjust(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontVariantAlternates(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontVariantLigatures(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontVariantEastAsian(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontVariantNumeric(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontLanguageOverride(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontFeatureSettings(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontVariationSettings(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontOpticalSizing(ref prop) => {
                    prop.get_system()
                }
            _ => None,
        }
    }

    /// Is it the default value of line-height?
    pub fn is_default_line_height(&self) -> bool {
        match *self {
            PropertyDeclaration::LineHeight(LineHeight::Normal) => true,
            _ => false
        }
    }

    #[cfg(feature = "servo")]
    /// Dummy method to avoid cfg()s
    pub fn get_system(&self) -> Option<()> {
        None
    }

    /// Returns whether the declaration may be serialized as part of a shorthand.
    ///
    /// This method returns false if this declaration contains variable or has a
    /// CSS-wide keyword value, since these values cannot be serialized as part
    /// of a shorthand.
    ///
    /// Caller should check `with_variables_from_shorthand()` and whether all
    /// needed declarations has the same CSS-wide keyword first.
    ///
    /// Note that, serialization of a shorthand may still fail because of other
    /// property-specific requirement even when this method returns true for all
    /// the longhand declarations.
    pub fn may_serialize_as_part_of_shorthand(&self) -> bool {
        match *self {
            PropertyDeclaration::CSSWideKeyword(..) |
            PropertyDeclaration::WithVariables(..) => false,
            PropertyDeclaration::Custom(..) =>
                unreachable!("Serializing a custom property as part of shorthand?"),
            _ => true,
        }
    }

    /// Return whether the value is stored as it was in the CSS source,
    /// preserving whitespace (as opposed to being parsed into a more abstract
    /// data structure).
    ///
    /// This is the case of custom properties and values that contain
    /// unsubstituted variables.
    pub fn value_is_unparsed(&self) -> bool {
      match *self {
          PropertyDeclaration::WithVariables(..) => true,
          PropertyDeclaration::Custom(ref declaration) => {
            !matches!(declaration.value.borrow(), DeclaredValue::CSSWideKeyword(..))
          }
          _ => false,
      }
    }

    /// Returns true if this property declaration is for one of the animatable
    /// properties.
    pub fn is_animatable(&self) -> bool {
        match self.id() {
            PropertyDeclarationId::Longhand(id) => id.is_animatable(),
            PropertyDeclarationId::Custom(..) => false,
        }
    }

    /// Returns true if this property is a custom property, false
    /// otherwise.
    pub fn is_custom(&self) -> bool {
        matches!(*self, PropertyDeclaration::Custom(..))
    }

    /// The `context` parameter controls this:
    ///
    /// <https://drafts.csswg.org/css-animations/#keyframes>
    /// > The <declaration-list> inside of <keyframe-block> accepts any CSS property
    /// > except those defined in this specification,
    /// > but does accept the `animation-play-state` property and interprets it specially.
    ///
    /// This will not actually parse Importance values, and will always set things
    /// to Importance::Normal. Parsing Importance values is the job of PropertyDeclarationParser,
    /// we only set them here so that we don't have to reallocate
    pub fn parse_into<'i, 't>(
        declarations: &mut SourcePropertyDeclaration,
        id: PropertyId,
        name: CowRcStr<'i>,
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<(), ParseError<'i>> {
        assert!(declarations.is_empty());

        if !id.allowed_in(context) {
            return Err(input.new_custom_error(
                StyleParseErrorKind::UnknownProperty(name)
            ));
        }

        let start = input.state();
        match id {
            PropertyId::Custom(property_name) => {
                // FIXME: fully implement https://github.com/w3c/csswg-drafts/issues/774
                // before adding skip_whitespace here.
                // This probably affects some test results.
                let value = match input.try(|i| CSSWideKeyword::parse(i)) {
                    Ok(keyword) => DeclaredValueOwned::CSSWideKeyword(keyword),
                    Err(()) => match ::custom_properties::SpecifiedValue::parse(input) {
                        Ok(value) => DeclaredValueOwned::Value(value),
                        Err(e) => return Err(StyleParseErrorKind::new_invalid(name, e)),
                    }
                };
                declarations.push(PropertyDeclaration::Custom(CustomDeclaration {
                    name: property_name,
                    value,
                }));
                Ok(())
            }
            PropertyId::LonghandAlias(id, _) |
            PropertyId::Longhand(id) => {
                input.skip_whitespace();  // Unnecessary for correctness, but may help try() rewind less.
                input.try(|i| CSSWideKeyword::parse(i)).map(|keyword| {
                    PropertyDeclaration::CSSWideKeyword(
                        WideKeywordDeclaration { id, keyword },
                    )
                }).or_else(|()| {
                    input.look_for_var_functions();
                    input.parse_entirely(|input| id.parse_value(context, input))
                    .or_else(|err| {
                        while let Ok(_) = input.next() {}  // Look for var() after the error.
                        if input.seen_var_functions() {
                            input.reset(&start);
                            let (first_token_type, css) =
                                ::custom_properties::parse_non_custom_with_var(input).map_err(|e| {
                                    StyleParseErrorKind::new_invalid(name, e)
                                })?;
                            Ok(PropertyDeclaration::WithVariables(VariableDeclaration {
                                id,
                                value: Arc::new(UnparsedValue {
                                css: css.into_owned(),
                                first_token_type: first_token_type,
                                url_data: context.url_data.clone(),
                                from_shorthand: None,
                                }),
                            }))
                        } else {
                            Err(StyleParseErrorKind::new_invalid(name, err))
                        }
                    })
                }).map(|declaration| {
                    declarations.push(declaration)
                })
            }
            PropertyId::ShorthandAlias(id, _) |
            PropertyId::Shorthand(id) => {
                input.skip_whitespace();  // Unnecessary for correctness, but may help try() rewind less.
                if let Ok(keyword) = input.try(|i| CSSWideKeyword::parse(i)) {
                    if id == ShorthandId::All {
                        declarations.all_shorthand = AllShorthand::CSSWideKeyword(keyword)
                    } else {
                        for longhand in id.longhands() {
                            declarations.push(PropertyDeclaration::CSSWideKeyword(
                                WideKeywordDeclaration {
                                    id: longhand,
                                    keyword,
                                },
                            ))
                        }
                    }
                    Ok(())
                } else {
                    input.look_for_var_functions();
                    // Not using parse_entirely here: each text_decoration::parse_into function
                    // needs to do so *before* pushing to `declarations`.
                    id.parse_into(declarations, context, input).or_else(|err| {
                        while let Ok(_) = input.next() {}  // Look for var() after the error.
                        if input.seen_var_functions() {
                            input.reset(&start);
                            let (first_token_type, css) =
                                ::custom_properties::parse_non_custom_with_var(input).map_err(|e| {
                                    StyleParseErrorKind::new_invalid(name, e)
                                })?;
                            let unparsed = Arc::new(UnparsedValue {
                                css: css.into_owned(),
                                first_token_type: first_token_type,
                                url_data: context.url_data.clone(),
                                from_shorthand: Some(id),
                            });
                            if id == ShorthandId::All {
                                declarations.all_shorthand = AllShorthand::WithVariables(unparsed)
                            } else {
                                for id in id.longhands() {
                                    declarations.push(
                                        PropertyDeclaration::WithVariables(VariableDeclaration {
                                            id,
                                            value: unparsed.clone(),
                                        })
                                    )
                                }
                            }
                            Ok(())
                        } else {
                            Err(StyleParseErrorKind::new_invalid(name, err))
                        }
                    })
                }
            }
        }
    }
}

const MAX_SUB_PROPERTIES_PER_SHORTHAND_EXCEPT_ALL: usize =
    18;

type SourcePropertyDeclarationArray =
    [PropertyDeclaration; MAX_SUB_PROPERTIES_PER_SHORTHAND_EXCEPT_ALL];

/// A stack-allocated vector of `PropertyDeclaration`
/// large enough to parse one CSS `key: value` declaration.
/// (Shorthands expand to multiple `PropertyDeclaration`s.)
pub struct SourcePropertyDeclaration {
    declarations: ::arrayvec::ArrayVec<SourcePropertyDeclarationArray>,

    /// Stored separately to keep MAX_SUB_PROPERTIES_PER_SHORTHAND_EXCEPT_ALL smaller.
    all_shorthand: AllShorthand,
}

impl SourcePropertyDeclaration {
    /// Create one. It’s big, try not to move it around.
    #[inline]
    pub fn new() -> Self {
        SourcePropertyDeclaration {
            declarations: ::arrayvec::ArrayVec::new(),
            all_shorthand: AllShorthand::NotSet,
        }
    }

    /// Similar to Vec::drain: leaves this empty when the return value is dropped.
    pub fn drain(&mut self) -> SourcePropertyDeclarationDrain {
        SourcePropertyDeclarationDrain {
            declarations: self.declarations.drain(..),
            all_shorthand: mem::replace(&mut self.all_shorthand, AllShorthand::NotSet),
        }
    }

    /// Reset to initial state
    pub fn clear(&mut self) {
        self.declarations.clear();
        self.all_shorthand = AllShorthand::NotSet;
    }

    fn is_empty(&self) -> bool {
        self.declarations.is_empty() && matches!(self.all_shorthand, AllShorthand::NotSet)
    }

    fn push(&mut self, declaration: PropertyDeclaration) {
        let _result = self.declarations.try_push(declaration);
        debug_assert!(_result.is_ok());
    }
}

/// Return type of SourcePropertyDeclaration::drain
pub struct SourcePropertyDeclarationDrain<'a> {
    declarations: ::arrayvec::Drain<'a, SourcePropertyDeclarationArray>,
    all_shorthand: AllShorthand,
}

enum AllShorthand {
    NotSet,
    CSSWideKeyword(CSSWideKeyword),
    WithVariables(Arc<UnparsedValue>)
}

#[cfg(feature = "gecko")]
pub use gecko_properties::style_structs;

/// The module where all the style structs are defined.
#[cfg(feature = "servo")]
pub mod style_structs {
    use fnv::FnvHasher;
    use super::longhands;
    use std::hash::{Hash, Hasher};
    use logical_geometry::WritingMode;
    use media_queries::Device;
    use values::computed::NonNegativeLength;

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Background style struct.
        pub struct Background {
                /// The background-color computed value.
                pub background_color: longhands::background_color::computed_value::T,
                /// The background-image computed value.
                pub background_image: longhands::background_image::computed_value::T,
                /// The background-position-x computed value.
                pub background_position_x: longhands::background_position_x::computed_value::T,
                /// The background-position-y computed value.
                pub background_position_y: longhands::background_position_y::computed_value::T,
                /// The background-repeat computed value.
                pub background_repeat: longhands::background_repeat::computed_value::T,
                /// The background-attachment computed value.
                pub background_attachment: longhands::background_attachment::computed_value::T,
                /// The background-clip computed value.
                pub background_clip: longhands::background_clip::computed_value::T,
                /// The background-origin computed value.
                pub background_origin: longhands::background_origin::computed_value::T,
                /// The background-size computed value.
                pub background_size: longhands::background_size::computed_value::T,
                /// The background-blend-mode computed value.
                pub background_blend_mode: longhands::background_blend_mode::computed_value::T,
        }

        impl Background {
                        /// Set background-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_color(&mut self, v: longhands::background_color::computed_value::T) {
                            self.background_color = v;
                        }
                        /// Set background-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_color_from(&mut self, other: &Self) {
                            self.background_color = other.background_color.clone();
                        }
                    /// Reset background-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_color(&mut self, other: &Self) {
                        self.copy_background_color_from(other)
                    }

                    /// Get the computed value for background-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_color(&self) -> longhands::background_color::computed_value::T {
                        self.background_color.clone()
                    }
                        /// Set background-image.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_image<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_image
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_image = longhands::background_image::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-image from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_image_from(&mut self, other: &Self) {
                            self.background_image = other.background_image.clone();
                        }
                    /// Reset background-image from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_image(&mut self, other: &Self) {
                        self.copy_background_image_from(other)
                    }

                    /// Get the computed value for background-image.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_image(&self) -> longhands::background_image::computed_value::T {
                        self.background_image.clone()
                    }
                        /// Set background-position-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_position_x<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_position_x
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_position_x = longhands::background_position_x::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-position-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_position_x_from(&mut self, other: &Self) {
                            self.background_position_x = other.background_position_x.clone();
                        }
                    /// Reset background-position-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_position_x(&mut self, other: &Self) {
                        self.copy_background_position_x_from(other)
                    }

                    /// Get the computed value for background-position-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_position_x(&self) -> longhands::background_position_x::computed_value::T {
                        self.background_position_x.clone()
                    }
                        /// Set background-position-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_position_y<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_position_y
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_position_y = longhands::background_position_y::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-position-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_position_y_from(&mut self, other: &Self) {
                            self.background_position_y = other.background_position_y.clone();
                        }
                    /// Reset background-position-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_position_y(&mut self, other: &Self) {
                        self.copy_background_position_y_from(other)
                    }

                    /// Get the computed value for background-position-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_position_y(&self) -> longhands::background_position_y::computed_value::T {
                        self.background_position_y.clone()
                    }
                        /// Set background-repeat.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_repeat<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_repeat
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_repeat = longhands::background_repeat::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-repeat from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_repeat_from(&mut self, other: &Self) {
                            self.background_repeat = other.background_repeat.clone();
                        }
                    /// Reset background-repeat from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_repeat(&mut self, other: &Self) {
                        self.copy_background_repeat_from(other)
                    }

                    /// Get the computed value for background-repeat.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_repeat(&self) -> longhands::background_repeat::computed_value::T {
                        self.background_repeat.clone()
                    }
                        /// Set background-attachment.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_attachment<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_attachment
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_attachment = longhands::background_attachment::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-attachment from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_attachment_from(&mut self, other: &Self) {
                            self.background_attachment = other.background_attachment.clone();
                        }
                    /// Reset background-attachment from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_attachment(&mut self, other: &Self) {
                        self.copy_background_attachment_from(other)
                    }

                    /// Get the computed value for background-attachment.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_attachment(&self) -> longhands::background_attachment::computed_value::T {
                        self.background_attachment.clone()
                    }
                        /// Set background-clip.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_clip<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_clip
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_clip = longhands::background_clip::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-clip from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_clip_from(&mut self, other: &Self) {
                            self.background_clip = other.background_clip.clone();
                        }
                    /// Reset background-clip from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_clip(&mut self, other: &Self) {
                        self.copy_background_clip_from(other)
                    }

                    /// Get the computed value for background-clip.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_clip(&self) -> longhands::background_clip::computed_value::T {
                        self.background_clip.clone()
                    }
                        /// Set background-origin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_origin<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_origin
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_origin = longhands::background_origin::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-origin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_origin_from(&mut self, other: &Self) {
                            self.background_origin = other.background_origin.clone();
                        }
                    /// Reset background-origin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_origin(&mut self, other: &Self) {
                        self.copy_background_origin_from(other)
                    }

                    /// Get the computed value for background-origin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_origin(&self) -> longhands::background_origin::computed_value::T {
                        self.background_origin.clone()
                    }
                        /// Set background-size.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_size<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_size
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_size = longhands::background_size::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-size from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_size_from(&mut self, other: &Self) {
                            self.background_size = other.background_size.clone();
                        }
                    /// Reset background-size from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_size(&mut self, other: &Self) {
                        self.copy_background_size_from(other)
                    }

                    /// Get the computed value for background-size.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_size(&self) -> longhands::background_size::computed_value::T {
                        self.background_size.clone()
                    }
                        /// Set background-blend-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_blend_mode<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_blend_mode
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_blend_mode = longhands::background_blend_mode::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-blend-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_blend_mode_from(&mut self, other: &Self) {
                            self.background_blend_mode = other.background_blend_mode.clone();
                        }
                    /// Reset background-blend-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_blend_mode(&mut self, other: &Self) {
                        self.copy_background_blend_mode_from(other)
                    }

                    /// Get the computed value for background-blend-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_blend_mode(&self) -> longhands::background_blend_mode::computed_value::T {
                        self.background_blend_mode.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Border style struct.
        pub struct Border {
                /// The border-top-color computed value.
                pub border_top_color: longhands::border_top_color::computed_value::T,
                /// The border-top-style computed value.
                pub border_top_style: longhands::border_top_style::computed_value::T,
                /// The border-top-width computed value.
                pub border_top_width: longhands::border_top_width::computed_value::T,
                /// The border-left-color computed value.
                pub border_left_color: longhands::border_left_color::computed_value::T,
                /// The border-left-style computed value.
                pub border_left_style: longhands::border_left_style::computed_value::T,
                /// The border-left-width computed value.
                pub border_left_width: longhands::border_left_width::computed_value::T,
                /// The border-bottom-color computed value.
                pub border_bottom_color: longhands::border_bottom_color::computed_value::T,
                /// The border-bottom-style computed value.
                pub border_bottom_style: longhands::border_bottom_style::computed_value::T,
                /// The border-bottom-width computed value.
                pub border_bottom_width: longhands::border_bottom_width::computed_value::T,
                /// The border-right-color computed value.
                pub border_right_color: longhands::border_right_color::computed_value::T,
                /// The border-right-style computed value.
                pub border_right_style: longhands::border_right_style::computed_value::T,
                /// The border-right-width computed value.
                pub border_right_width: longhands::border_right_width::computed_value::T,
                /// The border-block-start-color computed value.
                pub border_block_start_color: longhands::border_block_start_color::computed_value::T,
                /// The border-block-start-style computed value.
                pub border_block_start_style: longhands::border_block_start_style::computed_value::T,
                /// The border-block-start-width computed value.
                pub border_block_start_width: longhands::border_block_start_width::computed_value::T,
                /// The border-block-end-color computed value.
                pub border_block_end_color: longhands::border_block_end_color::computed_value::T,
                /// The border-block-end-style computed value.
                pub border_block_end_style: longhands::border_block_end_style::computed_value::T,
                /// The border-block-end-width computed value.
                pub border_block_end_width: longhands::border_block_end_width::computed_value::T,
                /// The border-inline-start-color computed value.
                pub border_inline_start_color: longhands::border_inline_start_color::computed_value::T,
                /// The border-inline-start-style computed value.
                pub border_inline_start_style: longhands::border_inline_start_style::computed_value::T,
                /// The border-inline-start-width computed value.
                pub border_inline_start_width: longhands::border_inline_start_width::computed_value::T,
                /// The border-inline-end-color computed value.
                pub border_inline_end_color: longhands::border_inline_end_color::computed_value::T,
                /// The border-inline-end-style computed value.
                pub border_inline_end_style: longhands::border_inline_end_style::computed_value::T,
                /// The border-inline-end-width computed value.
                pub border_inline_end_width: longhands::border_inline_end_width::computed_value::T,
                /// The border-top-left-radius computed value.
                pub border_top_left_radius: longhands::border_top_left_radius::computed_value::T,
                /// The border-top-right-radius computed value.
                pub border_top_right_radius: longhands::border_top_right_radius::computed_value::T,
                /// The border-bottom-right-radius computed value.
                pub border_bottom_right_radius: longhands::border_bottom_right_radius::computed_value::T,
                /// The border-bottom-left-radius computed value.
                pub border_bottom_left_radius: longhands::border_bottom_left_radius::computed_value::T,
                /// The box-decoration-break computed value.
                pub box_decoration_break: longhands::box_decoration_break::computed_value::T,
                /// The -moz-float-edge computed value.
                pub _moz_float_edge: longhands::_moz_float_edge::computed_value::T,
                /// The border-image-source computed value.
                pub border_image_source: longhands::border_image_source::computed_value::T,
                /// The border-image-outset computed value.
                pub border_image_outset: longhands::border_image_outset::computed_value::T,
                /// The border-image-repeat computed value.
                pub border_image_repeat: longhands::border_image_repeat::computed_value::T,
                /// The border-image-width computed value.
                pub border_image_width: longhands::border_image_width::computed_value::T,
                /// The border-image-slice computed value.
                pub border_image_slice: longhands::border_image_slice::computed_value::T,
        }

        impl Border {
                        /// Set border-top-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_top_color(&mut self, v: longhands::border_top_color::computed_value::T) {
                            self.border_top_color = v;
                        }
                        /// Set border-top-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_top_color_from(&mut self, other: &Self) {
                            self.border_top_color = other.border_top_color.clone();
                        }
                    /// Reset border-top-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_top_color(&mut self, other: &Self) {
                        self.copy_border_top_color_from(other)
                    }

                    /// Get the computed value for border-top-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_top_color(&self) -> longhands::border_top_color::computed_value::T {
                        self.border_top_color.clone()
                    }
                        /// Set border-top-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_top_style(&mut self, v: longhands::border_top_style::computed_value::T) {
                            self.border_top_style = v;
                        }
                        /// Set border-top-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_top_style_from(&mut self, other: &Self) {
                            self.border_top_style = other.border_top_style.clone();
                        }
                    /// Reset border-top-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_top_style(&mut self, other: &Self) {
                        self.copy_border_top_style_from(other)
                    }

                    /// Get the computed value for border-top-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_top_style(&self) -> longhands::border_top_style::computed_value::T {
                        self.border_top_style.clone()
                    }
                        /// Set border-top-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_top_width(&mut self, v: longhands::border_top_width::computed_value::T) {
                            self.border_top_width = v;
                        }
                        /// Set border-top-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_top_width_from(&mut self, other: &Self) {
                            self.border_top_width = other.border_top_width.clone();
                        }
                    /// Reset border-top-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_top_width(&mut self, other: &Self) {
                        self.copy_border_top_width_from(other)
                    }

                    /// Get the computed value for border-top-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_top_width(&self) -> longhands::border_top_width::computed_value::T {
                        self.border_top_width.clone()
                    }
                        /// Set border-left-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_left_color(&mut self, v: longhands::border_left_color::computed_value::T) {
                            self.border_left_color = v;
                        }
                        /// Set border-left-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_left_color_from(&mut self, other: &Self) {
                            self.border_left_color = other.border_left_color.clone();
                        }
                    /// Reset border-left-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_left_color(&mut self, other: &Self) {
                        self.copy_border_left_color_from(other)
                    }

                    /// Get the computed value for border-left-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_left_color(&self) -> longhands::border_left_color::computed_value::T {
                        self.border_left_color.clone()
                    }
                        /// Set border-left-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_left_style(&mut self, v: longhands::border_left_style::computed_value::T) {
                            self.border_left_style = v;
                        }
                        /// Set border-left-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_left_style_from(&mut self, other: &Self) {
                            self.border_left_style = other.border_left_style.clone();
                        }
                    /// Reset border-left-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_left_style(&mut self, other: &Self) {
                        self.copy_border_left_style_from(other)
                    }

                    /// Get the computed value for border-left-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_left_style(&self) -> longhands::border_left_style::computed_value::T {
                        self.border_left_style.clone()
                    }
                        /// Set border-left-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_left_width(&mut self, v: longhands::border_left_width::computed_value::T) {
                            self.border_left_width = v;
                        }
                        /// Set border-left-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_left_width_from(&mut self, other: &Self) {
                            self.border_left_width = other.border_left_width.clone();
                        }
                    /// Reset border-left-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_left_width(&mut self, other: &Self) {
                        self.copy_border_left_width_from(other)
                    }

                    /// Get the computed value for border-left-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_left_width(&self) -> longhands::border_left_width::computed_value::T {
                        self.border_left_width.clone()
                    }
                        /// Set border-bottom-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_bottom_color(&mut self, v: longhands::border_bottom_color::computed_value::T) {
                            self.border_bottom_color = v;
                        }
                        /// Set border-bottom-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_bottom_color_from(&mut self, other: &Self) {
                            self.border_bottom_color = other.border_bottom_color.clone();
                        }
                    /// Reset border-bottom-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_bottom_color(&mut self, other: &Self) {
                        self.copy_border_bottom_color_from(other)
                    }

                    /// Get the computed value for border-bottom-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_bottom_color(&self) -> longhands::border_bottom_color::computed_value::T {
                        self.border_bottom_color.clone()
                    }
                        /// Set border-bottom-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_bottom_style(&mut self, v: longhands::border_bottom_style::computed_value::T) {
                            self.border_bottom_style = v;
                        }
                        /// Set border-bottom-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_bottom_style_from(&mut self, other: &Self) {
                            self.border_bottom_style = other.border_bottom_style.clone();
                        }
                    /// Reset border-bottom-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_bottom_style(&mut self, other: &Self) {
                        self.copy_border_bottom_style_from(other)
                    }

                    /// Get the computed value for border-bottom-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_bottom_style(&self) -> longhands::border_bottom_style::computed_value::T {
                        self.border_bottom_style.clone()
                    }
                        /// Set border-bottom-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_bottom_width(&mut self, v: longhands::border_bottom_width::computed_value::T) {
                            self.border_bottom_width = v;
                        }
                        /// Set border-bottom-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_bottom_width_from(&mut self, other: &Self) {
                            self.border_bottom_width = other.border_bottom_width.clone();
                        }
                    /// Reset border-bottom-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_bottom_width(&mut self, other: &Self) {
                        self.copy_border_bottom_width_from(other)
                    }

                    /// Get the computed value for border-bottom-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_bottom_width(&self) -> longhands::border_bottom_width::computed_value::T {
                        self.border_bottom_width.clone()
                    }
                        /// Set border-right-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_right_color(&mut self, v: longhands::border_right_color::computed_value::T) {
                            self.border_right_color = v;
                        }
                        /// Set border-right-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_right_color_from(&mut self, other: &Self) {
                            self.border_right_color = other.border_right_color.clone();
                        }
                    /// Reset border-right-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_right_color(&mut self, other: &Self) {
                        self.copy_border_right_color_from(other)
                    }

                    /// Get the computed value for border-right-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_right_color(&self) -> longhands::border_right_color::computed_value::T {
                        self.border_right_color.clone()
                    }
                        /// Set border-right-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_right_style(&mut self, v: longhands::border_right_style::computed_value::T) {
                            self.border_right_style = v;
                        }
                        /// Set border-right-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_right_style_from(&mut self, other: &Self) {
                            self.border_right_style = other.border_right_style.clone();
                        }
                    /// Reset border-right-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_right_style(&mut self, other: &Self) {
                        self.copy_border_right_style_from(other)
                    }

                    /// Get the computed value for border-right-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_right_style(&self) -> longhands::border_right_style::computed_value::T {
                        self.border_right_style.clone()
                    }
                        /// Set border-right-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_right_width(&mut self, v: longhands::border_right_width::computed_value::T) {
                            self.border_right_width = v;
                        }
                        /// Set border-right-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_right_width_from(&mut self, other: &Self) {
                            self.border_right_width = other.border_right_width.clone();
                        }
                    /// Reset border-right-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_right_width(&mut self, other: &Self) {
                        self.copy_border_right_width_from(other)
                    }

                    /// Get the computed value for border-right-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_right_width(&self) -> longhands::border_right_width::computed_value::T {
                        self.border_right_width.clone()
                    }
                    
    /// Set the appropriate physical property for border-block-start-color given a writing mode.
    pub fn set_border_block_start_color(&mut self,
                                      v: longhands::border_block_start_color::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_color(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_color(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_color(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_color(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-start-color
    /// given a writing mode.
    pub fn copy_border_block_start_color_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_color_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_color_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_color_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_color_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-start-color
    /// given a writing mode.
    pub fn reset_border_block_start_color(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_block_start_color_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-block-start-color given a writing mode.
    pub fn clone_border_block_start_color(&self, wm: WritingMode)
        -> longhands::border_block_start_color::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_color()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_color()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_color()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_color()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-block-start-style given a writing mode.
    pub fn set_border_block_start_style(&mut self,
                                      v: longhands::border_block_start_style::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_style(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_style(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_style(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_style(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-start-style
    /// given a writing mode.
    pub fn copy_border_block_start_style_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_style_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_style_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_style_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_style_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-start-style
    /// given a writing mode.
    pub fn reset_border_block_start_style(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_block_start_style_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-block-start-style given a writing mode.
    pub fn clone_border_block_start_style(&self, wm: WritingMode)
        -> longhands::border_block_start_style::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_style()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_style()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_style()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_style()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-block-start-width given a writing mode.
    pub fn set_border_block_start_width(&mut self,
                                      v: longhands::border_block_start_width::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_width(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_width(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_width(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_width(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-start-width
    /// given a writing mode.
    pub fn copy_border_block_start_width_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_width_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_width_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_width_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_width_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-start-width
    /// given a writing mode.
    pub fn reset_border_block_start_width(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_block_start_width_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-block-start-width given a writing mode.
    pub fn clone_border_block_start_width(&self, wm: WritingMode)
        -> longhands::border_block_start_width::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_width()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_width()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_width()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_width()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-block-end-color given a writing mode.
    pub fn set_border_block_end_color(&mut self,
                                      v: longhands::border_block_end_color::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_color(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_color(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_color(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_color(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-end-color
    /// given a writing mode.
    pub fn copy_border_block_end_color_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_color_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_color_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_color_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_color_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-end-color
    /// given a writing mode.
    pub fn reset_border_block_end_color(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_block_end_color_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-block-end-color given a writing mode.
    pub fn clone_border_block_end_color(&self, wm: WritingMode)
        -> longhands::border_block_end_color::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_color()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_color()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_color()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_color()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-block-end-style given a writing mode.
    pub fn set_border_block_end_style(&mut self,
                                      v: longhands::border_block_end_style::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_style(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_style(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_style(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_style(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-end-style
    /// given a writing mode.
    pub fn copy_border_block_end_style_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_style_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_style_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_style_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_style_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-end-style
    /// given a writing mode.
    pub fn reset_border_block_end_style(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_block_end_style_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-block-end-style given a writing mode.
    pub fn clone_border_block_end_style(&self, wm: WritingMode)
        -> longhands::border_block_end_style::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_style()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_style()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_style()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_style()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-block-end-width given a writing mode.
    pub fn set_border_block_end_width(&mut self,
                                      v: longhands::border_block_end_width::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_width(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_width(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_width(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_width(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-end-width
    /// given a writing mode.
    pub fn copy_border_block_end_width_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_width_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_width_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_width_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_width_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-end-width
    /// given a writing mode.
    pub fn reset_border_block_end_width(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_block_end_width_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-block-end-width given a writing mode.
    pub fn clone_border_block_end_width(&self, wm: WritingMode)
        -> longhands::border_block_end_width::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_width()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_width()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_width()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_width()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-inline-start-color given a writing mode.
    pub fn set_border_inline_start_color(&mut self,
                                      v: longhands::border_inline_start_color::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_color(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_color(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_color(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_color(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-start-color
    /// given a writing mode.
    pub fn copy_border_inline_start_color_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_color_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_color_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_color_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_color_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-start-color
    /// given a writing mode.
    pub fn reset_border_inline_start_color(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_inline_start_color_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-inline-start-color given a writing mode.
    pub fn clone_border_inline_start_color(&self, wm: WritingMode)
        -> longhands::border_inline_start_color::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_color()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_color()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_color()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_color()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-inline-start-style given a writing mode.
    pub fn set_border_inline_start_style(&mut self,
                                      v: longhands::border_inline_start_style::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_style(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_style(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_style(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_style(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-start-style
    /// given a writing mode.
    pub fn copy_border_inline_start_style_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_style_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_style_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_style_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_style_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-start-style
    /// given a writing mode.
    pub fn reset_border_inline_start_style(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_inline_start_style_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-inline-start-style given a writing mode.
    pub fn clone_border_inline_start_style(&self, wm: WritingMode)
        -> longhands::border_inline_start_style::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_style()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_style()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_style()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_style()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-inline-start-width given a writing mode.
    pub fn set_border_inline_start_width(&mut self,
                                      v: longhands::border_inline_start_width::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_width(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_width(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_width(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_width(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-start-width
    /// given a writing mode.
    pub fn copy_border_inline_start_width_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_width_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_width_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_width_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_width_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-start-width
    /// given a writing mode.
    pub fn reset_border_inline_start_width(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_inline_start_width_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-inline-start-width given a writing mode.
    pub fn clone_border_inline_start_width(&self, wm: WritingMode)
        -> longhands::border_inline_start_width::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_width()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_width()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_width()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_width()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-inline-end-color given a writing mode.
    pub fn set_border_inline_end_color(&mut self,
                                      v: longhands::border_inline_end_color::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_color(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_color(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_color(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_color(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-end-color
    /// given a writing mode.
    pub fn copy_border_inline_end_color_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_color_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_color_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_color_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_color_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-end-color
    /// given a writing mode.
    pub fn reset_border_inline_end_color(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_inline_end_color_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-inline-end-color given a writing mode.
    pub fn clone_border_inline_end_color(&self, wm: WritingMode)
        -> longhands::border_inline_end_color::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_color()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_color()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_color()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_color()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-inline-end-style given a writing mode.
    pub fn set_border_inline_end_style(&mut self,
                                      v: longhands::border_inline_end_style::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_style(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_style(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_style(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_style(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-end-style
    /// given a writing mode.
    pub fn copy_border_inline_end_style_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_style_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_style_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_style_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_style_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-end-style
    /// given a writing mode.
    pub fn reset_border_inline_end_style(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_inline_end_style_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-inline-end-style given a writing mode.
    pub fn clone_border_inline_end_style(&self, wm: WritingMode)
        -> longhands::border_inline_end_style::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_style()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_style()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_style()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_style()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-inline-end-width given a writing mode.
    pub fn set_border_inline_end_width(&mut self,
                                      v: longhands::border_inline_end_width::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_width(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_width(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_width(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_width(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-end-width
    /// given a writing mode.
    pub fn copy_border_inline_end_width_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_width_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_width_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_width_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_width_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-end-width
    /// given a writing mode.
    pub fn reset_border_inline_end_width(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_inline_end_width_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-inline-end-width given a writing mode.
    pub fn clone_border_inline_end_width(&self, wm: WritingMode)
        -> longhands::border_inline_end_width::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_width()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_width()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_width()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_width()
        
                }
        }

    }

                        /// Set border-top-left-radius.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_top_left_radius(&mut self, v: longhands::border_top_left_radius::computed_value::T) {
                            self.border_top_left_radius = v;
                        }
                        /// Set border-top-left-radius from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_top_left_radius_from(&mut self, other: &Self) {
                            self.border_top_left_radius = other.border_top_left_radius.clone();
                        }
                    /// Reset border-top-left-radius from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_top_left_radius(&mut self, other: &Self) {
                        self.copy_border_top_left_radius_from(other)
                    }

                    /// Get the computed value for border-top-left-radius.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_top_left_radius(&self) -> longhands::border_top_left_radius::computed_value::T {
                        self.border_top_left_radius.clone()
                    }
                        /// Set border-top-right-radius.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_top_right_radius(&mut self, v: longhands::border_top_right_radius::computed_value::T) {
                            self.border_top_right_radius = v;
                        }
                        /// Set border-top-right-radius from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_top_right_radius_from(&mut self, other: &Self) {
                            self.border_top_right_radius = other.border_top_right_radius.clone();
                        }
                    /// Reset border-top-right-radius from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_top_right_radius(&mut self, other: &Self) {
                        self.copy_border_top_right_radius_from(other)
                    }

                    /// Get the computed value for border-top-right-radius.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_top_right_radius(&self) -> longhands::border_top_right_radius::computed_value::T {
                        self.border_top_right_radius.clone()
                    }
                        /// Set border-bottom-right-radius.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_bottom_right_radius(&mut self, v: longhands::border_bottom_right_radius::computed_value::T) {
                            self.border_bottom_right_radius = v;
                        }
                        /// Set border-bottom-right-radius from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_bottom_right_radius_from(&mut self, other: &Self) {
                            self.border_bottom_right_radius = other.border_bottom_right_radius.clone();
                        }
                    /// Reset border-bottom-right-radius from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_bottom_right_radius(&mut self, other: &Self) {
                        self.copy_border_bottom_right_radius_from(other)
                    }

                    /// Get the computed value for border-bottom-right-radius.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_bottom_right_radius(&self) -> longhands::border_bottom_right_radius::computed_value::T {
                        self.border_bottom_right_radius.clone()
                    }
                        /// Set border-bottom-left-radius.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_bottom_left_radius(&mut self, v: longhands::border_bottom_left_radius::computed_value::T) {
                            self.border_bottom_left_radius = v;
                        }
                        /// Set border-bottom-left-radius from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_bottom_left_radius_from(&mut self, other: &Self) {
                            self.border_bottom_left_radius = other.border_bottom_left_radius.clone();
                        }
                    /// Reset border-bottom-left-radius from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_bottom_left_radius(&mut self, other: &Self) {
                        self.copy_border_bottom_left_radius_from(other)
                    }

                    /// Get the computed value for border-bottom-left-radius.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_bottom_left_radius(&self) -> longhands::border_bottom_left_radius::computed_value::T {
                        self.border_bottom_left_radius.clone()
                    }
                        /// Set box-decoration-break.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_box_decoration_break(&mut self, v: longhands::box_decoration_break::computed_value::T) {
                            self.box_decoration_break = v;
                        }
                        /// Set box-decoration-break from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_box_decoration_break_from(&mut self, other: &Self) {
                            self.box_decoration_break = other.box_decoration_break.clone();
                        }
                    /// Reset box-decoration-break from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_box_decoration_break(&mut self, other: &Self) {
                        self.copy_box_decoration_break_from(other)
                    }

                    /// Get the computed value for box-decoration-break.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_box_decoration_break(&self) -> longhands::box_decoration_break::computed_value::T {
                        self.box_decoration_break.clone()
                    }
                        /// Set -moz-float-edge.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_float_edge(&mut self, v: longhands::_moz_float_edge::computed_value::T) {
                            self._moz_float_edge = v;
                        }
                        /// Set -moz-float-edge from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_float_edge_from(&mut self, other: &Self) {
                            self._moz_float_edge = other._moz_float_edge.clone();
                        }
                    /// Reset -moz-float-edge from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_float_edge(&mut self, other: &Self) {
                        self.copy__moz_float_edge_from(other)
                    }

                    /// Get the computed value for -moz-float-edge.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_float_edge(&self) -> longhands::_moz_float_edge::computed_value::T {
                        self._moz_float_edge.clone()
                    }
                        /// Set border-image-source.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_image_source(&mut self, v: longhands::border_image_source::computed_value::T) {
                            self.border_image_source = v;
                        }
                        /// Set border-image-source from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_image_source_from(&mut self, other: &Self) {
                            self.border_image_source = other.border_image_source.clone();
                        }
                    /// Reset border-image-source from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_image_source(&mut self, other: &Self) {
                        self.copy_border_image_source_from(other)
                    }

                    /// Get the computed value for border-image-source.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_image_source(&self) -> longhands::border_image_source::computed_value::T {
                        self.border_image_source.clone()
                    }
                        /// Set border-image-outset.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_image_outset(&mut self, v: longhands::border_image_outset::computed_value::T) {
                            self.border_image_outset = v;
                        }
                        /// Set border-image-outset from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_image_outset_from(&mut self, other: &Self) {
                            self.border_image_outset = other.border_image_outset.clone();
                        }
                    /// Reset border-image-outset from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_image_outset(&mut self, other: &Self) {
                        self.copy_border_image_outset_from(other)
                    }

                    /// Get the computed value for border-image-outset.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_image_outset(&self) -> longhands::border_image_outset::computed_value::T {
                        self.border_image_outset.clone()
                    }
                        /// Set border-image-repeat.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_image_repeat(&mut self, v: longhands::border_image_repeat::computed_value::T) {
                            self.border_image_repeat = v;
                        }
                        /// Set border-image-repeat from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_image_repeat_from(&mut self, other: &Self) {
                            self.border_image_repeat = other.border_image_repeat.clone();
                        }
                    /// Reset border-image-repeat from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_image_repeat(&mut self, other: &Self) {
                        self.copy_border_image_repeat_from(other)
                    }

                    /// Get the computed value for border-image-repeat.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_image_repeat(&self) -> longhands::border_image_repeat::computed_value::T {
                        self.border_image_repeat.clone()
                    }
                        /// Set border-image-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_image_width(&mut self, v: longhands::border_image_width::computed_value::T) {
                            self.border_image_width = v;
                        }
                        /// Set border-image-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_image_width_from(&mut self, other: &Self) {
                            self.border_image_width = other.border_image_width.clone();
                        }
                    /// Reset border-image-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_image_width(&mut self, other: &Self) {
                        self.copy_border_image_width_from(other)
                    }

                    /// Get the computed value for border-image-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_image_width(&self) -> longhands::border_image_width::computed_value::T {
                        self.border_image_width.clone()
                    }
                        /// Set border-image-slice.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_image_slice(&mut self, v: longhands::border_image_slice::computed_value::T) {
                            self.border_image_slice = v;
                        }
                        /// Set border-image-slice from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_image_slice_from(&mut self, other: &Self) {
                            self.border_image_slice = other.border_image_slice.clone();
                        }
                    /// Reset border-image-slice from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_image_slice(&mut self, other: &Self) {
                        self.copy_border_image_slice_from(other)
                    }

                    /// Get the computed value for border-image-slice.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_image_slice(&self) -> longhands::border_image_slice::computed_value::T {
                        self.border_image_slice.clone()
                    }
                    /// Whether the border-top property has nonzero width.
                    #[allow(non_snake_case)]
                    pub fn border_top_has_nonzero_width(&self) -> bool {
                        self.border_top_width != NonNegativeLength::zero()
                    }
                    /// Whether the border-right property has nonzero width.
                    #[allow(non_snake_case)]
                    pub fn border_right_has_nonzero_width(&self) -> bool {
                        self.border_right_width != NonNegativeLength::zero()
                    }
                    /// Whether the border-bottom property has nonzero width.
                    #[allow(non_snake_case)]
                    pub fn border_bottom_has_nonzero_width(&self) -> bool {
                        self.border_bottom_width != NonNegativeLength::zero()
                    }
                    /// Whether the border-left property has nonzero width.
                    #[allow(non_snake_case)]
                    pub fn border_left_has_nonzero_width(&self) -> bool {
                        self.border_left_width != NonNegativeLength::zero()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Box style struct.
        pub struct Box {
                /// The display computed value.
                pub display: longhands::display::computed_value::T,
                /// The -moz-top-layer computed value.
                pub _moz_top_layer: longhands::_moz_top_layer::computed_value::T,
                /// The position computed value.
                pub position: longhands::position::computed_value::T,
                /// The float computed value.
                pub float: longhands::float::computed_value::T,
                /// The clear computed value.
                pub clear: longhands::clear::computed_value::T,
                /// The vertical-align computed value.
                pub vertical_align: longhands::vertical_align::computed_value::T,
                /// The overflow-clip-box-inline computed value.
                pub overflow_clip_box_inline: longhands::overflow_clip_box_inline::computed_value::T,
                /// The overflow-clip-box-block computed value.
                pub overflow_clip_box_block: longhands::overflow_clip_box_block::computed_value::T,
                /// The overflow-x computed value.
                pub overflow_x: longhands::overflow_x::computed_value::T,
                /// The overflow-y computed value.
                pub overflow_y: longhands::overflow_y::computed_value::T,
                /// The transition-duration computed value.
                pub transition_duration: longhands::transition_duration::computed_value::T,
                /// The transition-timing-function computed value.
                pub transition_timing_function: longhands::transition_timing_function::computed_value::T,
                /// The transition-property computed value.
                pub transition_property: longhands::transition_property::computed_value::T,
                /// The transition-delay computed value.
                pub transition_delay: longhands::transition_delay::computed_value::T,
                /// The animation-name computed value.
                pub animation_name: longhands::animation_name::computed_value::T,
                /// The animation-duration computed value.
                pub animation_duration: longhands::animation_duration::computed_value::T,
                /// The animation-timing-function computed value.
                pub animation_timing_function: longhands::animation_timing_function::computed_value::T,
                /// The animation-iteration-count computed value.
                pub animation_iteration_count: longhands::animation_iteration_count::computed_value::T,
                /// The animation-direction computed value.
                pub animation_direction: longhands::animation_direction::computed_value::T,
                /// The animation-play-state computed value.
                pub animation_play_state: longhands::animation_play_state::computed_value::T,
                /// The animation-fill-mode computed value.
                pub animation_fill_mode: longhands::animation_fill_mode::computed_value::T,
                /// The animation-delay computed value.
                pub animation_delay: longhands::animation_delay::computed_value::T,
                /// The scroll-snap-points-x computed value.
                pub scroll_snap_points_x: longhands::scroll_snap_points_x::computed_value::T,
                /// The scroll-snap-points-y computed value.
                pub scroll_snap_points_y: longhands::scroll_snap_points_y::computed_value::T,
                /// The scroll-snap-destination computed value.
                pub scroll_snap_destination: longhands::scroll_snap_destination::computed_value::T,
                /// The scroll-snap-coordinate computed value.
                pub scroll_snap_coordinate: longhands::scroll_snap_coordinate::computed_value::T,
                /// The transform computed value.
                pub transform: longhands::transform::computed_value::T,
                /// The rotate computed value.
                pub rotate: longhands::rotate::computed_value::T,
                /// The scale computed value.
                pub scale: longhands::scale::computed_value::T,
                /// The translate computed value.
                pub translate: longhands::translate::computed_value::T,
                /// The scroll-behavior computed value.
                pub scroll_behavior: longhands::scroll_behavior::computed_value::T,
                /// The scroll-snap-type-x computed value.
                pub scroll_snap_type_x: longhands::scroll_snap_type_x::computed_value::T,
                /// The scroll-snap-type-y computed value.
                pub scroll_snap_type_y: longhands::scroll_snap_type_y::computed_value::T,
                /// The overscroll-behavior-x computed value.
                pub overscroll_behavior_x: longhands::overscroll_behavior_x::computed_value::T,
                /// The overscroll-behavior-y computed value.
                pub overscroll_behavior_y: longhands::overscroll_behavior_y::computed_value::T,
                /// The isolation computed value.
                pub isolation: longhands::isolation::computed_value::T,
                /// The page-break-after computed value.
                pub page_break_after: longhands::page_break_after::computed_value::T,
                /// The page-break-before computed value.
                pub page_break_before: longhands::page_break_before::computed_value::T,
                /// The page-break-inside computed value.
                pub page_break_inside: longhands::page_break_inside::computed_value::T,
                /// The resize computed value.
                pub resize: longhands::resize::computed_value::T,
                /// The perspective computed value.
                pub perspective: longhands::perspective::computed_value::T,
                /// The perspective-origin computed value.
                pub perspective_origin: longhands::perspective_origin::computed_value::T,
                /// The backface-visibility computed value.
                pub backface_visibility: longhands::backface_visibility::computed_value::T,
                /// The transform-box computed value.
                pub transform_box: longhands::transform_box::computed_value::T,
                /// The transform-style computed value.
                pub transform_style: longhands::transform_style::computed_value::T,
                /// The transform-origin computed value.
                pub transform_origin: longhands::transform_origin::computed_value::T,
                /// The contain computed value.
                pub contain: longhands::contain::computed_value::T,
                /// The -moz-appearance computed value.
                pub _moz_appearance: longhands::_moz_appearance::computed_value::T,
                /// The -moz-binding computed value.
                pub _moz_binding: longhands::_moz_binding::computed_value::T,
                /// The -moz-orient computed value.
                pub _moz_orient: longhands::_moz_orient::computed_value::T,
                /// The will-change computed value.
                pub will_change: longhands::will_change::computed_value::T,
                /// The shape-image-threshold computed value.
                pub shape_image_threshold: longhands::shape_image_threshold::computed_value::T,
                /// The shape-outside computed value.
                pub shape_outside: longhands::shape_outside::computed_value::T,
                /// The touch-action computed value.
                pub touch_action: longhands::touch_action::computed_value::T,
                /// The display value specified by the CSS stylesheets (without any style adjustments),
                /// which is needed for hypothetical layout boxes.
                pub original_display: longhands::display::computed_value::T,
        }

        impl Box {
                        /// Set `display`.
                        ///
                        /// We need to keep track of the original display for hypothetical boxes,
                        /// so we need to special-case this.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_display(&mut self, v: longhands::display::computed_value::T) {
                            self.display = v;
                            self.original_display = v;
                        }
                        /// Set `display` from other struct.
                        ///
                        /// Same as `set_display` above.
                        /// Thus, we need to special-case this.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_display_from(&mut self, other: &Self) {
                            self.display = other.display.clone();
                            self.original_display = other.display.clone();
                        }
                    /// Reset display from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_display(&mut self, other: &Self) {
                        self.copy_display_from(other)
                    }

                    /// Get the computed value for display.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_display(&self) -> longhands::display::computed_value::T {
                        self.display.clone()
                    }
                        /// Set -moz-top-layer.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_top_layer(&mut self, v: longhands::_moz_top_layer::computed_value::T) {
                            self._moz_top_layer = v;
                        }
                        /// Set -moz-top-layer from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_top_layer_from(&mut self, other: &Self) {
                            self._moz_top_layer = other._moz_top_layer.clone();
                        }
                    /// Reset -moz-top-layer from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_top_layer(&mut self, other: &Self) {
                        self.copy__moz_top_layer_from(other)
                    }

                    /// Get the computed value for -moz-top-layer.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_top_layer(&self) -> longhands::_moz_top_layer::computed_value::T {
                        self._moz_top_layer.clone()
                    }
                        /// Set position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_position(&mut self, v: longhands::position::computed_value::T) {
                            self.position = v;
                        }
                        /// Set position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_position_from(&mut self, other: &Self) {
                            self.position = other.position.clone();
                        }
                    /// Reset position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_position(&mut self, other: &Self) {
                        self.copy_position_from(other)
                    }

                    /// Get the computed value for position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_position(&self) -> longhands::position::computed_value::T {
                        self.position.clone()
                    }
                        /// Set float.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_float(&mut self, v: longhands::float::computed_value::T) {
                            self.float = v;
                        }
                        /// Set float from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_float_from(&mut self, other: &Self) {
                            self.float = other.float.clone();
                        }
                    /// Reset float from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_float(&mut self, other: &Self) {
                        self.copy_float_from(other)
                    }

                    /// Get the computed value for float.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_float(&self) -> longhands::float::computed_value::T {
                        self.float.clone()
                    }
                        /// Set clear.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_clear(&mut self, v: longhands::clear::computed_value::T) {
                            self.clear = v;
                        }
                        /// Set clear from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_clear_from(&mut self, other: &Self) {
                            self.clear = other.clear.clone();
                        }
                    /// Reset clear from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_clear(&mut self, other: &Self) {
                        self.copy_clear_from(other)
                    }

                    /// Get the computed value for clear.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_clear(&self) -> longhands::clear::computed_value::T {
                        self.clear.clone()
                    }
                        /// Set vertical-align.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_vertical_align(&mut self, v: longhands::vertical_align::computed_value::T) {
                            self.vertical_align = v;
                        }
                        /// Set vertical-align from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_vertical_align_from(&mut self, other: &Self) {
                            self.vertical_align = other.vertical_align.clone();
                        }
                    /// Reset vertical-align from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_vertical_align(&mut self, other: &Self) {
                        self.copy_vertical_align_from(other)
                    }

                    /// Get the computed value for vertical-align.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_vertical_align(&self) -> longhands::vertical_align::computed_value::T {
                        self.vertical_align.clone()
                    }
                        /// Set overflow-clip-box-inline.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_clip_box_inline(&mut self, v: longhands::overflow_clip_box_inline::computed_value::T) {
                            self.overflow_clip_box_inline = v;
                        }
                        /// Set overflow-clip-box-inline from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_clip_box_inline_from(&mut self, other: &Self) {
                            self.overflow_clip_box_inline = other.overflow_clip_box_inline.clone();
                        }
                    /// Reset overflow-clip-box-inline from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_clip_box_inline(&mut self, other: &Self) {
                        self.copy_overflow_clip_box_inline_from(other)
                    }

                    /// Get the computed value for overflow-clip-box-inline.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_clip_box_inline(&self) -> longhands::overflow_clip_box_inline::computed_value::T {
                        self.overflow_clip_box_inline.clone()
                    }
                        /// Set overflow-clip-box-block.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_clip_box_block(&mut self, v: longhands::overflow_clip_box_block::computed_value::T) {
                            self.overflow_clip_box_block = v;
                        }
                        /// Set overflow-clip-box-block from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_clip_box_block_from(&mut self, other: &Self) {
                            self.overflow_clip_box_block = other.overflow_clip_box_block.clone();
                        }
                    /// Reset overflow-clip-box-block from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_clip_box_block(&mut self, other: &Self) {
                        self.copy_overflow_clip_box_block_from(other)
                    }

                    /// Get the computed value for overflow-clip-box-block.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_clip_box_block(&self) -> longhands::overflow_clip_box_block::computed_value::T {
                        self.overflow_clip_box_block.clone()
                    }
                        /// Set overflow-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_x(&mut self, v: longhands::overflow_x::computed_value::T) {
                            self.overflow_x = v;
                        }
                        /// Set overflow-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_x_from(&mut self, other: &Self) {
                            self.overflow_x = other.overflow_x.clone();
                        }
                    /// Reset overflow-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_x(&mut self, other: &Self) {
                        self.copy_overflow_x_from(other)
                    }

                    /// Get the computed value for overflow-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_x(&self) -> longhands::overflow_x::computed_value::T {
                        self.overflow_x.clone()
                    }
                        /// Set overflow-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_y(&mut self, v: longhands::overflow_y::computed_value::T) {
                            self.overflow_y = v;
                        }
                        /// Set overflow-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_y_from(&mut self, other: &Self) {
                            self.overflow_y = other.overflow_y.clone();
                        }
                    /// Reset overflow-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_y(&mut self, other: &Self) {
                        self.copy_overflow_y_from(other)
                    }

                    /// Get the computed value for overflow-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_y(&self) -> longhands::overflow_y::computed_value::T {
                        self.overflow_y.clone()
                    }
                        /// Set transition-duration.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transition_duration<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::transition_duration
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.transition_duration = longhands::transition_duration::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set transition-duration from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transition_duration_from(&mut self, other: &Self) {
                            self.transition_duration = other.transition_duration.clone();
                        }
                    /// Reset transition-duration from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transition_duration(&mut self, other: &Self) {
                        self.copy_transition_duration_from(other)
                    }

                    /// Get the computed value for transition-duration.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transition_duration(&self) -> longhands::transition_duration::computed_value::T {
                        self.transition_duration.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn transition_duration_count(&self) -> usize {
                        self.transition_duration.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn transition_duration_at(&self, index: usize)
                        -> longhands::transition_duration::computed_value::SingleComputedValue {
                        self.transition_duration.0[index].clone()
                    }
                        /// Set transition-timing-function.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transition_timing_function<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::transition_timing_function
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.transition_timing_function = longhands::transition_timing_function::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set transition-timing-function from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transition_timing_function_from(&mut self, other: &Self) {
                            self.transition_timing_function = other.transition_timing_function.clone();
                        }
                    /// Reset transition-timing-function from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transition_timing_function(&mut self, other: &Self) {
                        self.copy_transition_timing_function_from(other)
                    }

                    /// Get the computed value for transition-timing-function.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transition_timing_function(&self) -> longhands::transition_timing_function::computed_value::T {
                        self.transition_timing_function.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn transition_timing_function_count(&self) -> usize {
                        self.transition_timing_function.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn transition_timing_function_at(&self, index: usize)
                        -> longhands::transition_timing_function::computed_value::SingleComputedValue {
                        self.transition_timing_function.0[index].clone()
                    }
                        /// Set transition-property.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transition_property<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::transition_property
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.transition_property = longhands::transition_property::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set transition-property from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transition_property_from(&mut self, other: &Self) {
                            self.transition_property = other.transition_property.clone();
                        }
                    /// Reset transition-property from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transition_property(&mut self, other: &Self) {
                        self.copy_transition_property_from(other)
                    }

                    /// Get the computed value for transition-property.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transition_property(&self) -> longhands::transition_property::computed_value::T {
                        self.transition_property.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn transition_property_count(&self) -> usize {
                        self.transition_property.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn transition_property_at(&self, index: usize)
                        -> longhands::transition_property::computed_value::SingleComputedValue {
                        self.transition_property.0[index].clone()
                    }
                        /// Set transition-delay.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transition_delay<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::transition_delay
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.transition_delay = longhands::transition_delay::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set transition-delay from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transition_delay_from(&mut self, other: &Self) {
                            self.transition_delay = other.transition_delay.clone();
                        }
                    /// Reset transition-delay from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transition_delay(&mut self, other: &Self) {
                        self.copy_transition_delay_from(other)
                    }

                    /// Get the computed value for transition-delay.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transition_delay(&self) -> longhands::transition_delay::computed_value::T {
                        self.transition_delay.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn transition_delay_count(&self) -> usize {
                        self.transition_delay.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn transition_delay_at(&self, index: usize)
                        -> longhands::transition_delay::computed_value::SingleComputedValue {
                        self.transition_delay.0[index].clone()
                    }
                        /// Set animation-name.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_name<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_name
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_name = longhands::animation_name::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-name from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_name_from(&mut self, other: &Self) {
                            self.animation_name = other.animation_name.clone();
                        }
                    /// Reset animation-name from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_name(&mut self, other: &Self) {
                        self.copy_animation_name_from(other)
                    }

                    /// Get the computed value for animation-name.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_name(&self) -> longhands::animation_name::computed_value::T {
                        self.animation_name.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_name_count(&self) -> usize {
                        self.animation_name.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_name_at(&self, index: usize)
                        -> longhands::animation_name::computed_value::SingleComputedValue {
                        self.animation_name.0[index].clone()
                    }
                        /// Set animation-duration.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_duration<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_duration
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_duration = longhands::animation_duration::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-duration from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_duration_from(&mut self, other: &Self) {
                            self.animation_duration = other.animation_duration.clone();
                        }
                    /// Reset animation-duration from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_duration(&mut self, other: &Self) {
                        self.copy_animation_duration_from(other)
                    }

                    /// Get the computed value for animation-duration.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_duration(&self) -> longhands::animation_duration::computed_value::T {
                        self.animation_duration.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_duration_count(&self) -> usize {
                        self.animation_duration.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_duration_at(&self, index: usize)
                        -> longhands::animation_duration::computed_value::SingleComputedValue {
                        self.animation_duration.0[index].clone()
                    }
                        /// Set animation-timing-function.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_timing_function<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_timing_function
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_timing_function = longhands::animation_timing_function::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-timing-function from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_timing_function_from(&mut self, other: &Self) {
                            self.animation_timing_function = other.animation_timing_function.clone();
                        }
                    /// Reset animation-timing-function from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_timing_function(&mut self, other: &Self) {
                        self.copy_animation_timing_function_from(other)
                    }

                    /// Get the computed value for animation-timing-function.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_timing_function(&self) -> longhands::animation_timing_function::computed_value::T {
                        self.animation_timing_function.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_timing_function_count(&self) -> usize {
                        self.animation_timing_function.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_timing_function_at(&self, index: usize)
                        -> longhands::animation_timing_function::computed_value::SingleComputedValue {
                        self.animation_timing_function.0[index].clone()
                    }
                        /// Set animation-iteration-count.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_iteration_count<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_iteration_count
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_iteration_count = longhands::animation_iteration_count::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-iteration-count from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_iteration_count_from(&mut self, other: &Self) {
                            self.animation_iteration_count = other.animation_iteration_count.clone();
                        }
                    /// Reset animation-iteration-count from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_iteration_count(&mut self, other: &Self) {
                        self.copy_animation_iteration_count_from(other)
                    }

                    /// Get the computed value for animation-iteration-count.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_iteration_count(&self) -> longhands::animation_iteration_count::computed_value::T {
                        self.animation_iteration_count.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_iteration_count_count(&self) -> usize {
                        self.animation_iteration_count.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_iteration_count_at(&self, index: usize)
                        -> longhands::animation_iteration_count::computed_value::SingleComputedValue {
                        self.animation_iteration_count.0[index].clone()
                    }
                        /// Set animation-direction.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_direction<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_direction
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_direction = longhands::animation_direction::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-direction from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_direction_from(&mut self, other: &Self) {
                            self.animation_direction = other.animation_direction.clone();
                        }
                    /// Reset animation-direction from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_direction(&mut self, other: &Self) {
                        self.copy_animation_direction_from(other)
                    }

                    /// Get the computed value for animation-direction.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_direction(&self) -> longhands::animation_direction::computed_value::T {
                        self.animation_direction.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_direction_count(&self) -> usize {
                        self.animation_direction.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_direction_at(&self, index: usize)
                        -> longhands::animation_direction::computed_value::SingleComputedValue {
                        self.animation_direction.0[index].clone()
                    }
                        /// Set animation-play-state.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_play_state<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_play_state
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_play_state = longhands::animation_play_state::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-play-state from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_play_state_from(&mut self, other: &Self) {
                            self.animation_play_state = other.animation_play_state.clone();
                        }
                    /// Reset animation-play-state from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_play_state(&mut self, other: &Self) {
                        self.copy_animation_play_state_from(other)
                    }

                    /// Get the computed value for animation-play-state.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_play_state(&self) -> longhands::animation_play_state::computed_value::T {
                        self.animation_play_state.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_play_state_count(&self) -> usize {
                        self.animation_play_state.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_play_state_at(&self, index: usize)
                        -> longhands::animation_play_state::computed_value::SingleComputedValue {
                        self.animation_play_state.0[index].clone()
                    }
                        /// Set animation-fill-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_fill_mode<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_fill_mode
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_fill_mode = longhands::animation_fill_mode::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-fill-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_fill_mode_from(&mut self, other: &Self) {
                            self.animation_fill_mode = other.animation_fill_mode.clone();
                        }
                    /// Reset animation-fill-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_fill_mode(&mut self, other: &Self) {
                        self.copy_animation_fill_mode_from(other)
                    }

                    /// Get the computed value for animation-fill-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_fill_mode(&self) -> longhands::animation_fill_mode::computed_value::T {
                        self.animation_fill_mode.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_fill_mode_count(&self) -> usize {
                        self.animation_fill_mode.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_fill_mode_at(&self, index: usize)
                        -> longhands::animation_fill_mode::computed_value::SingleComputedValue {
                        self.animation_fill_mode.0[index].clone()
                    }
                        /// Set animation-delay.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_delay<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_delay
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_delay = longhands::animation_delay::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-delay from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_delay_from(&mut self, other: &Self) {
                            self.animation_delay = other.animation_delay.clone();
                        }
                    /// Reset animation-delay from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_delay(&mut self, other: &Self) {
                        self.copy_animation_delay_from(other)
                    }

                    /// Get the computed value for animation-delay.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_delay(&self) -> longhands::animation_delay::computed_value::T {
                        self.animation_delay.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_delay_count(&self) -> usize {
                        self.animation_delay.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_delay_at(&self, index: usize)
                        -> longhands::animation_delay::computed_value::SingleComputedValue {
                        self.animation_delay.0[index].clone()
                    }
                        /// Set scroll-snap-points-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_snap_points_x(&mut self, v: longhands::scroll_snap_points_x::computed_value::T) {
                            self.scroll_snap_points_x = v;
                        }
                        /// Set scroll-snap-points-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_snap_points_x_from(&mut self, other: &Self) {
                            self.scroll_snap_points_x = other.scroll_snap_points_x.clone();
                        }
                    /// Reset scroll-snap-points-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_snap_points_x(&mut self, other: &Self) {
                        self.copy_scroll_snap_points_x_from(other)
                    }

                    /// Get the computed value for scroll-snap-points-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_snap_points_x(&self) -> longhands::scroll_snap_points_x::computed_value::T {
                        self.scroll_snap_points_x.clone()
                    }
                        /// Set scroll-snap-points-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_snap_points_y(&mut self, v: longhands::scroll_snap_points_y::computed_value::T) {
                            self.scroll_snap_points_y = v;
                        }
                        /// Set scroll-snap-points-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_snap_points_y_from(&mut self, other: &Self) {
                            self.scroll_snap_points_y = other.scroll_snap_points_y.clone();
                        }
                    /// Reset scroll-snap-points-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_snap_points_y(&mut self, other: &Self) {
                        self.copy_scroll_snap_points_y_from(other)
                    }

                    /// Get the computed value for scroll-snap-points-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_snap_points_y(&self) -> longhands::scroll_snap_points_y::computed_value::T {
                        self.scroll_snap_points_y.clone()
                    }
                        /// Set scroll-snap-destination.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_snap_destination(&mut self, v: longhands::scroll_snap_destination::computed_value::T) {
                            self.scroll_snap_destination = v;
                        }
                        /// Set scroll-snap-destination from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_snap_destination_from(&mut self, other: &Self) {
                            self.scroll_snap_destination = other.scroll_snap_destination.clone();
                        }
                    /// Reset scroll-snap-destination from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_snap_destination(&mut self, other: &Self) {
                        self.copy_scroll_snap_destination_from(other)
                    }

                    /// Get the computed value for scroll-snap-destination.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_snap_destination(&self) -> longhands::scroll_snap_destination::computed_value::T {
                        self.scroll_snap_destination.clone()
                    }
                        /// Set scroll-snap-coordinate.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_snap_coordinate<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::scroll_snap_coordinate
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.scroll_snap_coordinate = longhands::scroll_snap_coordinate::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set scroll-snap-coordinate from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_snap_coordinate_from(&mut self, other: &Self) {
                            self.scroll_snap_coordinate = other.scroll_snap_coordinate.clone();
                        }
                    /// Reset scroll-snap-coordinate from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_snap_coordinate(&mut self, other: &Self) {
                        self.copy_scroll_snap_coordinate_from(other)
                    }

                    /// Get the computed value for scroll-snap-coordinate.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_snap_coordinate(&self) -> longhands::scroll_snap_coordinate::computed_value::T {
                        self.scroll_snap_coordinate.clone()
                    }
                        /// Set transform.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transform(&mut self, v: longhands::transform::computed_value::T) {
                            self.transform = v;
                        }
                        /// Set transform from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transform_from(&mut self, other: &Self) {
                            self.transform = other.transform.clone();
                        }
                    /// Reset transform from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transform(&mut self, other: &Self) {
                        self.copy_transform_from(other)
                    }

                    /// Get the computed value for transform.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transform(&self) -> longhands::transform::computed_value::T {
                        self.transform.clone()
                    }
                        /// Set rotate.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_rotate(&mut self, v: longhands::rotate::computed_value::T) {
                            self.rotate = v;
                        }
                        /// Set rotate from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_rotate_from(&mut self, other: &Self) {
                            self.rotate = other.rotate.clone();
                        }
                    /// Reset rotate from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_rotate(&mut self, other: &Self) {
                        self.copy_rotate_from(other)
                    }

                    /// Get the computed value for rotate.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_rotate(&self) -> longhands::rotate::computed_value::T {
                        self.rotate.clone()
                    }
                        /// Set scale.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scale(&mut self, v: longhands::scale::computed_value::T) {
                            self.scale = v;
                        }
                        /// Set scale from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scale_from(&mut self, other: &Self) {
                            self.scale = other.scale.clone();
                        }
                    /// Reset scale from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scale(&mut self, other: &Self) {
                        self.copy_scale_from(other)
                    }

                    /// Get the computed value for scale.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scale(&self) -> longhands::scale::computed_value::T {
                        self.scale.clone()
                    }
                        /// Set translate.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_translate(&mut self, v: longhands::translate::computed_value::T) {
                            self.translate = v;
                        }
                        /// Set translate from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_translate_from(&mut self, other: &Self) {
                            self.translate = other.translate.clone();
                        }
                    /// Reset translate from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_translate(&mut self, other: &Self) {
                        self.copy_translate_from(other)
                    }

                    /// Get the computed value for translate.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_translate(&self) -> longhands::translate::computed_value::T {
                        self.translate.clone()
                    }
                        /// Set scroll-behavior.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_behavior(&mut self, v: longhands::scroll_behavior::computed_value::T) {
                            self.scroll_behavior = v;
                        }
                        /// Set scroll-behavior from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_behavior_from(&mut self, other: &Self) {
                            self.scroll_behavior = other.scroll_behavior.clone();
                        }
                    /// Reset scroll-behavior from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_behavior(&mut self, other: &Self) {
                        self.copy_scroll_behavior_from(other)
                    }

                    /// Get the computed value for scroll-behavior.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_behavior(&self) -> longhands::scroll_behavior::computed_value::T {
                        self.scroll_behavior.clone()
                    }
                        /// Set scroll-snap-type-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_snap_type_x(&mut self, v: longhands::scroll_snap_type_x::computed_value::T) {
                            self.scroll_snap_type_x = v;
                        }
                        /// Set scroll-snap-type-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_snap_type_x_from(&mut self, other: &Self) {
                            self.scroll_snap_type_x = other.scroll_snap_type_x.clone();
                        }
                    /// Reset scroll-snap-type-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_snap_type_x(&mut self, other: &Self) {
                        self.copy_scroll_snap_type_x_from(other)
                    }

                    /// Get the computed value for scroll-snap-type-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_snap_type_x(&self) -> longhands::scroll_snap_type_x::computed_value::T {
                        self.scroll_snap_type_x.clone()
                    }
                        /// Set scroll-snap-type-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_snap_type_y(&mut self, v: longhands::scroll_snap_type_y::computed_value::T) {
                            self.scroll_snap_type_y = v;
                        }
                        /// Set scroll-snap-type-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_snap_type_y_from(&mut self, other: &Self) {
                            self.scroll_snap_type_y = other.scroll_snap_type_y.clone();
                        }
                    /// Reset scroll-snap-type-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_snap_type_y(&mut self, other: &Self) {
                        self.copy_scroll_snap_type_y_from(other)
                    }

                    /// Get the computed value for scroll-snap-type-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_snap_type_y(&self) -> longhands::scroll_snap_type_y::computed_value::T {
                        self.scroll_snap_type_y.clone()
                    }
                        /// Set overscroll-behavior-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overscroll_behavior_x(&mut self, v: longhands::overscroll_behavior_x::computed_value::T) {
                            self.overscroll_behavior_x = v;
                        }
                        /// Set overscroll-behavior-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overscroll_behavior_x_from(&mut self, other: &Self) {
                            self.overscroll_behavior_x = other.overscroll_behavior_x.clone();
                        }
                    /// Reset overscroll-behavior-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overscroll_behavior_x(&mut self, other: &Self) {
                        self.copy_overscroll_behavior_x_from(other)
                    }

                    /// Get the computed value for overscroll-behavior-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overscroll_behavior_x(&self) -> longhands::overscroll_behavior_x::computed_value::T {
                        self.overscroll_behavior_x.clone()
                    }
                        /// Set overscroll-behavior-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overscroll_behavior_y(&mut self, v: longhands::overscroll_behavior_y::computed_value::T) {
                            self.overscroll_behavior_y = v;
                        }
                        /// Set overscroll-behavior-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overscroll_behavior_y_from(&mut self, other: &Self) {
                            self.overscroll_behavior_y = other.overscroll_behavior_y.clone();
                        }
                    /// Reset overscroll-behavior-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overscroll_behavior_y(&mut self, other: &Self) {
                        self.copy_overscroll_behavior_y_from(other)
                    }

                    /// Get the computed value for overscroll-behavior-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overscroll_behavior_y(&self) -> longhands::overscroll_behavior_y::computed_value::T {
                        self.overscroll_behavior_y.clone()
                    }
                        /// Set isolation.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_isolation(&mut self, v: longhands::isolation::computed_value::T) {
                            self.isolation = v;
                        }
                        /// Set isolation from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_isolation_from(&mut self, other: &Self) {
                            self.isolation = other.isolation.clone();
                        }
                    /// Reset isolation from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_isolation(&mut self, other: &Self) {
                        self.copy_isolation_from(other)
                    }

                    /// Get the computed value for isolation.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_isolation(&self) -> longhands::isolation::computed_value::T {
                        self.isolation.clone()
                    }
                        /// Set page-break-after.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_page_break_after(&mut self, v: longhands::page_break_after::computed_value::T) {
                            self.page_break_after = v;
                        }
                        /// Set page-break-after from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_page_break_after_from(&mut self, other: &Self) {
                            self.page_break_after = other.page_break_after.clone();
                        }
                    /// Reset page-break-after from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_page_break_after(&mut self, other: &Self) {
                        self.copy_page_break_after_from(other)
                    }

                    /// Get the computed value for page-break-after.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_page_break_after(&self) -> longhands::page_break_after::computed_value::T {
                        self.page_break_after.clone()
                    }
                        /// Set page-break-before.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_page_break_before(&mut self, v: longhands::page_break_before::computed_value::T) {
                            self.page_break_before = v;
                        }
                        /// Set page-break-before from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_page_break_before_from(&mut self, other: &Self) {
                            self.page_break_before = other.page_break_before.clone();
                        }
                    /// Reset page-break-before from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_page_break_before(&mut self, other: &Self) {
                        self.copy_page_break_before_from(other)
                    }

                    /// Get the computed value for page-break-before.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_page_break_before(&self) -> longhands::page_break_before::computed_value::T {
                        self.page_break_before.clone()
                    }
                        /// Set page-break-inside.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_page_break_inside(&mut self, v: longhands::page_break_inside::computed_value::T) {
                            self.page_break_inside = v;
                        }
                        /// Set page-break-inside from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_page_break_inside_from(&mut self, other: &Self) {
                            self.page_break_inside = other.page_break_inside.clone();
                        }
                    /// Reset page-break-inside from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_page_break_inside(&mut self, other: &Self) {
                        self.copy_page_break_inside_from(other)
                    }

                    /// Get the computed value for page-break-inside.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_page_break_inside(&self) -> longhands::page_break_inside::computed_value::T {
                        self.page_break_inside.clone()
                    }
                        /// Set resize.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_resize(&mut self, v: longhands::resize::computed_value::T) {
                            self.resize = v;
                        }
                        /// Set resize from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_resize_from(&mut self, other: &Self) {
                            self.resize = other.resize.clone();
                        }
                    /// Reset resize from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_resize(&mut self, other: &Self) {
                        self.copy_resize_from(other)
                    }

                    /// Get the computed value for resize.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_resize(&self) -> longhands::resize::computed_value::T {
                        self.resize.clone()
                    }
                        /// Set perspective.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_perspective(&mut self, v: longhands::perspective::computed_value::T) {
                            self.perspective = v;
                        }
                        /// Set perspective from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_perspective_from(&mut self, other: &Self) {
                            self.perspective = other.perspective.clone();
                        }
                    /// Reset perspective from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_perspective(&mut self, other: &Self) {
                        self.copy_perspective_from(other)
                    }

                    /// Get the computed value for perspective.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_perspective(&self) -> longhands::perspective::computed_value::T {
                        self.perspective.clone()
                    }
                        /// Set perspective-origin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_perspective_origin(&mut self, v: longhands::perspective_origin::computed_value::T) {
                            self.perspective_origin = v;
                        }
                        /// Set perspective-origin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_perspective_origin_from(&mut self, other: &Self) {
                            self.perspective_origin = other.perspective_origin.clone();
                        }
                    /// Reset perspective-origin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_perspective_origin(&mut self, other: &Self) {
                        self.copy_perspective_origin_from(other)
                    }

                    /// Get the computed value for perspective-origin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_perspective_origin(&self) -> longhands::perspective_origin::computed_value::T {
                        self.perspective_origin.clone()
                    }
                        /// Set backface-visibility.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_backface_visibility(&mut self, v: longhands::backface_visibility::computed_value::T) {
                            self.backface_visibility = v;
                        }
                        /// Set backface-visibility from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_backface_visibility_from(&mut self, other: &Self) {
                            self.backface_visibility = other.backface_visibility.clone();
                        }
                    /// Reset backface-visibility from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_backface_visibility(&mut self, other: &Self) {
                        self.copy_backface_visibility_from(other)
                    }

                    /// Get the computed value for backface-visibility.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_backface_visibility(&self) -> longhands::backface_visibility::computed_value::T {
                        self.backface_visibility.clone()
                    }
                        /// Set transform-box.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transform_box(&mut self, v: longhands::transform_box::computed_value::T) {
                            self.transform_box = v;
                        }
                        /// Set transform-box from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transform_box_from(&mut self, other: &Self) {
                            self.transform_box = other.transform_box.clone();
                        }
                    /// Reset transform-box from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transform_box(&mut self, other: &Self) {
                        self.copy_transform_box_from(other)
                    }

                    /// Get the computed value for transform-box.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transform_box(&self) -> longhands::transform_box::computed_value::T {
                        self.transform_box.clone()
                    }
                        /// Set transform-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transform_style(&mut self, v: longhands::transform_style::computed_value::T) {
                            self.transform_style = v;
                        }
                        /// Set transform-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transform_style_from(&mut self, other: &Self) {
                            self.transform_style = other.transform_style.clone();
                        }
                    /// Reset transform-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transform_style(&mut self, other: &Self) {
                        self.copy_transform_style_from(other)
                    }

                    /// Get the computed value for transform-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transform_style(&self) -> longhands::transform_style::computed_value::T {
                        self.transform_style.clone()
                    }
                        /// Set transform-origin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transform_origin(&mut self, v: longhands::transform_origin::computed_value::T) {
                            self.transform_origin = v;
                        }
                        /// Set transform-origin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transform_origin_from(&mut self, other: &Self) {
                            self.transform_origin = other.transform_origin.clone();
                        }
                    /// Reset transform-origin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transform_origin(&mut self, other: &Self) {
                        self.copy_transform_origin_from(other)
                    }

                    /// Get the computed value for transform-origin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transform_origin(&self) -> longhands::transform_origin::computed_value::T {
                        self.transform_origin.clone()
                    }
                        /// Set contain.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_contain(&mut self, v: longhands::contain::computed_value::T) {
                            self.contain = v;
                        }
                        /// Set contain from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_contain_from(&mut self, other: &Self) {
                            self.contain = other.contain.clone();
                        }
                    /// Reset contain from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_contain(&mut self, other: &Self) {
                        self.copy_contain_from(other)
                    }

                    /// Get the computed value for contain.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_contain(&self) -> longhands::contain::computed_value::T {
                        self.contain.clone()
                    }
                        /// Set -moz-appearance.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_appearance(&mut self, v: longhands::_moz_appearance::computed_value::T) {
                            self._moz_appearance = v;
                        }
                        /// Set -moz-appearance from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_appearance_from(&mut self, other: &Self) {
                            self._moz_appearance = other._moz_appearance.clone();
                        }
                    /// Reset -moz-appearance from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_appearance(&mut self, other: &Self) {
                        self.copy__moz_appearance_from(other)
                    }

                    /// Get the computed value for -moz-appearance.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_appearance(&self) -> longhands::_moz_appearance::computed_value::T {
                        self._moz_appearance.clone()
                    }
                        /// Set -moz-binding.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_binding(&mut self, v: longhands::_moz_binding::computed_value::T) {
                            self._moz_binding = v;
                        }
                        /// Set -moz-binding from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_binding_from(&mut self, other: &Self) {
                            self._moz_binding = other._moz_binding.clone();
                        }
                    /// Reset -moz-binding from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_binding(&mut self, other: &Self) {
                        self.copy__moz_binding_from(other)
                    }

                    /// Get the computed value for -moz-binding.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_binding(&self) -> longhands::_moz_binding::computed_value::T {
                        self._moz_binding.clone()
                    }
                        /// Set -moz-orient.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_orient(&mut self, v: longhands::_moz_orient::computed_value::T) {
                            self._moz_orient = v;
                        }
                        /// Set -moz-orient from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_orient_from(&mut self, other: &Self) {
                            self._moz_orient = other._moz_orient.clone();
                        }
                    /// Reset -moz-orient from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_orient(&mut self, other: &Self) {
                        self.copy__moz_orient_from(other)
                    }

                    /// Get the computed value for -moz-orient.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_orient(&self) -> longhands::_moz_orient::computed_value::T {
                        self._moz_orient.clone()
                    }
                        /// Set will-change.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_will_change(&mut self, v: longhands::will_change::computed_value::T) {
                            self.will_change = v;
                        }
                        /// Set will-change from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_will_change_from(&mut self, other: &Self) {
                            self.will_change = other.will_change.clone();
                        }
                    /// Reset will-change from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_will_change(&mut self, other: &Self) {
                        self.copy_will_change_from(other)
                    }

                    /// Get the computed value for will-change.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_will_change(&self) -> longhands::will_change::computed_value::T {
                        self.will_change.clone()
                    }
                        /// Set shape-image-threshold.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_shape_image_threshold(&mut self, v: longhands::shape_image_threshold::computed_value::T) {
                            self.shape_image_threshold = v;
                        }
                        /// Set shape-image-threshold from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_shape_image_threshold_from(&mut self, other: &Self) {
                            self.shape_image_threshold = other.shape_image_threshold.clone();
                        }
                    /// Reset shape-image-threshold from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_shape_image_threshold(&mut self, other: &Self) {
                        self.copy_shape_image_threshold_from(other)
                    }

                    /// Get the computed value for shape-image-threshold.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_shape_image_threshold(&self) -> longhands::shape_image_threshold::computed_value::T {
                        self.shape_image_threshold.clone()
                    }
                        /// Set shape-outside.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_shape_outside(&mut self, v: longhands::shape_outside::computed_value::T) {
                            self.shape_outside = v;
                        }
                        /// Set shape-outside from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_shape_outside_from(&mut self, other: &Self) {
                            self.shape_outside = other.shape_outside.clone();
                        }
                    /// Reset shape-outside from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_shape_outside(&mut self, other: &Self) {
                        self.copy_shape_outside_from(other)
                    }

                    /// Get the computed value for shape-outside.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_shape_outside(&self) -> longhands::shape_outside::computed_value::T {
                        self.shape_outside.clone()
                    }
                        /// Set touch-action.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_touch_action(&mut self, v: longhands::touch_action::computed_value::T) {
                            self.touch_action = v;
                        }
                        /// Set touch-action from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_touch_action_from(&mut self, other: &Self) {
                            self.touch_action = other.touch_action.clone();
                        }
                    /// Reset touch-action from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_touch_action(&mut self, other: &Self) {
                        self.copy_touch_action_from(other)
                    }

                    /// Get the computed value for touch-action.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_touch_action(&self) -> longhands::touch_action::computed_value::T {
                        self.touch_action.clone()
                    }
                /// Sets the display property, but without touching original_display,
                /// except when the adjustment comes from root or item display fixups.
                pub fn set_adjusted_display(
                    &mut self,
                    dpy: longhands::display::computed_value::T,
                    is_item_or_root: bool
                ) {
                    self.display = dpy;
                    if is_item_or_root {
                        self.original_display = dpy;
                    }
                }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Color style struct.
        pub struct Color {
                /// The color computed value.
                pub color: longhands::color::computed_value::T,
        }

        impl Color {
                        /// Set color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_color(&mut self, v: longhands::color::computed_value::T) {
                            self.color = v;
                        }
                        /// Set color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_color_from(&mut self, other: &Self) {
                            self.color = other.color.clone();
                        }
                    /// Reset color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_color(&mut self, other: &Self) {
                        self.copy_color_from(other)
                    }

                    /// Get the computed value for color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_color(&self) -> longhands::color::computed_value::T {
                        self.color.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Column style struct.
        pub struct Column {
                /// The column-width computed value.
                pub column_width: longhands::column_width::computed_value::T,
                /// The column-count computed value.
                pub column_count: longhands::column_count::computed_value::T,
                /// The column-gap computed value.
                pub column_gap: longhands::column_gap::computed_value::T,
                /// The column-fill computed value.
                pub column_fill: longhands::column_fill::computed_value::T,
                /// The column-rule-width computed value.
                pub column_rule_width: longhands::column_rule_width::computed_value::T,
                /// The column-rule-color computed value.
                pub column_rule_color: longhands::column_rule_color::computed_value::T,
                /// The column-span computed value.
                pub column_span: longhands::column_span::computed_value::T,
                /// The column-rule-style computed value.
                pub column_rule_style: longhands::column_rule_style::computed_value::T,
        }

        impl Column {
                        /// Set column-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_width(&mut self, v: longhands::column_width::computed_value::T) {
                            self.column_width = v;
                        }
                        /// Set column-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_width_from(&mut self, other: &Self) {
                            self.column_width = other.column_width.clone();
                        }
                    /// Reset column-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_width(&mut self, other: &Self) {
                        self.copy_column_width_from(other)
                    }

                    /// Get the computed value for column-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_width(&self) -> longhands::column_width::computed_value::T {
                        self.column_width.clone()
                    }
                        /// Set column-count.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_count(&mut self, v: longhands::column_count::computed_value::T) {
                            self.column_count = v;
                        }
                        /// Set column-count from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_count_from(&mut self, other: &Self) {
                            self.column_count = other.column_count.clone();
                        }
                    /// Reset column-count from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_count(&mut self, other: &Self) {
                        self.copy_column_count_from(other)
                    }

                    /// Get the computed value for column-count.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_count(&self) -> longhands::column_count::computed_value::T {
                        self.column_count.clone()
                    }
                        /// Set column-gap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_gap(&mut self, v: longhands::column_gap::computed_value::T) {
                            self.column_gap = v;
                        }
                        /// Set column-gap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_gap_from(&mut self, other: &Self) {
                            self.column_gap = other.column_gap.clone();
                        }
                    /// Reset column-gap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_gap(&mut self, other: &Self) {
                        self.copy_column_gap_from(other)
                    }

                    /// Get the computed value for column-gap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_gap(&self) -> longhands::column_gap::computed_value::T {
                        self.column_gap.clone()
                    }
                        /// Set column-fill.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_fill(&mut self, v: longhands::column_fill::computed_value::T) {
                            self.column_fill = v;
                        }
                        /// Set column-fill from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_fill_from(&mut self, other: &Self) {
                            self.column_fill = other.column_fill.clone();
                        }
                    /// Reset column-fill from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_fill(&mut self, other: &Self) {
                        self.copy_column_fill_from(other)
                    }

                    /// Get the computed value for column-fill.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_fill(&self) -> longhands::column_fill::computed_value::T {
                        self.column_fill.clone()
                    }
                        /// Set column-rule-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_rule_width(&mut self, v: longhands::column_rule_width::computed_value::T) {
                            self.column_rule_width = v;
                        }
                        /// Set column-rule-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_rule_width_from(&mut self, other: &Self) {
                            self.column_rule_width = other.column_rule_width.clone();
                        }
                    /// Reset column-rule-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_rule_width(&mut self, other: &Self) {
                        self.copy_column_rule_width_from(other)
                    }

                    /// Get the computed value for column-rule-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_rule_width(&self) -> longhands::column_rule_width::computed_value::T {
                        self.column_rule_width.clone()
                    }
                        /// Set column-rule-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_rule_color(&mut self, v: longhands::column_rule_color::computed_value::T) {
                            self.column_rule_color = v;
                        }
                        /// Set column-rule-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_rule_color_from(&mut self, other: &Self) {
                            self.column_rule_color = other.column_rule_color.clone();
                        }
                    /// Reset column-rule-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_rule_color(&mut self, other: &Self) {
                        self.copy_column_rule_color_from(other)
                    }

                    /// Get the computed value for column-rule-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_rule_color(&self) -> longhands::column_rule_color::computed_value::T {
                        self.column_rule_color.clone()
                    }
                        /// Set column-span.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_span(&mut self, v: longhands::column_span::computed_value::T) {
                            self.column_span = v;
                        }
                        /// Set column-span from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_span_from(&mut self, other: &Self) {
                            self.column_span = other.column_span.clone();
                        }
                    /// Reset column-span from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_span(&mut self, other: &Self) {
                        self.copy_column_span_from(other)
                    }

                    /// Get the computed value for column-span.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_span(&self) -> longhands::column_span::computed_value::T {
                        self.column_span.clone()
                    }
                        /// Set column-rule-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_rule_style(&mut self, v: longhands::column_rule_style::computed_value::T) {
                            self.column_rule_style = v;
                        }
                        /// Set column-rule-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_rule_style_from(&mut self, other: &Self) {
                            self.column_rule_style = other.column_rule_style.clone();
                        }
                    /// Reset column-rule-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_rule_style(&mut self, other: &Self) {
                        self.copy_column_rule_style_from(other)
                    }

                    /// Get the computed value for column-rule-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_rule_style(&self) -> longhands::column_rule_style::computed_value::T {
                        self.column_rule_style.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Counters style struct.
        pub struct Counters {
                /// The content computed value.
                pub content: longhands::content::computed_value::T,
                /// The counter-increment computed value.
                pub counter_increment: longhands::counter_increment::computed_value::T,
                /// The counter-reset computed value.
                pub counter_reset: longhands::counter_reset::computed_value::T,
        }

        impl Counters {
                        /// Set content.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_content(&mut self, v: longhands::content::computed_value::T) {
                            self.content = v;
                        }
                        /// Set content from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_content_from(&mut self, other: &Self) {
                            self.content = other.content.clone();
                        }
                    /// Reset content from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_content(&mut self, other: &Self) {
                        self.copy_content_from(other)
                    }

                    /// Get the computed value for content.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_content(&self) -> longhands::content::computed_value::T {
                        self.content.clone()
                    }
                        /// Set counter-increment.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_counter_increment(&mut self, v: longhands::counter_increment::computed_value::T) {
                            self.counter_increment = v;
                        }
                        /// Set counter-increment from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_counter_increment_from(&mut self, other: &Self) {
                            self.counter_increment = other.counter_increment.clone();
                        }
                    /// Reset counter-increment from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_counter_increment(&mut self, other: &Self) {
                        self.copy_counter_increment_from(other)
                    }

                    /// Get the computed value for counter-increment.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_counter_increment(&self) -> longhands::counter_increment::computed_value::T {
                        self.counter_increment.clone()
                    }
                        /// Set counter-reset.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_counter_reset(&mut self, v: longhands::counter_reset::computed_value::T) {
                            self.counter_reset = v;
                        }
                        /// Set counter-reset from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_counter_reset_from(&mut self, other: &Self) {
                            self.counter_reset = other.counter_reset.clone();
                        }
                    /// Reset counter-reset from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_counter_reset(&mut self, other: &Self) {
                        self.copy_counter_reset_from(other)
                    }

                    /// Get the computed value for counter-reset.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_counter_reset(&self) -> longhands::counter_reset::computed_value::T {
                        self.counter_reset.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Effects style struct.
        pub struct Effects {
                /// The opacity computed value.
                pub opacity: longhands::opacity::computed_value::T,
                /// The box-shadow computed value.
                pub box_shadow: longhands::box_shadow::computed_value::T,
                /// The clip computed value.
                pub clip: longhands::clip::computed_value::T,
                /// The filter computed value.
                pub filter: longhands::filter::computed_value::T,
                /// The mix-blend-mode computed value.
                pub mix_blend_mode: longhands::mix_blend_mode::computed_value::T,
        }

        impl Effects {
                        /// Set opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_opacity(&mut self, v: longhands::opacity::computed_value::T) {
                            self.opacity = v;
                        }
                        /// Set opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_opacity_from(&mut self, other: &Self) {
                            self.opacity = other.opacity.clone();
                        }
                    /// Reset opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_opacity(&mut self, other: &Self) {
                        self.copy_opacity_from(other)
                    }

                    /// Get the computed value for opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_opacity(&self) -> longhands::opacity::computed_value::T {
                        self.opacity.clone()
                    }
                        /// Set box-shadow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_box_shadow<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::box_shadow
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.box_shadow = longhands::box_shadow::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set box-shadow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_box_shadow_from(&mut self, other: &Self) {
                            self.box_shadow = other.box_shadow.clone();
                        }
                    /// Reset box-shadow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_box_shadow(&mut self, other: &Self) {
                        self.copy_box_shadow_from(other)
                    }

                    /// Get the computed value for box-shadow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_box_shadow(&self) -> longhands::box_shadow::computed_value::T {
                        self.box_shadow.clone()
                    }
                        /// Set clip.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_clip(&mut self, v: longhands::clip::computed_value::T) {
                            self.clip = v;
                        }
                        /// Set clip from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_clip_from(&mut self, other: &Self) {
                            self.clip = other.clip.clone();
                        }
                    /// Reset clip from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_clip(&mut self, other: &Self) {
                        self.copy_clip_from(other)
                    }

                    /// Get the computed value for clip.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_clip(&self) -> longhands::clip::computed_value::T {
                        self.clip.clone()
                    }
                        /// Set filter.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_filter<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::filter
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.filter = longhands::filter::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set filter from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_filter_from(&mut self, other: &Self) {
                            self.filter = other.filter.clone();
                        }
                    /// Reset filter from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_filter(&mut self, other: &Self) {
                        self.copy_filter_from(other)
                    }

                    /// Get the computed value for filter.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_filter(&self) -> longhands::filter::computed_value::T {
                        self.filter.clone()
                    }
                        /// Set mix-blend-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mix_blend_mode(&mut self, v: longhands::mix_blend_mode::computed_value::T) {
                            self.mix_blend_mode = v;
                        }
                        /// Set mix-blend-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mix_blend_mode_from(&mut self, other: &Self) {
                            self.mix_blend_mode = other.mix_blend_mode.clone();
                        }
                    /// Reset mix-blend-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mix_blend_mode(&mut self, other: &Self) {
                        self.copy_mix_blend_mode_from(other)
                    }

                    /// Get the computed value for mix-blend-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mix_blend_mode(&self) -> longhands::mix_blend_mode::computed_value::T {
                        self.mix_blend_mode.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf)]
        /// The Font style struct.
        pub struct Font {
                /// The font-family computed value.
                pub font_family: longhands::font_family::computed_value::T,
                /// The font-style computed value.
                pub font_style: longhands::font_style::computed_value::T,
                /// The font-variant-caps computed value.
                pub font_variant_caps: longhands::font_variant_caps::computed_value::T,
                /// The font-weight computed value.
                pub font_weight: longhands::font_weight::computed_value::T,
                /// The font-size computed value.
                pub font_size: longhands::font_size::computed_value::T,
                /// The font-size-adjust computed value.
                pub font_size_adjust: longhands::font_size_adjust::computed_value::T,
                /// The font-synthesis computed value.
                pub font_synthesis: longhands::font_synthesis::computed_value::T,
                /// The font-stretch computed value.
                pub font_stretch: longhands::font_stretch::computed_value::T,
                /// The font-kerning computed value.
                pub font_kerning: longhands::font_kerning::computed_value::T,
                /// The font-variant-alternates computed value.
                pub font_variant_alternates: longhands::font_variant_alternates::computed_value::T,
                /// The font-variant-east-asian computed value.
                pub font_variant_east_asian: longhands::font_variant_east_asian::computed_value::T,
                /// The font-variant-ligatures computed value.
                pub font_variant_ligatures: longhands::font_variant_ligatures::computed_value::T,
                /// The font-variant-numeric computed value.
                pub font_variant_numeric: longhands::font_variant_numeric::computed_value::T,
                /// The font-variant-position computed value.
                pub font_variant_position: longhands::font_variant_position::computed_value::T,
                /// The font-feature-settings computed value.
                pub font_feature_settings: longhands::font_feature_settings::computed_value::T,
                /// The font-variation-settings computed value.
                pub font_variation_settings: longhands::font_variation_settings::computed_value::T,
                /// The font-language-override computed value.
                pub font_language_override: longhands::font_language_override::computed_value::T,
                /// The font-optical-sizing computed value.
                pub font_optical_sizing: longhands::font_optical_sizing::computed_value::T,
                /// The -x-lang computed value.
                pub _x_lang: longhands::_x_lang::computed_value::T,
                /// The -moz-script-size-multiplier computed value.
                pub _moz_script_size_multiplier: longhands::_moz_script_size_multiplier::computed_value::T,
                /// The -moz-script-level computed value.
                pub _moz_script_level: longhands::_moz_script_level::computed_value::T,
                /// The -moz-math-display computed value.
                pub _moz_math_display: longhands::_moz_math_display::computed_value::T,
                /// The -moz-math-variant computed value.
                pub _moz_math_variant: longhands::_moz_math_variant::computed_value::T,
                /// The -moz-script-min-size computed value.
                pub _moz_script_min_size: longhands::_moz_script_min_size::computed_value::T,
                /// The -x-text-zoom computed value.
                pub _x_text_zoom: longhands::_x_text_zoom::computed_value::T,
                /// The -moz-osx-font-smoothing computed value.
                pub _moz_osx_font_smoothing: longhands::_moz_osx_font_smoothing::computed_value::T,
                /// The -moz-font-smoothing-background-color computed value.
                pub _moz_font_smoothing_background_color: longhands::_moz_font_smoothing_background_color::computed_value::T,
                /// The -moz-min-font-size-ratio computed value.
                pub _moz_min_font_size_ratio: longhands::_moz_min_font_size_ratio::computed_value::T,
                /// The font hash, used for font caching.
                pub hash: u64,
        }
        impl PartialEq for Font {
            fn eq(&self, other: &Font) -> bool {
                self.hash == other.hash
                    && self.font_family == other.font_family
                    && self.font_style == other.font_style
                    && self.font_variant_caps == other.font_variant_caps
                    && self.font_weight == other.font_weight
                    && self.font_size == other.font_size
                    && self.font_size_adjust == other.font_size_adjust
                    && self.font_synthesis == other.font_synthesis
                    && self.font_stretch == other.font_stretch
                    && self.font_kerning == other.font_kerning
                    && self.font_variant_alternates == other.font_variant_alternates
                    && self.font_variant_east_asian == other.font_variant_east_asian
                    && self.font_variant_ligatures == other.font_variant_ligatures
                    && self.font_variant_numeric == other.font_variant_numeric
                    && self.font_variant_position == other.font_variant_position
                    && self.font_feature_settings == other.font_feature_settings
                    && self.font_variation_settings == other.font_variation_settings
                    && self.font_language_override == other.font_language_override
                    && self.font_optical_sizing == other.font_optical_sizing
                    && self._x_lang == other._x_lang
                    && self._moz_script_size_multiplier == other._moz_script_size_multiplier
                    && self._moz_script_level == other._moz_script_level
                    && self._moz_math_display == other._moz_math_display
                    && self._moz_math_variant == other._moz_math_variant
                    && self._moz_script_min_size == other._moz_script_min_size
                    && self._x_text_zoom == other._x_text_zoom
                    && self._moz_osx_font_smoothing == other._moz_osx_font_smoothing
                    && self._moz_font_smoothing_background_color == other._moz_font_smoothing_background_color
                    && self._moz_min_font_size_ratio == other._moz_min_font_size_ratio
            }
        }

        impl Font {
                        /// Set font-family.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_family(&mut self, v: longhands::font_family::computed_value::T) {
                            self.font_family = v;
                        }
                        /// Set font-family from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_family_from(&mut self, other: &Self) {
                            self.font_family = other.font_family.clone();
                        }
                    /// Reset font-family from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_family(&mut self, other: &Self) {
                        self.copy_font_family_from(other)
                    }

                    /// Get the computed value for font-family.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_family(&self) -> longhands::font_family::computed_value::T {
                        self.font_family.clone()
                    }
                        /// Set font-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_style(&mut self, v: longhands::font_style::computed_value::T) {
                            self.font_style = v;
                        }
                        /// Set font-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_style_from(&mut self, other: &Self) {
                            self.font_style = other.font_style.clone();
                        }
                    /// Reset font-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_style(&mut self, other: &Self) {
                        self.copy_font_style_from(other)
                    }

                    /// Get the computed value for font-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_style(&self) -> longhands::font_style::computed_value::T {
                        self.font_style.clone()
                    }
                        /// Set font-variant-caps.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_caps(&mut self, v: longhands::font_variant_caps::computed_value::T) {
                            self.font_variant_caps = v;
                        }
                        /// Set font-variant-caps from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_caps_from(&mut self, other: &Self) {
                            self.font_variant_caps = other.font_variant_caps.clone();
                        }
                    /// Reset font-variant-caps from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_caps(&mut self, other: &Self) {
                        self.copy_font_variant_caps_from(other)
                    }

                    /// Get the computed value for font-variant-caps.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_caps(&self) -> longhands::font_variant_caps::computed_value::T {
                        self.font_variant_caps.clone()
                    }
                        /// Set font-weight.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_weight(&mut self, v: longhands::font_weight::computed_value::T) {
                            self.font_weight = v;
                        }
                        /// Set font-weight from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_weight_from(&mut self, other: &Self) {
                            self.font_weight = other.font_weight.clone();
                        }
                    /// Reset font-weight from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_weight(&mut self, other: &Self) {
                        self.copy_font_weight_from(other)
                    }

                    /// Get the computed value for font-weight.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_weight(&self) -> longhands::font_weight::computed_value::T {
                        self.font_weight.clone()
                    }
                        /// Set font-size.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_size(&mut self, v: longhands::font_size::computed_value::T) {
                            self.font_size = v;
                        }
                        /// Set font-size from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_size_from(&mut self, other: &Self) {
                            self.font_size = other.font_size.clone();
                        }
                    /// Reset font-size from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_size(&mut self, other: &Self) {
                        self.copy_font_size_from(other)
                    }

                    /// Get the computed value for font-size.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_size(&self) -> longhands::font_size::computed_value::T {
                        self.font_size.clone()
                    }
                        /// Set font-size-adjust.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_size_adjust(&mut self, v: longhands::font_size_adjust::computed_value::T) {
                            self.font_size_adjust = v;
                        }
                        /// Set font-size-adjust from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_size_adjust_from(&mut self, other: &Self) {
                            self.font_size_adjust = other.font_size_adjust.clone();
                        }
                    /// Reset font-size-adjust from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_size_adjust(&mut self, other: &Self) {
                        self.copy_font_size_adjust_from(other)
                    }

                    /// Get the computed value for font-size-adjust.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_size_adjust(&self) -> longhands::font_size_adjust::computed_value::T {
                        self.font_size_adjust.clone()
                    }
                        /// Set font-synthesis.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_synthesis(&mut self, v: longhands::font_synthesis::computed_value::T) {
                            self.font_synthesis = v;
                        }
                        /// Set font-synthesis from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_synthesis_from(&mut self, other: &Self) {
                            self.font_synthesis = other.font_synthesis.clone();
                        }
                    /// Reset font-synthesis from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_synthesis(&mut self, other: &Self) {
                        self.copy_font_synthesis_from(other)
                    }

                    /// Get the computed value for font-synthesis.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_synthesis(&self) -> longhands::font_synthesis::computed_value::T {
                        self.font_synthesis.clone()
                    }
                        /// Set font-stretch.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_stretch(&mut self, v: longhands::font_stretch::computed_value::T) {
                            self.font_stretch = v;
                        }
                        /// Set font-stretch from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_stretch_from(&mut self, other: &Self) {
                            self.font_stretch = other.font_stretch.clone();
                        }
                    /// Reset font-stretch from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_stretch(&mut self, other: &Self) {
                        self.copy_font_stretch_from(other)
                    }

                    /// Get the computed value for font-stretch.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_stretch(&self) -> longhands::font_stretch::computed_value::T {
                        self.font_stretch.clone()
                    }
                        /// Set font-kerning.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_kerning(&mut self, v: longhands::font_kerning::computed_value::T) {
                            self.font_kerning = v;
                        }
                        /// Set font-kerning from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_kerning_from(&mut self, other: &Self) {
                            self.font_kerning = other.font_kerning.clone();
                        }
                    /// Reset font-kerning from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_kerning(&mut self, other: &Self) {
                        self.copy_font_kerning_from(other)
                    }

                    /// Get the computed value for font-kerning.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_kerning(&self) -> longhands::font_kerning::computed_value::T {
                        self.font_kerning.clone()
                    }
                        /// Set font-variant-alternates.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_alternates(&mut self, v: longhands::font_variant_alternates::computed_value::T) {
                            self.font_variant_alternates = v;
                        }
                        /// Set font-variant-alternates from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_alternates_from(&mut self, other: &Self) {
                            self.font_variant_alternates = other.font_variant_alternates.clone();
                        }
                    /// Reset font-variant-alternates from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_alternates(&mut self, other: &Self) {
                        self.copy_font_variant_alternates_from(other)
                    }

                    /// Get the computed value for font-variant-alternates.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_alternates(&self) -> longhands::font_variant_alternates::computed_value::T {
                        self.font_variant_alternates.clone()
                    }
                        /// Set font-variant-east-asian.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_east_asian(&mut self, v: longhands::font_variant_east_asian::computed_value::T) {
                            self.font_variant_east_asian = v;
                        }
                        /// Set font-variant-east-asian from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_east_asian_from(&mut self, other: &Self) {
                            self.font_variant_east_asian = other.font_variant_east_asian.clone();
                        }
                    /// Reset font-variant-east-asian from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_east_asian(&mut self, other: &Self) {
                        self.copy_font_variant_east_asian_from(other)
                    }

                    /// Get the computed value for font-variant-east-asian.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_east_asian(&self) -> longhands::font_variant_east_asian::computed_value::T {
                        self.font_variant_east_asian.clone()
                    }
                        /// Set font-variant-ligatures.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_ligatures(&mut self, v: longhands::font_variant_ligatures::computed_value::T) {
                            self.font_variant_ligatures = v;
                        }
                        /// Set font-variant-ligatures from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_ligatures_from(&mut self, other: &Self) {
                            self.font_variant_ligatures = other.font_variant_ligatures.clone();
                        }
                    /// Reset font-variant-ligatures from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_ligatures(&mut self, other: &Self) {
                        self.copy_font_variant_ligatures_from(other)
                    }

                    /// Get the computed value for font-variant-ligatures.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_ligatures(&self) -> longhands::font_variant_ligatures::computed_value::T {
                        self.font_variant_ligatures.clone()
                    }
                        /// Set font-variant-numeric.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_numeric(&mut self, v: longhands::font_variant_numeric::computed_value::T) {
                            self.font_variant_numeric = v;
                        }
                        /// Set font-variant-numeric from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_numeric_from(&mut self, other: &Self) {
                            self.font_variant_numeric = other.font_variant_numeric.clone();
                        }
                    /// Reset font-variant-numeric from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_numeric(&mut self, other: &Self) {
                        self.copy_font_variant_numeric_from(other)
                    }

                    /// Get the computed value for font-variant-numeric.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_numeric(&self) -> longhands::font_variant_numeric::computed_value::T {
                        self.font_variant_numeric.clone()
                    }
                        /// Set font-variant-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_position(&mut self, v: longhands::font_variant_position::computed_value::T) {
                            self.font_variant_position = v;
                        }
                        /// Set font-variant-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_position_from(&mut self, other: &Self) {
                            self.font_variant_position = other.font_variant_position.clone();
                        }
                    /// Reset font-variant-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_position(&mut self, other: &Self) {
                        self.copy_font_variant_position_from(other)
                    }

                    /// Get the computed value for font-variant-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_position(&self) -> longhands::font_variant_position::computed_value::T {
                        self.font_variant_position.clone()
                    }
                        /// Set font-feature-settings.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_feature_settings(&mut self, v: longhands::font_feature_settings::computed_value::T) {
                            self.font_feature_settings = v;
                        }
                        /// Set font-feature-settings from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_feature_settings_from(&mut self, other: &Self) {
                            self.font_feature_settings = other.font_feature_settings.clone();
                        }
                    /// Reset font-feature-settings from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_feature_settings(&mut self, other: &Self) {
                        self.copy_font_feature_settings_from(other)
                    }

                    /// Get the computed value for font-feature-settings.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_feature_settings(&self) -> longhands::font_feature_settings::computed_value::T {
                        self.font_feature_settings.clone()
                    }
                        /// Set font-variation-settings.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variation_settings(&mut self, v: longhands::font_variation_settings::computed_value::T) {
                            self.font_variation_settings = v;
                        }
                        /// Set font-variation-settings from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variation_settings_from(&mut self, other: &Self) {
                            self.font_variation_settings = other.font_variation_settings.clone();
                        }
                    /// Reset font-variation-settings from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variation_settings(&mut self, other: &Self) {
                        self.copy_font_variation_settings_from(other)
                    }

                    /// Get the computed value for font-variation-settings.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variation_settings(&self) -> longhands::font_variation_settings::computed_value::T {
                        self.font_variation_settings.clone()
                    }
                        /// Set font-language-override.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_language_override(&mut self, v: longhands::font_language_override::computed_value::T) {
                            self.font_language_override = v;
                        }
                        /// Set font-language-override from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_language_override_from(&mut self, other: &Self) {
                            self.font_language_override = other.font_language_override.clone();
                        }
                    /// Reset font-language-override from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_language_override(&mut self, other: &Self) {
                        self.copy_font_language_override_from(other)
                    }

                    /// Get the computed value for font-language-override.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_language_override(&self) -> longhands::font_language_override::computed_value::T {
                        self.font_language_override.clone()
                    }
                        /// Set font-optical-sizing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_optical_sizing(&mut self, v: longhands::font_optical_sizing::computed_value::T) {
                            self.font_optical_sizing = v;
                        }
                        /// Set font-optical-sizing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_optical_sizing_from(&mut self, other: &Self) {
                            self.font_optical_sizing = other.font_optical_sizing.clone();
                        }
                    /// Reset font-optical-sizing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_optical_sizing(&mut self, other: &Self) {
                        self.copy_font_optical_sizing_from(other)
                    }

                    /// Get the computed value for font-optical-sizing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_optical_sizing(&self) -> longhands::font_optical_sizing::computed_value::T {
                        self.font_optical_sizing.clone()
                    }
                        /// Set -x-lang.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__x_lang(&mut self, v: longhands::_x_lang::computed_value::T) {
                            self._x_lang = v;
                        }
                        /// Set -x-lang from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__x_lang_from(&mut self, other: &Self) {
                            self._x_lang = other._x_lang.clone();
                        }
                    /// Reset -x-lang from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__x_lang(&mut self, other: &Self) {
                        self.copy__x_lang_from(other)
                    }

                    /// Get the computed value for -x-lang.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__x_lang(&self) -> longhands::_x_lang::computed_value::T {
                        self._x_lang.clone()
                    }
                        /// Set -moz-script-size-multiplier.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_script_size_multiplier(&mut self, v: longhands::_moz_script_size_multiplier::computed_value::T) {
                            self._moz_script_size_multiplier = v;
                        }
                        /// Set -moz-script-size-multiplier from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_script_size_multiplier_from(&mut self, other: &Self) {
                            self._moz_script_size_multiplier = other._moz_script_size_multiplier.clone();
                        }
                    /// Reset -moz-script-size-multiplier from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_script_size_multiplier(&mut self, other: &Self) {
                        self.copy__moz_script_size_multiplier_from(other)
                    }

                    /// Get the computed value for -moz-script-size-multiplier.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_script_size_multiplier(&self) -> longhands::_moz_script_size_multiplier::computed_value::T {
                        self._moz_script_size_multiplier.clone()
                    }
                        /// Set -moz-script-level.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_script_level(&mut self, v: longhands::_moz_script_level::computed_value::T) {
                            self._moz_script_level = v;
                        }
                        /// Set -moz-script-level from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_script_level_from(&mut self, other: &Self) {
                            self._moz_script_level = other._moz_script_level.clone();
                        }
                    /// Reset -moz-script-level from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_script_level(&mut self, other: &Self) {
                        self.copy__moz_script_level_from(other)
                    }

                    /// Get the computed value for -moz-script-level.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_script_level(&self) -> longhands::_moz_script_level::computed_value::T {
                        self._moz_script_level.clone()
                    }
                        /// Set -moz-math-display.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_math_display(&mut self, v: longhands::_moz_math_display::computed_value::T) {
                            self._moz_math_display = v;
                        }
                        /// Set -moz-math-display from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_math_display_from(&mut self, other: &Self) {
                            self._moz_math_display = other._moz_math_display.clone();
                        }
                    /// Reset -moz-math-display from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_math_display(&mut self, other: &Self) {
                        self.copy__moz_math_display_from(other)
                    }

                    /// Get the computed value for -moz-math-display.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_math_display(&self) -> longhands::_moz_math_display::computed_value::T {
                        self._moz_math_display.clone()
                    }
                        /// Set -moz-math-variant.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_math_variant(&mut self, v: longhands::_moz_math_variant::computed_value::T) {
                            self._moz_math_variant = v;
                        }
                        /// Set -moz-math-variant from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_math_variant_from(&mut self, other: &Self) {
                            self._moz_math_variant = other._moz_math_variant.clone();
                        }
                    /// Reset -moz-math-variant from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_math_variant(&mut self, other: &Self) {
                        self.copy__moz_math_variant_from(other)
                    }

                    /// Get the computed value for -moz-math-variant.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_math_variant(&self) -> longhands::_moz_math_variant::computed_value::T {
                        self._moz_math_variant.clone()
                    }
                        /// Set -moz-script-min-size.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_script_min_size(&mut self, v: longhands::_moz_script_min_size::computed_value::T) {
                            self._moz_script_min_size = v;
                        }
                        /// Set -moz-script-min-size from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_script_min_size_from(&mut self, other: &Self) {
                            self._moz_script_min_size = other._moz_script_min_size.clone();
                        }
                    /// Reset -moz-script-min-size from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_script_min_size(&mut self, other: &Self) {
                        self.copy__moz_script_min_size_from(other)
                    }

                    /// Get the computed value for -moz-script-min-size.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_script_min_size(&self) -> longhands::_moz_script_min_size::computed_value::T {
                        self._moz_script_min_size.clone()
                    }
                        /// Set -x-text-zoom.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__x_text_zoom(&mut self, v: longhands::_x_text_zoom::computed_value::T) {
                            self._x_text_zoom = v;
                        }
                        /// Set -x-text-zoom from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__x_text_zoom_from(&mut self, other: &Self) {
                            self._x_text_zoom = other._x_text_zoom.clone();
                        }
                    /// Reset -x-text-zoom from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__x_text_zoom(&mut self, other: &Self) {
                        self.copy__x_text_zoom_from(other)
                    }

                    /// Get the computed value for -x-text-zoom.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__x_text_zoom(&self) -> longhands::_x_text_zoom::computed_value::T {
                        self._x_text_zoom.clone()
                    }
                        /// Set -moz-osx-font-smoothing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_osx_font_smoothing(&mut self, v: longhands::_moz_osx_font_smoothing::computed_value::T) {
                            self._moz_osx_font_smoothing = v;
                        }
                        /// Set -moz-osx-font-smoothing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_osx_font_smoothing_from(&mut self, other: &Self) {
                            self._moz_osx_font_smoothing = other._moz_osx_font_smoothing.clone();
                        }
                    /// Reset -moz-osx-font-smoothing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_osx_font_smoothing(&mut self, other: &Self) {
                        self.copy__moz_osx_font_smoothing_from(other)
                    }

                    /// Get the computed value for -moz-osx-font-smoothing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_osx_font_smoothing(&self) -> longhands::_moz_osx_font_smoothing::computed_value::T {
                        self._moz_osx_font_smoothing.clone()
                    }
                        /// Set -moz-font-smoothing-background-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_font_smoothing_background_color(&mut self, v: longhands::_moz_font_smoothing_background_color::computed_value::T) {
                            self._moz_font_smoothing_background_color = v;
                        }
                        /// Set -moz-font-smoothing-background-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_font_smoothing_background_color_from(&mut self, other: &Self) {
                            self._moz_font_smoothing_background_color = other._moz_font_smoothing_background_color.clone();
                        }
                    /// Reset -moz-font-smoothing-background-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_font_smoothing_background_color(&mut self, other: &Self) {
                        self.copy__moz_font_smoothing_background_color_from(other)
                    }

                    /// Get the computed value for -moz-font-smoothing-background-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_font_smoothing_background_color(&self) -> longhands::_moz_font_smoothing_background_color::computed_value::T {
                        self._moz_font_smoothing_background_color.clone()
                    }
                        /// Set -moz-min-font-size-ratio.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_min_font_size_ratio(&mut self, v: longhands::_moz_min_font_size_ratio::computed_value::T) {
                            self._moz_min_font_size_ratio = v;
                        }
                        /// Set -moz-min-font-size-ratio from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_min_font_size_ratio_from(&mut self, other: &Self) {
                            self._moz_min_font_size_ratio = other._moz_min_font_size_ratio.clone();
                        }
                    /// Reset -moz-min-font-size-ratio from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_min_font_size_ratio(&mut self, other: &Self) {
                        self.copy__moz_min_font_size_ratio_from(other)
                    }

                    /// Get the computed value for -moz-min-font-size-ratio.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_min_font_size_ratio(&self) -> longhands::_moz_min_font_size_ratio::computed_value::T {
                        self._moz_min_font_size_ratio.clone()
                    }
                /// Computes a font hash in order to be able to cache fonts
                /// effectively in GFX and layout.
                pub fn compute_font_hash(&mut self) {
                    // Corresponds to the fields in
                    // `gfx::font_template::FontTemplateDescriptor`.
                    let mut hasher: FnvHasher = Default::default();
                    hasher.write_u16(self.font_weight.0);
                    self.font_stretch.hash(&mut hasher);
                    self.font_family.hash(&mut hasher);
                    self.hash = hasher.finish()
                }

                /// (Servo does not handle MathML, so this just calls copy_font_size_from)
                pub fn inherit_font_size_from(&mut self, parent: &Self,
                                              _: Option<NonNegativeLength>,
                                              _: &Device) {
                    self.copy_font_size_from(parent);
                }
                /// (Servo does not handle MathML, so this just calls set_font_size)
                pub fn apply_font_size(&mut self,
                                       v: longhands::font_size::computed_value::T,
                                       _: &Self,
                                       _: &Device) -> Option<NonNegativeLength> {
                    self.set_font_size(v);
                    None
                }
                /// (Servo does not handle MathML, so this does nothing)
                pub fn apply_unconstrained_font_size(&mut self, _: NonNegativeLength) {
                }

        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The InheritedBox style struct.
        pub struct InheritedBox {
                /// The visibility computed value.
                pub visibility: longhands::visibility::computed_value::T,
                /// The writing-mode computed value.
                pub writing_mode: longhands::writing_mode::computed_value::T,
                /// The direction computed value.
                pub direction: longhands::direction::computed_value::T,
                /// The text-orientation computed value.
                pub text_orientation: longhands::text_orientation::computed_value::T,
                /// The color-adjust computed value.
                pub color_adjust: longhands::color_adjust::computed_value::T,
                /// The image-rendering computed value.
                pub image_rendering: longhands::image_rendering::computed_value::T,
                /// The image-orientation computed value.
                pub image_orientation: longhands::image_orientation::computed_value::T,
        }

        impl InheritedBox {
                        /// Set visibility.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_visibility(&mut self, v: longhands::visibility::computed_value::T) {
                            self.visibility = v;
                        }
                        /// Set visibility from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_visibility_from(&mut self, other: &Self) {
                            self.visibility = other.visibility.clone();
                        }
                    /// Reset visibility from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_visibility(&mut self, other: &Self) {
                        self.copy_visibility_from(other)
                    }

                    /// Get the computed value for visibility.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_visibility(&self) -> longhands::visibility::computed_value::T {
                        self.visibility.clone()
                    }
                        /// Set writing-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_writing_mode(&mut self, v: longhands::writing_mode::computed_value::T) {
                            self.writing_mode = v;
                        }
                        /// Set writing-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_writing_mode_from(&mut self, other: &Self) {
                            self.writing_mode = other.writing_mode.clone();
                        }
                    /// Reset writing-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_writing_mode(&mut self, other: &Self) {
                        self.copy_writing_mode_from(other)
                    }

                    /// Get the computed value for writing-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_writing_mode(&self) -> longhands::writing_mode::computed_value::T {
                        self.writing_mode.clone()
                    }
                        /// Set direction.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_direction(&mut self, v: longhands::direction::computed_value::T) {
                            self.direction = v;
                        }
                        /// Set direction from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_direction_from(&mut self, other: &Self) {
                            self.direction = other.direction.clone();
                        }
                    /// Reset direction from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_direction(&mut self, other: &Self) {
                        self.copy_direction_from(other)
                    }

                    /// Get the computed value for direction.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_direction(&self) -> longhands::direction::computed_value::T {
                        self.direction.clone()
                    }
                        /// Set text-orientation.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_orientation(&mut self, v: longhands::text_orientation::computed_value::T) {
                            self.text_orientation = v;
                        }
                        /// Set text-orientation from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_orientation_from(&mut self, other: &Self) {
                            self.text_orientation = other.text_orientation.clone();
                        }
                    /// Reset text-orientation from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_orientation(&mut self, other: &Self) {
                        self.copy_text_orientation_from(other)
                    }

                    /// Get the computed value for text-orientation.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_orientation(&self) -> longhands::text_orientation::computed_value::T {
                        self.text_orientation.clone()
                    }
                        /// Set color-adjust.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_color_adjust(&mut self, v: longhands::color_adjust::computed_value::T) {
                            self.color_adjust = v;
                        }
                        /// Set color-adjust from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_color_adjust_from(&mut self, other: &Self) {
                            self.color_adjust = other.color_adjust.clone();
                        }
                    /// Reset color-adjust from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_color_adjust(&mut self, other: &Self) {
                        self.copy_color_adjust_from(other)
                    }

                    /// Get the computed value for color-adjust.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_color_adjust(&self) -> longhands::color_adjust::computed_value::T {
                        self.color_adjust.clone()
                    }
                        /// Set image-rendering.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_image_rendering(&mut self, v: longhands::image_rendering::computed_value::T) {
                            self.image_rendering = v;
                        }
                        /// Set image-rendering from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_image_rendering_from(&mut self, other: &Self) {
                            self.image_rendering = other.image_rendering.clone();
                        }
                    /// Reset image-rendering from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_image_rendering(&mut self, other: &Self) {
                        self.copy_image_rendering_from(other)
                    }

                    /// Get the computed value for image-rendering.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_image_rendering(&self) -> longhands::image_rendering::computed_value::T {
                        self.image_rendering.clone()
                    }
                        /// Set image-orientation.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_image_orientation(&mut self, v: longhands::image_orientation::computed_value::T) {
                            self.image_orientation = v;
                        }
                        /// Set image-orientation from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_image_orientation_from(&mut self, other: &Self) {
                            self.image_orientation = other.image_orientation.clone();
                        }
                    /// Reset image-orientation from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_image_orientation(&mut self, other: &Self) {
                        self.copy_image_orientation_from(other)
                    }

                    /// Get the computed value for image-orientation.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_image_orientation(&self) -> longhands::image_orientation::computed_value::T {
                        self.image_orientation.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The InheritedTable style struct.
        pub struct InheritedTable {
                /// The border-collapse computed value.
                pub border_collapse: longhands::border_collapse::computed_value::T,
                /// The empty-cells computed value.
                pub empty_cells: longhands::empty_cells::computed_value::T,
                /// The caption-side computed value.
                pub caption_side: longhands::caption_side::computed_value::T,
                /// The border-spacing computed value.
                pub border_spacing: longhands::border_spacing::computed_value::T,
        }

        impl InheritedTable {
                        /// Set border-collapse.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_collapse(&mut self, v: longhands::border_collapse::computed_value::T) {
                            self.border_collapse = v;
                        }
                        /// Set border-collapse from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_collapse_from(&mut self, other: &Self) {
                            self.border_collapse = other.border_collapse.clone();
                        }
                    /// Reset border-collapse from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_collapse(&mut self, other: &Self) {
                        self.copy_border_collapse_from(other)
                    }

                    /// Get the computed value for border-collapse.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_collapse(&self) -> longhands::border_collapse::computed_value::T {
                        self.border_collapse.clone()
                    }
                        /// Set empty-cells.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_empty_cells(&mut self, v: longhands::empty_cells::computed_value::T) {
                            self.empty_cells = v;
                        }
                        /// Set empty-cells from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_empty_cells_from(&mut self, other: &Self) {
                            self.empty_cells = other.empty_cells.clone();
                        }
                    /// Reset empty-cells from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_empty_cells(&mut self, other: &Self) {
                        self.copy_empty_cells_from(other)
                    }

                    /// Get the computed value for empty-cells.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_empty_cells(&self) -> longhands::empty_cells::computed_value::T {
                        self.empty_cells.clone()
                    }
                        /// Set caption-side.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_caption_side(&mut self, v: longhands::caption_side::computed_value::T) {
                            self.caption_side = v;
                        }
                        /// Set caption-side from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_caption_side_from(&mut self, other: &Self) {
                            self.caption_side = other.caption_side.clone();
                        }
                    /// Reset caption-side from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_caption_side(&mut self, other: &Self) {
                        self.copy_caption_side_from(other)
                    }

                    /// Get the computed value for caption-side.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_caption_side(&self) -> longhands::caption_side::computed_value::T {
                        self.caption_side.clone()
                    }
                        /// Set border-spacing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_spacing(&mut self, v: longhands::border_spacing::computed_value::T) {
                            self.border_spacing = v;
                        }
                        /// Set border-spacing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_spacing_from(&mut self, other: &Self) {
                            self.border_spacing = other.border_spacing.clone();
                        }
                    /// Reset border-spacing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_spacing(&mut self, other: &Self) {
                        self.copy_border_spacing_from(other)
                    }

                    /// Get the computed value for border-spacing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_spacing(&self) -> longhands::border_spacing::computed_value::T {
                        self.border_spacing.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The InheritedText style struct.
        pub struct InheritedText {
                /// The line-height computed value.
                pub line_height: longhands::line_height::computed_value::T,
                /// The text-transform computed value.
                pub text_transform: longhands::text_transform::computed_value::T,
                /// The hyphens computed value.
                pub hyphens: longhands::hyphens::computed_value::T,
                /// The -moz-text-size-adjust computed value.
                pub _moz_text_size_adjust: longhands::_moz_text_size_adjust::computed_value::T,
                /// The text-indent computed value.
                pub text_indent: longhands::text_indent::computed_value::T,
                /// The overflow-wrap computed value.
                pub overflow_wrap: longhands::overflow_wrap::computed_value::T,
                /// The word-break computed value.
                pub word_break: longhands::word_break::computed_value::T,
                /// The text-justify computed value.
                pub text_justify: longhands::text_justify::computed_value::T,
                /// The text-align-last computed value.
                pub text_align_last: longhands::text_align_last::computed_value::T,
                /// The text-align computed value.
                pub text_align: longhands::text_align::computed_value::T,
                /// The letter-spacing computed value.
                pub letter_spacing: longhands::letter_spacing::computed_value::T,
                /// The word-spacing computed value.
                pub word_spacing: longhands::word_spacing::computed_value::T,
                /// The white-space computed value.
                pub white_space: longhands::white_space::computed_value::T,
                /// The text-shadow computed value.
                pub text_shadow: longhands::text_shadow::computed_value::T,
                /// The text-emphasis-style computed value.
                pub text_emphasis_style: longhands::text_emphasis_style::computed_value::T,
                /// The text-emphasis-position computed value.
                pub text_emphasis_position: longhands::text_emphasis_position::computed_value::T,
                /// The text-emphasis-color computed value.
                pub text_emphasis_color: longhands::text_emphasis_color::computed_value::T,
                /// The -moz-tab-size computed value.
                pub _moz_tab_size: longhands::_moz_tab_size::computed_value::T,
                /// The -webkit-text-fill-color computed value.
                pub _webkit_text_fill_color: longhands::_webkit_text_fill_color::computed_value::T,
                /// The -webkit-text-stroke-color computed value.
                pub _webkit_text_stroke_color: longhands::_webkit_text_stroke_color::computed_value::T,
                /// The -webkit-text-stroke-width computed value.
                pub _webkit_text_stroke_width: longhands::_webkit_text_stroke_width::computed_value::T,
                /// The ruby-align computed value.
                pub ruby_align: longhands::ruby_align::computed_value::T,
                /// The ruby-position computed value.
                pub ruby_position: longhands::ruby_position::computed_value::T,
                /// The text-combine-upright computed value.
                pub text_combine_upright: longhands::text_combine_upright::computed_value::T,
                /// The text-rendering computed value.
                pub text_rendering: longhands::text_rendering::computed_value::T,
                /// The -moz-control-character-visibility computed value.
                pub _moz_control_character_visibility: longhands::_moz_control_character_visibility::computed_value::T,
                /// The "used" text-decorations that apply to this box.
                ///
                /// FIXME(emilio): This is technically a box-tree concept, and
                /// would be nice to move away from style.
                pub text_decorations_in_effect: ::values::computed::text::TextDecorationsInEffect,
        }

        impl InheritedText {
                        /// Set line-height.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_line_height(&mut self, v: longhands::line_height::computed_value::T) {
                            self.line_height = v;
                        }
                        /// Set line-height from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_line_height_from(&mut self, other: &Self) {
                            self.line_height = other.line_height.clone();
                        }
                    /// Reset line-height from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_line_height(&mut self, other: &Self) {
                        self.copy_line_height_from(other)
                    }

                    /// Get the computed value for line-height.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_line_height(&self) -> longhands::line_height::computed_value::T {
                        self.line_height.clone()
                    }
                        /// Set text-transform.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_transform(&mut self, v: longhands::text_transform::computed_value::T) {
                            self.text_transform = v;
                        }
                        /// Set text-transform from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_transform_from(&mut self, other: &Self) {
                            self.text_transform = other.text_transform.clone();
                        }
                    /// Reset text-transform from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_transform(&mut self, other: &Self) {
                        self.copy_text_transform_from(other)
                    }

                    /// Get the computed value for text-transform.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_transform(&self) -> longhands::text_transform::computed_value::T {
                        self.text_transform.clone()
                    }
                        /// Set hyphens.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_hyphens(&mut self, v: longhands::hyphens::computed_value::T) {
                            self.hyphens = v;
                        }
                        /// Set hyphens from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_hyphens_from(&mut self, other: &Self) {
                            self.hyphens = other.hyphens.clone();
                        }
                    /// Reset hyphens from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_hyphens(&mut self, other: &Self) {
                        self.copy_hyphens_from(other)
                    }

                    /// Get the computed value for hyphens.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_hyphens(&self) -> longhands::hyphens::computed_value::T {
                        self.hyphens.clone()
                    }
                        /// Set -moz-text-size-adjust.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_text_size_adjust(&mut self, v: longhands::_moz_text_size_adjust::computed_value::T) {
                            self._moz_text_size_adjust = v;
                        }
                        /// Set -moz-text-size-adjust from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_text_size_adjust_from(&mut self, other: &Self) {
                            self._moz_text_size_adjust = other._moz_text_size_adjust.clone();
                        }
                    /// Reset -moz-text-size-adjust from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_text_size_adjust(&mut self, other: &Self) {
                        self.copy__moz_text_size_adjust_from(other)
                    }

                    /// Get the computed value for -moz-text-size-adjust.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_text_size_adjust(&self) -> longhands::_moz_text_size_adjust::computed_value::T {
                        self._moz_text_size_adjust.clone()
                    }
                        /// Set text-indent.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_indent(&mut self, v: longhands::text_indent::computed_value::T) {
                            self.text_indent = v;
                        }
                        /// Set text-indent from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_indent_from(&mut self, other: &Self) {
                            self.text_indent = other.text_indent.clone();
                        }
                    /// Reset text-indent from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_indent(&mut self, other: &Self) {
                        self.copy_text_indent_from(other)
                    }

                    /// Get the computed value for text-indent.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_indent(&self) -> longhands::text_indent::computed_value::T {
                        self.text_indent.clone()
                    }
                        /// Set overflow-wrap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_wrap(&mut self, v: longhands::overflow_wrap::computed_value::T) {
                            self.overflow_wrap = v;
                        }
                        /// Set overflow-wrap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_wrap_from(&mut self, other: &Self) {
                            self.overflow_wrap = other.overflow_wrap.clone();
                        }
                    /// Reset overflow-wrap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_wrap(&mut self, other: &Self) {
                        self.copy_overflow_wrap_from(other)
                    }

                    /// Get the computed value for overflow-wrap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_wrap(&self) -> longhands::overflow_wrap::computed_value::T {
                        self.overflow_wrap.clone()
                    }
                        /// Set word-break.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_word_break(&mut self, v: longhands::word_break::computed_value::T) {
                            self.word_break = v;
                        }
                        /// Set word-break from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_word_break_from(&mut self, other: &Self) {
                            self.word_break = other.word_break.clone();
                        }
                    /// Reset word-break from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_word_break(&mut self, other: &Self) {
                        self.copy_word_break_from(other)
                    }

                    /// Get the computed value for word-break.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_word_break(&self) -> longhands::word_break::computed_value::T {
                        self.word_break.clone()
                    }
                        /// Set text-justify.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_justify(&mut self, v: longhands::text_justify::computed_value::T) {
                            self.text_justify = v;
                        }
                        /// Set text-justify from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_justify_from(&mut self, other: &Self) {
                            self.text_justify = other.text_justify.clone();
                        }
                    /// Reset text-justify from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_justify(&mut self, other: &Self) {
                        self.copy_text_justify_from(other)
                    }

                    /// Get the computed value for text-justify.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_justify(&self) -> longhands::text_justify::computed_value::T {
                        self.text_justify.clone()
                    }
                        /// Set text-align-last.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_align_last(&mut self, v: longhands::text_align_last::computed_value::T) {
                            self.text_align_last = v;
                        }
                        /// Set text-align-last from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_align_last_from(&mut self, other: &Self) {
                            self.text_align_last = other.text_align_last.clone();
                        }
                    /// Reset text-align-last from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_align_last(&mut self, other: &Self) {
                        self.copy_text_align_last_from(other)
                    }

                    /// Get the computed value for text-align-last.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_align_last(&self) -> longhands::text_align_last::computed_value::T {
                        self.text_align_last.clone()
                    }
                        /// Set text-align.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_align(&mut self, v: longhands::text_align::computed_value::T) {
                            self.text_align = v;
                        }
                        /// Set text-align from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_align_from(&mut self, other: &Self) {
                            self.text_align = other.text_align.clone();
                        }
                    /// Reset text-align from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_align(&mut self, other: &Self) {
                        self.copy_text_align_from(other)
                    }

                    /// Get the computed value for text-align.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_align(&self) -> longhands::text_align::computed_value::T {
                        self.text_align.clone()
                    }
                        /// Set letter-spacing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_letter_spacing(&mut self, v: longhands::letter_spacing::computed_value::T) {
                            self.letter_spacing = v;
                        }
                        /// Set letter-spacing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_letter_spacing_from(&mut self, other: &Self) {
                            self.letter_spacing = other.letter_spacing.clone();
                        }
                    /// Reset letter-spacing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_letter_spacing(&mut self, other: &Self) {
                        self.copy_letter_spacing_from(other)
                    }

                    /// Get the computed value for letter-spacing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_letter_spacing(&self) -> longhands::letter_spacing::computed_value::T {
                        self.letter_spacing.clone()
                    }
                        /// Set word-spacing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_word_spacing(&mut self, v: longhands::word_spacing::computed_value::T) {
                            self.word_spacing = v;
                        }
                        /// Set word-spacing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_word_spacing_from(&mut self, other: &Self) {
                            self.word_spacing = other.word_spacing.clone();
                        }
                    /// Reset word-spacing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_word_spacing(&mut self, other: &Self) {
                        self.copy_word_spacing_from(other)
                    }

                    /// Get the computed value for word-spacing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_word_spacing(&self) -> longhands::word_spacing::computed_value::T {
                        self.word_spacing.clone()
                    }
                        /// Set white-space.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_white_space(&mut self, v: longhands::white_space::computed_value::T) {
                            self.white_space = v;
                        }
                        /// Set white-space from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_white_space_from(&mut self, other: &Self) {
                            self.white_space = other.white_space.clone();
                        }
                    /// Reset white-space from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_white_space(&mut self, other: &Self) {
                        self.copy_white_space_from(other)
                    }

                    /// Get the computed value for white-space.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_white_space(&self) -> longhands::white_space::computed_value::T {
                        self.white_space.clone()
                    }
                        /// Set text-shadow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_shadow<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::text_shadow
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.text_shadow = longhands::text_shadow::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set text-shadow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_shadow_from(&mut self, other: &Self) {
                            self.text_shadow = other.text_shadow.clone();
                        }
                    /// Reset text-shadow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_shadow(&mut self, other: &Self) {
                        self.copy_text_shadow_from(other)
                    }

                    /// Get the computed value for text-shadow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_shadow(&self) -> longhands::text_shadow::computed_value::T {
                        self.text_shadow.clone()
                    }
                        /// Set text-emphasis-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_emphasis_style(&mut self, v: longhands::text_emphasis_style::computed_value::T) {
                            self.text_emphasis_style = v;
                        }
                        /// Set text-emphasis-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_emphasis_style_from(&mut self, other: &Self) {
                            self.text_emphasis_style = other.text_emphasis_style.clone();
                        }
                    /// Reset text-emphasis-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_emphasis_style(&mut self, other: &Self) {
                        self.copy_text_emphasis_style_from(other)
                    }

                    /// Get the computed value for text-emphasis-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_emphasis_style(&self) -> longhands::text_emphasis_style::computed_value::T {
                        self.text_emphasis_style.clone()
                    }
                        /// Set text-emphasis-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_emphasis_position(&mut self, v: longhands::text_emphasis_position::computed_value::T) {
                            self.text_emphasis_position = v;
                        }
                        /// Set text-emphasis-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_emphasis_position_from(&mut self, other: &Self) {
                            self.text_emphasis_position = other.text_emphasis_position.clone();
                        }
                    /// Reset text-emphasis-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_emphasis_position(&mut self, other: &Self) {
                        self.copy_text_emphasis_position_from(other)
                    }

                    /// Get the computed value for text-emphasis-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_emphasis_position(&self) -> longhands::text_emphasis_position::computed_value::T {
                        self.text_emphasis_position.clone()
                    }
                        /// Set text-emphasis-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_emphasis_color(&mut self, v: longhands::text_emphasis_color::computed_value::T) {
                            self.text_emphasis_color = v;
                        }
                        /// Set text-emphasis-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_emphasis_color_from(&mut self, other: &Self) {
                            self.text_emphasis_color = other.text_emphasis_color.clone();
                        }
                    /// Reset text-emphasis-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_emphasis_color(&mut self, other: &Self) {
                        self.copy_text_emphasis_color_from(other)
                    }

                    /// Get the computed value for text-emphasis-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_emphasis_color(&self) -> longhands::text_emphasis_color::computed_value::T {
                        self.text_emphasis_color.clone()
                    }
                        /// Set -moz-tab-size.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_tab_size(&mut self, v: longhands::_moz_tab_size::computed_value::T) {
                            self._moz_tab_size = v;
                        }
                        /// Set -moz-tab-size from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_tab_size_from(&mut self, other: &Self) {
                            self._moz_tab_size = other._moz_tab_size.clone();
                        }
                    /// Reset -moz-tab-size from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_tab_size(&mut self, other: &Self) {
                        self.copy__moz_tab_size_from(other)
                    }

                    /// Get the computed value for -moz-tab-size.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_tab_size(&self) -> longhands::_moz_tab_size::computed_value::T {
                        self._moz_tab_size.clone()
                    }
                        /// Set -webkit-text-fill-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__webkit_text_fill_color(&mut self, v: longhands::_webkit_text_fill_color::computed_value::T) {
                            self._webkit_text_fill_color = v;
                        }
                        /// Set -webkit-text-fill-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__webkit_text_fill_color_from(&mut self, other: &Self) {
                            self._webkit_text_fill_color = other._webkit_text_fill_color.clone();
                        }
                    /// Reset -webkit-text-fill-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__webkit_text_fill_color(&mut self, other: &Self) {
                        self.copy__webkit_text_fill_color_from(other)
                    }

                    /// Get the computed value for -webkit-text-fill-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__webkit_text_fill_color(&self) -> longhands::_webkit_text_fill_color::computed_value::T {
                        self._webkit_text_fill_color.clone()
                    }
                        /// Set -webkit-text-stroke-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__webkit_text_stroke_color(&mut self, v: longhands::_webkit_text_stroke_color::computed_value::T) {
                            self._webkit_text_stroke_color = v;
                        }
                        /// Set -webkit-text-stroke-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__webkit_text_stroke_color_from(&mut self, other: &Self) {
                            self._webkit_text_stroke_color = other._webkit_text_stroke_color.clone();
                        }
                    /// Reset -webkit-text-stroke-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__webkit_text_stroke_color(&mut self, other: &Self) {
                        self.copy__webkit_text_stroke_color_from(other)
                    }

                    /// Get the computed value for -webkit-text-stroke-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__webkit_text_stroke_color(&self) -> longhands::_webkit_text_stroke_color::computed_value::T {
                        self._webkit_text_stroke_color.clone()
                    }
                        /// Set -webkit-text-stroke-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__webkit_text_stroke_width(&mut self, v: longhands::_webkit_text_stroke_width::computed_value::T) {
                            self._webkit_text_stroke_width = v;
                        }
                        /// Set -webkit-text-stroke-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__webkit_text_stroke_width_from(&mut self, other: &Self) {
                            self._webkit_text_stroke_width = other._webkit_text_stroke_width.clone();
                        }
                    /// Reset -webkit-text-stroke-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__webkit_text_stroke_width(&mut self, other: &Self) {
                        self.copy__webkit_text_stroke_width_from(other)
                    }

                    /// Get the computed value for -webkit-text-stroke-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__webkit_text_stroke_width(&self) -> longhands::_webkit_text_stroke_width::computed_value::T {
                        self._webkit_text_stroke_width.clone()
                    }
                        /// Set ruby-align.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_ruby_align(&mut self, v: longhands::ruby_align::computed_value::T) {
                            self.ruby_align = v;
                        }
                        /// Set ruby-align from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_ruby_align_from(&mut self, other: &Self) {
                            self.ruby_align = other.ruby_align.clone();
                        }
                    /// Reset ruby-align from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_ruby_align(&mut self, other: &Self) {
                        self.copy_ruby_align_from(other)
                    }

                    /// Get the computed value for ruby-align.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_ruby_align(&self) -> longhands::ruby_align::computed_value::T {
                        self.ruby_align.clone()
                    }
                        /// Set ruby-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_ruby_position(&mut self, v: longhands::ruby_position::computed_value::T) {
                            self.ruby_position = v;
                        }
                        /// Set ruby-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_ruby_position_from(&mut self, other: &Self) {
                            self.ruby_position = other.ruby_position.clone();
                        }
                    /// Reset ruby-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_ruby_position(&mut self, other: &Self) {
                        self.copy_ruby_position_from(other)
                    }

                    /// Get the computed value for ruby-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_ruby_position(&self) -> longhands::ruby_position::computed_value::T {
                        self.ruby_position.clone()
                    }
                        /// Set text-combine-upright.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_combine_upright(&mut self, v: longhands::text_combine_upright::computed_value::T) {
                            self.text_combine_upright = v;
                        }
                        /// Set text-combine-upright from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_combine_upright_from(&mut self, other: &Self) {
                            self.text_combine_upright = other.text_combine_upright.clone();
                        }
                    /// Reset text-combine-upright from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_combine_upright(&mut self, other: &Self) {
                        self.copy_text_combine_upright_from(other)
                    }

                    /// Get the computed value for text-combine-upright.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_combine_upright(&self) -> longhands::text_combine_upright::computed_value::T {
                        self.text_combine_upright.clone()
                    }
                        /// Set text-rendering.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_rendering(&mut self, v: longhands::text_rendering::computed_value::T) {
                            self.text_rendering = v;
                        }
                        /// Set text-rendering from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_rendering_from(&mut self, other: &Self) {
                            self.text_rendering = other.text_rendering.clone();
                        }
                    /// Reset text-rendering from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_rendering(&mut self, other: &Self) {
                        self.copy_text_rendering_from(other)
                    }

                    /// Get the computed value for text-rendering.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_rendering(&self) -> longhands::text_rendering::computed_value::T {
                        self.text_rendering.clone()
                    }
                        /// Set -moz-control-character-visibility.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_control_character_visibility(&mut self, v: longhands::_moz_control_character_visibility::computed_value::T) {
                            self._moz_control_character_visibility = v;
                        }
                        /// Set -moz-control-character-visibility from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_control_character_visibility_from(&mut self, other: &Self) {
                            self._moz_control_character_visibility = other._moz_control_character_visibility.clone();
                        }
                    /// Reset -moz-control-character-visibility from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_control_character_visibility(&mut self, other: &Self) {
                        self.copy__moz_control_character_visibility_from(other)
                    }

                    /// Get the computed value for -moz-control-character-visibility.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_control_character_visibility(&self) -> longhands::_moz_control_character_visibility::computed_value::T {
                        self._moz_control_character_visibility.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The List style struct.
        pub struct List {
                /// The list-style-position computed value.
                pub list_style_position: longhands::list_style_position::computed_value::T,
                /// The list-style-type computed value.
                pub list_style_type: longhands::list_style_type::computed_value::T,
                /// The list-style-image computed value.
                pub list_style_image: longhands::list_style_image::computed_value::T,
                /// The quotes computed value.
                pub quotes: longhands::quotes::computed_value::T,
                /// The -moz-image-region computed value.
                pub _moz_image_region: longhands::_moz_image_region::computed_value::T,
        }

        impl List {
                        /// Set list-style-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_list_style_position(&mut self, v: longhands::list_style_position::computed_value::T) {
                            self.list_style_position = v;
                        }
                        /// Set list-style-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_list_style_position_from(&mut self, other: &Self) {
                            self.list_style_position = other.list_style_position.clone();
                        }
                    /// Reset list-style-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_list_style_position(&mut self, other: &Self) {
                        self.copy_list_style_position_from(other)
                    }

                    /// Get the computed value for list-style-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_list_style_position(&self) -> longhands::list_style_position::computed_value::T {
                        self.list_style_position.clone()
                    }
                        /// Set list-style-type.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_list_style_type(&mut self, v: longhands::list_style_type::computed_value::T) {
                            self.list_style_type = v;
                        }
                        /// Set list-style-type from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_list_style_type_from(&mut self, other: &Self) {
                            self.list_style_type = other.list_style_type.clone();
                        }
                    /// Reset list-style-type from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_list_style_type(&mut self, other: &Self) {
                        self.copy_list_style_type_from(other)
                    }

                    /// Get the computed value for list-style-type.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_list_style_type(&self) -> longhands::list_style_type::computed_value::T {
                        self.list_style_type.clone()
                    }
                        /// Set list-style-image.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_list_style_image(&mut self, v: longhands::list_style_image::computed_value::T) {
                            self.list_style_image = v;
                        }
                        /// Set list-style-image from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_list_style_image_from(&mut self, other: &Self) {
                            self.list_style_image = other.list_style_image.clone();
                        }
                    /// Reset list-style-image from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_list_style_image(&mut self, other: &Self) {
                        self.copy_list_style_image_from(other)
                    }

                    /// Get the computed value for list-style-image.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_list_style_image(&self) -> longhands::list_style_image::computed_value::T {
                        self.list_style_image.clone()
                    }
                        /// Set quotes.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_quotes(&mut self, v: longhands::quotes::computed_value::T) {
                            self.quotes = v;
                        }
                        /// Set quotes from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_quotes_from(&mut self, other: &Self) {
                            self.quotes = other.quotes.clone();
                        }
                    /// Reset quotes from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_quotes(&mut self, other: &Self) {
                        self.copy_quotes_from(other)
                    }

                    /// Get the computed value for quotes.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_quotes(&self) -> longhands::quotes::computed_value::T {
                        self.quotes.clone()
                    }
                        /// Set -moz-image-region.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_image_region(&mut self, v: longhands::_moz_image_region::computed_value::T) {
                            self._moz_image_region = v;
                        }
                        /// Set -moz-image-region from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_image_region_from(&mut self, other: &Self) {
                            self._moz_image_region = other._moz_image_region.clone();
                        }
                    /// Reset -moz-image-region from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_image_region(&mut self, other: &Self) {
                        self.copy__moz_image_region_from(other)
                    }

                    /// Get the computed value for -moz-image-region.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_image_region(&self) -> longhands::_moz_image_region::computed_value::T {
                        self._moz_image_region.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Margin style struct.
        pub struct Margin {
                /// The margin-top computed value.
                pub margin_top: longhands::margin_top::computed_value::T,
                /// The margin-left computed value.
                pub margin_left: longhands::margin_left::computed_value::T,
                /// The margin-bottom computed value.
                pub margin_bottom: longhands::margin_bottom::computed_value::T,
                /// The margin-right computed value.
                pub margin_right: longhands::margin_right::computed_value::T,
                /// The margin-block-start computed value.
                pub margin_block_start: longhands::margin_block_start::computed_value::T,
                /// The margin-block-end computed value.
                pub margin_block_end: longhands::margin_block_end::computed_value::T,
                /// The margin-inline-start computed value.
                pub margin_inline_start: longhands::margin_inline_start::computed_value::T,
                /// The margin-inline-end computed value.
                pub margin_inline_end: longhands::margin_inline_end::computed_value::T,
        }

        impl Margin {
                        /// Set margin-top.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_margin_top(&mut self, v: longhands::margin_top::computed_value::T) {
                            self.margin_top = v;
                        }
                        /// Set margin-top from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_margin_top_from(&mut self, other: &Self) {
                            self.margin_top = other.margin_top.clone();
                        }
                    /// Reset margin-top from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_margin_top(&mut self, other: &Self) {
                        self.copy_margin_top_from(other)
                    }

                    /// Get the computed value for margin-top.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_margin_top(&self) -> longhands::margin_top::computed_value::T {
                        self.margin_top.clone()
                    }
                        /// Set margin-left.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_margin_left(&mut self, v: longhands::margin_left::computed_value::T) {
                            self.margin_left = v;
                        }
                        /// Set margin-left from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_margin_left_from(&mut self, other: &Self) {
                            self.margin_left = other.margin_left.clone();
                        }
                    /// Reset margin-left from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_margin_left(&mut self, other: &Self) {
                        self.copy_margin_left_from(other)
                    }

                    /// Get the computed value for margin-left.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_margin_left(&self) -> longhands::margin_left::computed_value::T {
                        self.margin_left.clone()
                    }
                        /// Set margin-bottom.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_margin_bottom(&mut self, v: longhands::margin_bottom::computed_value::T) {
                            self.margin_bottom = v;
                        }
                        /// Set margin-bottom from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_margin_bottom_from(&mut self, other: &Self) {
                            self.margin_bottom = other.margin_bottom.clone();
                        }
                    /// Reset margin-bottom from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_margin_bottom(&mut self, other: &Self) {
                        self.copy_margin_bottom_from(other)
                    }

                    /// Get the computed value for margin-bottom.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_margin_bottom(&self) -> longhands::margin_bottom::computed_value::T {
                        self.margin_bottom.clone()
                    }
                        /// Set margin-right.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_margin_right(&mut self, v: longhands::margin_right::computed_value::T) {
                            self.margin_right = v;
                        }
                        /// Set margin-right from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_margin_right_from(&mut self, other: &Self) {
                            self.margin_right = other.margin_right.clone();
                        }
                    /// Reset margin-right from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_margin_right(&mut self, other: &Self) {
                        self.copy_margin_right_from(other)
                    }

                    /// Get the computed value for margin-right.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_margin_right(&self) -> longhands::margin_right::computed_value::T {
                        self.margin_right.clone()
                    }
                    
    /// Set the appropriate physical property for margin-block-start given a writing mode.
    pub fn set_margin_block_start(&mut self,
                                      v: longhands::margin_block_start::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_margin_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_margin_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_margin_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_margin_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-block-start
    /// given a writing mode.
    pub fn copy_margin_block_start_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_margin_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_margin_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_margin_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_margin_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-block-start
    /// given a writing mode.
    pub fn reset_margin_block_start(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_margin_block_start_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// margin-block-start given a writing mode.
    pub fn clone_margin_block_start(&self, wm: WritingMode)
        -> longhands::margin_block_start::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_margin_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_margin_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_margin_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_margin_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for margin-block-end given a writing mode.
    pub fn set_margin_block_end(&mut self,
                                      v: longhands::margin_block_end::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_margin_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_margin_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_margin_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_margin_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-block-end
    /// given a writing mode.
    pub fn copy_margin_block_end_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_margin_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_margin_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_margin_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_margin_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-block-end
    /// given a writing mode.
    pub fn reset_margin_block_end(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_margin_block_end_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// margin-block-end given a writing mode.
    pub fn clone_margin_block_end(&self, wm: WritingMode)
        -> longhands::margin_block_end::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_margin_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_margin_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_margin_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_margin_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for margin-inline-start given a writing mode.
    pub fn set_margin_inline_start(&mut self,
                                      v: longhands::margin_inline_start::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_margin_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_margin_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_margin_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_margin_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-inline-start
    /// given a writing mode.
    pub fn copy_margin_inline_start_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_margin_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_margin_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_margin_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_margin_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-inline-start
    /// given a writing mode.
    pub fn reset_margin_inline_start(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_margin_inline_start_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// margin-inline-start given a writing mode.
    pub fn clone_margin_inline_start(&self, wm: WritingMode)
        -> longhands::margin_inline_start::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_margin_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_margin_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_margin_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_margin_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for margin-inline-end given a writing mode.
    pub fn set_margin_inline_end(&mut self,
                                      v: longhands::margin_inline_end::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_margin_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_margin_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_margin_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_margin_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-inline-end
    /// given a writing mode.
    pub fn copy_margin_inline_end_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_margin_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_margin_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_margin_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_margin_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-inline-end
    /// given a writing mode.
    pub fn reset_margin_inline_end(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_margin_inline_end_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// margin-inline-end given a writing mode.
    pub fn clone_margin_inline_end(&self, wm: WritingMode)
        -> longhands::margin_inline_end::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_margin_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_margin_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_margin_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_margin_right()
        
                }
        }

    }

        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Outline style struct.
        pub struct Outline {
                /// The outline-color computed value.
                pub outline_color: longhands::outline_color::computed_value::T,
                /// The outline-style computed value.
                pub outline_style: longhands::outline_style::computed_value::T,
                /// The outline-width computed value.
                pub outline_width: longhands::outline_width::computed_value::T,
                /// The -moz-outline-radius-topleft computed value.
                pub _moz_outline_radius_topleft: longhands::_moz_outline_radius_topleft::computed_value::T,
                /// The -moz-outline-radius-topright computed value.
                pub _moz_outline_radius_topright: longhands::_moz_outline_radius_topright::computed_value::T,
                /// The -moz-outline-radius-bottomright computed value.
                pub _moz_outline_radius_bottomright: longhands::_moz_outline_radius_bottomright::computed_value::T,
                /// The -moz-outline-radius-bottomleft computed value.
                pub _moz_outline_radius_bottomleft: longhands::_moz_outline_radius_bottomleft::computed_value::T,
                /// The outline-offset computed value.
                pub outline_offset: longhands::outline_offset::computed_value::T,
        }

        impl Outline {
                        /// Set outline-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_outline_color(&mut self, v: longhands::outline_color::computed_value::T) {
                            self.outline_color = v;
                        }
                        /// Set outline-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_outline_color_from(&mut self, other: &Self) {
                            self.outline_color = other.outline_color.clone();
                        }
                    /// Reset outline-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_outline_color(&mut self, other: &Self) {
                        self.copy_outline_color_from(other)
                    }

                    /// Get the computed value for outline-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_outline_color(&self) -> longhands::outline_color::computed_value::T {
                        self.outline_color.clone()
                    }
                        /// Set outline-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_outline_style(&mut self, v: longhands::outline_style::computed_value::T) {
                            self.outline_style = v;
                        }
                        /// Set outline-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_outline_style_from(&mut self, other: &Self) {
                            self.outline_style = other.outline_style.clone();
                        }
                    /// Reset outline-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_outline_style(&mut self, other: &Self) {
                        self.copy_outline_style_from(other)
                    }

                    /// Get the computed value for outline-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_outline_style(&self) -> longhands::outline_style::computed_value::T {
                        self.outline_style.clone()
                    }
                        /// Set outline-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_outline_width(&mut self, v: longhands::outline_width::computed_value::T) {
                            self.outline_width = v;
                        }
                        /// Set outline-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_outline_width_from(&mut self, other: &Self) {
                            self.outline_width = other.outline_width.clone();
                        }
                    /// Reset outline-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_outline_width(&mut self, other: &Self) {
                        self.copy_outline_width_from(other)
                    }

                    /// Get the computed value for outline-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_outline_width(&self) -> longhands::outline_width::computed_value::T {
                        self.outline_width.clone()
                    }
                        /// Set -moz-outline-radius-topleft.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_outline_radius_topleft(&mut self, v: longhands::_moz_outline_radius_topleft::computed_value::T) {
                            self._moz_outline_radius_topleft = v;
                        }
                        /// Set -moz-outline-radius-topleft from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_outline_radius_topleft_from(&mut self, other: &Self) {
                            self._moz_outline_radius_topleft = other._moz_outline_radius_topleft.clone();
                        }
                    /// Reset -moz-outline-radius-topleft from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_outline_radius_topleft(&mut self, other: &Self) {
                        self.copy__moz_outline_radius_topleft_from(other)
                    }

                    /// Get the computed value for -moz-outline-radius-topleft.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_outline_radius_topleft(&self) -> longhands::_moz_outline_radius_topleft::computed_value::T {
                        self._moz_outline_radius_topleft.clone()
                    }
                        /// Set -moz-outline-radius-topright.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_outline_radius_topright(&mut self, v: longhands::_moz_outline_radius_topright::computed_value::T) {
                            self._moz_outline_radius_topright = v;
                        }
                        /// Set -moz-outline-radius-topright from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_outline_radius_topright_from(&mut self, other: &Self) {
                            self._moz_outline_radius_topright = other._moz_outline_radius_topright.clone();
                        }
                    /// Reset -moz-outline-radius-topright from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_outline_radius_topright(&mut self, other: &Self) {
                        self.copy__moz_outline_radius_topright_from(other)
                    }

                    /// Get the computed value for -moz-outline-radius-topright.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_outline_radius_topright(&self) -> longhands::_moz_outline_radius_topright::computed_value::T {
                        self._moz_outline_radius_topright.clone()
                    }
                        /// Set -moz-outline-radius-bottomright.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_outline_radius_bottomright(&mut self, v: longhands::_moz_outline_radius_bottomright::computed_value::T) {
                            self._moz_outline_radius_bottomright = v;
                        }
                        /// Set -moz-outline-radius-bottomright from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_outline_radius_bottomright_from(&mut self, other: &Self) {
                            self._moz_outline_radius_bottomright = other._moz_outline_radius_bottomright.clone();
                        }
                    /// Reset -moz-outline-radius-bottomright from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_outline_radius_bottomright(&mut self, other: &Self) {
                        self.copy__moz_outline_radius_bottomright_from(other)
                    }

                    /// Get the computed value for -moz-outline-radius-bottomright.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_outline_radius_bottomright(&self) -> longhands::_moz_outline_radius_bottomright::computed_value::T {
                        self._moz_outline_radius_bottomright.clone()
                    }
                        /// Set -moz-outline-radius-bottomleft.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_outline_radius_bottomleft(&mut self, v: longhands::_moz_outline_radius_bottomleft::computed_value::T) {
                            self._moz_outline_radius_bottomleft = v;
                        }
                        /// Set -moz-outline-radius-bottomleft from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_outline_radius_bottomleft_from(&mut self, other: &Self) {
                            self._moz_outline_radius_bottomleft = other._moz_outline_radius_bottomleft.clone();
                        }
                    /// Reset -moz-outline-radius-bottomleft from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_outline_radius_bottomleft(&mut self, other: &Self) {
                        self.copy__moz_outline_radius_bottomleft_from(other)
                    }

                    /// Get the computed value for -moz-outline-radius-bottomleft.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_outline_radius_bottomleft(&self) -> longhands::_moz_outline_radius_bottomleft::computed_value::T {
                        self._moz_outline_radius_bottomleft.clone()
                    }
                        /// Set outline-offset.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_outline_offset(&mut self, v: longhands::outline_offset::computed_value::T) {
                            self.outline_offset = v;
                        }
                        /// Set outline-offset from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_outline_offset_from(&mut self, other: &Self) {
                            self.outline_offset = other.outline_offset.clone();
                        }
                    /// Reset outline-offset from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_outline_offset(&mut self, other: &Self) {
                        self.copy_outline_offset_from(other)
                    }

                    /// Get the computed value for outline-offset.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_outline_offset(&self) -> longhands::outline_offset::computed_value::T {
                        self.outline_offset.clone()
                    }
                /// Whether the outline-width property is non-zero.
                #[inline]
                pub fn outline_has_nonzero_width(&self) -> bool {
                    self.outline_width != NonNegativeLength::zero()
                }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Padding style struct.
        pub struct Padding {
                /// The padding-top computed value.
                pub padding_top: longhands::padding_top::computed_value::T,
                /// The padding-left computed value.
                pub padding_left: longhands::padding_left::computed_value::T,
                /// The padding-bottom computed value.
                pub padding_bottom: longhands::padding_bottom::computed_value::T,
                /// The padding-right computed value.
                pub padding_right: longhands::padding_right::computed_value::T,
                /// The padding-block-start computed value.
                pub padding_block_start: longhands::padding_block_start::computed_value::T,
                /// The padding-block-end computed value.
                pub padding_block_end: longhands::padding_block_end::computed_value::T,
                /// The padding-inline-start computed value.
                pub padding_inline_start: longhands::padding_inline_start::computed_value::T,
                /// The padding-inline-end computed value.
                pub padding_inline_end: longhands::padding_inline_end::computed_value::T,
        }

        impl Padding {
                        /// Set padding-top.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_padding_top(&mut self, v: longhands::padding_top::computed_value::T) {
                            self.padding_top = v;
                        }
                        /// Set padding-top from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_padding_top_from(&mut self, other: &Self) {
                            self.padding_top = other.padding_top.clone();
                        }
                    /// Reset padding-top from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_padding_top(&mut self, other: &Self) {
                        self.copy_padding_top_from(other)
                    }

                    /// Get the computed value for padding-top.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_padding_top(&self) -> longhands::padding_top::computed_value::T {
                        self.padding_top.clone()
                    }
                        /// Set padding-left.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_padding_left(&mut self, v: longhands::padding_left::computed_value::T) {
                            self.padding_left = v;
                        }
                        /// Set padding-left from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_padding_left_from(&mut self, other: &Self) {
                            self.padding_left = other.padding_left.clone();
                        }
                    /// Reset padding-left from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_padding_left(&mut self, other: &Self) {
                        self.copy_padding_left_from(other)
                    }

                    /// Get the computed value for padding-left.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_padding_left(&self) -> longhands::padding_left::computed_value::T {
                        self.padding_left.clone()
                    }
                        /// Set padding-bottom.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_padding_bottom(&mut self, v: longhands::padding_bottom::computed_value::T) {
                            self.padding_bottom = v;
                        }
                        /// Set padding-bottom from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_padding_bottom_from(&mut self, other: &Self) {
                            self.padding_bottom = other.padding_bottom.clone();
                        }
                    /// Reset padding-bottom from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_padding_bottom(&mut self, other: &Self) {
                        self.copy_padding_bottom_from(other)
                    }

                    /// Get the computed value for padding-bottom.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_padding_bottom(&self) -> longhands::padding_bottom::computed_value::T {
                        self.padding_bottom.clone()
                    }
                        /// Set padding-right.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_padding_right(&mut self, v: longhands::padding_right::computed_value::T) {
                            self.padding_right = v;
                        }
                        /// Set padding-right from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_padding_right_from(&mut self, other: &Self) {
                            self.padding_right = other.padding_right.clone();
                        }
                    /// Reset padding-right from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_padding_right(&mut self, other: &Self) {
                        self.copy_padding_right_from(other)
                    }

                    /// Get the computed value for padding-right.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_padding_right(&self) -> longhands::padding_right::computed_value::T {
                        self.padding_right.clone()
                    }
                    
    /// Set the appropriate physical property for padding-block-start given a writing mode.
    pub fn set_padding_block_start(&mut self,
                                      v: longhands::padding_block_start::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_padding_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_padding_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_padding_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_padding_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-block-start
    /// given a writing mode.
    pub fn copy_padding_block_start_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_padding_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_padding_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_padding_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_padding_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-block-start
    /// given a writing mode.
    pub fn reset_padding_block_start(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_padding_block_start_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// padding-block-start given a writing mode.
    pub fn clone_padding_block_start(&self, wm: WritingMode)
        -> longhands::padding_block_start::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_padding_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_padding_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_padding_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_padding_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for padding-block-end given a writing mode.
    pub fn set_padding_block_end(&mut self,
                                      v: longhands::padding_block_end::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_padding_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_padding_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_padding_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_padding_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-block-end
    /// given a writing mode.
    pub fn copy_padding_block_end_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_padding_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_padding_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_padding_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_padding_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-block-end
    /// given a writing mode.
    pub fn reset_padding_block_end(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_padding_block_end_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// padding-block-end given a writing mode.
    pub fn clone_padding_block_end(&self, wm: WritingMode)
        -> longhands::padding_block_end::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_padding_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_padding_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_padding_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_padding_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for padding-inline-start given a writing mode.
    pub fn set_padding_inline_start(&mut self,
                                      v: longhands::padding_inline_start::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_padding_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_padding_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_padding_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_padding_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-inline-start
    /// given a writing mode.
    pub fn copy_padding_inline_start_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_padding_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_padding_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_padding_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_padding_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-inline-start
    /// given a writing mode.
    pub fn reset_padding_inline_start(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_padding_inline_start_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// padding-inline-start given a writing mode.
    pub fn clone_padding_inline_start(&self, wm: WritingMode)
        -> longhands::padding_inline_start::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_padding_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_padding_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_padding_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_padding_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for padding-inline-end given a writing mode.
    pub fn set_padding_inline_end(&mut self,
                                      v: longhands::padding_inline_end::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_padding_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_padding_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_padding_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_padding_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-inline-end
    /// given a writing mode.
    pub fn copy_padding_inline_end_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_padding_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_padding_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_padding_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_padding_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-inline-end
    /// given a writing mode.
    pub fn reset_padding_inline_end(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_padding_inline_end_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// padding-inline-end given a writing mode.
    pub fn clone_padding_inline_end(&self, wm: WritingMode)
        -> longhands::padding_inline_end::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_padding_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_padding_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_padding_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_padding_right()
        
                }
        }

    }

        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Pointing style struct.
        pub struct Pointing {
                /// The cursor computed value.
                pub cursor: longhands::cursor::computed_value::T,
                /// The pointer-events computed value.
                pub pointer_events: longhands::pointer_events::computed_value::T,
                /// The -moz-user-input computed value.
                pub _moz_user_input: longhands::_moz_user_input::computed_value::T,
                /// The -moz-user-modify computed value.
                pub _moz_user_modify: longhands::_moz_user_modify::computed_value::T,
                /// The -moz-user-focus computed value.
                pub _moz_user_focus: longhands::_moz_user_focus::computed_value::T,
                /// The caret-color computed value.
                pub caret_color: longhands::caret_color::computed_value::T,
        }

        impl Pointing {
                        /// Set cursor.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_cursor(&mut self, v: longhands::cursor::computed_value::T) {
                            self.cursor = v;
                        }
                        /// Set cursor from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_cursor_from(&mut self, other: &Self) {
                            self.cursor = other.cursor.clone();
                        }
                    /// Reset cursor from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_cursor(&mut self, other: &Self) {
                        self.copy_cursor_from(other)
                    }

                    /// Get the computed value for cursor.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_cursor(&self) -> longhands::cursor::computed_value::T {
                        self.cursor.clone()
                    }
                        /// Set pointer-events.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_pointer_events(&mut self, v: longhands::pointer_events::computed_value::T) {
                            self.pointer_events = v;
                        }
                        /// Set pointer-events from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_pointer_events_from(&mut self, other: &Self) {
                            self.pointer_events = other.pointer_events.clone();
                        }
                    /// Reset pointer-events from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_pointer_events(&mut self, other: &Self) {
                        self.copy_pointer_events_from(other)
                    }

                    /// Get the computed value for pointer-events.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_pointer_events(&self) -> longhands::pointer_events::computed_value::T {
                        self.pointer_events.clone()
                    }
                        /// Set -moz-user-input.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_user_input(&mut self, v: longhands::_moz_user_input::computed_value::T) {
                            self._moz_user_input = v;
                        }
                        /// Set -moz-user-input from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_user_input_from(&mut self, other: &Self) {
                            self._moz_user_input = other._moz_user_input.clone();
                        }
                    /// Reset -moz-user-input from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_user_input(&mut self, other: &Self) {
                        self.copy__moz_user_input_from(other)
                    }

                    /// Get the computed value for -moz-user-input.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_user_input(&self) -> longhands::_moz_user_input::computed_value::T {
                        self._moz_user_input.clone()
                    }
                        /// Set -moz-user-modify.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_user_modify(&mut self, v: longhands::_moz_user_modify::computed_value::T) {
                            self._moz_user_modify = v;
                        }
                        /// Set -moz-user-modify from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_user_modify_from(&mut self, other: &Self) {
                            self._moz_user_modify = other._moz_user_modify.clone();
                        }
                    /// Reset -moz-user-modify from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_user_modify(&mut self, other: &Self) {
                        self.copy__moz_user_modify_from(other)
                    }

                    /// Get the computed value for -moz-user-modify.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_user_modify(&self) -> longhands::_moz_user_modify::computed_value::T {
                        self._moz_user_modify.clone()
                    }
                        /// Set -moz-user-focus.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_user_focus(&mut self, v: longhands::_moz_user_focus::computed_value::T) {
                            self._moz_user_focus = v;
                        }
                        /// Set -moz-user-focus from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_user_focus_from(&mut self, other: &Self) {
                            self._moz_user_focus = other._moz_user_focus.clone();
                        }
                    /// Reset -moz-user-focus from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_user_focus(&mut self, other: &Self) {
                        self.copy__moz_user_focus_from(other)
                    }

                    /// Get the computed value for -moz-user-focus.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_user_focus(&self) -> longhands::_moz_user_focus::computed_value::T {
                        self._moz_user_focus.clone()
                    }
                        /// Set caret-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_caret_color(&mut self, v: longhands::caret_color::computed_value::T) {
                            self.caret_color = v;
                        }
                        /// Set caret-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_caret_color_from(&mut self, other: &Self) {
                            self.caret_color = other.caret_color.clone();
                        }
                    /// Reset caret-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_caret_color(&mut self, other: &Self) {
                        self.copy_caret_color_from(other)
                    }

                    /// Get the computed value for caret-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_caret_color(&self) -> longhands::caret_color::computed_value::T {
                        self.caret_color.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Position style struct.
        pub struct Position {
                /// The top computed value.
                pub top: longhands::top::computed_value::T,
                /// The left computed value.
                pub left: longhands::left::computed_value::T,
                /// The bottom computed value.
                pub bottom: longhands::bottom::computed_value::T,
                /// The right computed value.
                pub right: longhands::right::computed_value::T,
                /// The offset-block-start computed value.
                pub offset_block_start: longhands::offset_block_start::computed_value::T,
                /// The offset-block-end computed value.
                pub offset_block_end: longhands::offset_block_end::computed_value::T,
                /// The offset-inline-start computed value.
                pub offset_inline_start: longhands::offset_inline_start::computed_value::T,
                /// The offset-inline-end computed value.
                pub offset_inline_end: longhands::offset_inline_end::computed_value::T,
                /// The z-index computed value.
                pub z_index: longhands::z_index::computed_value::T,
                /// The flex-direction computed value.
                pub flex_direction: longhands::flex_direction::computed_value::T,
                /// The flex-wrap computed value.
                pub flex_wrap: longhands::flex_wrap::computed_value::T,
                /// The justify-content computed value.
                pub justify_content: longhands::justify_content::computed_value::T,
                /// The align-content computed value.
                pub align_content: longhands::align_content::computed_value::T,
                /// The align-items computed value.
                pub align_items: longhands::align_items::computed_value::T,
                /// The justify-items computed value.
                pub justify_items: longhands::justify_items::computed_value::T,
                /// The flex-grow computed value.
                pub flex_grow: longhands::flex_grow::computed_value::T,
                /// The flex-shrink computed value.
                pub flex_shrink: longhands::flex_shrink::computed_value::T,
                /// The align-self computed value.
                pub align_self: longhands::align_self::computed_value::T,
                /// The justify-self computed value.
                pub justify_self: longhands::justify_self::computed_value::T,
                /// The order computed value.
                pub order: longhands::order::computed_value::T,
                /// The flex-basis computed value.
                pub flex_basis: longhands::flex_basis::computed_value::T,
                /// The width computed value.
                pub width: longhands::width::computed_value::T,
                /// The min-width computed value.
                pub min_width: longhands::min_width::computed_value::T,
                /// The max-width computed value.
                pub max_width: longhands::max_width::computed_value::T,
                /// The height computed value.
                pub height: longhands::height::computed_value::T,
                /// The min-height computed value.
                pub min_height: longhands::min_height::computed_value::T,
                /// The max-height computed value.
                pub max_height: longhands::max_height::computed_value::T,
                /// The block-size computed value.
                pub block_size: longhands::block_size::computed_value::T,
                /// The min-block-size computed value.
                pub min_block_size: longhands::min_block_size::computed_value::T,
                /// The max-block-size computed value.
                pub max_block_size: longhands::max_block_size::computed_value::T,
                /// The inline-size computed value.
                pub inline_size: longhands::inline_size::computed_value::T,
                /// The min-inline-size computed value.
                pub min_inline_size: longhands::min_inline_size::computed_value::T,
                /// The max-inline-size computed value.
                pub max_inline_size: longhands::max_inline_size::computed_value::T,
                /// The box-sizing computed value.
                pub box_sizing: longhands::box_sizing::computed_value::T,
                /// The object-fit computed value.
                pub object_fit: longhands::object_fit::computed_value::T,
                /// The object-position computed value.
                pub object_position: longhands::object_position::computed_value::T,
                /// The grid-row-gap computed value.
                pub grid_row_gap: longhands::grid_row_gap::computed_value::T,
                /// The grid-row-start computed value.
                pub grid_row_start: longhands::grid_row_start::computed_value::T,
                /// The grid-row-end computed value.
                pub grid_row_end: longhands::grid_row_end::computed_value::T,
                /// The grid-auto-rows computed value.
                pub grid_auto_rows: longhands::grid_auto_rows::computed_value::T,
                /// The grid-template-rows computed value.
                pub grid_template_rows: longhands::grid_template_rows::computed_value::T,
                /// The grid-column-gap computed value.
                pub grid_column_gap: longhands::grid_column_gap::computed_value::T,
                /// The grid-column-start computed value.
                pub grid_column_start: longhands::grid_column_start::computed_value::T,
                /// The grid-column-end computed value.
                pub grid_column_end: longhands::grid_column_end::computed_value::T,
                /// The grid-auto-columns computed value.
                pub grid_auto_columns: longhands::grid_auto_columns::computed_value::T,
                /// The grid-template-columns computed value.
                pub grid_template_columns: longhands::grid_template_columns::computed_value::T,
                /// The grid-auto-flow computed value.
                pub grid_auto_flow: longhands::grid_auto_flow::computed_value::T,
                /// The grid-template-areas computed value.
                pub grid_template_areas: longhands::grid_template_areas::computed_value::T,
        }

        impl Position {
                        /// Set top.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_top(&mut self, v: longhands::top::computed_value::T) {
                            self.top = v;
                        }
                        /// Set top from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_top_from(&mut self, other: &Self) {
                            self.top = other.top.clone();
                        }
                    /// Reset top from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_top(&mut self, other: &Self) {
                        self.copy_top_from(other)
                    }

                    /// Get the computed value for top.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_top(&self) -> longhands::top::computed_value::T {
                        self.top.clone()
                    }
                        /// Set left.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_left(&mut self, v: longhands::left::computed_value::T) {
                            self.left = v;
                        }
                        /// Set left from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_left_from(&mut self, other: &Self) {
                            self.left = other.left.clone();
                        }
                    /// Reset left from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_left(&mut self, other: &Self) {
                        self.copy_left_from(other)
                    }

                    /// Get the computed value for left.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_left(&self) -> longhands::left::computed_value::T {
                        self.left.clone()
                    }
                        /// Set bottom.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_bottom(&mut self, v: longhands::bottom::computed_value::T) {
                            self.bottom = v;
                        }
                        /// Set bottom from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_bottom_from(&mut self, other: &Self) {
                            self.bottom = other.bottom.clone();
                        }
                    /// Reset bottom from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_bottom(&mut self, other: &Self) {
                        self.copy_bottom_from(other)
                    }

                    /// Get the computed value for bottom.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_bottom(&self) -> longhands::bottom::computed_value::T {
                        self.bottom.clone()
                    }
                        /// Set right.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_right(&mut self, v: longhands::right::computed_value::T) {
                            self.right = v;
                        }
                        /// Set right from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_right_from(&mut self, other: &Self) {
                            self.right = other.right.clone();
                        }
                    /// Reset right from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_right(&mut self, other: &Self) {
                        self.copy_right_from(other)
                    }

                    /// Get the computed value for right.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_right(&self) -> longhands::right::computed_value::T {
                        self.right.clone()
                    }
                    
    /// Set the appropriate physical property for offset-block-start given a writing mode.
    pub fn set_offset_block_start(&mut self,
                                      v: longhands::offset_block_start::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-block-start
    /// given a writing mode.
    pub fn copy_offset_block_start_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-block-start
    /// given a writing mode.
    pub fn reset_offset_block_start(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_offset_block_start_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// offset-block-start given a writing mode.
    pub fn clone_offset_block_start(&self, wm: WritingMode)
        -> longhands::offset_block_start::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for offset-block-end given a writing mode.
    pub fn set_offset_block_end(&mut self,
                                      v: longhands::offset_block_end::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-block-end
    /// given a writing mode.
    pub fn copy_offset_block_end_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-block-end
    /// given a writing mode.
    pub fn reset_offset_block_end(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_offset_block_end_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// offset-block-end given a writing mode.
    pub fn clone_offset_block_end(&self, wm: WritingMode)
        -> longhands::offset_block_end::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for offset-inline-start given a writing mode.
    pub fn set_offset_inline_start(&mut self,
                                      v: longhands::offset_inline_start::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-inline-start
    /// given a writing mode.
    pub fn copy_offset_inline_start_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-inline-start
    /// given a writing mode.
    pub fn reset_offset_inline_start(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_offset_inline_start_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// offset-inline-start given a writing mode.
    pub fn clone_offset_inline_start(&self, wm: WritingMode)
        -> longhands::offset_inline_start::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for offset-inline-end given a writing mode.
    pub fn set_offset_inline_end(&mut self,
                                      v: longhands::offset_inline_end::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-inline-end
    /// given a writing mode.
    pub fn copy_offset_inline_end_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-inline-end
    /// given a writing mode.
    pub fn reset_offset_inline_end(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_offset_inline_end_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// offset-inline-end given a writing mode.
    pub fn clone_offset_inline_end(&self, wm: WritingMode)
        -> longhands::offset_inline_end::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_right()
        
                }
        }

    }

                        /// Set z-index.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_z_index(&mut self, v: longhands::z_index::computed_value::T) {
                            self.z_index = v;
                        }
                        /// Set z-index from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_z_index_from(&mut self, other: &Self) {
                            self.z_index = other.z_index.clone();
                        }
                    /// Reset z-index from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_z_index(&mut self, other: &Self) {
                        self.copy_z_index_from(other)
                    }

                    /// Get the computed value for z-index.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_z_index(&self) -> longhands::z_index::computed_value::T {
                        self.z_index.clone()
                    }
                        /// Set flex-direction.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flex_direction(&mut self, v: longhands::flex_direction::computed_value::T) {
                            self.flex_direction = v;
                        }
                        /// Set flex-direction from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flex_direction_from(&mut self, other: &Self) {
                            self.flex_direction = other.flex_direction.clone();
                        }
                    /// Reset flex-direction from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flex_direction(&mut self, other: &Self) {
                        self.copy_flex_direction_from(other)
                    }

                    /// Get the computed value for flex-direction.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flex_direction(&self) -> longhands::flex_direction::computed_value::T {
                        self.flex_direction.clone()
                    }
                        /// Set flex-wrap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flex_wrap(&mut self, v: longhands::flex_wrap::computed_value::T) {
                            self.flex_wrap = v;
                        }
                        /// Set flex-wrap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flex_wrap_from(&mut self, other: &Self) {
                            self.flex_wrap = other.flex_wrap.clone();
                        }
                    /// Reset flex-wrap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flex_wrap(&mut self, other: &Self) {
                        self.copy_flex_wrap_from(other)
                    }

                    /// Get the computed value for flex-wrap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flex_wrap(&self) -> longhands::flex_wrap::computed_value::T {
                        self.flex_wrap.clone()
                    }
                        /// Set justify-content.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_justify_content(&mut self, v: longhands::justify_content::computed_value::T) {
                            self.justify_content = v;
                        }
                        /// Set justify-content from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_justify_content_from(&mut self, other: &Self) {
                            self.justify_content = other.justify_content.clone();
                        }
                    /// Reset justify-content from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_justify_content(&mut self, other: &Self) {
                        self.copy_justify_content_from(other)
                    }

                    /// Get the computed value for justify-content.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_justify_content(&self) -> longhands::justify_content::computed_value::T {
                        self.justify_content.clone()
                    }
                        /// Set align-content.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_align_content(&mut self, v: longhands::align_content::computed_value::T) {
                            self.align_content = v;
                        }
                        /// Set align-content from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_align_content_from(&mut self, other: &Self) {
                            self.align_content = other.align_content.clone();
                        }
                    /// Reset align-content from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_align_content(&mut self, other: &Self) {
                        self.copy_align_content_from(other)
                    }

                    /// Get the computed value for align-content.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_align_content(&self) -> longhands::align_content::computed_value::T {
                        self.align_content.clone()
                    }
                        /// Set align-items.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_align_items(&mut self, v: longhands::align_items::computed_value::T) {
                            self.align_items = v;
                        }
                        /// Set align-items from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_align_items_from(&mut self, other: &Self) {
                            self.align_items = other.align_items.clone();
                        }
                    /// Reset align-items from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_align_items(&mut self, other: &Self) {
                        self.copy_align_items_from(other)
                    }

                    /// Get the computed value for align-items.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_align_items(&self) -> longhands::align_items::computed_value::T {
                        self.align_items.clone()
                    }
                        /// Set justify-items.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_justify_items(&mut self, v: longhands::justify_items::computed_value::T) {
                            self.justify_items = v;
                        }
                        /// Set justify-items from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_justify_items_from(&mut self, other: &Self) {
                            self.justify_items = other.justify_items.clone();
                        }
                    /// Reset justify-items from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_justify_items(&mut self, other: &Self) {
                        self.copy_justify_items_from(other)
                    }

                    /// Get the computed value for justify-items.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_justify_items(&self) -> longhands::justify_items::computed_value::T {
                        self.justify_items.clone()
                    }
                        /// Set flex-grow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flex_grow(&mut self, v: longhands::flex_grow::computed_value::T) {
                            self.flex_grow = v;
                        }
                        /// Set flex-grow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flex_grow_from(&mut self, other: &Self) {
                            self.flex_grow = other.flex_grow.clone();
                        }
                    /// Reset flex-grow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flex_grow(&mut self, other: &Self) {
                        self.copy_flex_grow_from(other)
                    }

                    /// Get the computed value for flex-grow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flex_grow(&self) -> longhands::flex_grow::computed_value::T {
                        self.flex_grow.clone()
                    }
                        /// Set flex-shrink.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flex_shrink(&mut self, v: longhands::flex_shrink::computed_value::T) {
                            self.flex_shrink = v;
                        }
                        /// Set flex-shrink from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flex_shrink_from(&mut self, other: &Self) {
                            self.flex_shrink = other.flex_shrink.clone();
                        }
                    /// Reset flex-shrink from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flex_shrink(&mut self, other: &Self) {
                        self.copy_flex_shrink_from(other)
                    }

                    /// Get the computed value for flex-shrink.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flex_shrink(&self) -> longhands::flex_shrink::computed_value::T {
                        self.flex_shrink.clone()
                    }
                        /// Set align-self.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_align_self(&mut self, v: longhands::align_self::computed_value::T) {
                            self.align_self = v;
                        }
                        /// Set align-self from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_align_self_from(&mut self, other: &Self) {
                            self.align_self = other.align_self.clone();
                        }
                    /// Reset align-self from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_align_self(&mut self, other: &Self) {
                        self.copy_align_self_from(other)
                    }

                    /// Get the computed value for align-self.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_align_self(&self) -> longhands::align_self::computed_value::T {
                        self.align_self.clone()
                    }
                        /// Set justify-self.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_justify_self(&mut self, v: longhands::justify_self::computed_value::T) {
                            self.justify_self = v;
                        }
                        /// Set justify-self from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_justify_self_from(&mut self, other: &Self) {
                            self.justify_self = other.justify_self.clone();
                        }
                    /// Reset justify-self from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_justify_self(&mut self, other: &Self) {
                        self.copy_justify_self_from(other)
                    }

                    /// Get the computed value for justify-self.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_justify_self(&self) -> longhands::justify_self::computed_value::T {
                        self.justify_self.clone()
                    }
                        /// Set order.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_order(&mut self, v: longhands::order::computed_value::T) {
                            self.order = v;
                        }
                        /// Set order from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_order_from(&mut self, other: &Self) {
                            self.order = other.order.clone();
                        }
                    /// Reset order from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_order(&mut self, other: &Self) {
                        self.copy_order_from(other)
                    }

                    /// Get the computed value for order.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_order(&self) -> longhands::order::computed_value::T {
                        self.order.clone()
                    }
                        /// Set flex-basis.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flex_basis(&mut self, v: longhands::flex_basis::computed_value::T) {
                            self.flex_basis = v;
                        }
                        /// Set flex-basis from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flex_basis_from(&mut self, other: &Self) {
                            self.flex_basis = other.flex_basis.clone();
                        }
                    /// Reset flex-basis from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flex_basis(&mut self, other: &Self) {
                        self.copy_flex_basis_from(other)
                    }

                    /// Get the computed value for flex-basis.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flex_basis(&self) -> longhands::flex_basis::computed_value::T {
                        self.flex_basis.clone()
                    }
                        /// Set width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_width(&mut self, v: longhands::width::computed_value::T) {
                            self.width = v;
                        }
                        /// Set width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_width_from(&mut self, other: &Self) {
                            self.width = other.width.clone();
                        }
                    /// Reset width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_width(&mut self, other: &Self) {
                        self.copy_width_from(other)
                    }

                    /// Get the computed value for width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_width(&self) -> longhands::width::computed_value::T {
                        self.width.clone()
                    }
                        /// Set min-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_min_width(&mut self, v: longhands::min_width::computed_value::T) {
                            self.min_width = v;
                        }
                        /// Set min-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_min_width_from(&mut self, other: &Self) {
                            self.min_width = other.min_width.clone();
                        }
                    /// Reset min-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_min_width(&mut self, other: &Self) {
                        self.copy_min_width_from(other)
                    }

                    /// Get the computed value for min-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_min_width(&self) -> longhands::min_width::computed_value::T {
                        self.min_width.clone()
                    }
                        /// Set max-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_max_width(&mut self, v: longhands::max_width::computed_value::T) {
                            self.max_width = v;
                        }
                        /// Set max-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_max_width_from(&mut self, other: &Self) {
                            self.max_width = other.max_width.clone();
                        }
                    /// Reset max-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_max_width(&mut self, other: &Self) {
                        self.copy_max_width_from(other)
                    }

                    /// Get the computed value for max-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_max_width(&self) -> longhands::max_width::computed_value::T {
                        self.max_width.clone()
                    }
                        /// Set height.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_height(&mut self, v: longhands::height::computed_value::T) {
                            self.height = v;
                        }
                        /// Set height from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_height_from(&mut self, other: &Self) {
                            self.height = other.height.clone();
                        }
                    /// Reset height from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_height(&mut self, other: &Self) {
                        self.copy_height_from(other)
                    }

                    /// Get the computed value for height.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_height(&self) -> longhands::height::computed_value::T {
                        self.height.clone()
                    }
                        /// Set min-height.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_min_height(&mut self, v: longhands::min_height::computed_value::T) {
                            self.min_height = v;
                        }
                        /// Set min-height from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_min_height_from(&mut self, other: &Self) {
                            self.min_height = other.min_height.clone();
                        }
                    /// Reset min-height from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_min_height(&mut self, other: &Self) {
                        self.copy_min_height_from(other)
                    }

                    /// Get the computed value for min-height.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_min_height(&self) -> longhands::min_height::computed_value::T {
                        self.min_height.clone()
                    }
                        /// Set max-height.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_max_height(&mut self, v: longhands::max_height::computed_value::T) {
                            self.max_height = v;
                        }
                        /// Set max-height from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_max_height_from(&mut self, other: &Self) {
                            self.max_height = other.max_height.clone();
                        }
                    /// Reset max-height from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_max_height(&mut self, other: &Self) {
                        self.copy_max_height_from(other)
                    }

                    /// Get the computed value for max-height.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_max_height(&self) -> longhands::max_height::computed_value::T {
                        self.max_height.clone()
                    }
                    
    /// Set the appropriate physical property for block-size given a writing mode.
    pub fn set_block_size(&mut self,
                                      v: longhands::block_size::computed_value::T,
                                      wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.set_width(v)
            
        } else {
            
                self.set_height(v)
            
        }

    }

    /// Copy the appropriate physical property from another struct for block-size
    /// given a writing mode.
    pub fn copy_block_size_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.copy_width_from(other)
            
        } else {
            
                self.copy_height_from(other)
            
        }

    }

    /// Copy the appropriate physical property from another struct for block-size
    /// given a writing mode.
    pub fn reset_block_size(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_block_size_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// block-size given a writing mode.
    pub fn clone_block_size(&self, wm: WritingMode)
        -> longhands::block_size::computed_value::T {
    
    
        
        if wm.is_vertical() {
            
            self.clone_width()
        
        } else {
            
            self.clone_height()
        
        }

    }

                    
    /// Set the appropriate physical property for min-block-size given a writing mode.
    pub fn set_min_block_size(&mut self,
                                      v: longhands::min_block_size::computed_value::T,
                                      wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.set_min_width(v)
            
        } else {
            
                self.set_min_height(v)
            
        }

    }

    /// Copy the appropriate physical property from another struct for min-block-size
    /// given a writing mode.
    pub fn copy_min_block_size_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.copy_min_width_from(other)
            
        } else {
            
                self.copy_min_height_from(other)
            
        }

    }

    /// Copy the appropriate physical property from another struct for min-block-size
    /// given a writing mode.
    pub fn reset_min_block_size(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_min_block_size_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// min-block-size given a writing mode.
    pub fn clone_min_block_size(&self, wm: WritingMode)
        -> longhands::min_block_size::computed_value::T {
    
    
        
        if wm.is_vertical() {
            
            self.clone_min_width()
        
        } else {
            
            self.clone_min_height()
        
        }

    }

                    
    /// Set the appropriate physical property for max-block-size given a writing mode.
    pub fn set_max_block_size(&mut self,
                                      v: longhands::max_block_size::computed_value::T,
                                      wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.set_max_width(v)
            
        } else {
            
                self.set_max_height(v)
            
        }

    }

    /// Copy the appropriate physical property from another struct for max-block-size
    /// given a writing mode.
    pub fn copy_max_block_size_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.copy_max_width_from(other)
            
        } else {
            
                self.copy_max_height_from(other)
            
        }

    }

    /// Copy the appropriate physical property from another struct for max-block-size
    /// given a writing mode.
    pub fn reset_max_block_size(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_max_block_size_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// max-block-size given a writing mode.
    pub fn clone_max_block_size(&self, wm: WritingMode)
        -> longhands::max_block_size::computed_value::T {
    
    
        
        if wm.is_vertical() {
            
            self.clone_max_width()
        
        } else {
            
            self.clone_max_height()
        
        }

    }

                    
    /// Set the appropriate physical property for inline-size given a writing mode.
    pub fn set_inline_size(&mut self,
                                      v: longhands::inline_size::computed_value::T,
                                      wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.set_height(v)
            
        } else {
            
                self.set_width(v)
            
        }

    }

    /// Copy the appropriate physical property from another struct for inline-size
    /// given a writing mode.
    pub fn copy_inline_size_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.copy_height_from(other)
            
        } else {
            
                self.copy_width_from(other)
            
        }

    }

    /// Copy the appropriate physical property from another struct for inline-size
    /// given a writing mode.
    pub fn reset_inline_size(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_inline_size_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// inline-size given a writing mode.
    pub fn clone_inline_size(&self, wm: WritingMode)
        -> longhands::inline_size::computed_value::T {
    
    
        
        if wm.is_vertical() {
            
            self.clone_height()
        
        } else {
            
            self.clone_width()
        
        }

    }

                    
    /// Set the appropriate physical property for min-inline-size given a writing mode.
    pub fn set_min_inline_size(&mut self,
                                      v: longhands::min_inline_size::computed_value::T,
                                      wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.set_min_height(v)
            
        } else {
            
                self.set_min_width(v)
            
        }

    }

    /// Copy the appropriate physical property from another struct for min-inline-size
    /// given a writing mode.
    pub fn copy_min_inline_size_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.copy_min_height_from(other)
            
        } else {
            
                self.copy_min_width_from(other)
            
        }

    }

    /// Copy the appropriate physical property from another struct for min-inline-size
    /// given a writing mode.
    pub fn reset_min_inline_size(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_min_inline_size_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// min-inline-size given a writing mode.
    pub fn clone_min_inline_size(&self, wm: WritingMode)
        -> longhands::min_inline_size::computed_value::T {
    
    
        
        if wm.is_vertical() {
            
            self.clone_min_height()
        
        } else {
            
            self.clone_min_width()
        
        }

    }

                    
    /// Set the appropriate physical property for max-inline-size given a writing mode.
    pub fn set_max_inline_size(&mut self,
                                      v: longhands::max_inline_size::computed_value::T,
                                      wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.set_max_height(v)
            
        } else {
            
                self.set_max_width(v)
            
        }

    }

    /// Copy the appropriate physical property from another struct for max-inline-size
    /// given a writing mode.
    pub fn copy_max_inline_size_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.copy_max_height_from(other)
            
        } else {
            
                self.copy_max_width_from(other)
            
        }

    }

    /// Copy the appropriate physical property from another struct for max-inline-size
    /// given a writing mode.
    pub fn reset_max_inline_size(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_max_inline_size_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// max-inline-size given a writing mode.
    pub fn clone_max_inline_size(&self, wm: WritingMode)
        -> longhands::max_inline_size::computed_value::T {
    
    
        
        if wm.is_vertical() {
            
            self.clone_max_height()
        
        } else {
            
            self.clone_max_width()
        
        }

    }

                        /// Set box-sizing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_box_sizing(&mut self, v: longhands::box_sizing::computed_value::T) {
                            self.box_sizing = v;
                        }
                        /// Set box-sizing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_box_sizing_from(&mut self, other: &Self) {
                            self.box_sizing = other.box_sizing.clone();
                        }
                    /// Reset box-sizing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_box_sizing(&mut self, other: &Self) {
                        self.copy_box_sizing_from(other)
                    }

                    /// Get the computed value for box-sizing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_box_sizing(&self) -> longhands::box_sizing::computed_value::T {
                        self.box_sizing.clone()
                    }
                        /// Set object-fit.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_object_fit(&mut self, v: longhands::object_fit::computed_value::T) {
                            self.object_fit = v;
                        }
                        /// Set object-fit from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_object_fit_from(&mut self, other: &Self) {
                            self.object_fit = other.object_fit.clone();
                        }
                    /// Reset object-fit from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_object_fit(&mut self, other: &Self) {
                        self.copy_object_fit_from(other)
                    }

                    /// Get the computed value for object-fit.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_object_fit(&self) -> longhands::object_fit::computed_value::T {
                        self.object_fit.clone()
                    }
                        /// Set object-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_object_position(&mut self, v: longhands::object_position::computed_value::T) {
                            self.object_position = v;
                        }
                        /// Set object-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_object_position_from(&mut self, other: &Self) {
                            self.object_position = other.object_position.clone();
                        }
                    /// Reset object-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_object_position(&mut self, other: &Self) {
                        self.copy_object_position_from(other)
                    }

                    /// Get the computed value for object-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_object_position(&self) -> longhands::object_position::computed_value::T {
                        self.object_position.clone()
                    }
                        /// Set grid-row-gap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_row_gap(&mut self, v: longhands::grid_row_gap::computed_value::T) {
                            self.grid_row_gap = v;
                        }
                        /// Set grid-row-gap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_row_gap_from(&mut self, other: &Self) {
                            self.grid_row_gap = other.grid_row_gap.clone();
                        }
                    /// Reset grid-row-gap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_row_gap(&mut self, other: &Self) {
                        self.copy_grid_row_gap_from(other)
                    }

                    /// Get the computed value for grid-row-gap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_row_gap(&self) -> longhands::grid_row_gap::computed_value::T {
                        self.grid_row_gap.clone()
                    }
                        /// Set grid-row-start.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_row_start(&mut self, v: longhands::grid_row_start::computed_value::T) {
                            self.grid_row_start = v;
                        }
                        /// Set grid-row-start from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_row_start_from(&mut self, other: &Self) {
                            self.grid_row_start = other.grid_row_start.clone();
                        }
                    /// Reset grid-row-start from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_row_start(&mut self, other: &Self) {
                        self.copy_grid_row_start_from(other)
                    }

                    /// Get the computed value for grid-row-start.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_row_start(&self) -> longhands::grid_row_start::computed_value::T {
                        self.grid_row_start.clone()
                    }
                        /// Set grid-row-end.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_row_end(&mut self, v: longhands::grid_row_end::computed_value::T) {
                            self.grid_row_end = v;
                        }
                        /// Set grid-row-end from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_row_end_from(&mut self, other: &Self) {
                            self.grid_row_end = other.grid_row_end.clone();
                        }
                    /// Reset grid-row-end from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_row_end(&mut self, other: &Self) {
                        self.copy_grid_row_end_from(other)
                    }

                    /// Get the computed value for grid-row-end.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_row_end(&self) -> longhands::grid_row_end::computed_value::T {
                        self.grid_row_end.clone()
                    }
                        /// Set grid-auto-rows.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_auto_rows(&mut self, v: longhands::grid_auto_rows::computed_value::T) {
                            self.grid_auto_rows = v;
                        }
                        /// Set grid-auto-rows from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_auto_rows_from(&mut self, other: &Self) {
                            self.grid_auto_rows = other.grid_auto_rows.clone();
                        }
                    /// Reset grid-auto-rows from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_auto_rows(&mut self, other: &Self) {
                        self.copy_grid_auto_rows_from(other)
                    }

                    /// Get the computed value for grid-auto-rows.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_auto_rows(&self) -> longhands::grid_auto_rows::computed_value::T {
                        self.grid_auto_rows.clone()
                    }
                        /// Set grid-template-rows.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_template_rows(&mut self, v: longhands::grid_template_rows::computed_value::T) {
                            self.grid_template_rows = v;
                        }
                        /// Set grid-template-rows from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_template_rows_from(&mut self, other: &Self) {
                            self.grid_template_rows = other.grid_template_rows.clone();
                        }
                    /// Reset grid-template-rows from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_template_rows(&mut self, other: &Self) {
                        self.copy_grid_template_rows_from(other)
                    }

                    /// Get the computed value for grid-template-rows.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_template_rows(&self) -> longhands::grid_template_rows::computed_value::T {
                        self.grid_template_rows.clone()
                    }
                        /// Set grid-column-gap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_column_gap(&mut self, v: longhands::grid_column_gap::computed_value::T) {
                            self.grid_column_gap = v;
                        }
                        /// Set grid-column-gap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_column_gap_from(&mut self, other: &Self) {
                            self.grid_column_gap = other.grid_column_gap.clone();
                        }
                    /// Reset grid-column-gap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_column_gap(&mut self, other: &Self) {
                        self.copy_grid_column_gap_from(other)
                    }

                    /// Get the computed value for grid-column-gap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_column_gap(&self) -> longhands::grid_column_gap::computed_value::T {
                        self.grid_column_gap.clone()
                    }
                        /// Set grid-column-start.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_column_start(&mut self, v: longhands::grid_column_start::computed_value::T) {
                            self.grid_column_start = v;
                        }
                        /// Set grid-column-start from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_column_start_from(&mut self, other: &Self) {
                            self.grid_column_start = other.grid_column_start.clone();
                        }
                    /// Reset grid-column-start from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_column_start(&mut self, other: &Self) {
                        self.copy_grid_column_start_from(other)
                    }

                    /// Get the computed value for grid-column-start.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_column_start(&self) -> longhands::grid_column_start::computed_value::T {
                        self.grid_column_start.clone()
                    }
                        /// Set grid-column-end.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_column_end(&mut self, v: longhands::grid_column_end::computed_value::T) {
                            self.grid_column_end = v;
                        }
                        /// Set grid-column-end from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_column_end_from(&mut self, other: &Self) {
                            self.grid_column_end = other.grid_column_end.clone();
                        }
                    /// Reset grid-column-end from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_column_end(&mut self, other: &Self) {
                        self.copy_grid_column_end_from(other)
                    }

                    /// Get the computed value for grid-column-end.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_column_end(&self) -> longhands::grid_column_end::computed_value::T {
                        self.grid_column_end.clone()
                    }
                        /// Set grid-auto-columns.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_auto_columns(&mut self, v: longhands::grid_auto_columns::computed_value::T) {
                            self.grid_auto_columns = v;
                        }
                        /// Set grid-auto-columns from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_auto_columns_from(&mut self, other: &Self) {
                            self.grid_auto_columns = other.grid_auto_columns.clone();
                        }
                    /// Reset grid-auto-columns from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_auto_columns(&mut self, other: &Self) {
                        self.copy_grid_auto_columns_from(other)
                    }

                    /// Get the computed value for grid-auto-columns.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_auto_columns(&self) -> longhands::grid_auto_columns::computed_value::T {
                        self.grid_auto_columns.clone()
                    }
                        /// Set grid-template-columns.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_template_columns(&mut self, v: longhands::grid_template_columns::computed_value::T) {
                            self.grid_template_columns = v;
                        }
                        /// Set grid-template-columns from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_template_columns_from(&mut self, other: &Self) {
                            self.grid_template_columns = other.grid_template_columns.clone();
                        }
                    /// Reset grid-template-columns from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_template_columns(&mut self, other: &Self) {
                        self.copy_grid_template_columns_from(other)
                    }

                    /// Get the computed value for grid-template-columns.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_template_columns(&self) -> longhands::grid_template_columns::computed_value::T {
                        self.grid_template_columns.clone()
                    }
                        /// Set grid-auto-flow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_auto_flow(&mut self, v: longhands::grid_auto_flow::computed_value::T) {
                            self.grid_auto_flow = v;
                        }
                        /// Set grid-auto-flow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_auto_flow_from(&mut self, other: &Self) {
                            self.grid_auto_flow = other.grid_auto_flow.clone();
                        }
                    /// Reset grid-auto-flow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_auto_flow(&mut self, other: &Self) {
                        self.copy_grid_auto_flow_from(other)
                    }

                    /// Get the computed value for grid-auto-flow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_auto_flow(&self) -> longhands::grid_auto_flow::computed_value::T {
                        self.grid_auto_flow.clone()
                    }
                        /// Set grid-template-areas.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_template_areas(&mut self, v: longhands::grid_template_areas::computed_value::T) {
                            self.grid_template_areas = v;
                        }
                        /// Set grid-template-areas from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_template_areas_from(&mut self, other: &Self) {
                            self.grid_template_areas = other.grid_template_areas.clone();
                        }
                    /// Reset grid-template-areas from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_template_areas(&mut self, other: &Self) {
                        self.copy_grid_template_areas_from(other)
                    }

                    /// Get the computed value for grid-template-areas.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_template_areas(&self) -> longhands::grid_template_areas::computed_value::T {
                        self.grid_template_areas.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Table style struct.
        pub struct Table {
                /// The table-layout computed value.
                pub table_layout: longhands::table_layout::computed_value::T,
                /// The -x-span computed value.
                pub _x_span: longhands::_x_span::computed_value::T,
        }

        impl Table {
                        /// Set table-layout.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_table_layout(&mut self, v: longhands::table_layout::computed_value::T) {
                            self.table_layout = v;
                        }
                        /// Set table-layout from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_table_layout_from(&mut self, other: &Self) {
                            self.table_layout = other.table_layout.clone();
                        }
                    /// Reset table-layout from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_table_layout(&mut self, other: &Self) {
                        self.copy_table_layout_from(other)
                    }

                    /// Get the computed value for table-layout.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_table_layout(&self) -> longhands::table_layout::computed_value::T {
                        self.table_layout.clone()
                    }
                        /// Set -x-span.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__x_span(&mut self, v: longhands::_x_span::computed_value::T) {
                            self._x_span = v;
                        }
                        /// Set -x-span from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__x_span_from(&mut self, other: &Self) {
                            self._x_span = other._x_span.clone();
                        }
                    /// Reset -x-span from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__x_span(&mut self, other: &Self) {
                        self.copy__x_span_from(other)
                    }

                    /// Get the computed value for -x-span.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__x_span(&self) -> longhands::_x_span::computed_value::T {
                        self._x_span.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Text style struct.
        pub struct Text {
                /// The text-overflow computed value.
                pub text_overflow: longhands::text_overflow::computed_value::T,
                /// The unicode-bidi computed value.
                pub unicode_bidi: longhands::unicode_bidi::computed_value::T,
                /// The text-decoration-line computed value.
                pub text_decoration_line: longhands::text_decoration_line::computed_value::T,
                /// The text-decoration-style computed value.
                pub text_decoration_style: longhands::text_decoration_style::computed_value::T,
                /// The text-decoration-color computed value.
                pub text_decoration_color: longhands::text_decoration_color::computed_value::T,
                /// The initial-letter computed value.
                pub initial_letter: longhands::initial_letter::computed_value::T,
        }

        impl Text {
                        /// Set text-overflow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_overflow(&mut self, v: longhands::text_overflow::computed_value::T) {
                            self.text_overflow = v;
                        }
                        /// Set text-overflow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_overflow_from(&mut self, other: &Self) {
                            self.text_overflow = other.text_overflow.clone();
                        }
                    /// Reset text-overflow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_overflow(&mut self, other: &Self) {
                        self.copy_text_overflow_from(other)
                    }

                    /// Get the computed value for text-overflow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_overflow(&self) -> longhands::text_overflow::computed_value::T {
                        self.text_overflow.clone()
                    }
                        /// Set unicode-bidi.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_unicode_bidi(&mut self, v: longhands::unicode_bidi::computed_value::T) {
                            self.unicode_bidi = v;
                        }
                        /// Set unicode-bidi from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_unicode_bidi_from(&mut self, other: &Self) {
                            self.unicode_bidi = other.unicode_bidi.clone();
                        }
                    /// Reset unicode-bidi from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_unicode_bidi(&mut self, other: &Self) {
                        self.copy_unicode_bidi_from(other)
                    }

                    /// Get the computed value for unicode-bidi.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_unicode_bidi(&self) -> longhands::unicode_bidi::computed_value::T {
                        self.unicode_bidi.clone()
                    }
                        /// Set text-decoration-line.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_decoration_line(&mut self, v: longhands::text_decoration_line::computed_value::T) {
                            self.text_decoration_line = v;
                        }
                        /// Set text-decoration-line from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_decoration_line_from(&mut self, other: &Self) {
                            self.text_decoration_line = other.text_decoration_line.clone();
                        }
                    /// Reset text-decoration-line from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_decoration_line(&mut self, other: &Self) {
                        self.copy_text_decoration_line_from(other)
                    }

                    /// Get the computed value for text-decoration-line.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_decoration_line(&self) -> longhands::text_decoration_line::computed_value::T {
                        self.text_decoration_line.clone()
                    }
                        /// Set text-decoration-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_decoration_style(&mut self, v: longhands::text_decoration_style::computed_value::T) {
                            self.text_decoration_style = v;
                        }
                        /// Set text-decoration-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_decoration_style_from(&mut self, other: &Self) {
                            self.text_decoration_style = other.text_decoration_style.clone();
                        }
                    /// Reset text-decoration-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_decoration_style(&mut self, other: &Self) {
                        self.copy_text_decoration_style_from(other)
                    }

                    /// Get the computed value for text-decoration-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_decoration_style(&self) -> longhands::text_decoration_style::computed_value::T {
                        self.text_decoration_style.clone()
                    }
                        /// Set text-decoration-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_decoration_color(&mut self, v: longhands::text_decoration_color::computed_value::T) {
                            self.text_decoration_color = v;
                        }
                        /// Set text-decoration-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_decoration_color_from(&mut self, other: &Self) {
                            self.text_decoration_color = other.text_decoration_color.clone();
                        }
                    /// Reset text-decoration-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_decoration_color(&mut self, other: &Self) {
                        self.copy_text_decoration_color_from(other)
                    }

                    /// Get the computed value for text-decoration-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_decoration_color(&self) -> longhands::text_decoration_color::computed_value::T {
                        self.text_decoration_color.clone()
                    }
                        /// Set initial-letter.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_initial_letter(&mut self, v: longhands::initial_letter::computed_value::T) {
                            self.initial_letter = v;
                        }
                        /// Set initial-letter from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_initial_letter_from(&mut self, other: &Self) {
                            self.initial_letter = other.initial_letter.clone();
                        }
                    /// Reset initial-letter from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_initial_letter(&mut self, other: &Self) {
                        self.copy_initial_letter_from(other)
                    }

                    /// Get the computed value for initial-letter.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_initial_letter(&self) -> longhands::initial_letter::computed_value::T {
                        self.initial_letter.clone()
                    }
                /// Whether the text decoration has an underline.
                #[inline]
                pub fn has_underline(&self) -> bool {
                    self.text_decoration_line.contains(longhands::text_decoration_line::SpecifiedValue::UNDERLINE)
                }

                /// Whether the text decoration has an overline.
                #[inline]
                pub fn has_overline(&self) -> bool {
                    self.text_decoration_line.contains(longhands::text_decoration_line::SpecifiedValue::OVERLINE)
                }

                /// Whether the text decoration has a line through.
                #[inline]
                pub fn has_line_through(&self) -> bool {
                    self.text_decoration_line.contains(longhands::text_decoration_line::SpecifiedValue::LINE_THROUGH)
                }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The UI style struct.
        pub struct UI {
                /// The ime-mode computed value.
                pub ime_mode: longhands::ime_mode::computed_value::T,
                /// The -moz-user-select computed value.
                pub _moz_user_select: longhands::_moz_user_select::computed_value::T,
                /// The -moz-window-dragging computed value.
                pub _moz_window_dragging: longhands::_moz_window_dragging::computed_value::T,
                /// The -moz-window-shadow computed value.
                pub _moz_window_shadow: longhands::_moz_window_shadow::computed_value::T,
                /// The -moz-window-opacity computed value.
                pub _moz_window_opacity: longhands::_moz_window_opacity::computed_value::T,
                /// The -moz-window-transform computed value.
                pub _moz_window_transform: longhands::_moz_window_transform::computed_value::T,
                /// The -moz-window-transform-origin computed value.
                pub _moz_window_transform_origin: longhands::_moz_window_transform_origin::computed_value::T,
                /// The -moz-force-broken-image-icon computed value.
                pub _moz_force_broken_image_icon: longhands::_moz_force_broken_image_icon::computed_value::T,
        }

        impl UI {
                        /// Set ime-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_ime_mode(&mut self, v: longhands::ime_mode::computed_value::T) {
                            self.ime_mode = v;
                        }
                        /// Set ime-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_ime_mode_from(&mut self, other: &Self) {
                            self.ime_mode = other.ime_mode.clone();
                        }
                    /// Reset ime-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_ime_mode(&mut self, other: &Self) {
                        self.copy_ime_mode_from(other)
                    }

                    /// Get the computed value for ime-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_ime_mode(&self) -> longhands::ime_mode::computed_value::T {
                        self.ime_mode.clone()
                    }
                        /// Set -moz-user-select.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_user_select(&mut self, v: longhands::_moz_user_select::computed_value::T) {
                            self._moz_user_select = v;
                        }
                        /// Set -moz-user-select from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_user_select_from(&mut self, other: &Self) {
                            self._moz_user_select = other._moz_user_select.clone();
                        }
                    /// Reset -moz-user-select from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_user_select(&mut self, other: &Self) {
                        self.copy__moz_user_select_from(other)
                    }

                    /// Get the computed value for -moz-user-select.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_user_select(&self) -> longhands::_moz_user_select::computed_value::T {
                        self._moz_user_select.clone()
                    }
                        /// Set -moz-window-dragging.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_dragging(&mut self, v: longhands::_moz_window_dragging::computed_value::T) {
                            self._moz_window_dragging = v;
                        }
                        /// Set -moz-window-dragging from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_dragging_from(&mut self, other: &Self) {
                            self._moz_window_dragging = other._moz_window_dragging.clone();
                        }
                    /// Reset -moz-window-dragging from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_dragging(&mut self, other: &Self) {
                        self.copy__moz_window_dragging_from(other)
                    }

                    /// Get the computed value for -moz-window-dragging.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_dragging(&self) -> longhands::_moz_window_dragging::computed_value::T {
                        self._moz_window_dragging.clone()
                    }
                        /// Set -moz-window-shadow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_shadow(&mut self, v: longhands::_moz_window_shadow::computed_value::T) {
                            self._moz_window_shadow = v;
                        }
                        /// Set -moz-window-shadow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_shadow_from(&mut self, other: &Self) {
                            self._moz_window_shadow = other._moz_window_shadow.clone();
                        }
                    /// Reset -moz-window-shadow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_shadow(&mut self, other: &Self) {
                        self.copy__moz_window_shadow_from(other)
                    }

                    /// Get the computed value for -moz-window-shadow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_shadow(&self) -> longhands::_moz_window_shadow::computed_value::T {
                        self._moz_window_shadow.clone()
                    }
                        /// Set -moz-window-opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_opacity(&mut self, v: longhands::_moz_window_opacity::computed_value::T) {
                            self._moz_window_opacity = v;
                        }
                        /// Set -moz-window-opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_opacity_from(&mut self, other: &Self) {
                            self._moz_window_opacity = other._moz_window_opacity.clone();
                        }
                    /// Reset -moz-window-opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_opacity(&mut self, other: &Self) {
                        self.copy__moz_window_opacity_from(other)
                    }

                    /// Get the computed value for -moz-window-opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_opacity(&self) -> longhands::_moz_window_opacity::computed_value::T {
                        self._moz_window_opacity.clone()
                    }
                        /// Set -moz-window-transform.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_transform(&mut self, v: longhands::_moz_window_transform::computed_value::T) {
                            self._moz_window_transform = v;
                        }
                        /// Set -moz-window-transform from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_transform_from(&mut self, other: &Self) {
                            self._moz_window_transform = other._moz_window_transform.clone();
                        }
                    /// Reset -moz-window-transform from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_transform(&mut self, other: &Self) {
                        self.copy__moz_window_transform_from(other)
                    }

                    /// Get the computed value for -moz-window-transform.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_transform(&self) -> longhands::_moz_window_transform::computed_value::T {
                        self._moz_window_transform.clone()
                    }
                        /// Set -moz-window-transform-origin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_transform_origin(&mut self, v: longhands::_moz_window_transform_origin::computed_value::T) {
                            self._moz_window_transform_origin = v;
                        }
                        /// Set -moz-window-transform-origin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_transform_origin_from(&mut self, other: &Self) {
                            self._moz_window_transform_origin = other._moz_window_transform_origin.clone();
                        }
                    /// Reset -moz-window-transform-origin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_transform_origin(&mut self, other: &Self) {
                        self.copy__moz_window_transform_origin_from(other)
                    }

                    /// Get the computed value for -moz-window-transform-origin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_transform_origin(&self) -> longhands::_moz_window_transform_origin::computed_value::T {
                        self._moz_window_transform_origin.clone()
                    }
                        /// Set -moz-force-broken-image-icon.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_force_broken_image_icon(&mut self, v: longhands::_moz_force_broken_image_icon::computed_value::T) {
                            self._moz_force_broken_image_icon = v;
                        }
                        /// Set -moz-force-broken-image-icon from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_force_broken_image_icon_from(&mut self, other: &Self) {
                            self._moz_force_broken_image_icon = other._moz_force_broken_image_icon.clone();
                        }
                    /// Reset -moz-force-broken-image-icon from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_force_broken_image_icon(&mut self, other: &Self) {
                        self.copy__moz_force_broken_image_icon_from(other)
                    }

                    /// Get the computed value for -moz-force-broken-image-icon.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_force_broken_image_icon(&self) -> longhands::_moz_force_broken_image_icon::computed_value::T {
                        self._moz_force_broken_image_icon.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The InheritedSVG style struct.
        pub struct InheritedSVG {
                /// The text-anchor computed value.
                pub text_anchor: longhands::text_anchor::computed_value::T,
                /// The color-interpolation computed value.
                pub color_interpolation: longhands::color_interpolation::computed_value::T,
                /// The color-interpolation-filters computed value.
                pub color_interpolation_filters: longhands::color_interpolation_filters::computed_value::T,
                /// The fill computed value.
                pub fill: longhands::fill::computed_value::T,
                /// The fill-opacity computed value.
                pub fill_opacity: longhands::fill_opacity::computed_value::T,
                /// The fill-rule computed value.
                pub fill_rule: longhands::fill_rule::computed_value::T,
                /// The shape-rendering computed value.
                pub shape_rendering: longhands::shape_rendering::computed_value::T,
                /// The stroke computed value.
                pub stroke: longhands::stroke::computed_value::T,
                /// The stroke-width computed value.
                pub stroke_width: longhands::stroke_width::computed_value::T,
                /// The stroke-linecap computed value.
                pub stroke_linecap: longhands::stroke_linecap::computed_value::T,
                /// The stroke-linejoin computed value.
                pub stroke_linejoin: longhands::stroke_linejoin::computed_value::T,
                /// The stroke-miterlimit computed value.
                pub stroke_miterlimit: longhands::stroke_miterlimit::computed_value::T,
                /// The stroke-opacity computed value.
                pub stroke_opacity: longhands::stroke_opacity::computed_value::T,
                /// The stroke-dasharray computed value.
                pub stroke_dasharray: longhands::stroke_dasharray::computed_value::T,
                /// The stroke-dashoffset computed value.
                pub stroke_dashoffset: longhands::stroke_dashoffset::computed_value::T,
                /// The clip-rule computed value.
                pub clip_rule: longhands::clip_rule::computed_value::T,
                /// The marker-start computed value.
                pub marker_start: longhands::marker_start::computed_value::T,
                /// The marker-mid computed value.
                pub marker_mid: longhands::marker_mid::computed_value::T,
                /// The marker-end computed value.
                pub marker_end: longhands::marker_end::computed_value::T,
                /// The paint-order computed value.
                pub paint_order: longhands::paint_order::computed_value::T,
                /// The -moz-context-properties computed value.
                pub _moz_context_properties: longhands::_moz_context_properties::computed_value::T,
        }

        impl InheritedSVG {
                        /// Set text-anchor.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_anchor(&mut self, v: longhands::text_anchor::computed_value::T) {
                            self.text_anchor = v;
                        }
                        /// Set text-anchor from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_anchor_from(&mut self, other: &Self) {
                            self.text_anchor = other.text_anchor.clone();
                        }
                    /// Reset text-anchor from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_anchor(&mut self, other: &Self) {
                        self.copy_text_anchor_from(other)
                    }

                    /// Get the computed value for text-anchor.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_anchor(&self) -> longhands::text_anchor::computed_value::T {
                        self.text_anchor.clone()
                    }
                        /// Set color-interpolation.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_color_interpolation(&mut self, v: longhands::color_interpolation::computed_value::T) {
                            self.color_interpolation = v;
                        }
                        /// Set color-interpolation from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_color_interpolation_from(&mut self, other: &Self) {
                            self.color_interpolation = other.color_interpolation.clone();
                        }
                    /// Reset color-interpolation from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_color_interpolation(&mut self, other: &Self) {
                        self.copy_color_interpolation_from(other)
                    }

                    /// Get the computed value for color-interpolation.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_color_interpolation(&self) -> longhands::color_interpolation::computed_value::T {
                        self.color_interpolation.clone()
                    }
                        /// Set color-interpolation-filters.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_color_interpolation_filters(&mut self, v: longhands::color_interpolation_filters::computed_value::T) {
                            self.color_interpolation_filters = v;
                        }
                        /// Set color-interpolation-filters from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_color_interpolation_filters_from(&mut self, other: &Self) {
                            self.color_interpolation_filters = other.color_interpolation_filters.clone();
                        }
                    /// Reset color-interpolation-filters from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_color_interpolation_filters(&mut self, other: &Self) {
                        self.copy_color_interpolation_filters_from(other)
                    }

                    /// Get the computed value for color-interpolation-filters.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_color_interpolation_filters(&self) -> longhands::color_interpolation_filters::computed_value::T {
                        self.color_interpolation_filters.clone()
                    }
                        /// Set fill.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_fill(&mut self, v: longhands::fill::computed_value::T) {
                            self.fill = v;
                        }
                        /// Set fill from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_fill_from(&mut self, other: &Self) {
                            self.fill = other.fill.clone();
                        }
                    /// Reset fill from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_fill(&mut self, other: &Self) {
                        self.copy_fill_from(other)
                    }

                    /// Get the computed value for fill.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_fill(&self) -> longhands::fill::computed_value::T {
                        self.fill.clone()
                    }
                        /// Set fill-opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_fill_opacity(&mut self, v: longhands::fill_opacity::computed_value::T) {
                            self.fill_opacity = v;
                        }
                        /// Set fill-opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_fill_opacity_from(&mut self, other: &Self) {
                            self.fill_opacity = other.fill_opacity.clone();
                        }
                    /// Reset fill-opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_fill_opacity(&mut self, other: &Self) {
                        self.copy_fill_opacity_from(other)
                    }

                    /// Get the computed value for fill-opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_fill_opacity(&self) -> longhands::fill_opacity::computed_value::T {
                        self.fill_opacity.clone()
                    }
                        /// Set fill-rule.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_fill_rule(&mut self, v: longhands::fill_rule::computed_value::T) {
                            self.fill_rule = v;
                        }
                        /// Set fill-rule from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_fill_rule_from(&mut self, other: &Self) {
                            self.fill_rule = other.fill_rule.clone();
                        }
                    /// Reset fill-rule from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_fill_rule(&mut self, other: &Self) {
                        self.copy_fill_rule_from(other)
                    }

                    /// Get the computed value for fill-rule.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_fill_rule(&self) -> longhands::fill_rule::computed_value::T {
                        self.fill_rule.clone()
                    }
                        /// Set shape-rendering.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_shape_rendering(&mut self, v: longhands::shape_rendering::computed_value::T) {
                            self.shape_rendering = v;
                        }
                        /// Set shape-rendering from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_shape_rendering_from(&mut self, other: &Self) {
                            self.shape_rendering = other.shape_rendering.clone();
                        }
                    /// Reset shape-rendering from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_shape_rendering(&mut self, other: &Self) {
                        self.copy_shape_rendering_from(other)
                    }

                    /// Get the computed value for shape-rendering.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_shape_rendering(&self) -> longhands::shape_rendering::computed_value::T {
                        self.shape_rendering.clone()
                    }
                        /// Set stroke.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke(&mut self, v: longhands::stroke::computed_value::T) {
                            self.stroke = v;
                        }
                        /// Set stroke from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_from(&mut self, other: &Self) {
                            self.stroke = other.stroke.clone();
                        }
                    /// Reset stroke from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke(&mut self, other: &Self) {
                        self.copy_stroke_from(other)
                    }

                    /// Get the computed value for stroke.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke(&self) -> longhands::stroke::computed_value::T {
                        self.stroke.clone()
                    }
                        /// Set stroke-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_width(&mut self, v: longhands::stroke_width::computed_value::T) {
                            self.stroke_width = v;
                        }
                        /// Set stroke-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_width_from(&mut self, other: &Self) {
                            self.stroke_width = other.stroke_width.clone();
                        }
                    /// Reset stroke-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_width(&mut self, other: &Self) {
                        self.copy_stroke_width_from(other)
                    }

                    /// Get the computed value for stroke-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_width(&self) -> longhands::stroke_width::computed_value::T {
                        self.stroke_width.clone()
                    }
                        /// Set stroke-linecap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_linecap(&mut self, v: longhands::stroke_linecap::computed_value::T) {
                            self.stroke_linecap = v;
                        }
                        /// Set stroke-linecap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_linecap_from(&mut self, other: &Self) {
                            self.stroke_linecap = other.stroke_linecap.clone();
                        }
                    /// Reset stroke-linecap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_linecap(&mut self, other: &Self) {
                        self.copy_stroke_linecap_from(other)
                    }

                    /// Get the computed value for stroke-linecap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_linecap(&self) -> longhands::stroke_linecap::computed_value::T {
                        self.stroke_linecap.clone()
                    }
                        /// Set stroke-linejoin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_linejoin(&mut self, v: longhands::stroke_linejoin::computed_value::T) {
                            self.stroke_linejoin = v;
                        }
                        /// Set stroke-linejoin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_linejoin_from(&mut self, other: &Self) {
                            self.stroke_linejoin = other.stroke_linejoin.clone();
                        }
                    /// Reset stroke-linejoin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_linejoin(&mut self, other: &Self) {
                        self.copy_stroke_linejoin_from(other)
                    }

                    /// Get the computed value for stroke-linejoin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_linejoin(&self) -> longhands::stroke_linejoin::computed_value::T {
                        self.stroke_linejoin.clone()
                    }
                        /// Set stroke-miterlimit.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_miterlimit(&mut self, v: longhands::stroke_miterlimit::computed_value::T) {
                            self.stroke_miterlimit = v;
                        }
                        /// Set stroke-miterlimit from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_miterlimit_from(&mut self, other: &Self) {
                            self.stroke_miterlimit = other.stroke_miterlimit.clone();
                        }
                    /// Reset stroke-miterlimit from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_miterlimit(&mut self, other: &Self) {
                        self.copy_stroke_miterlimit_from(other)
                    }

                    /// Get the computed value for stroke-miterlimit.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_miterlimit(&self) -> longhands::stroke_miterlimit::computed_value::T {
                        self.stroke_miterlimit.clone()
                    }
                        /// Set stroke-opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_opacity(&mut self, v: longhands::stroke_opacity::computed_value::T) {
                            self.stroke_opacity = v;
                        }
                        /// Set stroke-opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_opacity_from(&mut self, other: &Self) {
                            self.stroke_opacity = other.stroke_opacity.clone();
                        }
                    /// Reset stroke-opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_opacity(&mut self, other: &Self) {
                        self.copy_stroke_opacity_from(other)
                    }

                    /// Get the computed value for stroke-opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_opacity(&self) -> longhands::stroke_opacity::computed_value::T {
                        self.stroke_opacity.clone()
                    }
                        /// Set stroke-dasharray.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_dasharray(&mut self, v: longhands::stroke_dasharray::computed_value::T) {
                            self.stroke_dasharray = v;
                        }
                        /// Set stroke-dasharray from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_dasharray_from(&mut self, other: &Self) {
                            self.stroke_dasharray = other.stroke_dasharray.clone();
                        }
                    /// Reset stroke-dasharray from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_dasharray(&mut self, other: &Self) {
                        self.copy_stroke_dasharray_from(other)
                    }

                    /// Get the computed value for stroke-dasharray.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_dasharray(&self) -> longhands::stroke_dasharray::computed_value::T {
                        self.stroke_dasharray.clone()
                    }
                        /// Set stroke-dashoffset.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_dashoffset(&mut self, v: longhands::stroke_dashoffset::computed_value::T) {
                            self.stroke_dashoffset = v;
                        }
                        /// Set stroke-dashoffset from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_dashoffset_from(&mut self, other: &Self) {
                            self.stroke_dashoffset = other.stroke_dashoffset.clone();
                        }
                    /// Reset stroke-dashoffset from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_dashoffset(&mut self, other: &Self) {
                        self.copy_stroke_dashoffset_from(other)
                    }

                    /// Get the computed value for stroke-dashoffset.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_dashoffset(&self) -> longhands::stroke_dashoffset::computed_value::T {
                        self.stroke_dashoffset.clone()
                    }
                        /// Set clip-rule.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_clip_rule(&mut self, v: longhands::clip_rule::computed_value::T) {
                            self.clip_rule = v;
                        }
                        /// Set clip-rule from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_clip_rule_from(&mut self, other: &Self) {
                            self.clip_rule = other.clip_rule.clone();
                        }
                    /// Reset clip-rule from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_clip_rule(&mut self, other: &Self) {
                        self.copy_clip_rule_from(other)
                    }

                    /// Get the computed value for clip-rule.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_clip_rule(&self) -> longhands::clip_rule::computed_value::T {
                        self.clip_rule.clone()
                    }
                        /// Set marker-start.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_marker_start(&mut self, v: longhands::marker_start::computed_value::T) {
                            self.marker_start = v;
                        }
                        /// Set marker-start from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_marker_start_from(&mut self, other: &Self) {
                            self.marker_start = other.marker_start.clone();
                        }
                    /// Reset marker-start from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_marker_start(&mut self, other: &Self) {
                        self.copy_marker_start_from(other)
                    }

                    /// Get the computed value for marker-start.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_marker_start(&self) -> longhands::marker_start::computed_value::T {
                        self.marker_start.clone()
                    }
                        /// Set marker-mid.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_marker_mid(&mut self, v: longhands::marker_mid::computed_value::T) {
                            self.marker_mid = v;
                        }
                        /// Set marker-mid from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_marker_mid_from(&mut self, other: &Self) {
                            self.marker_mid = other.marker_mid.clone();
                        }
                    /// Reset marker-mid from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_marker_mid(&mut self, other: &Self) {
                        self.copy_marker_mid_from(other)
                    }

                    /// Get the computed value for marker-mid.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_marker_mid(&self) -> longhands::marker_mid::computed_value::T {
                        self.marker_mid.clone()
                    }
                        /// Set marker-end.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_marker_end(&mut self, v: longhands::marker_end::computed_value::T) {
                            self.marker_end = v;
                        }
                        /// Set marker-end from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_marker_end_from(&mut self, other: &Self) {
                            self.marker_end = other.marker_end.clone();
                        }
                    /// Reset marker-end from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_marker_end(&mut self, other: &Self) {
                        self.copy_marker_end_from(other)
                    }

                    /// Get the computed value for marker-end.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_marker_end(&self) -> longhands::marker_end::computed_value::T {
                        self.marker_end.clone()
                    }
                        /// Set paint-order.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_paint_order(&mut self, v: longhands::paint_order::computed_value::T) {
                            self.paint_order = v;
                        }
                        /// Set paint-order from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_paint_order_from(&mut self, other: &Self) {
                            self.paint_order = other.paint_order.clone();
                        }
                    /// Reset paint-order from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_paint_order(&mut self, other: &Self) {
                        self.copy_paint_order_from(other)
                    }

                    /// Get the computed value for paint-order.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_paint_order(&self) -> longhands::paint_order::computed_value::T {
                        self.paint_order.clone()
                    }
                        /// Set -moz-context-properties.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_context_properties<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::_moz_context_properties
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self._moz_context_properties = longhands::_moz_context_properties::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set -moz-context-properties from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_context_properties_from(&mut self, other: &Self) {
                            self._moz_context_properties = other._moz_context_properties.clone();
                        }
                    /// Reset -moz-context-properties from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_context_properties(&mut self, other: &Self) {
                        self.copy__moz_context_properties_from(other)
                    }

                    /// Get the computed value for -moz-context-properties.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_context_properties(&self) -> longhands::_moz_context_properties::computed_value::T {
                        self._moz_context_properties.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The SVG style struct.
        pub struct SVG {
                /// The dominant-baseline computed value.
                pub dominant_baseline: longhands::dominant_baseline::computed_value::T,
                /// The vector-effect computed value.
                pub vector_effect: longhands::vector_effect::computed_value::T,
                /// The stop-color computed value.
                pub stop_color: longhands::stop_color::computed_value::T,
                /// The stop-opacity computed value.
                pub stop_opacity: longhands::stop_opacity::computed_value::T,
                /// The flood-color computed value.
                pub flood_color: longhands::flood_color::computed_value::T,
                /// The flood-opacity computed value.
                pub flood_opacity: longhands::flood_opacity::computed_value::T,
                /// The lighting-color computed value.
                pub lighting_color: longhands::lighting_color::computed_value::T,
                /// The mask-type computed value.
                pub mask_type: longhands::mask_type::computed_value::T,
                /// The clip-path computed value.
                pub clip_path: longhands::clip_path::computed_value::T,
                /// The mask-mode computed value.
                pub mask_mode: longhands::mask_mode::computed_value::T,
                /// The mask-repeat computed value.
                pub mask_repeat: longhands::mask_repeat::computed_value::T,
                /// The mask-position-x computed value.
                pub mask_position_x: longhands::mask_position_x::computed_value::T,
                /// The mask-position-y computed value.
                pub mask_position_y: longhands::mask_position_y::computed_value::T,
                /// The mask-clip computed value.
                pub mask_clip: longhands::mask_clip::computed_value::T,
                /// The mask-origin computed value.
                pub mask_origin: longhands::mask_origin::computed_value::T,
                /// The mask-size computed value.
                pub mask_size: longhands::mask_size::computed_value::T,
                /// The mask-composite computed value.
                pub mask_composite: longhands::mask_composite::computed_value::T,
                /// The mask-image computed value.
                pub mask_image: longhands::mask_image::computed_value::T,
        }

        impl SVG {
                        /// Set dominant-baseline.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_dominant_baseline(&mut self, v: longhands::dominant_baseline::computed_value::T) {
                            self.dominant_baseline = v;
                        }
                        /// Set dominant-baseline from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_dominant_baseline_from(&mut self, other: &Self) {
                            self.dominant_baseline = other.dominant_baseline.clone();
                        }
                    /// Reset dominant-baseline from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_dominant_baseline(&mut self, other: &Self) {
                        self.copy_dominant_baseline_from(other)
                    }

                    /// Get the computed value for dominant-baseline.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_dominant_baseline(&self) -> longhands::dominant_baseline::computed_value::T {
                        self.dominant_baseline.clone()
                    }
                        /// Set vector-effect.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_vector_effect(&mut self, v: longhands::vector_effect::computed_value::T) {
                            self.vector_effect = v;
                        }
                        /// Set vector-effect from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_vector_effect_from(&mut self, other: &Self) {
                            self.vector_effect = other.vector_effect.clone();
                        }
                    /// Reset vector-effect from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_vector_effect(&mut self, other: &Self) {
                        self.copy_vector_effect_from(other)
                    }

                    /// Get the computed value for vector-effect.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_vector_effect(&self) -> longhands::vector_effect::computed_value::T {
                        self.vector_effect.clone()
                    }
                        /// Set stop-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stop_color(&mut self, v: longhands::stop_color::computed_value::T) {
                            self.stop_color = v;
                        }
                        /// Set stop-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stop_color_from(&mut self, other: &Self) {
                            self.stop_color = other.stop_color.clone();
                        }
                    /// Reset stop-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stop_color(&mut self, other: &Self) {
                        self.copy_stop_color_from(other)
                    }

                    /// Get the computed value for stop-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stop_color(&self) -> longhands::stop_color::computed_value::T {
                        self.stop_color.clone()
                    }
                        /// Set stop-opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stop_opacity(&mut self, v: longhands::stop_opacity::computed_value::T) {
                            self.stop_opacity = v;
                        }
                        /// Set stop-opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stop_opacity_from(&mut self, other: &Self) {
                            self.stop_opacity = other.stop_opacity.clone();
                        }
                    /// Reset stop-opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stop_opacity(&mut self, other: &Self) {
                        self.copy_stop_opacity_from(other)
                    }

                    /// Get the computed value for stop-opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stop_opacity(&self) -> longhands::stop_opacity::computed_value::T {
                        self.stop_opacity.clone()
                    }
                        /// Set flood-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flood_color(&mut self, v: longhands::flood_color::computed_value::T) {
                            self.flood_color = v;
                        }
                        /// Set flood-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flood_color_from(&mut self, other: &Self) {
                            self.flood_color = other.flood_color.clone();
                        }
                    /// Reset flood-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flood_color(&mut self, other: &Self) {
                        self.copy_flood_color_from(other)
                    }

                    /// Get the computed value for flood-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flood_color(&self) -> longhands::flood_color::computed_value::T {
                        self.flood_color.clone()
                    }
                        /// Set flood-opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flood_opacity(&mut self, v: longhands::flood_opacity::computed_value::T) {
                            self.flood_opacity = v;
                        }
                        /// Set flood-opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flood_opacity_from(&mut self, other: &Self) {
                            self.flood_opacity = other.flood_opacity.clone();
                        }
                    /// Reset flood-opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flood_opacity(&mut self, other: &Self) {
                        self.copy_flood_opacity_from(other)
                    }

                    /// Get the computed value for flood-opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flood_opacity(&self) -> longhands::flood_opacity::computed_value::T {
                        self.flood_opacity.clone()
                    }
                        /// Set lighting-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_lighting_color(&mut self, v: longhands::lighting_color::computed_value::T) {
                            self.lighting_color = v;
                        }
                        /// Set lighting-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_lighting_color_from(&mut self, other: &Self) {
                            self.lighting_color = other.lighting_color.clone();
                        }
                    /// Reset lighting-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_lighting_color(&mut self, other: &Self) {
                        self.copy_lighting_color_from(other)
                    }

                    /// Get the computed value for lighting-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_lighting_color(&self) -> longhands::lighting_color::computed_value::T {
                        self.lighting_color.clone()
                    }
                        /// Set mask-type.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_type(&mut self, v: longhands::mask_type::computed_value::T) {
                            self.mask_type = v;
                        }
                        /// Set mask-type from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_type_from(&mut self, other: &Self) {
                            self.mask_type = other.mask_type.clone();
                        }
                    /// Reset mask-type from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_type(&mut self, other: &Self) {
                        self.copy_mask_type_from(other)
                    }

                    /// Get the computed value for mask-type.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_type(&self) -> longhands::mask_type::computed_value::T {
                        self.mask_type.clone()
                    }
                        /// Set clip-path.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_clip_path(&mut self, v: longhands::clip_path::computed_value::T) {
                            self.clip_path = v;
                        }
                        /// Set clip-path from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_clip_path_from(&mut self, other: &Self) {
                            self.clip_path = other.clip_path.clone();
                        }
                    /// Reset clip-path from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_clip_path(&mut self, other: &Self) {
                        self.copy_clip_path_from(other)
                    }

                    /// Get the computed value for clip-path.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_clip_path(&self) -> longhands::clip_path::computed_value::T {
                        self.clip_path.clone()
                    }
                        /// Set mask-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_mode<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_mode
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_mode = longhands::mask_mode::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_mode_from(&mut self, other: &Self) {
                            self.mask_mode = other.mask_mode.clone();
                        }
                    /// Reset mask-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_mode(&mut self, other: &Self) {
                        self.copy_mask_mode_from(other)
                    }

                    /// Get the computed value for mask-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_mode(&self) -> longhands::mask_mode::computed_value::T {
                        self.mask_mode.clone()
                    }
                        /// Set mask-repeat.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_repeat<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_repeat
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_repeat = longhands::mask_repeat::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-repeat from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_repeat_from(&mut self, other: &Self) {
                            self.mask_repeat = other.mask_repeat.clone();
                        }
                    /// Reset mask-repeat from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_repeat(&mut self, other: &Self) {
                        self.copy_mask_repeat_from(other)
                    }

                    /// Get the computed value for mask-repeat.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_repeat(&self) -> longhands::mask_repeat::computed_value::T {
                        self.mask_repeat.clone()
                    }
                        /// Set mask-position-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_position_x<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_position_x
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_position_x = longhands::mask_position_x::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-position-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_position_x_from(&mut self, other: &Self) {
                            self.mask_position_x = other.mask_position_x.clone();
                        }
                    /// Reset mask-position-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_position_x(&mut self, other: &Self) {
                        self.copy_mask_position_x_from(other)
                    }

                    /// Get the computed value for mask-position-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_position_x(&self) -> longhands::mask_position_x::computed_value::T {
                        self.mask_position_x.clone()
                    }
                        /// Set mask-position-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_position_y<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_position_y
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_position_y = longhands::mask_position_y::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-position-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_position_y_from(&mut self, other: &Self) {
                            self.mask_position_y = other.mask_position_y.clone();
                        }
                    /// Reset mask-position-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_position_y(&mut self, other: &Self) {
                        self.copy_mask_position_y_from(other)
                    }

                    /// Get the computed value for mask-position-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_position_y(&self) -> longhands::mask_position_y::computed_value::T {
                        self.mask_position_y.clone()
                    }
                        /// Set mask-clip.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_clip<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_clip
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_clip = longhands::mask_clip::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-clip from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_clip_from(&mut self, other: &Self) {
                            self.mask_clip = other.mask_clip.clone();
                        }
                    /// Reset mask-clip from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_clip(&mut self, other: &Self) {
                        self.copy_mask_clip_from(other)
                    }

                    /// Get the computed value for mask-clip.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_clip(&self) -> longhands::mask_clip::computed_value::T {
                        self.mask_clip.clone()
                    }
                        /// Set mask-origin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_origin<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_origin
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_origin = longhands::mask_origin::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-origin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_origin_from(&mut self, other: &Self) {
                            self.mask_origin = other.mask_origin.clone();
                        }
                    /// Reset mask-origin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_origin(&mut self, other: &Self) {
                        self.copy_mask_origin_from(other)
                    }

                    /// Get the computed value for mask-origin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_origin(&self) -> longhands::mask_origin::computed_value::T {
                        self.mask_origin.clone()
                    }
                        /// Set mask-size.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_size(&mut self, v: longhands::mask_size::computed_value::T) {
                            self.mask_size = v;
                        }
                        /// Set mask-size from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_size_from(&mut self, other: &Self) {
                            self.mask_size = other.mask_size.clone();
                        }
                    /// Reset mask-size from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_size(&mut self, other: &Self) {
                        self.copy_mask_size_from(other)
                    }

                    /// Get the computed value for mask-size.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_size(&self) -> longhands::mask_size::computed_value::T {
                        self.mask_size.clone()
                    }
                        /// Set mask-composite.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_composite<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_composite
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_composite = longhands::mask_composite::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-composite from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_composite_from(&mut self, other: &Self) {
                            self.mask_composite = other.mask_composite.clone();
                        }
                    /// Reset mask-composite from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_composite(&mut self, other: &Self) {
                        self.copy_mask_composite_from(other)
                    }

                    /// Get the computed value for mask-composite.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_composite(&self) -> longhands::mask_composite::computed_value::T {
                        self.mask_composite.clone()
                    }
                        /// Set mask-image.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_image<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_image
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_image = longhands::mask_image::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-image from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_image_from(&mut self, other: &Self) {
                            self.mask_image = other.mask_image.clone();
                        }
                    /// Reset mask-image from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_image(&mut self, other: &Self) {
                        self.copy_mask_image_from(other)
                    }

                    /// Get the computed value for mask-image.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_image(&self) -> longhands::mask_image::computed_value::T {
                        self.mask_image.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The XUL style struct.
        pub struct XUL {
                /// The -moz-box-align computed value.
                pub _moz_box_align: longhands::_moz_box_align::computed_value::T,
                /// The -moz-box-direction computed value.
                pub _moz_box_direction: longhands::_moz_box_direction::computed_value::T,
                /// The -moz-box-flex computed value.
                pub _moz_box_flex: longhands::_moz_box_flex::computed_value::T,
                /// The -moz-box-orient computed value.
                pub _moz_box_orient: longhands::_moz_box_orient::computed_value::T,
                /// The -moz-box-pack computed value.
                pub _moz_box_pack: longhands::_moz_box_pack::computed_value::T,
                /// The -moz-stack-sizing computed value.
                pub _moz_stack_sizing: longhands::_moz_stack_sizing::computed_value::T,
                /// The -moz-box-ordinal-group computed value.
                pub _moz_box_ordinal_group: longhands::_moz_box_ordinal_group::computed_value::T,
        }

        impl XUL {
                        /// Set -moz-box-align.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_align(&mut self, v: longhands::_moz_box_align::computed_value::T) {
                            self._moz_box_align = v;
                        }
                        /// Set -moz-box-align from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_align_from(&mut self, other: &Self) {
                            self._moz_box_align = other._moz_box_align.clone();
                        }
                    /// Reset -moz-box-align from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_align(&mut self, other: &Self) {
                        self.copy__moz_box_align_from(other)
                    }

                    /// Get the computed value for -moz-box-align.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_align(&self) -> longhands::_moz_box_align::computed_value::T {
                        self._moz_box_align.clone()
                    }
                        /// Set -moz-box-direction.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_direction(&mut self, v: longhands::_moz_box_direction::computed_value::T) {
                            self._moz_box_direction = v;
                        }
                        /// Set -moz-box-direction from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_direction_from(&mut self, other: &Self) {
                            self._moz_box_direction = other._moz_box_direction.clone();
                        }
                    /// Reset -moz-box-direction from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_direction(&mut self, other: &Self) {
                        self.copy__moz_box_direction_from(other)
                    }

                    /// Get the computed value for -moz-box-direction.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_direction(&self) -> longhands::_moz_box_direction::computed_value::T {
                        self._moz_box_direction.clone()
                    }
                        /// Set -moz-box-flex.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_flex(&mut self, v: longhands::_moz_box_flex::computed_value::T) {
                            self._moz_box_flex = v;
                        }
                        /// Set -moz-box-flex from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_flex_from(&mut self, other: &Self) {
                            self._moz_box_flex = other._moz_box_flex.clone();
                        }
                    /// Reset -moz-box-flex from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_flex(&mut self, other: &Self) {
                        self.copy__moz_box_flex_from(other)
                    }

                    /// Get the computed value for -moz-box-flex.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_flex(&self) -> longhands::_moz_box_flex::computed_value::T {
                        self._moz_box_flex.clone()
                    }
                        /// Set -moz-box-orient.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_orient(&mut self, v: longhands::_moz_box_orient::computed_value::T) {
                            self._moz_box_orient = v;
                        }
                        /// Set -moz-box-orient from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_orient_from(&mut self, other: &Self) {
                            self._moz_box_orient = other._moz_box_orient.clone();
                        }
                    /// Reset -moz-box-orient from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_orient(&mut self, other: &Self) {
                        self.copy__moz_box_orient_from(other)
                    }

                    /// Get the computed value for -moz-box-orient.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_orient(&self) -> longhands::_moz_box_orient::computed_value::T {
                        self._moz_box_orient.clone()
                    }
                        /// Set -moz-box-pack.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_pack(&mut self, v: longhands::_moz_box_pack::computed_value::T) {
                            self._moz_box_pack = v;
                        }
                        /// Set -moz-box-pack from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_pack_from(&mut self, other: &Self) {
                            self._moz_box_pack = other._moz_box_pack.clone();
                        }
                    /// Reset -moz-box-pack from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_pack(&mut self, other: &Self) {
                        self.copy__moz_box_pack_from(other)
                    }

                    /// Get the computed value for -moz-box-pack.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_pack(&self) -> longhands::_moz_box_pack::computed_value::T {
                        self._moz_box_pack.clone()
                    }
                        /// Set -moz-stack-sizing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_stack_sizing(&mut self, v: longhands::_moz_stack_sizing::computed_value::T) {
                            self._moz_stack_sizing = v;
                        }
                        /// Set -moz-stack-sizing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_stack_sizing_from(&mut self, other: &Self) {
                            self._moz_stack_sizing = other._moz_stack_sizing.clone();
                        }
                    /// Reset -moz-stack-sizing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_stack_sizing(&mut self, other: &Self) {
                        self.copy__moz_stack_sizing_from(other)
                    }

                    /// Get the computed value for -moz-stack-sizing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_stack_sizing(&self) -> longhands::_moz_stack_sizing::computed_value::T {
                        self._moz_stack_sizing.clone()
                    }
                        /// Set -moz-box-ordinal-group.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_ordinal_group(&mut self, v: longhands::_moz_box_ordinal_group::computed_value::T) {
                            self._moz_box_ordinal_group = v;
                        }
                        /// Set -moz-box-ordinal-group from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_ordinal_group_from(&mut self, other: &Self) {
                            self._moz_box_ordinal_group = other._moz_box_ordinal_group.clone();
                        }
                    /// Reset -moz-box-ordinal-group from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_ordinal_group(&mut self, other: &Self) {
                        self.copy__moz_box_ordinal_group_from(other)
                    }

                    /// Get the computed value for -moz-box-ordinal-group.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_ordinal_group(&self) -> longhands::_moz_box_ordinal_group::computed_value::T {
                        self._moz_box_ordinal_group.clone()
                    }
        }

}

    impl style_structs::Background {

    }

    impl style_structs::Border {

    }

    impl style_structs::Box {
                /// Iterate over the values of transition-duration.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_duration_iter(&self) -> TransitionDurationIter {
                    TransitionDurationIter {
                        style_struct: self,
                        current: 0,
                        max: self.transition_duration_count(),
                    }
                }

                /// Get a value mod `index` for the property transition-duration.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_duration_mod(&self, index: usize)
                    -> longhands::transition_duration::computed_value::SingleComputedValue {
                    self.transition_duration_at(index % self.transition_duration_count())
                }
                /// Iterate over the values of transition-timing-function.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_timing_function_iter(&self) -> TransitionTimingFunctionIter {
                    TransitionTimingFunctionIter {
                        style_struct: self,
                        current: 0,
                        max: self.transition_timing_function_count(),
                    }
                }

                /// Get a value mod `index` for the property transition-timing-function.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_timing_function_mod(&self, index: usize)
                    -> longhands::transition_timing_function::computed_value::SingleComputedValue {
                    self.transition_timing_function_at(index % self.transition_timing_function_count())
                }
                /// Iterate over the values of transition-property.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_property_iter(&self) -> TransitionPropertyIter {
                    TransitionPropertyIter {
                        style_struct: self,
                        current: 0,
                        max: self.transition_property_count(),
                    }
                }

                /// Get a value mod `index` for the property transition-property.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_property_mod(&self, index: usize)
                    -> longhands::transition_property::computed_value::SingleComputedValue {
                    self.transition_property_at(index % self.transition_property_count())
                }
                /// Iterate over the values of transition-delay.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_delay_iter(&self) -> TransitionDelayIter {
                    TransitionDelayIter {
                        style_struct: self,
                        current: 0,
                        max: self.transition_delay_count(),
                    }
                }

                /// Get a value mod `index` for the property transition-delay.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_delay_mod(&self, index: usize)
                    -> longhands::transition_delay::computed_value::SingleComputedValue {
                    self.transition_delay_at(index % self.transition_delay_count())
                }
                /// Iterate over the values of animation-name.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_name_iter(&self) -> AnimationNameIter {
                    AnimationNameIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_name_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-name.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_name_mod(&self, index: usize)
                    -> longhands::animation_name::computed_value::SingleComputedValue {
                    self.animation_name_at(index % self.animation_name_count())
                }
                /// Iterate over the values of animation-duration.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_duration_iter(&self) -> AnimationDurationIter {
                    AnimationDurationIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_duration_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-duration.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_duration_mod(&self, index: usize)
                    -> longhands::animation_duration::computed_value::SingleComputedValue {
                    self.animation_duration_at(index % self.animation_duration_count())
                }
                /// Iterate over the values of animation-timing-function.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_timing_function_iter(&self) -> AnimationTimingFunctionIter {
                    AnimationTimingFunctionIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_timing_function_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-timing-function.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_timing_function_mod(&self, index: usize)
                    -> longhands::animation_timing_function::computed_value::SingleComputedValue {
                    self.animation_timing_function_at(index % self.animation_timing_function_count())
                }
                /// Iterate over the values of animation-iteration-count.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_iteration_count_iter(&self) -> AnimationIterationCountIter {
                    AnimationIterationCountIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_iteration_count_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-iteration-count.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_iteration_count_mod(&self, index: usize)
                    -> longhands::animation_iteration_count::computed_value::SingleComputedValue {
                    self.animation_iteration_count_at(index % self.animation_iteration_count_count())
                }
                /// Iterate over the values of animation-direction.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_direction_iter(&self) -> AnimationDirectionIter {
                    AnimationDirectionIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_direction_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-direction.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_direction_mod(&self, index: usize)
                    -> longhands::animation_direction::computed_value::SingleComputedValue {
                    self.animation_direction_at(index % self.animation_direction_count())
                }
                /// Iterate over the values of animation-play-state.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_play_state_iter(&self) -> AnimationPlayStateIter {
                    AnimationPlayStateIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_play_state_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-play-state.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_play_state_mod(&self, index: usize)
                    -> longhands::animation_play_state::computed_value::SingleComputedValue {
                    self.animation_play_state_at(index % self.animation_play_state_count())
                }
                /// Iterate over the values of animation-fill-mode.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_fill_mode_iter(&self) -> AnimationFillModeIter {
                    AnimationFillModeIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_fill_mode_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-fill-mode.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_fill_mode_mod(&self, index: usize)
                    -> longhands::animation_fill_mode::computed_value::SingleComputedValue {
                    self.animation_fill_mode_at(index % self.animation_fill_mode_count())
                }
                /// Iterate over the values of animation-delay.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_delay_iter(&self) -> AnimationDelayIter {
                    AnimationDelayIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_delay_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-delay.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_delay_mod(&self, index: usize)
                    -> longhands::animation_delay::computed_value::SingleComputedValue {
                    self.animation_delay_at(index % self.animation_delay_count())
                }

            /// Returns whether there is any animation specified with
            /// animation-name other than `none`.
            pub fn specifies_animations(&self) -> bool {
                self.animation_name_iter().any(|name| name.0.is_some())
            }

            /// Returns whether there are any transitions specified.
            #[cfg(feature = "servo")]
            pub fn specifies_transitions(&self) -> bool {
                self.transition_duration_iter()
                    .take(self.transition_property_count())
                    .any(|t| t.seconds() > 0.)
            }
    }

            /// An iterator over the values of the transition-duration properties.
            pub struct TransitionDurationIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for TransitionDurationIter<'a> {
                type Item = longhands::transition_duration::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.transition_duration_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the transition-timing-function properties.
            pub struct TransitionTimingFunctionIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for TransitionTimingFunctionIter<'a> {
                type Item = longhands::transition_timing_function::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.transition_timing_function_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the transition-property properties.
            pub struct TransitionPropertyIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for TransitionPropertyIter<'a> {
                type Item = longhands::transition_property::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.transition_property_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the transition-delay properties.
            pub struct TransitionDelayIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for TransitionDelayIter<'a> {
                type Item = longhands::transition_delay::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.transition_delay_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-name properties.
            pub struct AnimationNameIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationNameIter<'a> {
                type Item = longhands::animation_name::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_name_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-duration properties.
            pub struct AnimationDurationIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationDurationIter<'a> {
                type Item = longhands::animation_duration::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_duration_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-timing-function properties.
            pub struct AnimationTimingFunctionIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationTimingFunctionIter<'a> {
                type Item = longhands::animation_timing_function::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_timing_function_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-iteration-count properties.
            pub struct AnimationIterationCountIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationIterationCountIter<'a> {
                type Item = longhands::animation_iteration_count::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_iteration_count_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-direction properties.
            pub struct AnimationDirectionIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationDirectionIter<'a> {
                type Item = longhands::animation_direction::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_direction_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-play-state properties.
            pub struct AnimationPlayStateIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationPlayStateIter<'a> {
                type Item = longhands::animation_play_state::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_play_state_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-fill-mode properties.
            pub struct AnimationFillModeIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationFillModeIter<'a> {
                type Item = longhands::animation_fill_mode::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_fill_mode_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-delay properties.
            pub struct AnimationDelayIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationDelayIter<'a> {
                type Item = longhands::animation_delay::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_delay_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
    impl style_structs::Color {

    }

    impl style_structs::Column {

            /// Whether this is a multicol style.
            #[cfg(feature = "servo")]
            pub fn is_multicol(&self) -> bool {
                match self.column_width {
                    Either::First(_width) => true,
                    Either::Second(_auto) => !self.column_count.is_auto(),
                }
            }
    }

    impl style_structs::Counters {

    }

    impl style_structs::Effects {

    }

    impl style_structs::Font {

    }

    impl style_structs::InheritedBox {

    }

    impl style_structs::InheritedTable {

    }

    impl style_structs::InheritedText {

    }

    impl style_structs::List {

    }

    impl style_structs::Margin {

    }

    impl style_structs::Outline {

    }

    impl style_structs::Padding {

    }

    impl style_structs::Pointing {

    }

    impl style_structs::Position {

    }

    impl style_structs::Table {

    }

    impl style_structs::Text {

    }

    impl style_structs::UI {

    }

    impl style_structs::InheritedSVG {

    }

    impl style_structs::SVG {

    }

    impl style_structs::XUL {

    }



#[cfg(feature = "gecko")]
pub use gecko_properties::{ComputedValues, ComputedValuesInner};

#[cfg(feature = "servo")]
#[cfg_attr(feature = "servo", derive(Clone, Debug))]
/// Actual data of ComputedValues, to match up with Gecko
pub struct ComputedValuesInner {
        background: Arc<style_structs::Background>,
        border: Arc<style_structs::Border>,
        box_: Arc<style_structs::Box>,
        color: Arc<style_structs::Color>,
        column: Arc<style_structs::Column>,
        counters: Arc<style_structs::Counters>,
        effects: Arc<style_structs::Effects>,
        font: Arc<style_structs::Font>,
        inheritedbox: Arc<style_structs::InheritedBox>,
        inheritedtable: Arc<style_structs::InheritedTable>,
        inheritedtext: Arc<style_structs::InheritedText>,
        list: Arc<style_structs::List>,
        margin: Arc<style_structs::Margin>,
        outline: Arc<style_structs::Outline>,
        padding: Arc<style_structs::Padding>,
        pointing: Arc<style_structs::Pointing>,
        position: Arc<style_structs::Position>,
        table: Arc<style_structs::Table>,
        text: Arc<style_structs::Text>,
        ui: Arc<style_structs::UI>,
        inheritedsvg: Arc<style_structs::InheritedSVG>,
        svg: Arc<style_structs::SVG>,
        xul: Arc<style_structs::XUL>,
    custom_properties: Option<Arc<::custom_properties::CustomPropertiesMap>>,
    /// The writing mode of this computed values struct.
    pub writing_mode: WritingMode,

    /// A set of flags we use to store misc information regarding this style.
    pub flags: ComputedValueFlags,

    /// The rule node representing the ordered list of rules matched for this
    /// node.  Can be None for default values and text nodes.  This is
    /// essentially an optimization to avoid referencing the root rule node.
    pub rules: Option<StrongRuleNode>,

    /// The element's computed values if visited, only computed if there's a
    /// relevant link for this element. A element's "relevant link" is the
    /// element being matched if it is a link or the nearest ancestor link.
    visited_style: Option<Arc<ComputedValues>>,
}

/// The struct that Servo uses to represent computed values.
///
/// This struct contains an immutable atomically-reference-counted pointer to
/// every kind of style struct.
///
/// When needed, the structs may be copied in order to get mutated.
#[cfg(feature = "servo")]
#[cfg_attr(feature = "servo", derive(Clone, Debug))]
pub struct ComputedValues {
    /// The actual computed values
    ///
    /// In Gecko the outer ComputedValues is actually a style context,
    /// whereas ComputedValuesInner is the core set of computed values.
    ///
    /// We maintain this distinction in servo to reduce the amount of special casing.
    inner: ComputedValuesInner,
}

impl ComputedValues {
    /// Returns whether this style's display value is equal to contents.
    pub fn is_display_contents(&self) -> bool {
        self.get_box().clone_display().is_contents()
    }

    /// Whether we're a visited style.
    pub fn is_style_if_visited(&self) -> bool {
        self.flags.contains(ComputedValueFlags::IS_STYLE_IF_VISITED)
    }

    /// Gets a reference to the rule node. Panic if no rule node exists.
    pub fn rules(&self) -> &StrongRuleNode {
        self.rules.as_ref().unwrap()
    }

    /// Returns the visited style, if any.
    pub fn visited_style(&self) -> Option<&ComputedValues> {
        self.visited_style.as_ref().map(|s| &**s)
    }

    /// Returns the visited rules, if applicable.
    pub fn visited_rules(&self) -> Option<&StrongRuleNode> {
        self.visited_style.as_ref().and_then(|s| s.rules.as_ref())
    }

    /// Returns whether we're in a display: none subtree.
    pub fn is_in_display_none_subtree(&self) -> bool {
        use properties::computed_value_flags::ComputedValueFlags;

        self.flags.contains(ComputedValueFlags::IS_IN_DISPLAY_NONE_SUBTREE)
    }

    /// Gets a reference to the custom properties map (if one exists).
    pub fn custom_properties(&self) -> Option<&Arc<::custom_properties::CustomPropertiesMap>> {
        self.custom_properties.as_ref()
    }
}

#[cfg(feature = "servo")]
impl ComputedValues {
    /// Create a new refcounted `ComputedValues`
    pub fn new(
        _: &Device,
        _: Option<&ComputedValues>,
        _: Option<&PseudoElement>,
        custom_properties: Option<Arc<::custom_properties::CustomPropertiesMap>>,
        writing_mode: WritingMode,
        flags: ComputedValueFlags,
        rules: Option<StrongRuleNode>,
        visited_style: Option<Arc<ComputedValues>>,
        background: Arc<style_structs::Background>,
        border: Arc<style_structs::Border>,
        box_: Arc<style_structs::Box>,
        color: Arc<style_structs::Color>,
        column: Arc<style_structs::Column>,
        counters: Arc<style_structs::Counters>,
        effects: Arc<style_structs::Effects>,
        font: Arc<style_structs::Font>,
        inheritedbox: Arc<style_structs::InheritedBox>,
        inheritedtable: Arc<style_structs::InheritedTable>,
        inheritedtext: Arc<style_structs::InheritedText>,
        list: Arc<style_structs::List>,
        margin: Arc<style_structs::Margin>,
        outline: Arc<style_structs::Outline>,
        padding: Arc<style_structs::Padding>,
        pointing: Arc<style_structs::Pointing>,
        position: Arc<style_structs::Position>,
        table: Arc<style_structs::Table>,
        text: Arc<style_structs::Text>,
        ui: Arc<style_structs::UI>,
        inheritedsvg: Arc<style_structs::InheritedSVG>,
        svg: Arc<style_structs::SVG>,
        xul: Arc<style_structs::XUL>,
    ) -> Arc<Self> {
        Arc::new(Self {
            inner: ComputedValuesInner {
                custom_properties,
                writing_mode,
                rules,
                visited_style,
                flags,
                background,
                border,
                box_,
                color,
                column,
                counters,
                effects,
                font,
                inheritedbox,
                inheritedtable,
                inheritedtext,
                list,
                margin,
                outline,
                padding,
                pointing,
                position,
                table,
                text,
                ui,
                inheritedsvg,
                svg,
                xul,
            }
        })
    }

    /// Get the initial computed values.
    pub fn initial_values() -> &'static Self { &*INITIAL_SERVO_VALUES }
}

#[cfg(feature = "servo")]
impl ops::Deref for ComputedValues {
    type Target = ComputedValuesInner;
    fn deref(&self) -> &ComputedValuesInner {
        &self.inner
    }
}

#[cfg(feature = "servo")]
impl ops::DerefMut for ComputedValues {
    fn deref_mut(&mut self) -> &mut ComputedValuesInner {
        &mut self.inner
    }
}

#[cfg(feature = "servo")]
impl ComputedValuesInner {
        /// Clone the Background struct.
        #[inline]
        pub fn clone_background(&self) -> Arc<style_structs::Background> {
            self.background.clone()
        }

        /// Get a immutable reference to the Background struct.
        #[inline]
        pub fn get_background(&self) -> &style_structs::Background {
            &self.background
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Background`.
        pub fn background_arc(&self) -> &Arc<style_structs::Background> {
            &self.background
        }

        /// Get a mutable reference to the Background struct.
        #[inline]
        pub fn mutate_background(&mut self) -> &mut style_structs::Background {
            Arc::make_mut(&mut self.background)
        }
        /// Clone the Border struct.
        #[inline]
        pub fn clone_border(&self) -> Arc<style_structs::Border> {
            self.border.clone()
        }

        /// Get a immutable reference to the Border struct.
        #[inline]
        pub fn get_border(&self) -> &style_structs::Border {
            &self.border
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Border`.
        pub fn border_arc(&self) -> &Arc<style_structs::Border> {
            &self.border
        }

        /// Get a mutable reference to the Border struct.
        #[inline]
        pub fn mutate_border(&mut self) -> &mut style_structs::Border {
            Arc::make_mut(&mut self.border)
        }
        /// Clone the Box struct.
        #[inline]
        pub fn clone_box(&self) -> Arc<style_structs::Box> {
            self.box_.clone()
        }

        /// Get a immutable reference to the Box struct.
        #[inline]
        pub fn get_box(&self) -> &style_structs::Box {
            &self.box_
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Box`.
        pub fn box_arc(&self) -> &Arc<style_structs::Box> {
            &self.box_
        }

        /// Get a mutable reference to the Box struct.
        #[inline]
        pub fn mutate_box(&mut self) -> &mut style_structs::Box {
            Arc::make_mut(&mut self.box_)
        }
        /// Clone the Color struct.
        #[inline]
        pub fn clone_color(&self) -> Arc<style_structs::Color> {
            self.color.clone()
        }

        /// Get a immutable reference to the Color struct.
        #[inline]
        pub fn get_color(&self) -> &style_structs::Color {
            &self.color
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Color`.
        pub fn color_arc(&self) -> &Arc<style_structs::Color> {
            &self.color
        }

        /// Get a mutable reference to the Color struct.
        #[inline]
        pub fn mutate_color(&mut self) -> &mut style_structs::Color {
            Arc::make_mut(&mut self.color)
        }
        /// Clone the Column struct.
        #[inline]
        pub fn clone_column(&self) -> Arc<style_structs::Column> {
            self.column.clone()
        }

        /// Get a immutable reference to the Column struct.
        #[inline]
        pub fn get_column(&self) -> &style_structs::Column {
            &self.column
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Column`.
        pub fn column_arc(&self) -> &Arc<style_structs::Column> {
            &self.column
        }

        /// Get a mutable reference to the Column struct.
        #[inline]
        pub fn mutate_column(&mut self) -> &mut style_structs::Column {
            Arc::make_mut(&mut self.column)
        }
        /// Clone the Counters struct.
        #[inline]
        pub fn clone_counters(&self) -> Arc<style_structs::Counters> {
            self.counters.clone()
        }

        /// Get a immutable reference to the Counters struct.
        #[inline]
        pub fn get_counters(&self) -> &style_structs::Counters {
            &self.counters
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Counters`.
        pub fn counters_arc(&self) -> &Arc<style_structs::Counters> {
            &self.counters
        }

        /// Get a mutable reference to the Counters struct.
        #[inline]
        pub fn mutate_counters(&mut self) -> &mut style_structs::Counters {
            Arc::make_mut(&mut self.counters)
        }
        /// Clone the Effects struct.
        #[inline]
        pub fn clone_effects(&self) -> Arc<style_structs::Effects> {
            self.effects.clone()
        }

        /// Get a immutable reference to the Effects struct.
        #[inline]
        pub fn get_effects(&self) -> &style_structs::Effects {
            &self.effects
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Effects`.
        pub fn effects_arc(&self) -> &Arc<style_structs::Effects> {
            &self.effects
        }

        /// Get a mutable reference to the Effects struct.
        #[inline]
        pub fn mutate_effects(&mut self) -> &mut style_structs::Effects {
            Arc::make_mut(&mut self.effects)
        }
        /// Clone the Font struct.
        #[inline]
        pub fn clone_font(&self) -> Arc<style_structs::Font> {
            self.font.clone()
        }

        /// Get a immutable reference to the Font struct.
        #[inline]
        pub fn get_font(&self) -> &style_structs::Font {
            &self.font
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Font`.
        pub fn font_arc(&self) -> &Arc<style_structs::Font> {
            &self.font
        }

        /// Get a mutable reference to the Font struct.
        #[inline]
        pub fn mutate_font(&mut self) -> &mut style_structs::Font {
            Arc::make_mut(&mut self.font)
        }
        /// Clone the InheritedBox struct.
        #[inline]
        pub fn clone_inheritedbox(&self) -> Arc<style_structs::InheritedBox> {
            self.inheritedbox.clone()
        }

        /// Get a immutable reference to the InheritedBox struct.
        #[inline]
        pub fn get_inheritedbox(&self) -> &style_structs::InheritedBox {
            &self.inheritedbox
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `InheritedBox`.
        pub fn inheritedbox_arc(&self) -> &Arc<style_structs::InheritedBox> {
            &self.inheritedbox
        }

        /// Get a mutable reference to the InheritedBox struct.
        #[inline]
        pub fn mutate_inheritedbox(&mut self) -> &mut style_structs::InheritedBox {
            Arc::make_mut(&mut self.inheritedbox)
        }
        /// Clone the InheritedTable struct.
        #[inline]
        pub fn clone_inheritedtable(&self) -> Arc<style_structs::InheritedTable> {
            self.inheritedtable.clone()
        }

        /// Get a immutable reference to the InheritedTable struct.
        #[inline]
        pub fn get_inheritedtable(&self) -> &style_structs::InheritedTable {
            &self.inheritedtable
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `InheritedTable`.
        pub fn inheritedtable_arc(&self) -> &Arc<style_structs::InheritedTable> {
            &self.inheritedtable
        }

        /// Get a mutable reference to the InheritedTable struct.
        #[inline]
        pub fn mutate_inheritedtable(&mut self) -> &mut style_structs::InheritedTable {
            Arc::make_mut(&mut self.inheritedtable)
        }
        /// Clone the InheritedText struct.
        #[inline]
        pub fn clone_inheritedtext(&self) -> Arc<style_structs::InheritedText> {
            self.inheritedtext.clone()
        }

        /// Get a immutable reference to the InheritedText struct.
        #[inline]
        pub fn get_inheritedtext(&self) -> &style_structs::InheritedText {
            &self.inheritedtext
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `InheritedText`.
        pub fn inheritedtext_arc(&self) -> &Arc<style_structs::InheritedText> {
            &self.inheritedtext
        }

        /// Get a mutable reference to the InheritedText struct.
        #[inline]
        pub fn mutate_inheritedtext(&mut self) -> &mut style_structs::InheritedText {
            Arc::make_mut(&mut self.inheritedtext)
        }
        /// Clone the List struct.
        #[inline]
        pub fn clone_list(&self) -> Arc<style_structs::List> {
            self.list.clone()
        }

        /// Get a immutable reference to the List struct.
        #[inline]
        pub fn get_list(&self) -> &style_structs::List {
            &self.list
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `List`.
        pub fn list_arc(&self) -> &Arc<style_structs::List> {
            &self.list
        }

        /// Get a mutable reference to the List struct.
        #[inline]
        pub fn mutate_list(&mut self) -> &mut style_structs::List {
            Arc::make_mut(&mut self.list)
        }
        /// Clone the Margin struct.
        #[inline]
        pub fn clone_margin(&self) -> Arc<style_structs::Margin> {
            self.margin.clone()
        }

        /// Get a immutable reference to the Margin struct.
        #[inline]
        pub fn get_margin(&self) -> &style_structs::Margin {
            &self.margin
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Margin`.
        pub fn margin_arc(&self) -> &Arc<style_structs::Margin> {
            &self.margin
        }

        /// Get a mutable reference to the Margin struct.
        #[inline]
        pub fn mutate_margin(&mut self) -> &mut style_structs::Margin {
            Arc::make_mut(&mut self.margin)
        }
        /// Clone the Outline struct.
        #[inline]
        pub fn clone_outline(&self) -> Arc<style_structs::Outline> {
            self.outline.clone()
        }

        /// Get a immutable reference to the Outline struct.
        #[inline]
        pub fn get_outline(&self) -> &style_structs::Outline {
            &self.outline
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Outline`.
        pub fn outline_arc(&self) -> &Arc<style_structs::Outline> {
            &self.outline
        }

        /// Get a mutable reference to the Outline struct.
        #[inline]
        pub fn mutate_outline(&mut self) -> &mut style_structs::Outline {
            Arc::make_mut(&mut self.outline)
        }
        /// Clone the Padding struct.
        #[inline]
        pub fn clone_padding(&self) -> Arc<style_structs::Padding> {
            self.padding.clone()
        }

        /// Get a immutable reference to the Padding struct.
        #[inline]
        pub fn get_padding(&self) -> &style_structs::Padding {
            &self.padding
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Padding`.
        pub fn padding_arc(&self) -> &Arc<style_structs::Padding> {
            &self.padding
        }

        /// Get a mutable reference to the Padding struct.
        #[inline]
        pub fn mutate_padding(&mut self) -> &mut style_structs::Padding {
            Arc::make_mut(&mut self.padding)
        }
        /// Clone the Pointing struct.
        #[inline]
        pub fn clone_pointing(&self) -> Arc<style_structs::Pointing> {
            self.pointing.clone()
        }

        /// Get a immutable reference to the Pointing struct.
        #[inline]
        pub fn get_pointing(&self) -> &style_structs::Pointing {
            &self.pointing
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Pointing`.
        pub fn pointing_arc(&self) -> &Arc<style_structs::Pointing> {
            &self.pointing
        }

        /// Get a mutable reference to the Pointing struct.
        #[inline]
        pub fn mutate_pointing(&mut self) -> &mut style_structs::Pointing {
            Arc::make_mut(&mut self.pointing)
        }
        /// Clone the Position struct.
        #[inline]
        pub fn clone_position(&self) -> Arc<style_structs::Position> {
            self.position.clone()
        }

        /// Get a immutable reference to the Position struct.
        #[inline]
        pub fn get_position(&self) -> &style_structs::Position {
            &self.position
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Position`.
        pub fn position_arc(&self) -> &Arc<style_structs::Position> {
            &self.position
        }

        /// Get a mutable reference to the Position struct.
        #[inline]
        pub fn mutate_position(&mut self) -> &mut style_structs::Position {
            Arc::make_mut(&mut self.position)
        }
        /// Clone the Table struct.
        #[inline]
        pub fn clone_table(&self) -> Arc<style_structs::Table> {
            self.table.clone()
        }

        /// Get a immutable reference to the Table struct.
        #[inline]
        pub fn get_table(&self) -> &style_structs::Table {
            &self.table
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Table`.
        pub fn table_arc(&self) -> &Arc<style_structs::Table> {
            &self.table
        }

        /// Get a mutable reference to the Table struct.
        #[inline]
        pub fn mutate_table(&mut self) -> &mut style_structs::Table {
            Arc::make_mut(&mut self.table)
        }
        /// Clone the Text struct.
        #[inline]
        pub fn clone_text(&self) -> Arc<style_structs::Text> {
            self.text.clone()
        }

        /// Get a immutable reference to the Text struct.
        #[inline]
        pub fn get_text(&self) -> &style_structs::Text {
            &self.text
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Text`.
        pub fn text_arc(&self) -> &Arc<style_structs::Text> {
            &self.text
        }

        /// Get a mutable reference to the Text struct.
        #[inline]
        pub fn mutate_text(&mut self) -> &mut style_structs::Text {
            Arc::make_mut(&mut self.text)
        }
        /// Clone the UI struct.
        #[inline]
        pub fn clone_ui(&self) -> Arc<style_structs::UI> {
            self.ui.clone()
        }

        /// Get a immutable reference to the UI struct.
        #[inline]
        pub fn get_ui(&self) -> &style_structs::UI {
            &self.ui
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `UI`.
        pub fn ui_arc(&self) -> &Arc<style_structs::UI> {
            &self.ui
        }

        /// Get a mutable reference to the UI struct.
        #[inline]
        pub fn mutate_ui(&mut self) -> &mut style_structs::UI {
            Arc::make_mut(&mut self.ui)
        }
        /// Clone the InheritedSVG struct.
        #[inline]
        pub fn clone_inheritedsvg(&self) -> Arc<style_structs::InheritedSVG> {
            self.inheritedsvg.clone()
        }

        /// Get a immutable reference to the InheritedSVG struct.
        #[inline]
        pub fn get_inheritedsvg(&self) -> &style_structs::InheritedSVG {
            &self.inheritedsvg
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `InheritedSVG`.
        pub fn inheritedsvg_arc(&self) -> &Arc<style_structs::InheritedSVG> {
            &self.inheritedsvg
        }

        /// Get a mutable reference to the InheritedSVG struct.
        #[inline]
        pub fn mutate_inheritedsvg(&mut self) -> &mut style_structs::InheritedSVG {
            Arc::make_mut(&mut self.inheritedsvg)
        }
        /// Clone the SVG struct.
        #[inline]
        pub fn clone_svg(&self) -> Arc<style_structs::SVG> {
            self.svg.clone()
        }

        /// Get a immutable reference to the SVG struct.
        #[inline]
        pub fn get_svg(&self) -> &style_structs::SVG {
            &self.svg
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `SVG`.
        pub fn svg_arc(&self) -> &Arc<style_structs::SVG> {
            &self.svg
        }

        /// Get a mutable reference to the SVG struct.
        #[inline]
        pub fn mutate_svg(&mut self) -> &mut style_structs::SVG {
            Arc::make_mut(&mut self.svg)
        }
        /// Clone the XUL struct.
        #[inline]
        pub fn clone_xul(&self) -> Arc<style_structs::XUL> {
            self.xul.clone()
        }

        /// Get a immutable reference to the XUL struct.
        #[inline]
        pub fn get_xul(&self) -> &style_structs::XUL {
            &self.xul
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `XUL`.
        pub fn xul_arc(&self) -> &Arc<style_structs::XUL> {
            &self.xul
        }

        /// Get a mutable reference to the XUL struct.
        #[inline]
        pub fn mutate_xul(&mut self) -> &mut style_structs::XUL {
            Arc::make_mut(&mut self.xul)
        }

    /// Gets a reference to the rule node. Panic if no rule node exists.
    pub fn rules(&self) -> &StrongRuleNode {
        self.rules.as_ref().unwrap()
    }

    /// Whether this style has a -moz-binding value. This is always false for
    /// Servo for obvious reasons.
    pub fn has_moz_binding(&self) -> bool { false }

    #[inline]
    /// Returns whether the "content" property for the given style is completely
    /// ineffective, and would yield an empty `::before` or `::after`
    /// pseudo-element.
    pub fn ineffective_content_property(&self) -> bool {
        use properties::longhands::content::computed_value::T;
        match self.get_counters().content {
            T::Normal | T::None => true,
            T::Items(ref items) => items.is_empty(),
        }
    }

    /// Whether the current style or any of its ancestors is multicolumn.
    #[inline]
    pub fn can_be_fragmented(&self) -> bool {
        self.flags.contains(ComputedValueFlags::CAN_BE_FRAGMENTED)
    }

    /// Whether the current style is multicolumn.
    #[inline]
    pub fn is_multicol(&self) -> bool {
        self.get_column().is_multicol()
    }

    /// Resolves the currentColor keyword.
    ///
    /// Any color value from computed values (except for the 'color' property
    /// itself) should go through this method.
    ///
    /// Usage example:
    /// let top_color = style.resolve_color(style.Border.border_top_color);
    #[inline]
    pub fn resolve_color(&self, color: computed::Color) -> RGBA {
        color.to_rgba(self.get_color().color)
    }

    /// Get the logical computed inline size.
    #[inline]
    pub fn content_inline_size(&self) -> computed::LengthOrPercentageOrAuto {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() {
            position_style.height
        } else {
            position_style.width
        }
    }

    /// Get the logical computed block size.
    #[inline]
    pub fn content_block_size(&self) -> computed::LengthOrPercentageOrAuto {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() { position_style.width } else { position_style.height }
    }

    /// Get the logical computed min inline size.
    #[inline]
    pub fn min_inline_size(&self) -> computed::LengthOrPercentage {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() { position_style.min_height } else { position_style.min_width }
    }

    /// Get the logical computed min block size.
    #[inline]
    pub fn min_block_size(&self) -> computed::LengthOrPercentage {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() { position_style.min_width } else { position_style.min_height }
    }

    /// Get the logical computed max inline size.
    #[inline]
    pub fn max_inline_size(&self) -> computed::LengthOrPercentageOrNone {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() { position_style.max_height } else { position_style.max_width }
    }

    /// Get the logical computed max block size.
    #[inline]
    pub fn max_block_size(&self) -> computed::LengthOrPercentageOrNone {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() { position_style.max_width } else { position_style.max_height }
    }

    /// Get the logical computed padding for this writing mode.
    #[inline]
    pub fn logical_padding(&self) -> LogicalMargin<computed::LengthOrPercentage> {
        let padding_style = self.get_padding();
        LogicalMargin::from_physical(self.writing_mode, SideOffsets2D::new(
            padding_style.padding_top.0,
            padding_style.padding_right.0,
            padding_style.padding_bottom.0,
            padding_style.padding_left.0,
        ))
    }

    /// Get the logical border width
    #[inline]
    pub fn border_width_for_writing_mode(&self, writing_mode: WritingMode) -> LogicalMargin<Au> {
        let border_style = self.get_border();
        LogicalMargin::from_physical(writing_mode, SideOffsets2D::new(
            Au::from(border_style.border_top_width),
            Au::from(border_style.border_right_width),
            Au::from(border_style.border_bottom_width),
            Au::from(border_style.border_left_width),
        ))
    }

    /// Gets the logical computed border widths for this style.
    #[inline]
    pub fn logical_border_width(&self) -> LogicalMargin<Au> {
        self.border_width_for_writing_mode(self.writing_mode)
    }

    /// Gets the logical computed margin from this style.
    #[inline]
    pub fn logical_margin(&self) -> LogicalMargin<computed::LengthOrPercentageOrAuto> {
        let margin_style = self.get_margin();
        LogicalMargin::from_physical(self.writing_mode, SideOffsets2D::new(
            margin_style.margin_top,
            margin_style.margin_right,
            margin_style.margin_bottom,
            margin_style.margin_left,
        ))
    }

    /// Gets the logical position from this style.
    #[inline]
    pub fn logical_position(&self) -> LogicalMargin<computed::LengthOrPercentageOrAuto> {
        // FIXME(SimonSapin): should be the writing mode of the containing block, maybe?
        let position_style = self.get_position();
        LogicalMargin::from_physical(self.writing_mode, SideOffsets2D::new(
            position_style.top,
            position_style.right,
            position_style.bottom,
            position_style.left,
        ))
    }

    /// Return true if the effects force the transform style to be Flat
    pub fn overrides_transform_style(&self) -> bool {
        use computed_values::mix_blend_mode::T as MixBlendMode;

        let effects = self.get_effects();
        // TODO(gw): Add clip-path, isolation, mask-image, mask-border-source when supported.
        effects.opacity < 1.0 ||
           !effects.filter.0.is_empty() ||
           !effects.clip.is_auto() ||
           effects.mix_blend_mode != MixBlendMode::Normal
    }

    /// <https://drafts.csswg.org/css-transforms/#grouping-property-values>
    pub fn get_used_transform_style(&self) -> computed_values::transform_style::T {
        use computed_values::transform_style::T as TransformStyle;

        let box_ = self.get_box();

        if self.overrides_transform_style() {
            TransformStyle::Flat
        } else {
            // Return the computed value if not overridden by the above exceptions
            box_.transform_style
        }
    }

    /// Whether given this transform value, the compositor would require a
    /// layer.
    pub fn transform_requires_layer(&self) -> bool {
        use values::generics::transform::TransformOperation;
        // Check if the transform matrix is 2D or 3D
        for transform in &self.get_box().transform.0 {
            match *transform {
                TransformOperation::Perspective(..) => {
                    return true;
                }
                TransformOperation::Matrix3D(m) => {
                    // See http://dev.w3.org/csswg/css-transforms/#2d-matrix
                    if m.m31 != 0.0 || m.m32 != 0.0 ||
                       m.m13 != 0.0 || m.m23 != 0.0 ||
                       m.m43 != 0.0 || m.m14 != 0.0 ||
                       m.m24 != 0.0 || m.m34 != 0.0 ||
                       m.m33 != 1.0 || m.m44 != 1.0 {
                        return true;
                    }
                }
                TransformOperation::Translate3D(_, _, z) |
                TransformOperation::TranslateZ(z) => {
                    if z.px() != 0. {
                        return true;
                    }
                }
                _ => {}
            }
        }

        // Neither perspective nor transform present
        false
    }

    /// Serializes the computed value of this property as a string.
    pub fn computed_value_to_string(&self, property: PropertyDeclarationId) -> String {
        match property {
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundColor) => {
                        self.background.background_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundImage) => {
                        self.background.background_image.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundPositionX) => {
                        self.background.background_position_x.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundPositionY) => {
                        self.background.background_position_y.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundRepeat) => {
                        self.background.background_repeat.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundAttachment) => {
                        self.background.background_attachment.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundClip) => {
                        self.background.background_clip.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundOrigin) => {
                        self.background.background_origin.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundSize) => {
                        self.background.background_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundBlendMode) => {
                        self.background.background_blend_mode.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderTopColor) => {
                        self.border.border_top_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderTopStyle) => {
                        self.border.border_top_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderTopWidth) => {
                        self.border.border_top_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderLeftColor) => {
                        self.border.border_left_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderLeftStyle) => {
                        self.border.border_left_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderLeftWidth) => {
                        self.border.border_left_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBottomColor) => {
                        self.border.border_bottom_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBottomStyle) => {
                        self.border.border_bottom_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBottomWidth) => {
                        self.border.border_bottom_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderRightColor) => {
                        self.border.border_right_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderRightStyle) => {
                        self.border.border_right_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderRightWidth) => {
                        self.border.border_right_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBlockStartColor) => {
                        self.border.border_block_start_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBlockStartStyle) => {
                        self.border.border_block_start_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBlockStartWidth) => {
                        self.border.border_block_start_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBlockEndColor) => {
                        self.border.border_block_end_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBlockEndStyle) => {
                        self.border.border_block_end_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBlockEndWidth) => {
                        self.border.border_block_end_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderInlineStartColor) => {
                        self.border.border_inline_start_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderInlineStartStyle) => {
                        self.border.border_inline_start_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderInlineStartWidth) => {
                        self.border.border_inline_start_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderInlineEndColor) => {
                        self.border.border_inline_end_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderInlineEndStyle) => {
                        self.border.border_inline_end_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderInlineEndWidth) => {
                        self.border.border_inline_end_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderTopLeftRadius) => {
                        self.border.border_top_left_radius.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderTopRightRadius) => {
                        self.border.border_top_right_radius.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBottomRightRadius) => {
                        self.border.border_bottom_right_radius.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBottomLeftRadius) => {
                        self.border.border_bottom_left_radius.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BoxDecorationBreak) => {
                        self.border.box_decoration_break.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozFloatEdge) => {
                        self.border._moz_float_edge.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderImageSource) => {
                        self.border.border_image_source.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderImageOutset) => {
                        self.border.border_image_outset.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderImageRepeat) => {
                        self.border.border_image_repeat.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderImageWidth) => {
                        self.border.border_image_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderImageSlice) => {
                        self.border.border_image_slice.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Display) => {
                        self.box_.display.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozTopLayer) => {
                        self.box_._moz_top_layer.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Position) => {
                        self.box_.position.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Float) => {
                        self.box_.float.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Clear) => {
                        self.box_.clear.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::VerticalAlign) => {
                        self.box_.vertical_align.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OverflowClipBoxInline) => {
                        self.box_.overflow_clip_box_inline.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OverflowClipBoxBlock) => {
                        self.box_.overflow_clip_box_block.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OverflowX) => {
                        self.box_.overflow_x.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OverflowY) => {
                        self.box_.overflow_y.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TransitionDuration) => {
                        self.box_.transition_duration.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TransitionTimingFunction) => {
                        self.box_.transition_timing_function.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TransitionProperty) => {
                        self.box_.transition_property.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TransitionDelay) => {
                        self.box_.transition_delay.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationName) => {
                        self.box_.animation_name.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationDuration) => {
                        self.box_.animation_duration.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationTimingFunction) => {
                        self.box_.animation_timing_function.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationIterationCount) => {
                        self.box_.animation_iteration_count.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationDirection) => {
                        self.box_.animation_direction.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationPlayState) => {
                        self.box_.animation_play_state.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationFillMode) => {
                        self.box_.animation_fill_mode.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationDelay) => {
                        self.box_.animation_delay.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ScrollSnapPointsX) => {
                        self.box_.scroll_snap_points_x.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ScrollSnapPointsY) => {
                        self.box_.scroll_snap_points_y.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ScrollSnapDestination) => {
                        self.box_.scroll_snap_destination.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ScrollSnapCoordinate) => {
                        self.box_.scroll_snap_coordinate.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Transform) => {
                        self.box_.transform.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Rotate) => {
                        self.box_.rotate.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Scale) => {
                        self.box_.scale.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Translate) => {
                        self.box_.translate.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ScrollBehavior) => {
                        self.box_.scroll_behavior.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ScrollSnapTypeX) => {
                        self.box_.scroll_snap_type_x.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ScrollSnapTypeY) => {
                        self.box_.scroll_snap_type_y.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OverscrollBehaviorX) => {
                        self.box_.overscroll_behavior_x.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OverscrollBehaviorY) => {
                        self.box_.overscroll_behavior_y.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Isolation) => {
                        self.box_.isolation.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PageBreakAfter) => {
                        self.box_.page_break_after.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PageBreakBefore) => {
                        self.box_.page_break_before.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PageBreakInside) => {
                        self.box_.page_break_inside.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Resize) => {
                        self.box_.resize.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Perspective) => {
                        self.box_.perspective.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PerspectiveOrigin) => {
                        self.box_.perspective_origin.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackfaceVisibility) => {
                        self.box_.backface_visibility.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TransformBox) => {
                        self.box_.transform_box.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TransformStyle) => {
                        self.box_.transform_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TransformOrigin) => {
                        self.box_.transform_origin.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Contain) => {
                        self.box_.contain.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozAppearance) => {
                        self.box_._moz_appearance.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBinding) => {
                        self.box_._moz_binding.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozOrient) => {
                        self.box_._moz_orient.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WillChange) => {
                        self.box_.will_change.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ShapeImageThreshold) => {
                        self.box_.shape_image_threshold.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ShapeOutside) => {
                        self.box_.shape_outside.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TouchAction) => {
                        self.box_.touch_action.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Color) => {
                        self.color.color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnWidth) => {
                        self.column.column_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnCount) => {
                        self.column.column_count.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnGap) => {
                        self.column.column_gap.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnFill) => {
                        self.column.column_fill.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnRuleWidth) => {
                        self.column.column_rule_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnRuleColor) => {
                        self.column.column_rule_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnSpan) => {
                        self.column.column_span.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnRuleStyle) => {
                        self.column.column_rule_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Content) => {
                        self.counters.content.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::CounterIncrement) => {
                        self.counters.counter_increment.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::CounterReset) => {
                        self.counters.counter_reset.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Opacity) => {
                        self.effects.opacity.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BoxShadow) => {
                        self.effects.box_shadow.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Clip) => {
                        self.effects.clip.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Filter) => {
                        self.effects.filter.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MixBlendMode) => {
                        self.effects.mix_blend_mode.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontFamily) => {
                        self.font.font_family.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontStyle) => {
                        self.font.font_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontVariantCaps) => {
                        self.font.font_variant_caps.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontWeight) => {
                        self.font.font_weight.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontSize) => {
                        self.font.font_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontSizeAdjust) => {
                        self.font.font_size_adjust.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontSynthesis) => {
                        self.font.font_synthesis.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontStretch) => {
                        self.font.font_stretch.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontKerning) => {
                        self.font.font_kerning.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontVariantAlternates) => {
                        self.font.font_variant_alternates.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontVariantEastAsian) => {
                        self.font.font_variant_east_asian.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontVariantLigatures) => {
                        self.font.font_variant_ligatures.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontVariantNumeric) => {
                        self.font.font_variant_numeric.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontVariantPosition) => {
                        self.font.font_variant_position.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontFeatureSettings) => {
                        self.font.font_feature_settings.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontVariationSettings) => {
                        self.font.font_variation_settings.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontLanguageOverride) => {
                        self.font.font_language_override.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontOpticalSizing) => {
                        self.font.font_optical_sizing.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::XLang) => {
                        self.font._x_lang.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozScriptSizeMultiplier) => {
                        self.font._moz_script_size_multiplier.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozScriptLevel) => {
                        self.font._moz_script_level.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozMathDisplay) => {
                        self.font._moz_math_display.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozMathVariant) => {
                        self.font._moz_math_variant.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozScriptMinSize) => {
                        self.font._moz_script_min_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::XTextZoom) => {
                        self.font._x_text_zoom.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozOsxFontSmoothing) => {
                        self.font._moz_osx_font_smoothing.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozFontSmoothingBackgroundColor) => {
                        self.font._moz_font_smoothing_background_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozMinFontSizeRatio) => {
                        self.font._moz_min_font_size_ratio.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Visibility) => {
                        self.inheritedbox.visibility.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WritingMode) => {
                        self.inheritedbox.writing_mode.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Direction) => {
                        self.inheritedbox.direction.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextOrientation) => {
                        self.inheritedbox.text_orientation.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColorAdjust) => {
                        self.inheritedbox.color_adjust.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ImageRendering) => {
                        self.inheritedbox.image_rendering.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ImageOrientation) => {
                        self.inheritedbox.image_orientation.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderCollapse) => {
                        self.inheritedtable.border_collapse.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::EmptyCells) => {
                        self.inheritedtable.empty_cells.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::CaptionSide) => {
                        self.inheritedtable.caption_side.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderSpacing) => {
                        self.inheritedtable.border_spacing.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::LineHeight) => {
                        self.inheritedtext.line_height.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextTransform) => {
                        self.inheritedtext.text_transform.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Hyphens) => {
                        self.inheritedtext.hyphens.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozTextSizeAdjust) => {
                        self.inheritedtext._moz_text_size_adjust.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextIndent) => {
                        self.inheritedtext.text_indent.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OverflowWrap) => {
                        self.inheritedtext.overflow_wrap.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WordBreak) => {
                        self.inheritedtext.word_break.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextJustify) => {
                        self.inheritedtext.text_justify.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextAlignLast) => {
                        self.inheritedtext.text_align_last.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextAlign) => {
                        self.inheritedtext.text_align.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::LetterSpacing) => {
                        self.inheritedtext.letter_spacing.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WordSpacing) => {
                        self.inheritedtext.word_spacing.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WhiteSpace) => {
                        self.inheritedtext.white_space.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextShadow) => {
                        self.inheritedtext.text_shadow.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextEmphasisStyle) => {
                        self.inheritedtext.text_emphasis_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextEmphasisPosition) => {
                        self.inheritedtext.text_emphasis_position.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextEmphasisColor) => {
                        self.inheritedtext.text_emphasis_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozTabSize) => {
                        self.inheritedtext._moz_tab_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WebkitTextFillColor) => {
                        self.inheritedtext._webkit_text_fill_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WebkitTextStrokeColor) => {
                        self.inheritedtext._webkit_text_stroke_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WebkitTextStrokeWidth) => {
                        self.inheritedtext._webkit_text_stroke_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::RubyAlign) => {
                        self.inheritedtext.ruby_align.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::RubyPosition) => {
                        self.inheritedtext.ruby_position.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextCombineUpright) => {
                        self.inheritedtext.text_combine_upright.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextRendering) => {
                        self.inheritedtext.text_rendering.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozControlCharacterVisibility) => {
                        self.inheritedtext._moz_control_character_visibility.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ListStylePosition) => {
                        self.list.list_style_position.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ListStyleType) => {
                        self.list.list_style_type.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ListStyleImage) => {
                        self.list.list_style_image.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Quotes) => {
                        self.list.quotes.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozImageRegion) => {
                        self.list._moz_image_region.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginTop) => {
                        self.margin.margin_top.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginLeft) => {
                        self.margin.margin_left.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginBottom) => {
                        self.margin.margin_bottom.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginRight) => {
                        self.margin.margin_right.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginBlockStart) => {
                        self.margin.margin_block_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginBlockEnd) => {
                        self.margin.margin_block_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginInlineStart) => {
                        self.margin.margin_inline_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginInlineEnd) => {
                        self.margin.margin_inline_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OutlineColor) => {
                        self.outline.outline_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OutlineStyle) => {
                        self.outline.outline_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OutlineWidth) => {
                        self.outline.outline_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozOutlineRadiusTopleft) => {
                        self.outline._moz_outline_radius_topleft.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozOutlineRadiusTopright) => {
                        self.outline._moz_outline_radius_topright.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozOutlineRadiusBottomright) => {
                        self.outline._moz_outline_radius_bottomright.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozOutlineRadiusBottomleft) => {
                        self.outline._moz_outline_radius_bottomleft.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OutlineOffset) => {
                        self.outline.outline_offset.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingTop) => {
                        self.padding.padding_top.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingLeft) => {
                        self.padding.padding_left.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingBottom) => {
                        self.padding.padding_bottom.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingRight) => {
                        self.padding.padding_right.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingBlockStart) => {
                        self.padding.padding_block_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingBlockEnd) => {
                        self.padding.padding_block_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingInlineStart) => {
                        self.padding.padding_inline_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingInlineEnd) => {
                        self.padding.padding_inline_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Cursor) => {
                        self.pointing.cursor.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PointerEvents) => {
                        self.pointing.pointer_events.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozUserInput) => {
                        self.pointing._moz_user_input.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozUserModify) => {
                        self.pointing._moz_user_modify.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozUserFocus) => {
                        self.pointing._moz_user_focus.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::CaretColor) => {
                        self.pointing.caret_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Top) => {
                        self.position.top.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Left) => {
                        self.position.left.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Bottom) => {
                        self.position.bottom.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Right) => {
                        self.position.right.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OffsetBlockStart) => {
                        self.position.offset_block_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OffsetBlockEnd) => {
                        self.position.offset_block_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OffsetInlineStart) => {
                        self.position.offset_inline_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OffsetInlineEnd) => {
                        self.position.offset_inline_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ZIndex) => {
                        self.position.z_index.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FlexDirection) => {
                        self.position.flex_direction.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FlexWrap) => {
                        self.position.flex_wrap.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::JustifyContent) => {
                        self.position.justify_content.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AlignContent) => {
                        self.position.align_content.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AlignItems) => {
                        self.position.align_items.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::JustifyItems) => {
                        self.position.justify_items.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FlexGrow) => {
                        self.position.flex_grow.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FlexShrink) => {
                        self.position.flex_shrink.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AlignSelf) => {
                        self.position.align_self.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::JustifySelf) => {
                        self.position.justify_self.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Order) => {
                        self.position.order.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FlexBasis) => {
                        self.position.flex_basis.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Width) => {
                        self.position.width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MinWidth) => {
                        self.position.min_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaxWidth) => {
                        self.position.max_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Height) => {
                        self.position.height.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MinHeight) => {
                        self.position.min_height.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaxHeight) => {
                        self.position.max_height.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BlockSize) => {
                        self.position.block_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MinBlockSize) => {
                        self.position.min_block_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaxBlockSize) => {
                        self.position.max_block_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::InlineSize) => {
                        self.position.inline_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MinInlineSize) => {
                        self.position.min_inline_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaxInlineSize) => {
                        self.position.max_inline_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BoxSizing) => {
                        self.position.box_sizing.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ObjectFit) => {
                        self.position.object_fit.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ObjectPosition) => {
                        self.position.object_position.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridRowGap) => {
                        self.position.grid_row_gap.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridRowStart) => {
                        self.position.grid_row_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridRowEnd) => {
                        self.position.grid_row_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridAutoRows) => {
                        self.position.grid_auto_rows.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridTemplateRows) => {
                        self.position.grid_template_rows.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridColumnGap) => {
                        self.position.grid_column_gap.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridColumnStart) => {
                        self.position.grid_column_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridColumnEnd) => {
                        self.position.grid_column_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridAutoColumns) => {
                        self.position.grid_auto_columns.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridTemplateColumns) => {
                        self.position.grid_template_columns.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridAutoFlow) => {
                        self.position.grid_auto_flow.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridTemplateAreas) => {
                        self.position.grid_template_areas.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TableLayout) => {
                        self.table.table_layout.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::XSpan) => {
                        self.table._x_span.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextOverflow) => {
                        self.text.text_overflow.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::UnicodeBidi) => {
                        self.text.unicode_bidi.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextDecorationLine) => {
                        self.text.text_decoration_line.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextDecorationStyle) => {
                        self.text.text_decoration_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextDecorationColor) => {
                        self.text.text_decoration_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::InitialLetter) => {
                        self.text.initial_letter.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ImeMode) => {
                        self.ui.ime_mode.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozUserSelect) => {
                        self.ui._moz_user_select.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozWindowDragging) => {
                        self.ui._moz_window_dragging.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozWindowShadow) => {
                        self.ui._moz_window_shadow.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozWindowOpacity) => {
                        self.ui._moz_window_opacity.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozWindowTransform) => {
                        self.ui._moz_window_transform.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozWindowTransformOrigin) => {
                        self.ui._moz_window_transform_origin.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozForceBrokenImageIcon) => {
                        self.ui._moz_force_broken_image_icon.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextAnchor) => {
                        self.inheritedsvg.text_anchor.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColorInterpolation) => {
                        self.inheritedsvg.color_interpolation.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColorInterpolationFilters) => {
                        self.inheritedsvg.color_interpolation_filters.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Fill) => {
                        self.inheritedsvg.fill.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FillOpacity) => {
                        self.inheritedsvg.fill_opacity.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FillRule) => {
                        self.inheritedsvg.fill_rule.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ShapeRendering) => {
                        self.inheritedsvg.shape_rendering.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Stroke) => {
                        self.inheritedsvg.stroke.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StrokeWidth) => {
                        self.inheritedsvg.stroke_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StrokeLinecap) => {
                        self.inheritedsvg.stroke_linecap.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StrokeLinejoin) => {
                        self.inheritedsvg.stroke_linejoin.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StrokeMiterlimit) => {
                        self.inheritedsvg.stroke_miterlimit.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StrokeOpacity) => {
                        self.inheritedsvg.stroke_opacity.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StrokeDasharray) => {
                        self.inheritedsvg.stroke_dasharray.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StrokeDashoffset) => {
                        self.inheritedsvg.stroke_dashoffset.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ClipRule) => {
                        self.inheritedsvg.clip_rule.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarkerStart) => {
                        self.inheritedsvg.marker_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarkerMid) => {
                        self.inheritedsvg.marker_mid.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarkerEnd) => {
                        self.inheritedsvg.marker_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaintOrder) => {
                        self.inheritedsvg.paint_order.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozContextProperties) => {
                        self.inheritedsvg._moz_context_properties.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::DominantBaseline) => {
                        self.svg.dominant_baseline.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::VectorEffect) => {
                        self.svg.vector_effect.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StopColor) => {
                        self.svg.stop_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StopOpacity) => {
                        self.svg.stop_opacity.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FloodColor) => {
                        self.svg.flood_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FloodOpacity) => {
                        self.svg.flood_opacity.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::LightingColor) => {
                        self.svg.lighting_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskType) => {
                        self.svg.mask_type.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ClipPath) => {
                        self.svg.clip_path.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskMode) => {
                        self.svg.mask_mode.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskRepeat) => {
                        self.svg.mask_repeat.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskPositionX) => {
                        self.svg.mask_position_x.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskPositionY) => {
                        self.svg.mask_position_y.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskClip) => {
                        self.svg.mask_clip.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskOrigin) => {
                        self.svg.mask_origin.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskSize) => {
                        self.svg.mask_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskComposite) => {
                        self.svg.mask_composite.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskImage) => {
                        self.svg.mask_image.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBoxAlign) => {
                        self.xul._moz_box_align.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBoxDirection) => {
                        self.xul._moz_box_direction.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBoxFlex) => {
                        self.xul._moz_box_flex.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBoxOrient) => {
                        self.xul._moz_box_orient.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBoxPack) => {
                        self.xul._moz_box_pack.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozStackSizing) => {
                        self.xul._moz_stack_sizing.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBoxOrdinalGroup) => {
                        self.xul._moz_box_ordinal_group.to_css_string()
                    }
            PropertyDeclarationId::Custom(name) => {
                self.custom_properties
                    .as_ref()
                    .and_then(|map| map.get(name))
                    .map(|value| value.to_css_string())
                    .unwrap_or(String::new())
            }
        }
    }
}

    pub use ::servo_arc::RawOffsetArc as BuilderArc;
    /// Clone an arc, returning a regular arc
    fn clone_arc<T: 'static>(x: &BuilderArc<T>) -> Arc<T> {
        Arc::from_raw_offset(x.clone())
    }

/// A reference to a style struct of the parent, or our own style struct.
pub enum StyleStructRef<'a, T: 'static> {
    /// A borrowed struct from the parent, for example, for inheriting style.
    Borrowed(&'a BuilderArc<T>),
    /// An owned struct, that we've already mutated.
    Owned(UniqueArc<T>),
    /// Temporarily vacated, will panic if accessed
    Vacated,
}

impl<'a, T: 'a> StyleStructRef<'a, T>
    where T: Clone,
{
    /// Ensure a mutable reference of this value exists, either cloning the
    /// borrowed value, or returning the owned one.
    pub fn mutate(&mut self) -> &mut T {
        if let StyleStructRef::Borrowed(v) = *self {
            *self = StyleStructRef::Owned(UniqueArc::new((**v).clone()));
        }

        match *self {
            StyleStructRef::Owned(ref mut v) => v,
            StyleStructRef::Borrowed(..) => unreachable!(),
            StyleStructRef::Vacated => panic!("Accessed vacated style struct")
        }
    }

    /// Extract a unique Arc from this struct, vacating it.
    ///
    /// The vacated state is a transient one, please put the Arc back
    /// when done via `put()`. This function is to be used to separate
    /// the struct being mutated from the computed context
    pub fn take(&mut self) -> UniqueArc<T> {
        use std::mem::replace;
        let inner = replace(self, StyleStructRef::Vacated);

        match inner {
            StyleStructRef::Owned(arc) => arc,
            StyleStructRef::Borrowed(arc) => UniqueArc::new((**arc).clone()),
            StyleStructRef::Vacated => panic!("Accessed vacated style struct"),
        }
    }

    /// Replace vacated ref with an arc
    pub fn put(&mut self, arc: UniqueArc<T>) {
        debug_assert!(matches!(*self, StyleStructRef::Vacated));
        *self = StyleStructRef::Owned(arc);
    }

    /// Get a mutable reference to the owned struct, or `None` if the struct
    /// hasn't been mutated.
    pub fn get_if_mutated(&mut self) -> Option<&mut T> {
        match *self {
            StyleStructRef::Owned(ref mut v) => Some(v),
            StyleStructRef::Borrowed(..) => None,
            StyleStructRef::Vacated => panic!("Accessed vacated style struct")
        }
    }

    /// Returns an `Arc` to the internal struct, constructing one if
    /// appropriate.
    pub fn build(self) -> Arc<T> {
        match self {
            StyleStructRef::Owned(v) => v.shareable(),
            StyleStructRef::Borrowed(v) => clone_arc(v),
            StyleStructRef::Vacated => panic!("Accessed vacated style struct")
        }
    }
}

impl<'a, T: 'a> ops::Deref for StyleStructRef<'a, T> {
    type Target = T;

    fn deref(&self) -> &T {
        match *self {
            StyleStructRef::Owned(ref v) => &**v,
            StyleStructRef::Borrowed(v) => &**v,
            StyleStructRef::Vacated => panic!("Accessed vacated style struct")
        }
    }
}

/// A type used to compute a struct with minimal overhead.
///
/// This allows holding references to the parent/default computed values without
/// actually cloning them, until we either build the style, or mutate the
/// inherited value.
pub struct StyleBuilder<'a> {
    /// The device we're using to compute style.
    ///
    /// This provides access to viewport unit ratios, etc.
    pub device: &'a Device,

    /// The style we're inheriting from.
    ///
    /// This is effectively
    /// `parent_style.unwrap_or(device.default_computed_values())`.
    inherited_style: &'a ComputedValues,

    /// The style we're inheriting from for properties that don't inherit from
    /// ::first-line.  This is the same as inherited_style, unless
    /// inherited_style is a ::first-line style.
    inherited_style_ignoring_first_line: &'a ComputedValues,

    /// The style we're getting reset structs from.
    reset_style: &'a ComputedValues,

    /// The style we're inheriting from explicitly, or none if we're the root of
    /// a subtree.
    parent_style: Option<&'a ComputedValues>,

    /// The rule node representing the ordered list of rules matched for this
    /// node.
    pub rules: Option<StrongRuleNode>,

    custom_properties: Option<Arc<::custom_properties::CustomPropertiesMap>>,

    /// The pseudo-element this style will represent.
    pub pseudo: Option<&'a PseudoElement>,

    /// Whether we have mutated any reset structs since the the last time
    /// `clear_modified_reset` was called.  This is used to tell whether the
    /// `StyleAdjuster` did any work.
    modified_reset: bool,

    /// The writing mode flags.
    ///
    /// TODO(emilio): Make private.
    pub writing_mode: WritingMode,
    /// Flags for the computed value.
    pub flags: ComputedValueFlags,
    /// The element's style if visited, only computed if there's a relevant link
    /// for this element.  A element's "relevant link" is the element being
    /// matched if it is a link or the nearest ancestor link.
    visited_style: Option<Arc<ComputedValues>>,
        background: StyleStructRef<'a, style_structs::Background>,
        border: StyleStructRef<'a, style_structs::Border>,
        box_: StyleStructRef<'a, style_structs::Box>,
        color: StyleStructRef<'a, style_structs::Color>,
        column: StyleStructRef<'a, style_structs::Column>,
        counters: StyleStructRef<'a, style_structs::Counters>,
        effects: StyleStructRef<'a, style_structs::Effects>,
        font: StyleStructRef<'a, style_structs::Font>,
        inheritedbox: StyleStructRef<'a, style_structs::InheritedBox>,
        inheritedtable: StyleStructRef<'a, style_structs::InheritedTable>,
        inheritedtext: StyleStructRef<'a, style_structs::InheritedText>,
        list: StyleStructRef<'a, style_structs::List>,
        margin: StyleStructRef<'a, style_structs::Margin>,
        outline: StyleStructRef<'a, style_structs::Outline>,
        padding: StyleStructRef<'a, style_structs::Padding>,
        pointing: StyleStructRef<'a, style_structs::Pointing>,
        position: StyleStructRef<'a, style_structs::Position>,
        table: StyleStructRef<'a, style_structs::Table>,
        text: StyleStructRef<'a, style_structs::Text>,
        ui: StyleStructRef<'a, style_structs::UI>,
        inheritedsvg: StyleStructRef<'a, style_structs::InheritedSVG>,
        svg: StyleStructRef<'a, style_structs::SVG>,
        xul: StyleStructRef<'a, style_structs::XUL>,
}

impl<'a> StyleBuilder<'a> {
    /// Trivially construct a `StyleBuilder`.
    fn new(
        device: &'a Device,
        parent_style: Option<&'a ComputedValues>,
        parent_style_ignoring_first_line: Option<&'a ComputedValues>,
        pseudo: Option<&'a PseudoElement>,
        cascade_flags: CascadeFlags,
        rules: Option<StrongRuleNode>,
        custom_properties: Option<Arc<::custom_properties::CustomPropertiesMap>>,
        visited_style: Option<Arc<ComputedValues>>,
    ) -> Self {
        debug_assert_eq!(parent_style.is_some(), parent_style_ignoring_first_line.is_some());
        #[cfg(feature = "gecko")]
        debug_assert!(parent_style.is_none() ||
                      ::std::ptr::eq(parent_style.unwrap(),
                                     parent_style_ignoring_first_line.unwrap()) ||
                      parent_style.unwrap().pseudo() == Some(PseudoElement::FirstLine));
        let reset_style = device.default_computed_values();
        let inherited_style = parent_style.unwrap_or(reset_style);
        let inherited_style_ignoring_first_line = parent_style_ignoring_first_line.unwrap_or(reset_style);
        // FIXME(bz): INHERIT_ALL seems like a fundamentally broken idea.  I'm
        // 99% sure it should give incorrect behavior for table anonymous box
        // backgrounds, for example.  This code doesn't attempt to make it play
        // nice with inherited_style_ignoring_first_line.
        let reset_style = if cascade_flags.contains(CascadeFlags::INHERIT_ALL) {
            inherited_style
        } else {
            reset_style
        };

        let mut flags = inherited_style.flags.inherited();
        if cascade_flags.contains(CascadeFlags::VISITED_DEPENDENT_ONLY) {
            flags.insert(ComputedValueFlags::IS_STYLE_IF_VISITED);
        }

        StyleBuilder {
            device,
            parent_style,
            inherited_style,
            inherited_style_ignoring_first_line,
            reset_style,
            pseudo,
            rules,
            modified_reset: false,
            custom_properties,
            writing_mode: inherited_style.writing_mode,
            flags,
            visited_style,
            background: StyleStructRef::Borrowed(reset_style.background_arc()),
            border: StyleStructRef::Borrowed(reset_style.border_arc()),
            box_: StyleStructRef::Borrowed(reset_style.box_arc()),
            color: StyleStructRef::Borrowed(inherited_style.color_arc()),
            column: StyleStructRef::Borrowed(reset_style.column_arc()),
            counters: StyleStructRef::Borrowed(reset_style.counters_arc()),
            effects: StyleStructRef::Borrowed(reset_style.effects_arc()),
            font: StyleStructRef::Borrowed(inherited_style.font_arc()),
            inheritedbox: StyleStructRef::Borrowed(inherited_style.inheritedbox_arc()),
            inheritedtable: StyleStructRef::Borrowed(inherited_style.inheritedtable_arc()),
            inheritedtext: StyleStructRef::Borrowed(inherited_style.inheritedtext_arc()),
            list: StyleStructRef::Borrowed(inherited_style.list_arc()),
            margin: StyleStructRef::Borrowed(reset_style.margin_arc()),
            outline: StyleStructRef::Borrowed(reset_style.outline_arc()),
            padding: StyleStructRef::Borrowed(reset_style.padding_arc()),
            pointing: StyleStructRef::Borrowed(inherited_style.pointing_arc()),
            position: StyleStructRef::Borrowed(reset_style.position_arc()),
            table: StyleStructRef::Borrowed(reset_style.table_arc()),
            text: StyleStructRef::Borrowed(reset_style.text_arc()),
            ui: StyleStructRef::Borrowed(reset_style.ui_arc()),
            inheritedsvg: StyleStructRef::Borrowed(inherited_style.inheritedsvg_arc()),
            svg: StyleStructRef::Borrowed(reset_style.svg_arc()),
            xul: StyleStructRef::Borrowed(reset_style.xul_arc()),
        }
    }

    /// Whether we're a visited style.
    pub fn is_style_if_visited(&self) -> bool {
        self.flags.contains(ComputedValueFlags::IS_STYLE_IF_VISITED)
    }

    /// NOTE(emilio): This is done so we can compute relative units with respect
    /// to the parent style, but all the early properties / writing-mode / etc
    /// are already set to the right ones on the kid.
    ///
    /// Do _not_ actually call this to construct a style, this should mostly be
    /// used for animations.
    pub fn for_animation(
        device: &'a Device,
        style_to_derive_from: &'a ComputedValues,
        parent_style: Option<&'a ComputedValues>,
    ) -> Self {
        let reset_style = device.default_computed_values();
        let inherited_style = parent_style.unwrap_or(reset_style);
        #[cfg(feature = "gecko")]
        debug_assert!(parent_style.is_none() ||
                      parent_style.unwrap().pseudo() != Some(PseudoElement::FirstLine));
        StyleBuilder {
            device,
            parent_style,
            inherited_style,
            // None of our callers pass in ::first-line parent styles.
            inherited_style_ignoring_first_line: inherited_style,
            reset_style,
            pseudo: None,
            modified_reset: false,
            rules: None,
            custom_properties: style_to_derive_from.custom_properties().cloned(),
            writing_mode: style_to_derive_from.writing_mode,
            flags: style_to_derive_from.flags,
            visited_style: None,
            background: StyleStructRef::Borrowed(
                style_to_derive_from.background_arc()
            ),
            border: StyleStructRef::Borrowed(
                style_to_derive_from.border_arc()
            ),
            box_: StyleStructRef::Borrowed(
                style_to_derive_from.box_arc()
            ),
            color: StyleStructRef::Borrowed(
                style_to_derive_from.color_arc()
            ),
            column: StyleStructRef::Borrowed(
                style_to_derive_from.column_arc()
            ),
            counters: StyleStructRef::Borrowed(
                style_to_derive_from.counters_arc()
            ),
            effects: StyleStructRef::Borrowed(
                style_to_derive_from.effects_arc()
            ),
            font: StyleStructRef::Borrowed(
                style_to_derive_from.font_arc()
            ),
            inheritedbox: StyleStructRef::Borrowed(
                style_to_derive_from.inheritedbox_arc()
            ),
            inheritedtable: StyleStructRef::Borrowed(
                style_to_derive_from.inheritedtable_arc()
            ),
            inheritedtext: StyleStructRef::Borrowed(
                style_to_derive_from.inheritedtext_arc()
            ),
            list: StyleStructRef::Borrowed(
                style_to_derive_from.list_arc()
            ),
            margin: StyleStructRef::Borrowed(
                style_to_derive_from.margin_arc()
            ),
            outline: StyleStructRef::Borrowed(
                style_to_derive_from.outline_arc()
            ),
            padding: StyleStructRef::Borrowed(
                style_to_derive_from.padding_arc()
            ),
            pointing: StyleStructRef::Borrowed(
                style_to_derive_from.pointing_arc()
            ),
            position: StyleStructRef::Borrowed(
                style_to_derive_from.position_arc()
            ),
            table: StyleStructRef::Borrowed(
                style_to_derive_from.table_arc()
            ),
            text: StyleStructRef::Borrowed(
                style_to_derive_from.text_arc()
            ),
            ui: StyleStructRef::Borrowed(
                style_to_derive_from.ui_arc()
            ),
            inheritedsvg: StyleStructRef::Borrowed(
                style_to_derive_from.inheritedsvg_arc()
            ),
            svg: StyleStructRef::Borrowed(
                style_to_derive_from.svg_arc()
            ),
            xul: StyleStructRef::Borrowed(
                style_to_derive_from.xul_arc()
            ),
        }
    }

    /// Copy the reset properties from `style`.
    pub fn copy_reset_from(&mut self, style: &'a ComputedValues) {
        self.background =
            StyleStructRef::Borrowed(style.background_arc());
        self.border =
            StyleStructRef::Borrowed(style.border_arc());
        self.box_ =
            StyleStructRef::Borrowed(style.box_arc());
        self.column =
            StyleStructRef::Borrowed(style.column_arc());
        self.counters =
            StyleStructRef::Borrowed(style.counters_arc());
        self.effects =
            StyleStructRef::Borrowed(style.effects_arc());
        self.margin =
            StyleStructRef::Borrowed(style.margin_arc());
        self.outline =
            StyleStructRef::Borrowed(style.outline_arc());
        self.padding =
            StyleStructRef::Borrowed(style.padding_arc());
        self.position =
            StyleStructRef::Borrowed(style.position_arc());
        self.table =
            StyleStructRef::Borrowed(style.table_arc());
        self.text =
            StyleStructRef::Borrowed(style.text_arc());
        self.ui =
            StyleStructRef::Borrowed(style.ui_arc());
        self.svg =
            StyleStructRef::Borrowed(style.svg_arc());
        self.xul =
            StyleStructRef::Borrowed(style.xul_arc());
    }

    /// Inherit `align_content` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_align_content(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_align_content_from(
                inherited_struct,
            );
    }

    /// Reset `align_content` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_align_content(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_align_content(
                reset_struct,
            );
    }

    /// Set the `align_content` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_align_content(
        &mut self,
        value: longhands::align_content::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_align_content(
                value,
            );
    }
    /// Inherit `align_items` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_align_items(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_align_items_from(
                inherited_struct,
            );
    }

    /// Reset `align_items` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_align_items(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_align_items(
                reset_struct,
            );
    }

    /// Set the `align_items` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_align_items(
        &mut self,
        value: longhands::align_items::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_align_items(
                value,
            );
    }
    /// Inherit `align_self` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_align_self(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_align_self_from(
                inherited_struct,
            );
    }

    /// Reset `align_self` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_align_self(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_align_self(
                reset_struct,
            );
    }

    /// Set the `align_self` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_align_self(
        &mut self,
        value: longhands::align_self::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_align_self(
                value,
            );
    }
    /// Inherit `backface_visibility` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_backface_visibility(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_backface_visibility_from(
                inherited_struct,
            );
    }

    /// Reset `backface_visibility` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_backface_visibility(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_backface_visibility(
                reset_struct,
            );
    }

    /// Set the `backface_visibility` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_backface_visibility(
        &mut self,
        value: longhands::backface_visibility::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_backface_visibility(
                value,
            );
    }
    /// Inherit `border_collapse` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_collapse(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtable();




        self.inheritedtable.mutate()
            .copy_border_collapse_from(
                inherited_struct,
            );
    }

    /// Reset `border_collapse` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_collapse(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtable();


        self.inheritedtable.mutate()
            .reset_border_collapse(
                reset_struct,
            );
    }

    /// Set the `border_collapse` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_collapse(
        &mut self,
        value: longhands::border_collapse::computed_value::T
    ) {

        
        self.inheritedtable.mutate()
            .set_border_collapse(
                value,
            );
    }
    /// Inherit `border_image_repeat` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_image_repeat(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_image_repeat_from(
                inherited_struct,
            );
    }

    /// Reset `border_image_repeat` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_image_repeat(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_image_repeat(
                reset_struct,
            );
    }

    /// Set the `border_image_repeat` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_image_repeat(
        &mut self,
        value: longhands::border_image_repeat::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_image_repeat(
                value,
            );
    }
    /// Inherit `box_decoration_break` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_box_decoration_break(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_box_decoration_break_from(
                inherited_struct,
            );
    }

    /// Reset `box_decoration_break` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_box_decoration_break(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_box_decoration_break(
                reset_struct,
            );
    }

    /// Set the `box_decoration_break` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_box_decoration_break(
        &mut self,
        value: longhands::box_decoration_break::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_box_decoration_break(
                value,
            );
    }
    /// Inherit `box_sizing` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_box_sizing(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_box_sizing_from(
                inherited_struct,
            );
    }

    /// Reset `box_sizing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_box_sizing(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_box_sizing(
                reset_struct,
            );
    }

    /// Set the `box_sizing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_box_sizing(
        &mut self,
        value: longhands::box_sizing::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_box_sizing(
                value,
            );
    }
    /// Inherit `caption_side` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_caption_side(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtable();




        self.inheritedtable.mutate()
            .copy_caption_side_from(
                inherited_struct,
            );
    }

    /// Reset `caption_side` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_caption_side(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtable();


        self.inheritedtable.mutate()
            .reset_caption_side(
                reset_struct,
            );
    }

    /// Set the `caption_side` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_caption_side(
        &mut self,
        value: longhands::caption_side::computed_value::T
    ) {

        
        self.inheritedtable.mutate()
            .set_caption_side(
                value,
            );
    }
    /// Inherit `clear` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_clear(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_clear_from(
                inherited_struct,
            );
    }

    /// Reset `clear` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_clear(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_clear(
                reset_struct,
            );
    }

    /// Set the `clear` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_clear(
        &mut self,
        value: longhands::clear::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_clear(
                value,
            );
    }
    /// Inherit `clip_rule` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_clip_rule(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_clip_rule_from(
                inherited_struct,
            );
    }

    /// Reset `clip_rule` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_clip_rule(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_clip_rule(
                reset_struct,
            );
    }

    /// Set the `clip_rule` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_clip_rule(
        &mut self,
        value: longhands::clip_rule::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_clip_rule(
                value,
            );
    }
    /// Inherit `color_adjust` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_color_adjust(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedbox();




        self.inheritedbox.mutate()
            .copy_color_adjust_from(
                inherited_struct,
            );
    }

    /// Reset `color_adjust` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_color_adjust(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedbox();


        self.inheritedbox.mutate()
            .reset_color_adjust(
                reset_struct,
            );
    }

    /// Set the `color_adjust` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_color_adjust(
        &mut self,
        value: longhands::color_adjust::computed_value::T
    ) {

        
        self.inheritedbox.mutate()
            .set_color_adjust(
                value,
            );
    }
    /// Inherit `color_interpolation` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_color_interpolation(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_color_interpolation_from(
                inherited_struct,
            );
    }

    /// Reset `color_interpolation` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_color_interpolation(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_color_interpolation(
                reset_struct,
            );
    }

    /// Set the `color_interpolation` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_color_interpolation(
        &mut self,
        value: longhands::color_interpolation::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_color_interpolation(
                value,
            );
    }
    /// Inherit `color_interpolation_filters` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_color_interpolation_filters(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_color_interpolation_filters_from(
                inherited_struct,
            );
    }

    /// Reset `color_interpolation_filters` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_color_interpolation_filters(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_color_interpolation_filters(
                reset_struct,
            );
    }

    /// Set the `color_interpolation_filters` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_color_interpolation_filters(
        &mut self,
        value: longhands::color_interpolation_filters::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_color_interpolation_filters(
                value,
            );
    }
    /// Inherit `column_count` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_count(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_count_from(
                inherited_struct,
            );
    }

    /// Reset `column_count` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_count(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_count(
                reset_struct,
            );
    }

    /// Set the `column_count` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_count(
        &mut self,
        value: longhands::column_count::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_count(
                value,
            );
    }
    /// Inherit `column_fill` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_fill(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_fill_from(
                inherited_struct,
            );
    }

    /// Reset `column_fill` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_fill(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_fill(
                reset_struct,
            );
    }

    /// Set the `column_fill` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_fill(
        &mut self,
        value: longhands::column_fill::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_fill(
                value,
            );
    }
    /// Inherit `column_rule_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_rule_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_rule_style_from(
                inherited_struct,
            );
    }

    /// Reset `column_rule_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_rule_style(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_rule_style(
                reset_struct,
            );
    }

    /// Set the `column_rule_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_rule_style(
        &mut self,
        value: longhands::column_rule_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_rule_style(
                value,
            );
    }
    /// Inherit `column_span` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_span(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_span_from(
                inherited_struct,
            );
    }

    /// Reset `column_span` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_span(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_span(
                reset_struct,
            );
    }

    /// Set the `column_span` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_span(
        &mut self,
        value: longhands::column_span::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_span(
                value,
            );
    }
    /// Inherit `contain` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_contain(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_contain_from(
                inherited_struct,
            );
    }

    /// Reset `contain` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_contain(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_contain(
                reset_struct,
            );
    }

    /// Set the `contain` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_contain(
        &mut self,
        value: longhands::contain::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_contain(
                value,
            );
    }
    /// Inherit `direction` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_direction(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedbox();




        self.inheritedbox.mutate()
            .copy_direction_from(
                inherited_struct,
            );
    }

    /// Reset `direction` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_direction(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedbox();


        self.inheritedbox.mutate()
            .reset_direction(
                reset_struct,
            );
    }

    /// Set the `direction` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_direction(
        &mut self,
        value: longhands::direction::computed_value::T
    ) {

        
        self.inheritedbox.mutate()
            .set_direction(
                value,
            );
    }
    /// Inherit `dominant_baseline` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_dominant_baseline(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_dominant_baseline_from(
                inherited_struct,
            );
    }

    /// Reset `dominant_baseline` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_dominant_baseline(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_dominant_baseline(
                reset_struct,
            );
    }

    /// Set the `dominant_baseline` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_dominant_baseline(
        &mut self,
        value: longhands::dominant_baseline::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_dominant_baseline(
                value,
            );
    }
    /// Inherit `empty_cells` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_empty_cells(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtable();




        self.inheritedtable.mutate()
            .copy_empty_cells_from(
                inherited_struct,
            );
    }

    /// Reset `empty_cells` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_empty_cells(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtable();


        self.inheritedtable.mutate()
            .reset_empty_cells(
                reset_struct,
            );
    }

    /// Set the `empty_cells` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_empty_cells(
        &mut self,
        value: longhands::empty_cells::computed_value::T
    ) {

        
        self.inheritedtable.mutate()
            .set_empty_cells(
                value,
            );
    }
    /// Inherit `fill_rule` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_fill_rule(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_fill_rule_from(
                inherited_struct,
            );
    }

    /// Reset `fill_rule` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_fill_rule(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_fill_rule(
                reset_struct,
            );
    }

    /// Set the `fill_rule` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_fill_rule(
        &mut self,
        value: longhands::fill_rule::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_fill_rule(
                value,
            );
    }
    /// Inherit `flex_direction` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flex_direction(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_flex_direction_from(
                inherited_struct,
            );
    }

    /// Reset `flex_direction` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_flex_direction(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_flex_direction(
                reset_struct,
            );
    }

    /// Set the `flex_direction` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flex_direction(
        &mut self,
        value: longhands::flex_direction::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_flex_direction(
                value,
            );
    }
    /// Inherit `flex_wrap` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flex_wrap(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_flex_wrap_from(
                inherited_struct,
            );
    }

    /// Reset `flex_wrap` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_flex_wrap(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_flex_wrap(
                reset_struct,
            );
    }

    /// Set the `flex_wrap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flex_wrap(
        &mut self,
        value: longhands::flex_wrap::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_flex_wrap(
                value,
            );
    }
    /// Inherit `float` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_float(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_float_from(
                inherited_struct,
            );
    }

    /// Reset `float` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_float(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_float(
                reset_struct,
            );
    }

    /// Set the `float` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_float(
        &mut self,
        value: longhands::float::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_float(
                value,
            );
    }
    /// Inherit `font_kerning` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_kerning(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_kerning_from(
                inherited_struct,
            );
    }

    /// Reset `font_kerning` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_kerning(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_kerning(
                reset_struct,
            );
    }

    /// Set the `font_kerning` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_kerning(
        &mut self,
        value: longhands::font_kerning::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_kerning(
                value,
            );
    }
    /// Inherit `font_optical_sizing` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_optical_sizing(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_optical_sizing_from(
                inherited_struct,
            );
    }

    /// Reset `font_optical_sizing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_optical_sizing(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_optical_sizing(
                reset_struct,
            );
    }

    /// Set the `font_optical_sizing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_optical_sizing(
        &mut self,
        value: longhands::font_optical_sizing::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_optical_sizing(
                value,
            );
    }
    /// Inherit `font_stretch` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_stretch(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_stretch_from(
                inherited_struct,
            );
    }

    /// Reset `font_stretch` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_stretch(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_stretch(
                reset_struct,
            );
    }

    /// Set the `font_stretch` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_stretch(
        &mut self,
        value: longhands::font_stretch::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_stretch(
                value,
            );
    }
    /// Inherit `font_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_style(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_style_from(
                inherited_struct,
            );
    }

    /// Reset `font_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_style(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_style(
                reset_struct,
            );
    }

    /// Set the `font_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_style(
        &mut self,
        value: longhands::font_style::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_style(
                value,
            );
    }
    /// Inherit `font_synthesis` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_synthesis(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_synthesis_from(
                inherited_struct,
            );
    }

    /// Reset `font_synthesis` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_synthesis(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_synthesis(
                reset_struct,
            );
    }

    /// Set the `font_synthesis` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_synthesis(
        &mut self,
        value: longhands::font_synthesis::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_synthesis(
                value,
            );
    }
    /// Inherit `font_variant_caps` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_variant_caps(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_variant_caps_from(
                inherited_struct,
            );
    }

    /// Reset `font_variant_caps` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_caps(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_variant_caps(
                reset_struct,
            );
    }

    /// Set the `font_variant_caps` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_caps(
        &mut self,
        value: longhands::font_variant_caps::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_variant_caps(
                value,
            );
    }
    /// Inherit `font_variant_position` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_variant_position(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_variant_position_from(
                inherited_struct,
            );
    }

    /// Reset `font_variant_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_position(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_variant_position(
                reset_struct,
            );
    }

    /// Set the `font_variant_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_position(
        &mut self,
        value: longhands::font_variant_position::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_variant_position(
                value,
            );
    }
    /// Inherit `font_weight` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_weight(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_weight_from(
                inherited_struct,
            );
    }

    /// Reset `font_weight` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_weight(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_weight(
                reset_struct,
            );
    }

    /// Set the `font_weight` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_weight(
        &mut self,
        value: longhands::font_weight::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_weight(
                value,
            );
    }
    /// Inherit `grid_auto_flow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_auto_flow(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_auto_flow_from(
                inherited_struct,
            );
    }

    /// Reset `grid_auto_flow` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_auto_flow(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_auto_flow(
                reset_struct,
            );
    }

    /// Set the `grid_auto_flow` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_auto_flow(
        &mut self,
        value: longhands::grid_auto_flow::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_auto_flow(
                value,
            );
    }
    /// Inherit `hyphens` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_hyphens(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_hyphens_from(
                inherited_struct,
            );
    }

    /// Reset `hyphens` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_hyphens(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_hyphens(
                reset_struct,
            );
    }

    /// Set the `hyphens` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_hyphens(
        &mut self,
        value: longhands::hyphens::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_hyphens(
                value,
            );
    }
    /// Inherit `image_orientation` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_image_orientation(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedbox();




        self.inheritedbox.mutate()
            .copy_image_orientation_from(
                inherited_struct,
            );
    }

    /// Reset `image_orientation` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_image_orientation(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedbox();


        self.inheritedbox.mutate()
            .reset_image_orientation(
                reset_struct,
            );
    }

    /// Set the `image_orientation` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_image_orientation(
        &mut self,
        value: longhands::image_orientation::computed_value::T
    ) {

        
        self.inheritedbox.mutate()
            .set_image_orientation(
                value,
            );
    }
    /// Inherit `image_rendering` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_image_rendering(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedbox();




        self.inheritedbox.mutate()
            .copy_image_rendering_from(
                inherited_struct,
            );
    }

    /// Reset `image_rendering` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_image_rendering(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedbox();


        self.inheritedbox.mutate()
            .reset_image_rendering(
                reset_struct,
            );
    }

    /// Set the `image_rendering` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_image_rendering(
        &mut self,
        value: longhands::image_rendering::computed_value::T
    ) {

        
        self.inheritedbox.mutate()
            .set_image_rendering(
                value,
            );
    }
    /// Inherit `ime_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_ime_mode(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy_ime_mode_from(
                inherited_struct,
            );
    }

    /// Reset `ime_mode` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_ime_mode(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset_ime_mode(
                reset_struct,
            );
    }

    /// Set the `ime_mode` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_ime_mode(
        &mut self,
        value: longhands::ime_mode::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set_ime_mode(
                value,
            );
    }
    /// Inherit `initial_letter` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_initial_letter(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_text();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.text.mutate()
            .copy_initial_letter_from(
                inherited_struct,
            );
    }

    /// Reset `initial_letter` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_initial_letter(&mut self) {
        let reset_struct =
            self.reset_style.get_text();

        self.modified_reset = true;

        self.text.mutate()
            .reset_initial_letter(
                reset_struct,
            );
    }

    /// Set the `initial_letter` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_initial_letter(
        &mut self,
        value: longhands::initial_letter::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.text.mutate()
            .set_initial_letter(
                value,
            );
    }
    /// Inherit `isolation` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_isolation(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_isolation_from(
                inherited_struct,
            );
    }

    /// Reset `isolation` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_isolation(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_isolation(
                reset_struct,
            );
    }

    /// Set the `isolation` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_isolation(
        &mut self,
        value: longhands::isolation::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_isolation(
                value,
            );
    }
    /// Inherit `justify_content` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_justify_content(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_justify_content_from(
                inherited_struct,
            );
    }

    /// Reset `justify_content` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_justify_content(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_justify_content(
                reset_struct,
            );
    }

    /// Set the `justify_content` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_justify_content(
        &mut self,
        value: longhands::justify_content::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_justify_content(
                value,
            );
    }
    /// Inherit `justify_items` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_justify_items(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_justify_items_from(
                inherited_struct,
            );
    }

    /// Reset `justify_items` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_justify_items(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_justify_items(
                reset_struct,
            );
    }

    /// Set the `justify_items` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_justify_items(
        &mut self,
        value: longhands::justify_items::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_justify_items(
                value,
            );
    }
    /// Inherit `justify_self` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_justify_self(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_justify_self_from(
                inherited_struct,
            );
    }

    /// Reset `justify_self` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_justify_self(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_justify_self(
                reset_struct,
            );
    }

    /// Set the `justify_self` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_justify_self(
        &mut self,
        value: longhands::justify_self::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_justify_self(
                value,
            );
    }
    /// Inherit `list_style_position` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_list_style_position(&mut self) {
        let inherited_struct =
            self.inherited_style.get_list();




        self.list.mutate()
            .copy_list_style_position_from(
                inherited_struct,
            );
    }

    /// Reset `list_style_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_list_style_position(&mut self) {
        let reset_struct =
            self.reset_style.get_list();


        self.list.mutate()
            .reset_list_style_position(
                reset_struct,
            );
    }

    /// Set the `list_style_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_list_style_position(
        &mut self,
        value: longhands::list_style_position::computed_value::T
    ) {

        
        self.list.mutate()
            .set_list_style_position(
                value,
            );
    }
    /// Inherit `mask_type` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_type(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_type_from(
                inherited_struct,
            );
    }

    /// Reset `mask_type` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_type(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_type(
                reset_struct,
            );
    }

    /// Set the `mask_type` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_mask_type(
        &mut self,
        value: longhands::mask_type::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_mask_type(
                value,
            );
    }
    /// Inherit `mix_blend_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mix_blend_mode(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_effects();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.effects.mutate()
            .copy_mix_blend_mode_from(
                inherited_struct,
            );
    }

    /// Reset `mix_blend_mode` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mix_blend_mode(&mut self) {
        let reset_struct =
            self.reset_style.get_effects();

        self.modified_reset = true;

        self.effects.mutate()
            .reset_mix_blend_mode(
                reset_struct,
            );
    }

    /// Set the `mix_blend_mode` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_mix_blend_mode(
        &mut self,
        value: longhands::mix_blend_mode::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.effects.mutate()
            .set_mix_blend_mode(
                value,
            );
    }
    /// Inherit `_moz_appearance` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_appearance(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy__moz_appearance_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_appearance` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_appearance(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset__moz_appearance(
                reset_struct,
            );
    }

    /// Set the `_moz_appearance` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_appearance(
        &mut self,
        value: longhands::_moz_appearance::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set__moz_appearance(
                value,
            );
    }
    /// Inherit `_moz_box_align` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_align(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_xul();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.xul.mutate()
            .copy__moz_box_align_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_box_align` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_box_align(&mut self) {
        let reset_struct =
            self.reset_style.get_xul();

        self.modified_reset = true;

        self.xul.mutate()
            .reset__moz_box_align(
                reset_struct,
            );
    }

    /// Set the `_moz_box_align` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_align(
        &mut self,
        value: longhands::_moz_box_align::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.xul.mutate()
            .set__moz_box_align(
                value,
            );
    }
    /// Inherit `_moz_box_direction` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_direction(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_xul();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.xul.mutate()
            .copy__moz_box_direction_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_box_direction` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_box_direction(&mut self) {
        let reset_struct =
            self.reset_style.get_xul();

        self.modified_reset = true;

        self.xul.mutate()
            .reset__moz_box_direction(
                reset_struct,
            );
    }

    /// Set the `_moz_box_direction` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_direction(
        &mut self,
        value: longhands::_moz_box_direction::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.xul.mutate()
            .set__moz_box_direction(
                value,
            );
    }
    /// Inherit `_moz_box_orient` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_orient(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_xul();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.xul.mutate()
            .copy__moz_box_orient_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_box_orient` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_box_orient(&mut self) {
        let reset_struct =
            self.reset_style.get_xul();

        self.modified_reset = true;

        self.xul.mutate()
            .reset__moz_box_orient(
                reset_struct,
            );
    }

    /// Set the `_moz_box_orient` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_orient(
        &mut self,
        value: longhands::_moz_box_orient::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.xul.mutate()
            .set__moz_box_orient(
                value,
            );
    }
    /// Inherit `_moz_box_pack` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_pack(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_xul();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.xul.mutate()
            .copy__moz_box_pack_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_box_pack` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_box_pack(&mut self) {
        let reset_struct =
            self.reset_style.get_xul();

        self.modified_reset = true;

        self.xul.mutate()
            .reset__moz_box_pack(
                reset_struct,
            );
    }

    /// Set the `_moz_box_pack` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_pack(
        &mut self,
        value: longhands::_moz_box_pack::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.xul.mutate()
            .set__moz_box_pack(
                value,
            );
    }
    /// Inherit `_moz_control_character_visibility` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_control_character_visibility(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy__moz_control_character_visibility_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_control_character_visibility` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_control_character_visibility(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset__moz_control_character_visibility(
                reset_struct,
            );
    }

    /// Set the `_moz_control_character_visibility` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_control_character_visibility(
        &mut self,
        value: longhands::_moz_control_character_visibility::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set__moz_control_character_visibility(
                value,
            );
    }
    /// Inherit `_moz_float_edge` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_float_edge(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy__moz_float_edge_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_float_edge` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_float_edge(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset__moz_float_edge(
                reset_struct,
            );
    }

    /// Set the `_moz_float_edge` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_float_edge(
        &mut self,
        value: longhands::_moz_float_edge::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set__moz_float_edge(
                value,
            );
    }
    /// Inherit `_moz_force_broken_image_icon` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_force_broken_image_icon(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy__moz_force_broken_image_icon_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_force_broken_image_icon` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_force_broken_image_icon(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset__moz_force_broken_image_icon(
                reset_struct,
            );
    }

    /// Set the `_moz_force_broken_image_icon` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_force_broken_image_icon(
        &mut self,
        value: longhands::_moz_force_broken_image_icon::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set__moz_force_broken_image_icon(
                value,
            );
    }
    /// Inherit `_moz_math_display` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_math_display(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_math_display_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_math_display` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_math_display(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_math_display(
                reset_struct,
            );
    }

    /// Set the `_moz_math_display` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_math_display(
        &mut self,
        value: longhands::_moz_math_display::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_math_display(
                value,
            );
    }
    /// Inherit `_moz_math_variant` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_math_variant(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_math_variant_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_math_variant` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_math_variant(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_math_variant(
                reset_struct,
            );
    }

    /// Set the `_moz_math_variant` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_math_variant(
        &mut self,
        value: longhands::_moz_math_variant::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_math_variant(
                value,
            );
    }
    /// Inherit `_moz_min_font_size_ratio` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_min_font_size_ratio(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_min_font_size_ratio_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_min_font_size_ratio` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_min_font_size_ratio(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_min_font_size_ratio(
                reset_struct,
            );
    }

    /// Set the `_moz_min_font_size_ratio` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_min_font_size_ratio(
        &mut self,
        value: longhands::_moz_min_font_size_ratio::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_min_font_size_ratio(
                value,
            );
    }
    /// Inherit `_moz_orient` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_orient(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy__moz_orient_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_orient` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_orient(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset__moz_orient(
                reset_struct,
            );
    }

    /// Set the `_moz_orient` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_orient(
        &mut self,
        value: longhands::_moz_orient::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set__moz_orient(
                value,
            );
    }
    /// Inherit `_moz_osx_font_smoothing` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_osx_font_smoothing(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_osx_font_smoothing_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_osx_font_smoothing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_osx_font_smoothing(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_osx_font_smoothing(
                reset_struct,
            );
    }

    /// Set the `_moz_osx_font_smoothing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_osx_font_smoothing(
        &mut self,
        value: longhands::_moz_osx_font_smoothing::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_osx_font_smoothing(
                value,
            );
    }
    /// Inherit `_moz_script_level` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_script_level(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_script_level_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_script_level` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_script_level(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_script_level(
                reset_struct,
            );
    }

    /// Set the `_moz_script_level` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_script_level(
        &mut self,
        value: longhands::_moz_script_level::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_script_level(
                value,
            );
    }
    /// Inherit `_moz_script_min_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_script_min_size(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_script_min_size_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_script_min_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_script_min_size(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_script_min_size(
                reset_struct,
            );
    }

    /// Set the `_moz_script_min_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_script_min_size(
        &mut self,
        value: longhands::_moz_script_min_size::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_script_min_size(
                value,
            );
    }
    /// Inherit `_moz_script_size_multiplier` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_script_size_multiplier(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_script_size_multiplier_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_script_size_multiplier` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_script_size_multiplier(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_script_size_multiplier(
                reset_struct,
            );
    }

    /// Set the `_moz_script_size_multiplier` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_script_size_multiplier(
        &mut self,
        value: longhands::_moz_script_size_multiplier::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_script_size_multiplier(
                value,
            );
    }
    /// Inherit `_moz_stack_sizing` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_stack_sizing(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_xul();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.xul.mutate()
            .copy__moz_stack_sizing_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_stack_sizing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_stack_sizing(&mut self) {
        let reset_struct =
            self.reset_style.get_xul();

        self.modified_reset = true;

        self.xul.mutate()
            .reset__moz_stack_sizing(
                reset_struct,
            );
    }

    /// Set the `_moz_stack_sizing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_stack_sizing(
        &mut self,
        value: longhands::_moz_stack_sizing::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.xul.mutate()
            .set__moz_stack_sizing(
                value,
            );
    }
    /// Inherit `_moz_text_size_adjust` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_text_size_adjust(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy__moz_text_size_adjust_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_text_size_adjust` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_text_size_adjust(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset__moz_text_size_adjust(
                reset_struct,
            );
    }

    /// Set the `_moz_text_size_adjust` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_text_size_adjust(
        &mut self,
        value: longhands::_moz_text_size_adjust::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set__moz_text_size_adjust(
                value,
            );
    }
    /// Inherit `_moz_top_layer` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_top_layer(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy__moz_top_layer_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_top_layer` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_top_layer(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset__moz_top_layer(
                reset_struct,
            );
    }

    /// Set the `_moz_top_layer` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_top_layer(
        &mut self,
        value: longhands::_moz_top_layer::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set__moz_top_layer(
                value,
            );
    }
    /// Inherit `_moz_user_focus` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_user_focus(&mut self) {
        let inherited_struct =
            self.inherited_style.get_pointing();




        self.pointing.mutate()
            .copy__moz_user_focus_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_user_focus` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_user_focus(&mut self) {
        let reset_struct =
            self.reset_style.get_pointing();


        self.pointing.mutate()
            .reset__moz_user_focus(
                reset_struct,
            );
    }

    /// Set the `_moz_user_focus` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_user_focus(
        &mut self,
        value: longhands::_moz_user_focus::computed_value::T
    ) {

        
        self.pointing.mutate()
            .set__moz_user_focus(
                value,
            );
    }
    /// Inherit `_moz_user_input` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_user_input(&mut self) {
        let inherited_struct =
            self.inherited_style.get_pointing();




        self.pointing.mutate()
            .copy__moz_user_input_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_user_input` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_user_input(&mut self) {
        let reset_struct =
            self.reset_style.get_pointing();


        self.pointing.mutate()
            .reset__moz_user_input(
                reset_struct,
            );
    }

    /// Set the `_moz_user_input` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_user_input(
        &mut self,
        value: longhands::_moz_user_input::computed_value::T
    ) {

        
        self.pointing.mutate()
            .set__moz_user_input(
                value,
            );
    }
    /// Inherit `_moz_user_modify` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_user_modify(&mut self) {
        let inherited_struct =
            self.inherited_style.get_pointing();




        self.pointing.mutate()
            .copy__moz_user_modify_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_user_modify` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_user_modify(&mut self) {
        let reset_struct =
            self.reset_style.get_pointing();


        self.pointing.mutate()
            .reset__moz_user_modify(
                reset_struct,
            );
    }

    /// Set the `_moz_user_modify` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_user_modify(
        &mut self,
        value: longhands::_moz_user_modify::computed_value::T
    ) {

        
        self.pointing.mutate()
            .set__moz_user_modify(
                value,
            );
    }
    /// Inherit `_moz_user_select` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_user_select(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy__moz_user_select_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_user_select` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_user_select(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset__moz_user_select(
                reset_struct,
            );
    }

    /// Set the `_moz_user_select` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_user_select(
        &mut self,
        value: longhands::_moz_user_select::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set__moz_user_select(
                value,
            );
    }
    /// Inherit `_moz_window_dragging` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_dragging(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy__moz_window_dragging_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_window_dragging` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_window_dragging(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset__moz_window_dragging(
                reset_struct,
            );
    }

    /// Set the `_moz_window_dragging` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_dragging(
        &mut self,
        value: longhands::_moz_window_dragging::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set__moz_window_dragging(
                value,
            );
    }
    /// Inherit `_moz_window_shadow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_shadow(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy__moz_window_shadow_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_window_shadow` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_window_shadow(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset__moz_window_shadow(
                reset_struct,
            );
    }

    /// Set the `_moz_window_shadow` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_shadow(
        &mut self,
        value: longhands::_moz_window_shadow::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set__moz_window_shadow(
                value,
            );
    }
    /// Inherit `object_fit` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_object_fit(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_object_fit_from(
                inherited_struct,
            );
    }

    /// Reset `object_fit` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_object_fit(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_object_fit(
                reset_struct,
            );
    }

    /// Set the `object_fit` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_object_fit(
        &mut self,
        value: longhands::object_fit::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_object_fit(
                value,
            );
    }
    /// Inherit `outline_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_outline_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy_outline_style_from(
                inherited_struct,
            );
    }

    /// Reset `outline_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_outline_style(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset_outline_style(
                reset_struct,
            );
    }

    /// Set the `outline_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_outline_style(
        &mut self,
        value: longhands::outline_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set_outline_style(
                value,
            );
    }
    /// Inherit `overflow_wrap` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_wrap(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_overflow_wrap_from(
                inherited_struct,
            );
    }

    /// Reset `overflow_wrap` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_overflow_wrap(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_overflow_wrap(
                reset_struct,
            );
    }

    /// Set the `overflow_wrap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_wrap(
        &mut self,
        value: longhands::overflow_wrap::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_overflow_wrap(
                value,
            );
    }
    /// Inherit `overflow_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_x(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_overflow_x_from(
                inherited_struct,
            );
    }

    /// Reset `overflow_x` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_overflow_x(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_overflow_x(
                reset_struct,
            );
    }

    /// Set the `overflow_x` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_x(
        &mut self,
        value: longhands::overflow_x::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_overflow_x(
                value,
            );
    }
    /// Inherit `page_break_after` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_page_break_after(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_page_break_after_from(
                inherited_struct,
            );
    }

    /// Reset `page_break_after` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_page_break_after(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_page_break_after(
                reset_struct,
            );
    }

    /// Set the `page_break_after` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_page_break_after(
        &mut self,
        value: longhands::page_break_after::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_page_break_after(
                value,
            );
    }
    /// Inherit `page_break_before` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_page_break_before(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_page_break_before_from(
                inherited_struct,
            );
    }

    /// Reset `page_break_before` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_page_break_before(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_page_break_before(
                reset_struct,
            );
    }

    /// Set the `page_break_before` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_page_break_before(
        &mut self,
        value: longhands::page_break_before::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_page_break_before(
                value,
            );
    }
    /// Inherit `page_break_inside` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_page_break_inside(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_page_break_inside_from(
                inherited_struct,
            );
    }

    /// Reset `page_break_inside` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_page_break_inside(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_page_break_inside(
                reset_struct,
            );
    }

    /// Set the `page_break_inside` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_page_break_inside(
        &mut self,
        value: longhands::page_break_inside::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_page_break_inside(
                value,
            );
    }
    /// Inherit `paint_order` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_paint_order(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_paint_order_from(
                inherited_struct,
            );
    }

    /// Reset `paint_order` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_paint_order(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_paint_order(
                reset_struct,
            );
    }

    /// Set the `paint_order` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_paint_order(
        &mut self,
        value: longhands::paint_order::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_paint_order(
                value,
            );
    }
    /// Inherit `pointer_events` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_pointer_events(&mut self) {
        let inherited_struct =
            self.inherited_style.get_pointing();




        self.pointing.mutate()
            .copy_pointer_events_from(
                inherited_struct,
            );
    }

    /// Reset `pointer_events` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_pointer_events(&mut self) {
        let reset_struct =
            self.reset_style.get_pointing();


        self.pointing.mutate()
            .reset_pointer_events(
                reset_struct,
            );
    }

    /// Set the `pointer_events` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_pointer_events(
        &mut self,
        value: longhands::pointer_events::computed_value::T
    ) {

        
        self.pointing.mutate()
            .set_pointer_events(
                value,
            );
    }
    /// Inherit `position` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_position(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_position_from(
                inherited_struct,
            );
    }

    /// Reset `position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_position(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_position(
                reset_struct,
            );
    }

    /// Set the `position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_position(
        &mut self,
        value: longhands::position::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_position(
                value,
            );
    }
    /// Inherit `resize` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_resize(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_resize_from(
                inherited_struct,
            );
    }

    /// Reset `resize` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_resize(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_resize(
                reset_struct,
            );
    }

    /// Set the `resize` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_resize(
        &mut self,
        value: longhands::resize::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_resize(
                value,
            );
    }
    /// Inherit `ruby_align` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_ruby_align(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_ruby_align_from(
                inherited_struct,
            );
    }

    /// Reset `ruby_align` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_ruby_align(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_ruby_align(
                reset_struct,
            );
    }

    /// Set the `ruby_align` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_ruby_align(
        &mut self,
        value: longhands::ruby_align::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_ruby_align(
                value,
            );
    }
    /// Inherit `ruby_position` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_ruby_position(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_ruby_position_from(
                inherited_struct,
            );
    }

    /// Reset `ruby_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_ruby_position(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_ruby_position(
                reset_struct,
            );
    }

    /// Set the `ruby_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_ruby_position(
        &mut self,
        value: longhands::ruby_position::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_ruby_position(
                value,
            );
    }
    /// Inherit `scroll_behavior` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_behavior(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_scroll_behavior_from(
                inherited_struct,
            );
    }

    /// Reset `scroll_behavior` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scroll_behavior(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_scroll_behavior(
                reset_struct,
            );
    }

    /// Set the `scroll_behavior` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_behavior(
        &mut self,
        value: longhands::scroll_behavior::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_scroll_behavior(
                value,
            );
    }
    /// Inherit `shape_rendering` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_shape_rendering(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_shape_rendering_from(
                inherited_struct,
            );
    }

    /// Reset `shape_rendering` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_shape_rendering(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_shape_rendering(
                reset_struct,
            );
    }

    /// Set the `shape_rendering` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_shape_rendering(
        &mut self,
        value: longhands::shape_rendering::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_shape_rendering(
                value,
            );
    }
    /// Inherit `stroke_linecap` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke_linecap(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_linecap_from(
                inherited_struct,
            );
    }

    /// Reset `stroke_linecap` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_linecap(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke_linecap(
                reset_struct,
            );
    }

    /// Set the `stroke_linecap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_linecap(
        &mut self,
        value: longhands::stroke_linecap::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke_linecap(
                value,
            );
    }
    /// Inherit `stroke_linejoin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke_linejoin(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_linejoin_from(
                inherited_struct,
            );
    }

    /// Reset `stroke_linejoin` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_linejoin(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke_linejoin(
                reset_struct,
            );
    }

    /// Set the `stroke_linejoin` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_linejoin(
        &mut self,
        value: longhands::stroke_linejoin::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke_linejoin(
                value,
            );
    }
    /// Inherit `table_layout` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_table_layout(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_table();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.table.mutate()
            .copy_table_layout_from(
                inherited_struct,
            );
    }

    /// Reset `table_layout` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_table_layout(&mut self) {
        let reset_struct =
            self.reset_style.get_table();

        self.modified_reset = true;

        self.table.mutate()
            .reset_table_layout(
                reset_struct,
            );
    }

    /// Set the `table_layout` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_table_layout(
        &mut self,
        value: longhands::table_layout::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.table.mutate()
            .set_table_layout(
                value,
            );
    }
    /// Inherit `text_align_last` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_align_last(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_align_last_from(
                inherited_struct,
            );
    }

    /// Reset `text_align_last` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_align_last(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_align_last(
                reset_struct,
            );
    }

    /// Set the `text_align_last` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_align_last(
        &mut self,
        value: longhands::text_align_last::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_align_last(
                value,
            );
    }
    /// Inherit `text_anchor` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_anchor(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_text_anchor_from(
                inherited_struct,
            );
    }

    /// Reset `text_anchor` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_anchor(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_text_anchor(
                reset_struct,
            );
    }

    /// Set the `text_anchor` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_anchor(
        &mut self,
        value: longhands::text_anchor::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_text_anchor(
                value,
            );
    }
    /// Inherit `text_combine_upright` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_combine_upright(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_combine_upright_from(
                inherited_struct,
            );
    }

    /// Reset `text_combine_upright` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_combine_upright(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_combine_upright(
                reset_struct,
            );
    }

    /// Set the `text_combine_upright` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_combine_upright(
        &mut self,
        value: longhands::text_combine_upright::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_combine_upright(
                value,
            );
    }
    /// Inherit `text_decoration_line` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_decoration_line(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_text();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.text.mutate()
            .copy_text_decoration_line_from(
                inherited_struct,
            );
    }

    /// Reset `text_decoration_line` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_decoration_line(&mut self) {
        let reset_struct =
            self.reset_style.get_text();

        self.modified_reset = true;

        self.text.mutate()
            .reset_text_decoration_line(
                reset_struct,
            );
    }

    /// Set the `text_decoration_line` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_decoration_line(
        &mut self,
        value: longhands::text_decoration_line::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.text.mutate()
            .set_text_decoration_line(
                value,
            );
    }
    /// Inherit `text_decoration_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_decoration_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_text();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.text.mutate()
            .copy_text_decoration_style_from(
                inherited_struct,
            );
    }

    /// Reset `text_decoration_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_decoration_style(&mut self) {
        let reset_struct =
            self.reset_style.get_text();

        self.modified_reset = true;

        self.text.mutate()
            .reset_text_decoration_style(
                reset_struct,
            );
    }

    /// Set the `text_decoration_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_decoration_style(
        &mut self,
        value: longhands::text_decoration_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.text.mutate()
            .set_text_decoration_style(
                value,
            );
    }
    /// Inherit `text_justify` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_justify(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_justify_from(
                inherited_struct,
            );
    }

    /// Reset `text_justify` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_justify(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_justify(
                reset_struct,
            );
    }

    /// Set the `text_justify` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_justify(
        &mut self,
        value: longhands::text_justify::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_justify(
                value,
            );
    }
    /// Inherit `text_orientation` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_orientation(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedbox();




        self.inheritedbox.mutate()
            .copy_text_orientation_from(
                inherited_struct,
            );
    }

    /// Reset `text_orientation` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_orientation(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedbox();


        self.inheritedbox.mutate()
            .reset_text_orientation(
                reset_struct,
            );
    }

    /// Set the `text_orientation` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_orientation(
        &mut self,
        value: longhands::text_orientation::computed_value::T
    ) {

        
        self.inheritedbox.mutate()
            .set_text_orientation(
                value,
            );
    }
    /// Inherit `text_rendering` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_rendering(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_rendering_from(
                inherited_struct,
            );
    }

    /// Reset `text_rendering` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_rendering(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_rendering(
                reset_struct,
            );
    }

    /// Set the `text_rendering` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_rendering(
        &mut self,
        value: longhands::text_rendering::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_rendering(
                value,
            );
    }
    /// Inherit `text_transform` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_transform(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_transform_from(
                inherited_struct,
            );
    }

    /// Reset `text_transform` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_transform(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_transform(
                reset_struct,
            );
    }

    /// Set the `text_transform` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_transform(
        &mut self,
        value: longhands::text_transform::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_transform(
                value,
            );
    }
    /// Inherit `touch_action` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_touch_action(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_touch_action_from(
                inherited_struct,
            );
    }

    /// Reset `touch_action` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_touch_action(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_touch_action(
                reset_struct,
            );
    }

    /// Set the `touch_action` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_touch_action(
        &mut self,
        value: longhands::touch_action::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_touch_action(
                value,
            );
    }
    /// Inherit `transform_box` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transform_box(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transform_box_from(
                inherited_struct,
            );
    }

    /// Reset `transform_box` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transform_box(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transform_box(
                reset_struct,
            );
    }

    /// Set the `transform_box` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_transform_box(
        &mut self,
        value: longhands::transform_box::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_transform_box(
                value,
            );
    }
    /// Inherit `transform_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transform_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transform_style_from(
                inherited_struct,
            );
    }

    /// Reset `transform_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transform_style(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transform_style(
                reset_struct,
            );
    }

    /// Set the `transform_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_transform_style(
        &mut self,
        value: longhands::transform_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_transform_style(
                value,
            );
    }
    /// Inherit `unicode_bidi` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_unicode_bidi(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_text();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.text.mutate()
            .copy_unicode_bidi_from(
                inherited_struct,
            );
    }

    /// Reset `unicode_bidi` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_unicode_bidi(&mut self) {
        let reset_struct =
            self.reset_style.get_text();

        self.modified_reset = true;

        self.text.mutate()
            .reset_unicode_bidi(
                reset_struct,
            );
    }

    /// Set the `unicode_bidi` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_unicode_bidi(
        &mut self,
        value: longhands::unicode_bidi::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.text.mutate()
            .set_unicode_bidi(
                value,
            );
    }
    /// Inherit `vector_effect` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_vector_effect(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_vector_effect_from(
                inherited_struct,
            );
    }

    /// Reset `vector_effect` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_vector_effect(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_vector_effect(
                reset_struct,
            );
    }

    /// Set the `vector_effect` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_vector_effect(
        &mut self,
        value: longhands::vector_effect::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_vector_effect(
                value,
            );
    }
    /// Inherit `visibility` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_visibility(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedbox();




        self.inheritedbox.mutate()
            .copy_visibility_from(
                inherited_struct,
            );
    }

    /// Reset `visibility` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_visibility(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedbox();


        self.inheritedbox.mutate()
            .reset_visibility(
                reset_struct,
            );
    }

    /// Set the `visibility` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_visibility(
        &mut self,
        value: longhands::visibility::computed_value::T
    ) {

        
        self.inheritedbox.mutate()
            .set_visibility(
                value,
            );
    }
    /// Inherit `white_space` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_white_space(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_white_space_from(
                inherited_struct,
            );
    }

    /// Reset `white_space` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_white_space(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_white_space(
                reset_struct,
            );
    }

    /// Set the `white_space` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_white_space(
        &mut self,
        value: longhands::white_space::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_white_space(
                value,
            );
    }
    /// Inherit `word_break` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_word_break(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_word_break_from(
                inherited_struct,
            );
    }

    /// Reset `word_break` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_word_break(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_word_break(
                reset_struct,
            );
    }

    /// Set the `word_break` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_word_break(
        &mut self,
        value: longhands::word_break::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_word_break(
                value,
            );
    }
    /// Inherit `writing_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_writing_mode(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedbox();




        self.inheritedbox.mutate()
            .copy_writing_mode_from(
                inherited_struct,
            );
    }

    /// Reset `writing_mode` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_writing_mode(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedbox();


        self.inheritedbox.mutate()
            .reset_writing_mode(
                reset_struct,
            );
    }

    /// Set the `writing_mode` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_writing_mode(
        &mut self,
        value: longhands::writing_mode::computed_value::T
    ) {

        
        self.inheritedbox.mutate()
            .set_writing_mode(
                value,
            );
    }
    /// Inherit `_x_span` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__x_span(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_table();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.table.mutate()
            .copy__x_span_from(
                inherited_struct,
            );
    }

    /// Reset `_x_span` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__x_span(&mut self) {
        let reset_struct =
            self.reset_style.get_table();

        self.modified_reset = true;

        self.table.mutate()
            .reset__x_span(
                reset_struct,
            );
    }

    /// Set the `_x_span` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__x_span(
        &mut self,
        value: longhands::_x_span::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.table.mutate()
            .set__x_span(
                value,
            );
    }
    /// Inherit `_x_text_zoom` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__x_text_zoom(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__x_text_zoom_from(
                inherited_struct,
            );
    }

    /// Reset `_x_text_zoom` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__x_text_zoom(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__x_text_zoom(
                reset_struct,
            );
    }

    /// Set the `_x_text_zoom` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__x_text_zoom(
        &mut self,
        value: longhands::_x_text_zoom::computed_value::T
    ) {

        
        self.font.mutate()
            .set__x_text_zoom(
                value,
            );
    }
    /// Inherit `z_index` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_z_index(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_z_index_from(
                inherited_struct,
            );
    }

    /// Reset `z_index` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_z_index(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_z_index(
                reset_struct,
            );
    }

    /// Set the `z_index` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_z_index(
        &mut self,
        value: longhands::z_index::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_z_index(
                value,
            );
    }
    /// Inherit `_moz_box_ordinal_group` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_ordinal_group(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_xul();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.xul.mutate()
            .copy__moz_box_ordinal_group_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_box_ordinal_group` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_box_ordinal_group(&mut self) {
        let reset_struct =
            self.reset_style.get_xul();

        self.modified_reset = true;

        self.xul.mutate()
            .reset__moz_box_ordinal_group(
                reset_struct,
            );
    }

    /// Set the `_moz_box_ordinal_group` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_ordinal_group(
        &mut self,
        value: longhands::_moz_box_ordinal_group::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.xul.mutate()
            .set__moz_box_ordinal_group(
                value,
            );
    }
    /// Inherit `order` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_order(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_order_from(
                inherited_struct,
            );
    }

    /// Reset `order` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_order(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_order(
                reset_struct,
            );
    }

    /// Set the `order` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_order(
        &mut self,
        value: longhands::order::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_order(
                value,
            );
    }
    /// Inherit `overscroll_behavior_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overscroll_behavior_x(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_overscroll_behavior_x_from(
                inherited_struct,
            );
    }

    /// Reset `overscroll_behavior_x` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_overscroll_behavior_x(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_overscroll_behavior_x(
                reset_struct,
            );
    }

    /// Set the `overscroll_behavior_x` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overscroll_behavior_x(
        &mut self,
        value: longhands::overscroll_behavior_x::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_overscroll_behavior_x(
                value,
            );
    }
    /// Inherit `overscroll_behavior_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overscroll_behavior_y(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_overscroll_behavior_y_from(
                inherited_struct,
            );
    }

    /// Reset `overscroll_behavior_y` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_overscroll_behavior_y(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_overscroll_behavior_y(
                reset_struct,
            );
    }

    /// Set the `overscroll_behavior_y` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overscroll_behavior_y(
        &mut self,
        value: longhands::overscroll_behavior_y::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_overscroll_behavior_y(
                value,
            );
    }
    /// Inherit `scroll_snap_type_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_snap_type_x(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_scroll_snap_type_x_from(
                inherited_struct,
            );
    }

    /// Reset `scroll_snap_type_x` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scroll_snap_type_x(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_scroll_snap_type_x(
                reset_struct,
            );
    }

    /// Set the `scroll_snap_type_x` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_snap_type_x(
        &mut self,
        value: longhands::scroll_snap_type_x::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_scroll_snap_type_x(
                value,
            );
    }
    /// Inherit `scroll_snap_type_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_snap_type_y(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_scroll_snap_type_y_from(
                inherited_struct,
            );
    }

    /// Reset `scroll_snap_type_y` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scroll_snap_type_y(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_scroll_snap_type_y(
                reset_struct,
            );
    }

    /// Set the `scroll_snap_type_y` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_snap_type_y(
        &mut self,
        value: longhands::scroll_snap_type_y::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_scroll_snap_type_y(
                value,
            );
    }
    /// Inherit `flex_grow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flex_grow(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_flex_grow_from(
                inherited_struct,
            );
    }

    /// Reset `flex_grow` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_flex_grow(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_flex_grow(
                reset_struct,
            );
    }

    /// Set the `flex_grow` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flex_grow(
        &mut self,
        value: longhands::flex_grow::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_flex_grow(
                value,
            );
    }
    /// Inherit `flex_shrink` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flex_shrink(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_flex_shrink_from(
                inherited_struct,
            );
    }

    /// Reset `flex_shrink` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_flex_shrink(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_flex_shrink(
                reset_struct,
            );
    }

    /// Set the `flex_shrink` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flex_shrink(
        &mut self,
        value: longhands::flex_shrink::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_flex_shrink(
                value,
            );
    }
    /// Inherit `_moz_box_flex` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_flex(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_xul();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.xul.mutate()
            .copy__moz_box_flex_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_box_flex` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_box_flex(&mut self) {
        let reset_struct =
            self.reset_style.get_xul();

        self.modified_reset = true;

        self.xul.mutate()
            .reset__moz_box_flex(
                reset_struct,
            );
    }

    /// Set the `_moz_box_flex` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_flex(
        &mut self,
        value: longhands::_moz_box_flex::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.xul.mutate()
            .set__moz_box_flex(
                value,
            );
    }
    /// Inherit `flood_opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flood_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_flood_opacity_from(
                inherited_struct,
            );
    }

    /// Reset `flood_opacity` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_flood_opacity(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_flood_opacity(
                reset_struct,
            );
    }

    /// Set the `flood_opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flood_opacity(
        &mut self,
        value: longhands::flood_opacity::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_flood_opacity(
                value,
            );
    }
    /// Inherit `_moz_window_opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy__moz_window_opacity_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_window_opacity` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_window_opacity(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset__moz_window_opacity(
                reset_struct,
            );
    }

    /// Set the `_moz_window_opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_opacity(
        &mut self,
        value: longhands::_moz_window_opacity::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set__moz_window_opacity(
                value,
            );
    }
    /// Inherit `opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_effects();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.effects.mutate()
            .copy_opacity_from(
                inherited_struct,
            );
    }

    /// Reset `opacity` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_opacity(&mut self) {
        let reset_struct =
            self.reset_style.get_effects();

        self.modified_reset = true;

        self.effects.mutate()
            .reset_opacity(
                reset_struct,
            );
    }

    /// Set the `opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_opacity(
        &mut self,
        value: longhands::opacity::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.effects.mutate()
            .set_opacity(
                value,
            );
    }
    /// Inherit `shape_image_threshold` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_shape_image_threshold(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_shape_image_threshold_from(
                inherited_struct,
            );
    }

    /// Reset `shape_image_threshold` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_shape_image_threshold(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_shape_image_threshold(
                reset_struct,
            );
    }

    /// Set the `shape_image_threshold` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_shape_image_threshold(
        &mut self,
        value: longhands::shape_image_threshold::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_shape_image_threshold(
                value,
            );
    }
    /// Inherit `stop_opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stop_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_stop_opacity_from(
                inherited_struct,
            );
    }

    /// Reset `stop_opacity` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stop_opacity(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_stop_opacity(
                reset_struct,
            );
    }

    /// Set the `stop_opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stop_opacity(
        &mut self,
        value: longhands::stop_opacity::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_stop_opacity(
                value,
            );
    }
    /// Inherit `border_block_end_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_block_end_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_block_end_style_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_block_end_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_block_end_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_block_end_style(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_block_end_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_block_end_style(
        &mut self,
        value: longhands::border_block_end_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_block_end_style(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_block_start_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_block_start_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_block_start_style_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_block_start_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_block_start_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_block_start_style(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_block_start_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_block_start_style(
        &mut self,
        value: longhands::border_block_start_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_block_start_style(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_bottom_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_bottom_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_bottom_style_from(
                inherited_struct,
            );
    }

    /// Reset `border_bottom_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_bottom_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_bottom_style(
                reset_struct,
            );
    }

    /// Set the `border_bottom_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_bottom_style(
        &mut self,
        value: longhands::border_bottom_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_bottom_style(
                value,
            );
    }
    /// Inherit `border_inline_end_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_inline_end_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_inline_end_style_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_inline_end_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_inline_end_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_inline_end_style(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_inline_end_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_inline_end_style(
        &mut self,
        value: longhands::border_inline_end_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_inline_end_style(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_inline_start_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_inline_start_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_inline_start_style_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_inline_start_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_inline_start_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_inline_start_style(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_inline_start_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_inline_start_style(
        &mut self,
        value: longhands::border_inline_start_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_inline_start_style(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_left_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_left_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_left_style_from(
                inherited_struct,
            );
    }

    /// Reset `border_left_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_left_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_left_style(
                reset_struct,
            );
    }

    /// Set the `border_left_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_left_style(
        &mut self,
        value: longhands::border_left_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_left_style(
                value,
            );
    }
    /// Inherit `border_right_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_right_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_right_style_from(
                inherited_struct,
            );
    }

    /// Reset `border_right_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_right_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_right_style(
                reset_struct,
            );
    }

    /// Set the `border_right_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_right_style(
        &mut self,
        value: longhands::border_right_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_right_style(
                value,
            );
    }
    /// Inherit `border_top_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_top_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_top_style_from(
                inherited_struct,
            );
    }

    /// Reset `border_top_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_top_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_top_style(
                reset_struct,
            );
    }

    /// Set the `border_top_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_top_style(
        &mut self,
        value: longhands::border_top_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_top_style(
                value,
            );
    }
    /// Inherit `animation_delay` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_delay(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_delay_from(
                inherited_struct,
            );
    }

    /// Reset `animation_delay` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_delay(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_delay(
                reset_struct,
            );
    }

    /// Inherit `animation_direction` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_direction(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_direction_from(
                inherited_struct,
            );
    }

    /// Reset `animation_direction` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_direction(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_direction(
                reset_struct,
            );
    }

    /// Inherit `animation_duration` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_duration(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_duration_from(
                inherited_struct,
            );
    }

    /// Reset `animation_duration` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_duration(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_duration(
                reset_struct,
            );
    }

    /// Inherit `animation_fill_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_fill_mode(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_fill_mode_from(
                inherited_struct,
            );
    }

    /// Reset `animation_fill_mode` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_fill_mode(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_fill_mode(
                reset_struct,
            );
    }

    /// Inherit `animation_iteration_count` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_iteration_count(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_iteration_count_from(
                inherited_struct,
            );
    }

    /// Reset `animation_iteration_count` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_iteration_count(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_iteration_count(
                reset_struct,
            );
    }

    /// Inherit `animation_name` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_name(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_name_from(
                inherited_struct,
            );
    }

    /// Reset `animation_name` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_name(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_name(
                reset_struct,
            );
    }

    /// Inherit `animation_play_state` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_play_state(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_play_state_from(
                inherited_struct,
            );
    }

    /// Reset `animation_play_state` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_play_state(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_play_state(
                reset_struct,
            );
    }

    /// Inherit `animation_timing_function` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_timing_function(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_timing_function_from(
                inherited_struct,
            );
    }

    /// Reset `animation_timing_function` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_timing_function(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_timing_function(
                reset_struct,
            );
    }

    /// Inherit `background_attachment` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_attachment(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_attachment_from(
                inherited_struct,
            );
    }

    /// Reset `background_attachment` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_attachment(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_attachment(
                reset_struct,
            );
    }

    /// Inherit `background_blend_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_blend_mode(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_blend_mode_from(
                inherited_struct,
            );
    }

    /// Reset `background_blend_mode` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_blend_mode(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_blend_mode(
                reset_struct,
            );
    }

    /// Inherit `background_clip` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_clip(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_clip_from(
                inherited_struct,
            );
    }

    /// Reset `background_clip` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_clip(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_clip(
                reset_struct,
            );
    }

    /// Inherit `background_image` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_image(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_image_from(
                inherited_struct,
            );
    }

    /// Reset `background_image` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_image(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_image(
                reset_struct,
            );
    }

    /// Inherit `background_origin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_origin(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_origin_from(
                inherited_struct,
            );
    }

    /// Reset `background_origin` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_origin(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_origin(
                reset_struct,
            );
    }

    /// Inherit `background_position_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_position_x(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_position_x_from(
                inherited_struct,
            );
    }

    /// Reset `background_position_x` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_position_x(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_position_x(
                reset_struct,
            );
    }

    /// Inherit `background_position_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_position_y(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_position_y_from(
                inherited_struct,
            );
    }

    /// Reset `background_position_y` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_position_y(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_position_y(
                reset_struct,
            );
    }

    /// Inherit `background_repeat` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_repeat(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_repeat_from(
                inherited_struct,
            );
    }

    /// Reset `background_repeat` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_repeat(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_repeat(
                reset_struct,
            );
    }

    /// Inherit `background_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_size_from(
                inherited_struct,
            );
    }

    /// Reset `background_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_size(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_size(
                reset_struct,
            );
    }

    /// Inherit `border_image_outset` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_image_outset(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_image_outset_from(
                inherited_struct,
            );
    }

    /// Reset `border_image_outset` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_image_outset(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_image_outset(
                reset_struct,
            );
    }

    /// Set the `border_image_outset` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_image_outset(
        &mut self,
        value: longhands::border_image_outset::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_image_outset(
                value,
            );
    }
    /// Inherit `border_image_slice` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_image_slice(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_image_slice_from(
                inherited_struct,
            );
    }

    /// Reset `border_image_slice` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_image_slice(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_image_slice(
                reset_struct,
            );
    }

    /// Set the `border_image_slice` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_image_slice(
        &mut self,
        value: longhands::border_image_slice::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_image_slice(
                value,
            );
    }
    /// Inherit `border_image_source` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_image_source(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_image_source_from(
                inherited_struct,
            );
    }

    /// Reset `border_image_source` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_image_source(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_image_source(
                reset_struct,
            );
    }

    /// Set the `border_image_source` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_image_source(
        &mut self,
        value: longhands::border_image_source::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_image_source(
                value,
            );
    }
    /// Inherit `border_image_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_image_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_image_width_from(
                inherited_struct,
            );
    }

    /// Reset `border_image_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_image_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_image_width(
                reset_struct,
            );
    }

    /// Set the `border_image_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_image_width(
        &mut self,
        value: longhands::border_image_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_image_width(
                value,
            );
    }
    /// Inherit `border_spacing` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_spacing(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtable();




        self.inheritedtable.mutate()
            .copy_border_spacing_from(
                inherited_struct,
            );
    }

    /// Reset `border_spacing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_spacing(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtable();


        self.inheritedtable.mutate()
            .reset_border_spacing(
                reset_struct,
            );
    }

    /// Set the `border_spacing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_spacing(
        &mut self,
        value: longhands::border_spacing::computed_value::T
    ) {

        
        self.inheritedtable.mutate()
            .set_border_spacing(
                value,
            );
    }
    /// Inherit `box_shadow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_box_shadow(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_effects();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.effects.mutate()
            .copy_box_shadow_from(
                inherited_struct,
            );
    }

    /// Reset `box_shadow` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_box_shadow(&mut self) {
        let reset_struct =
            self.reset_style.get_effects();

        self.modified_reset = true;

        self.effects.mutate()
            .reset_box_shadow(
                reset_struct,
            );
    }

    /// Inherit `caret_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_caret_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_pointing();




        self.pointing.mutate()
            .copy_caret_color_from(
                inherited_struct,
            );
    }

    /// Reset `caret_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_caret_color(&mut self) {
        let reset_struct =
            self.reset_style.get_pointing();


        self.pointing.mutate()
            .reset_caret_color(
                reset_struct,
            );
    }

    /// Set the `caret_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_caret_color(
        &mut self,
        value: longhands::caret_color::computed_value::T
    ) {

        
        self.pointing.mutate()
            .set_caret_color(
                value,
            );
    }
    /// Inherit `clip_path` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_clip_path(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_clip_path_from(
                inherited_struct,
            );
    }

    /// Reset `clip_path` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_clip_path(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_clip_path(
                reset_struct,
            );
    }

    /// Set the `clip_path` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_clip_path(
        &mut self,
        value: longhands::clip_path::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_clip_path(
                value,
            );
    }
    /// Inherit `color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_color();




        self.color.mutate()
            .copy_color_from(
                inherited_struct,
            );
    }

    /// Reset `color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_color(&mut self) {
        let reset_struct =
            self.reset_style.get_color();


        self.color.mutate()
            .reset_color(
                reset_struct,
            );
    }

    /// Set the `color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_color(
        &mut self,
        value: longhands::color::computed_value::T
    ) {

        
        self.color.mutate()
            .set_color(
                value,
            );
    }
    /// Inherit `column_gap` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_gap(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_gap_from(
                inherited_struct,
            );
    }

    /// Reset `column_gap` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_gap(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_gap(
                reset_struct,
            );
    }

    /// Set the `column_gap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_gap(
        &mut self,
        value: longhands::column_gap::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_gap(
                value,
            );
    }
    /// Inherit `column_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_width_from(
                inherited_struct,
            );
    }

    /// Reset `column_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_width(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_width(
                reset_struct,
            );
    }

    /// Set the `column_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_width(
        &mut self,
        value: longhands::column_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_width(
                value,
            );
    }
    /// Inherit `content` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_content(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_counters();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;

        self.flags.insert(ComputedValueFlags::INHERITS_CONTENT);


        self.counters.mutate()
            .copy_content_from(
                inherited_struct,
            );
    }

    /// Reset `content` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_content(&mut self) {
        let reset_struct =
            self.reset_style.get_counters();

        self.modified_reset = true;

        self.counters.mutate()
            .reset_content(
                reset_struct,
            );
    }

    /// Set the `content` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_content(
        &mut self,
        value: longhands::content::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.counters.mutate()
            .set_content(
                value,
                self.device,
            );
    }
    /// Inherit `counter_increment` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_counter_increment(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_counters();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.counters.mutate()
            .copy_counter_increment_from(
                inherited_struct,
            );
    }

    /// Reset `counter_increment` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_counter_increment(&mut self) {
        let reset_struct =
            self.reset_style.get_counters();

        self.modified_reset = true;

        self.counters.mutate()
            .reset_counter_increment(
                reset_struct,
            );
    }

    /// Set the `counter_increment` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_counter_increment(
        &mut self,
        value: longhands::counter_increment::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.counters.mutate()
            .set_counter_increment(
                value,
            );
    }
    /// Inherit `counter_reset` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_counter_reset(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_counters();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.counters.mutate()
            .copy_counter_reset_from(
                inherited_struct,
            );
    }

    /// Reset `counter_reset` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_counter_reset(&mut self) {
        let reset_struct =
            self.reset_style.get_counters();

        self.modified_reset = true;

        self.counters.mutate()
            .reset_counter_reset(
                reset_struct,
            );
    }

    /// Set the `counter_reset` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_counter_reset(
        &mut self,
        value: longhands::counter_reset::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.counters.mutate()
            .set_counter_reset(
                value,
            );
    }
    /// Inherit `cursor` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_cursor(&mut self) {
        let inherited_struct =
            self.inherited_style.get_pointing();




        self.pointing.mutate()
            .copy_cursor_from(
                inherited_struct,
            );
    }

    /// Reset `cursor` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_cursor(&mut self) {
        let reset_struct =
            self.reset_style.get_pointing();


        self.pointing.mutate()
            .reset_cursor(
                reset_struct,
            );
    }

    /// Set the `cursor` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_cursor(
        &mut self,
        value: longhands::cursor::computed_value::T
    ) {

        
        self.pointing.mutate()
            .set_cursor(
                value,
            );
    }
    /// Inherit `display` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_display(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;


        self.flags.insert(ComputedValueFlags::INHERITS_DISPLAY);

        self.box_.mutate()
            .copy_display_from(
                inherited_struct,
            );
    }

    /// Reset `display` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_display(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_display(
                reset_struct,
            );
    }

    /// Set the `display` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_display(
        &mut self,
        value: longhands::display::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_display(
                value,
            );
    }
    /// Inherit `filter` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_filter(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_effects();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.effects.mutate()
            .copy_filter_from(
                inherited_struct,
            );
    }

    /// Reset `filter` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_filter(&mut self) {
        let reset_struct =
            self.reset_style.get_effects();

        self.modified_reset = true;

        self.effects.mutate()
            .reset_filter(
                reset_struct,
            );
    }

    /// Inherit `font_family` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_family(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_family_from(
                inherited_struct,
            );
    }

    /// Reset `font_family` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_family(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_family(
                reset_struct,
            );
    }

    /// Set the `font_family` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_family(
        &mut self,
        value: longhands::font_family::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_family(
                value,
            );
    }
    /// Inherit `font_feature_settings` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_feature_settings(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_feature_settings_from(
                inherited_struct,
            );
    }

    /// Reset `font_feature_settings` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_feature_settings(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_feature_settings(
                reset_struct,
            );
    }

    /// Set the `font_feature_settings` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_feature_settings(
        &mut self,
        value: longhands::font_feature_settings::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_feature_settings(
                value,
            );
    }
    /// Inherit `font_language_override` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_language_override(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_language_override_from(
                inherited_struct,
            );
    }

    /// Reset `font_language_override` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_language_override(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_language_override(
                reset_struct,
            );
    }

    /// Set the `font_language_override` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_language_override(
        &mut self,
        value: longhands::font_language_override::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_language_override(
                value,
            );
    }
    /// Inherit `font_size_adjust` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_size_adjust(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_size_adjust_from(
                inherited_struct,
            );
    }

    /// Reset `font_size_adjust` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_size_adjust(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_size_adjust(
                reset_struct,
            );
    }

    /// Set the `font_size_adjust` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_size_adjust(
        &mut self,
        value: longhands::font_size_adjust::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_size_adjust(
                value,
            );
    }
    /// Inherit `font_variant_alternates` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_variant_alternates(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_variant_alternates_from(
                inherited_struct,
            );
    }

    /// Reset `font_variant_alternates` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_alternates(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_variant_alternates(
                reset_struct,
            );
    }

    /// Set the `font_variant_alternates` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_alternates(
        &mut self,
        value: longhands::font_variant_alternates::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_variant_alternates(
                value,
                self.device,
            );
    }
    /// Inherit `font_variant_east_asian` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_variant_east_asian(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_variant_east_asian_from(
                inherited_struct,
            );
    }

    /// Reset `font_variant_east_asian` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_east_asian(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_variant_east_asian(
                reset_struct,
            );
    }

    /// Set the `font_variant_east_asian` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_east_asian(
        &mut self,
        value: longhands::font_variant_east_asian::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_variant_east_asian(
                value,
            );
    }
    /// Inherit `font_variant_ligatures` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_variant_ligatures(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_variant_ligatures_from(
                inherited_struct,
            );
    }

    /// Reset `font_variant_ligatures` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_ligatures(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_variant_ligatures(
                reset_struct,
            );
    }

    /// Set the `font_variant_ligatures` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_ligatures(
        &mut self,
        value: longhands::font_variant_ligatures::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_variant_ligatures(
                value,
            );
    }
    /// Inherit `font_variant_numeric` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_variant_numeric(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_variant_numeric_from(
                inherited_struct,
            );
    }

    /// Reset `font_variant_numeric` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_numeric(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_variant_numeric(
                reset_struct,
            );
    }

    /// Set the `font_variant_numeric` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_numeric(
        &mut self,
        value: longhands::font_variant_numeric::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_variant_numeric(
                value,
            );
    }
    /// Inherit `font_variation_settings` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_variation_settings(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_variation_settings_from(
                inherited_struct,
            );
    }

    /// Reset `font_variation_settings` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variation_settings(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_variation_settings(
                reset_struct,
            );
    }

    /// Set the `font_variation_settings` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variation_settings(
        &mut self,
        value: longhands::font_variation_settings::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_variation_settings(
                value,
            );
    }
    /// Inherit `grid_template_areas` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_template_areas(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_template_areas_from(
                inherited_struct,
            );
    }

    /// Reset `grid_template_areas` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_template_areas(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_template_areas(
                reset_struct,
            );
    }

    /// Set the `grid_template_areas` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_template_areas(
        &mut self,
        value: longhands::grid_template_areas::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_template_areas(
                value,
            );
    }
    /// Inherit `letter_spacing` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_letter_spacing(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_letter_spacing_from(
                inherited_struct,
            );
    }

    /// Reset `letter_spacing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_letter_spacing(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_letter_spacing(
                reset_struct,
            );
    }

    /// Set the `letter_spacing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_letter_spacing(
        &mut self,
        value: longhands::letter_spacing::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_letter_spacing(
                value,
            );
    }
    /// Inherit `line_height` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_line_height(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_line_height_from(
                inherited_struct,
            );
    }

    /// Reset `line_height` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_line_height(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_line_height(
                reset_struct,
            );
    }

    /// Set the `line_height` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_line_height(
        &mut self,
        value: longhands::line_height::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_line_height(
                value,
            );
    }
    /// Inherit `list_style_image` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_list_style_image(&mut self) {
        let inherited_struct =
            self.inherited_style.get_list();




        self.list.mutate()
            .copy_list_style_image_from(
                inherited_struct,
            );
    }

    /// Reset `list_style_image` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_list_style_image(&mut self) {
        let reset_struct =
            self.reset_style.get_list();


        self.list.mutate()
            .reset_list_style_image(
                reset_struct,
            );
    }

    /// Set the `list_style_image` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_list_style_image(
        &mut self,
        value: longhands::list_style_image::computed_value::T
    ) {

        
        self.list.mutate()
            .set_list_style_image(
                value,
            );
    }
    /// Inherit `list_style_type` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_list_style_type(&mut self) {
        let inherited_struct =
            self.inherited_style.get_list();




        self.list.mutate()
            .copy_list_style_type_from(
                inherited_struct,
            );
    }

    /// Reset `list_style_type` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_list_style_type(&mut self) {
        let reset_struct =
            self.reset_style.get_list();


        self.list.mutate()
            .reset_list_style_type(
                reset_struct,
            );
    }

    /// Set the `list_style_type` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_list_style_type(
        &mut self,
        value: longhands::list_style_type::computed_value::T
    ) {

        
        self.list.mutate()
            .set_list_style_type(
                value,
                self.device,
            );
    }
    /// Inherit `mask_clip` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_clip(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_clip_from(
                inherited_struct,
            );
    }

    /// Reset `mask_clip` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_clip(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_clip(
                reset_struct,
            );
    }

    /// Inherit `mask_composite` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_composite(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_composite_from(
                inherited_struct,
            );
    }

    /// Reset `mask_composite` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_composite(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_composite(
                reset_struct,
            );
    }

    /// Inherit `mask_image` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_image(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_image_from(
                inherited_struct,
            );
    }

    /// Reset `mask_image` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_image(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_image(
                reset_struct,
            );
    }

    /// Inherit `mask_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_mode(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_mode_from(
                inherited_struct,
            );
    }

    /// Reset `mask_mode` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_mode(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_mode(
                reset_struct,
            );
    }

    /// Inherit `mask_origin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_origin(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_origin_from(
                inherited_struct,
            );
    }

    /// Reset `mask_origin` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_origin(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_origin(
                reset_struct,
            );
    }

    /// Inherit `mask_position_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_position_x(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_position_x_from(
                inherited_struct,
            );
    }

    /// Reset `mask_position_x` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_position_x(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_position_x(
                reset_struct,
            );
    }

    /// Inherit `mask_position_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_position_y(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_position_y_from(
                inherited_struct,
            );
    }

    /// Reset `mask_position_y` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_position_y(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_position_y(
                reset_struct,
            );
    }

    /// Inherit `mask_repeat` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_repeat(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_repeat_from(
                inherited_struct,
            );
    }

    /// Reset `mask_repeat` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_repeat(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_repeat(
                reset_struct,
            );
    }

    /// Inherit `mask_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_size_from(
                inherited_struct,
            );
    }

    /// Reset `mask_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_size(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_size(
                reset_struct,
            );
    }

    /// Set the `mask_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_mask_size(
        &mut self,
        value: longhands::mask_size::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_mask_size(
                value,
            );
    }
    /// Inherit `_moz_context_properties` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_context_properties(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy__moz_context_properties_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_context_properties` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_context_properties(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset__moz_context_properties(
                reset_struct,
            );
    }

    /// Inherit `_moz_tab_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_tab_size(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy__moz_tab_size_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_tab_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_tab_size(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset__moz_tab_size(
                reset_struct,
            );
    }

    /// Set the `_moz_tab_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_tab_size(
        &mut self,
        value: longhands::_moz_tab_size::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set__moz_tab_size(
                value,
            );
    }
    /// Inherit `outline_offset` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_outline_offset(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy_outline_offset_from(
                inherited_struct,
            );
    }

    /// Reset `outline_offset` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_outline_offset(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset_outline_offset(
                reset_struct,
            );
    }

    /// Set the `outline_offset` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_outline_offset(
        &mut self,
        value: longhands::outline_offset::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set_outline_offset(
                value,
            );
    }
    /// Inherit `overflow_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_y(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_overflow_y_from(
                inherited_struct,
            );
    }

    /// Reset `overflow_y` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_overflow_y(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_overflow_y(
                reset_struct,
            );
    }

    /// Set the `overflow_y` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_y(
        &mut self,
        value: longhands::overflow_y::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_overflow_y(
                value,
            );
    }
    /// Inherit `perspective` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_perspective(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_perspective_from(
                inherited_struct,
            );
    }

    /// Reset `perspective` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_perspective(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_perspective(
                reset_struct,
            );
    }

    /// Set the `perspective` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_perspective(
        &mut self,
        value: longhands::perspective::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_perspective(
                value,
            );
    }
    /// Inherit `perspective_origin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_perspective_origin(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_perspective_origin_from(
                inherited_struct,
            );
    }

    /// Reset `perspective_origin` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_perspective_origin(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_perspective_origin(
                reset_struct,
            );
    }

    /// Set the `perspective_origin` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_perspective_origin(
        &mut self,
        value: longhands::perspective_origin::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_perspective_origin(
                value,
            );
    }
    /// Inherit `quotes` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_quotes(&mut self) {
        let inherited_struct =
            self.inherited_style.get_list();




        self.list.mutate()
            .copy_quotes_from(
                inherited_struct,
            );
    }

    /// Reset `quotes` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_quotes(&mut self) {
        let reset_struct =
            self.reset_style.get_list();


        self.list.mutate()
            .reset_quotes(
                reset_struct,
            );
    }

    /// Set the `quotes` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_quotes(
        &mut self,
        value: longhands::quotes::computed_value::T
    ) {

        
        self.list.mutate()
            .set_quotes(
                value,
            );
    }
    /// Inherit `rotate` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_rotate(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_rotate_from(
                inherited_struct,
            );
    }

    /// Reset `rotate` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_rotate(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_rotate(
                reset_struct,
            );
    }

    /// Set the `rotate` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_rotate(
        &mut self,
        value: longhands::rotate::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_rotate(
                value,
            );
    }
    /// Inherit `scale` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scale(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_scale_from(
                inherited_struct,
            );
    }

    /// Reset `scale` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scale(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_scale(
                reset_struct,
            );
    }

    /// Set the `scale` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scale(
        &mut self,
        value: longhands::scale::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_scale(
                value,
            );
    }
    /// Inherit `scroll_snap_coordinate` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_snap_coordinate(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_scroll_snap_coordinate_from(
                inherited_struct,
            );
    }

    /// Reset `scroll_snap_coordinate` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scroll_snap_coordinate(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_scroll_snap_coordinate(
                reset_struct,
            );
    }

    /// Inherit `shape_outside` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_shape_outside(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_shape_outside_from(
                inherited_struct,
            );
    }

    /// Reset `shape_outside` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_shape_outside(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_shape_outside(
                reset_struct,
            );
    }

    /// Set the `shape_outside` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_shape_outside(
        &mut self,
        value: longhands::shape_outside::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_shape_outside(
                value,
            );
    }
    /// Inherit `stroke_dasharray` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke_dasharray(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_dasharray_from(
                inherited_struct,
            );
    }

    /// Reset `stroke_dasharray` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_dasharray(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke_dasharray(
                reset_struct,
            );
    }

    /// Set the `stroke_dasharray` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_dasharray(
        &mut self,
        value: longhands::stroke_dasharray::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke_dasharray(
                value,
            );
    }
    /// Inherit `stroke_dashoffset` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke_dashoffset(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_dashoffset_from(
                inherited_struct,
            );
    }

    /// Reset `stroke_dashoffset` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_dashoffset(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke_dashoffset(
                reset_struct,
            );
    }

    /// Set the `stroke_dashoffset` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_dashoffset(
        &mut self,
        value: longhands::stroke_dashoffset::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke_dashoffset(
                value,
            );
    }
    /// Inherit `stroke_miterlimit` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke_miterlimit(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_miterlimit_from(
                inherited_struct,
            );
    }

    /// Reset `stroke_miterlimit` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_miterlimit(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke_miterlimit(
                reset_struct,
            );
    }

    /// Set the `stroke_miterlimit` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_miterlimit(
        &mut self,
        value: longhands::stroke_miterlimit::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke_miterlimit(
                value,
            );
    }
    /// Inherit `stroke_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_width_from(
                inherited_struct,
            );
    }

    /// Reset `stroke_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_width(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke_width(
                reset_struct,
            );
    }

    /// Set the `stroke_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_width(
        &mut self,
        value: longhands::stroke_width::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke_width(
                value,
            );
    }
    /// Inherit `text_align` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_align(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_align_from(
                inherited_struct,
            );
    }

    /// Reset `text_align` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_align(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_align(
                reset_struct,
            );
    }

    /// Set the `text_align` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_align(
        &mut self,
        value: longhands::text_align::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_align(
                value,
            );
    }
    /// Inherit `text_emphasis_position` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_emphasis_position(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_emphasis_position_from(
                inherited_struct,
            );
    }

    /// Reset `text_emphasis_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_emphasis_position(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_emphasis_position(
                reset_struct,
            );
    }

    /// Set the `text_emphasis_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_emphasis_position(
        &mut self,
        value: longhands::text_emphasis_position::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_emphasis_position(
                value,
            );
    }
    /// Inherit `text_emphasis_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_emphasis_style(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_emphasis_style_from(
                inherited_struct,
            );
    }

    /// Reset `text_emphasis_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_emphasis_style(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_emphasis_style(
                reset_struct,
            );
    }

    /// Set the `text_emphasis_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_emphasis_style(
        &mut self,
        value: longhands::text_emphasis_style::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_emphasis_style(
                value,
            );
    }
    /// Inherit `text_indent` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_indent(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_indent_from(
                inherited_struct,
            );
    }

    /// Reset `text_indent` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_indent(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_indent(
                reset_struct,
            );
    }

    /// Set the `text_indent` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_indent(
        &mut self,
        value: longhands::text_indent::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_indent(
                value,
            );
    }
    /// Inherit `text_overflow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_overflow(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_text();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.text.mutate()
            .copy_text_overflow_from(
                inherited_struct,
            );
    }

    /// Reset `text_overflow` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_overflow(&mut self) {
        let reset_struct =
            self.reset_style.get_text();

        self.modified_reset = true;

        self.text.mutate()
            .reset_text_overflow(
                reset_struct,
            );
    }

    /// Set the `text_overflow` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_overflow(
        &mut self,
        value: longhands::text_overflow::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.text.mutate()
            .set_text_overflow(
                value,
            );
    }
    /// Inherit `text_shadow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_shadow(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_shadow_from(
                inherited_struct,
            );
    }

    /// Reset `text_shadow` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_shadow(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_shadow(
                reset_struct,
            );
    }

    /// Inherit `transition_delay` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transition_delay(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transition_delay_from(
                inherited_struct,
            );
    }

    /// Reset `transition_delay` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transition_delay(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transition_delay(
                reset_struct,
            );
    }

    /// Inherit `transition_duration` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transition_duration(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transition_duration_from(
                inherited_struct,
            );
    }

    /// Reset `transition_duration` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transition_duration(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transition_duration(
                reset_struct,
            );
    }

    /// Inherit `transition_property` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transition_property(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transition_property_from(
                inherited_struct,
            );
    }

    /// Reset `transition_property` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transition_property(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transition_property(
                reset_struct,
            );
    }

    /// Inherit `transition_timing_function` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transition_timing_function(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transition_timing_function_from(
                inherited_struct,
            );
    }

    /// Reset `transition_timing_function` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transition_timing_function(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transition_timing_function(
                reset_struct,
            );
    }

    /// Inherit `translate` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_translate(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_translate_from(
                inherited_struct,
            );
    }

    /// Reset `translate` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_translate(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_translate(
                reset_struct,
            );
    }

    /// Set the `translate` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_translate(
        &mut self,
        value: longhands::translate::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_translate(
                value,
            );
    }
    /// Inherit `vertical_align` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_vertical_align(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_vertical_align_from(
                inherited_struct,
            );
    }

    /// Reset `vertical_align` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_vertical_align(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_vertical_align(
                reset_struct,
            );
    }

    /// Set the `vertical_align` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_vertical_align(
        &mut self,
        value: longhands::vertical_align::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_vertical_align(
                value,
            );
    }
    /// Inherit `will_change` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_will_change(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_will_change_from(
                inherited_struct,
            );
    }

    /// Reset `will_change` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_will_change(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_will_change(
                reset_struct,
            );
    }

    /// Set the `will_change` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_will_change(
        &mut self,
        value: longhands::will_change::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_will_change(
                value,
            );
    }
    /// Inherit `word_spacing` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_word_spacing(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_word_spacing_from(
                inherited_struct,
            );
    }

    /// Reset `word_spacing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_word_spacing(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_word_spacing(
                reset_struct,
            );
    }

    /// Set the `word_spacing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_word_spacing(
        &mut self,
        value: longhands::word_spacing::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_word_spacing(
                value,
            );
    }
    /// Inherit `_x_lang` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__x_lang(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__x_lang_from(
                inherited_struct,
            );
    }

    /// Reset `_x_lang` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__x_lang(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__x_lang(
                reset_struct,
            );
    }

    /// Set the `_x_lang` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__x_lang(
        &mut self,
        value: longhands::_x_lang::computed_value::T
    ) {

        
        self.font.mutate()
            .set__x_lang(
                value,
            );
    }
    /// Inherit `overflow_clip_box_block` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_clip_box_block(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_overflow_clip_box_block_from(
                inherited_struct,
            );
    }

    /// Reset `overflow_clip_box_block` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_overflow_clip_box_block(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_overflow_clip_box_block(
                reset_struct,
            );
    }

    /// Set the `overflow_clip_box_block` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_clip_box_block(
        &mut self,
        value: longhands::overflow_clip_box_block::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_overflow_clip_box_block(
                value,
            );
    }
    /// Inherit `overflow_clip_box_inline` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_clip_box_inline(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_overflow_clip_box_inline_from(
                inherited_struct,
            );
    }

    /// Reset `overflow_clip_box_inline` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_overflow_clip_box_inline(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_overflow_clip_box_inline(
                reset_struct,
            );
    }

    /// Set the `overflow_clip_box_inline` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_clip_box_inline(
        &mut self,
        value: longhands::overflow_clip_box_inline::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_overflow_clip_box_inline(
                value,
            );
    }
    /// Inherit `fill_opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_fill_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_fill_opacity_from(
                inherited_struct,
            );
    }

    /// Reset `fill_opacity` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_fill_opacity(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_fill_opacity(
                reset_struct,
            );
    }

    /// Set the `fill_opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_fill_opacity(
        &mut self,
        value: longhands::fill_opacity::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_fill_opacity(
                value,
            );
    }
    /// Inherit `stroke_opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_opacity_from(
                inherited_struct,
            );
    }

    /// Reset `stroke_opacity` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_opacity(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke_opacity(
                reset_struct,
            );
    }

    /// Set the `stroke_opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_opacity(
        &mut self,
        value: longhands::stroke_opacity::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke_opacity(
                value,
            );
    }
    /// Inherit `scroll_snap_points_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_snap_points_x(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_scroll_snap_points_x_from(
                inherited_struct,
            );
    }

    /// Reset `scroll_snap_points_x` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scroll_snap_points_x(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_scroll_snap_points_x(
                reset_struct,
            );
    }

    /// Set the `scroll_snap_points_x` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_snap_points_x(
        &mut self,
        value: longhands::scroll_snap_points_x::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_scroll_snap_points_x(
                value,
            );
    }
    /// Inherit `scroll_snap_points_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_snap_points_y(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_scroll_snap_points_y_from(
                inherited_struct,
            );
    }

    /// Reset `scroll_snap_points_y` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scroll_snap_points_y(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_scroll_snap_points_y(
                reset_struct,
            );
    }

    /// Set the `scroll_snap_points_y` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_snap_points_y(
        &mut self,
        value: longhands::scroll_snap_points_y::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_scroll_snap_points_y(
                value,
            );
    }
    /// Inherit `_moz_window_transform` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_transform(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy__moz_window_transform_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_window_transform` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_window_transform(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset__moz_window_transform(
                reset_struct,
            );
    }

    /// Set the `_moz_window_transform` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_transform(
        &mut self,
        value: longhands::_moz_window_transform::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set__moz_window_transform(
                value,
            );
    }
    /// Inherit `transform` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transform(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transform_from(
                inherited_struct,
            );
    }

    /// Reset `transform` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transform(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transform(
                reset_struct,
            );
    }

    /// Set the `transform` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_transform(
        &mut self,
        value: longhands::transform::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_transform(
                value,
            );
    }
    /// Inherit `clip` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_clip(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_effects();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.effects.mutate()
            .copy_clip_from(
                inherited_struct,
            );
    }

    /// Reset `clip` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_clip(&mut self) {
        let reset_struct =
            self.reset_style.get_effects();

        self.modified_reset = true;

        self.effects.mutate()
            .reset_clip(
                reset_struct,
            );
    }

    /// Set the `clip` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_clip(
        &mut self,
        value: longhands::clip::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.effects.mutate()
            .set_clip(
                value,
            );
    }
    /// Inherit `_moz_image_region` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_image_region(&mut self) {
        let inherited_struct =
            self.inherited_style.get_list();




        self.list.mutate()
            .copy__moz_image_region_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_image_region` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_image_region(&mut self) {
        let reset_struct =
            self.reset_style.get_list();


        self.list.mutate()
            .reset__moz_image_region(
                reset_struct,
            );
    }

    /// Set the `_moz_image_region` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_image_region(
        &mut self,
        value: longhands::_moz_image_region::computed_value::T
    ) {

        
        self.list.mutate()
            .set__moz_image_region(
                value,
            );
    }
    /// Inherit `grid_template_columns` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_template_columns(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_template_columns_from(
                inherited_struct,
            );
    }

    /// Reset `grid_template_columns` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_template_columns(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_template_columns(
                reset_struct,
            );
    }

    /// Set the `grid_template_columns` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_template_columns(
        &mut self,
        value: longhands::grid_template_columns::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_template_columns(
                value,
            );
    }
    /// Inherit `grid_template_rows` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_template_rows(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_template_rows_from(
                inherited_struct,
            );
    }

    /// Reset `grid_template_rows` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_template_rows(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_template_rows(
                reset_struct,
            );
    }

    /// Set the `grid_template_rows` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_template_rows(
        &mut self,
        value: longhands::grid_template_rows::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_template_rows(
                value,
            );
    }
    /// Inherit `object_position` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_object_position(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_object_position_from(
                inherited_struct,
            );
    }

    /// Reset `object_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_object_position(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_object_position(
                reset_struct,
            );
    }

    /// Set the `object_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_object_position(
        &mut self,
        value: longhands::object_position::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_object_position(
                value,
            );
    }
    /// Inherit `scroll_snap_destination` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_snap_destination(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_scroll_snap_destination_from(
                inherited_struct,
            );
    }

    /// Reset `scroll_snap_destination` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scroll_snap_destination(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_scroll_snap_destination(
                reset_struct,
            );
    }

    /// Set the `scroll_snap_destination` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_snap_destination(
        &mut self,
        value: longhands::scroll_snap_destination::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_scroll_snap_destination(
                value,
            );
    }
    /// Inherit `fill` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_fill(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_fill_from(
                inherited_struct,
            );
    }

    /// Reset `fill` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_fill(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_fill(
                reset_struct,
            );
    }

    /// Set the `fill` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_fill(
        &mut self,
        value: longhands::fill::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_fill(
                value,
            );
    }
    /// Inherit `stroke` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_from(
                inherited_struct,
            );
    }

    /// Reset `stroke` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke(
                reset_struct,
            );
    }

    /// Set the `stroke` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke(
        &mut self,
        value: longhands::stroke::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke(
                value,
            );
    }
    /// Inherit `grid_auto_columns` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_auto_columns(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_auto_columns_from(
                inherited_struct,
            );
    }

    /// Reset `grid_auto_columns` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_auto_columns(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_auto_columns(
                reset_struct,
            );
    }

    /// Set the `grid_auto_columns` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_auto_columns(
        &mut self,
        value: longhands::grid_auto_columns::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_auto_columns(
                value,
            );
    }
    /// Inherit `grid_auto_rows` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_auto_rows(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_auto_rows_from(
                inherited_struct,
            );
    }

    /// Reset `grid_auto_rows` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_auto_rows(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_auto_rows(
                reset_struct,
            );
    }

    /// Set the `grid_auto_rows` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_auto_rows(
        &mut self,
        value: longhands::grid_auto_rows::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_auto_rows(
                value,
            );
    }
    /// Inherit `_moz_window_transform_origin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_transform_origin(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy__moz_window_transform_origin_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_window_transform_origin` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_window_transform_origin(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset__moz_window_transform_origin(
                reset_struct,
            );
    }

    /// Set the `_moz_window_transform_origin` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_transform_origin(
        &mut self,
        value: longhands::_moz_window_transform_origin::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set__moz_window_transform_origin(
                value,
            );
    }
    /// Inherit `transform_origin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transform_origin(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transform_origin_from(
                inherited_struct,
            );
    }

    /// Reset `transform_origin` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transform_origin(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transform_origin(
                reset_struct,
            );
    }

    /// Set the `transform_origin` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_transform_origin(
        &mut self,
        value: longhands::transform_origin::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_transform_origin(
                value,
            );
    }
    /// Inherit `max_block_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_max_block_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_max_block_size_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `max_block_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_max_block_size(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_max_block_size(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `max_block_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_max_block_size(
        &mut self,
        value: longhands::max_block_size::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_max_block_size(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `max_height` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_max_height(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_max_height_from(
                inherited_struct,
            );
    }

    /// Reset `max_height` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_max_height(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_max_height(
                reset_struct,
            );
    }

    /// Set the `max_height` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_max_height(
        &mut self,
        value: longhands::max_height::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_max_height(
                value,
            );
    }
    /// Inherit `max_inline_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_max_inline_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_max_inline_size_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `max_inline_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_max_inline_size(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_max_inline_size(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `max_inline_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_max_inline_size(
        &mut self,
        value: longhands::max_inline_size::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_max_inline_size(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `max_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_max_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_max_width_from(
                inherited_struct,
            );
    }

    /// Reset `max_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_max_width(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_max_width(
                reset_struct,
            );
    }

    /// Set the `max_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_max_width(
        &mut self,
        value: longhands::max_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_max_width(
                value,
            );
    }
    /// Inherit `flood_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flood_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_flood_color_from(
                inherited_struct,
            );
    }

    /// Reset `flood_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_flood_color(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_flood_color(
                reset_struct,
            );
    }

    /// Set the `flood_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flood_color(
        &mut self,
        value: longhands::flood_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_flood_color(
                value,
            );
    }
    /// Inherit `lighting_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_lighting_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_lighting_color_from(
                inherited_struct,
            );
    }

    /// Reset `lighting_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_lighting_color(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_lighting_color(
                reset_struct,
            );
    }

    /// Set the `lighting_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_lighting_color(
        &mut self,
        value: longhands::lighting_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_lighting_color(
                value,
            );
    }
    /// Inherit `_moz_font_smoothing_background_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_font_smoothing_background_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_font_smoothing_background_color_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_font_smoothing_background_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_font_smoothing_background_color(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_font_smoothing_background_color(
                reset_struct,
            );
    }

    /// Set the `_moz_font_smoothing_background_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_font_smoothing_background_color(
        &mut self,
        value: longhands::_moz_font_smoothing_background_color::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_font_smoothing_background_color(
                value,
            );
    }
    /// Inherit `stop_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stop_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_stop_color_from(
                inherited_struct,
            );
    }

    /// Reset `stop_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stop_color(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_stop_color(
                reset_struct,
            );
    }

    /// Set the `stop_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stop_color(
        &mut self,
        value: longhands::stop_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_stop_color(
                value,
            );
    }
    /// Inherit `marker_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_marker_end(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_marker_end_from(
                inherited_struct,
            );
    }

    /// Reset `marker_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_marker_end(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_marker_end(
                reset_struct,
            );
    }

    /// Set the `marker_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_marker_end(
        &mut self,
        value: longhands::marker_end::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_marker_end(
                value,
            );
    }
    /// Inherit `marker_mid` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_marker_mid(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_marker_mid_from(
                inherited_struct,
            );
    }

    /// Reset `marker_mid` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_marker_mid(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_marker_mid(
                reset_struct,
            );
    }

    /// Set the `marker_mid` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_marker_mid(
        &mut self,
        value: longhands::marker_mid::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_marker_mid(
                value,
            );
    }
    /// Inherit `marker_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_marker_start(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_marker_start_from(
                inherited_struct,
            );
    }

    /// Reset `marker_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_marker_start(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_marker_start(
                reset_struct,
            );
    }

    /// Set the `marker_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_marker_start(
        &mut self,
        value: longhands::marker_start::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_marker_start(
                value,
            );
    }
    /// Inherit `_moz_binding` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_binding(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy__moz_binding_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_binding` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_binding(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset__moz_binding(
                reset_struct,
            );
    }

    /// Set the `_moz_binding` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_binding(
        &mut self,
        value: longhands::_moz_binding::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set__moz_binding(
                value,
            );
    }
    /// Inherit `grid_column_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_column_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_column_end_from(
                inherited_struct,
            );
    }

    /// Reset `grid_column_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_column_end(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_column_end(
                reset_struct,
            );
    }

    /// Set the `grid_column_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_column_end(
        &mut self,
        value: longhands::grid_column_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_column_end(
                value,
            );
    }
    /// Inherit `grid_column_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_column_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_column_start_from(
                inherited_struct,
            );
    }

    /// Reset `grid_column_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_column_start(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_column_start(
                reset_struct,
            );
    }

    /// Set the `grid_column_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_column_start(
        &mut self,
        value: longhands::grid_column_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_column_start(
                value,
            );
    }
    /// Inherit `grid_row_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_row_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_row_end_from(
                inherited_struct,
            );
    }

    /// Reset `grid_row_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_row_end(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_row_end(
                reset_struct,
            );
    }

    /// Set the `grid_row_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_row_end(
        &mut self,
        value: longhands::grid_row_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_row_end(
                value,
            );
    }
    /// Inherit `grid_row_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_row_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_row_start_from(
                inherited_struct,
            );
    }

    /// Reset `grid_row_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_row_start(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_row_start(
                reset_struct,
            );
    }

    /// Set the `grid_row_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_row_start(
        &mut self,
        value: longhands::grid_row_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_row_start(
                value,
            );
    }
    /// Inherit `border_bottom_left_radius` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_bottom_left_radius(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_bottom_left_radius_from(
                inherited_struct,
            );
    }

    /// Reset `border_bottom_left_radius` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_bottom_left_radius(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_bottom_left_radius(
                reset_struct,
            );
    }

    /// Set the `border_bottom_left_radius` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_bottom_left_radius(
        &mut self,
        value: longhands::border_bottom_left_radius::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_bottom_left_radius(
                value,
            );
    }
    /// Inherit `border_bottom_right_radius` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_bottom_right_radius(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_bottom_right_radius_from(
                inherited_struct,
            );
    }

    /// Reset `border_bottom_right_radius` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_bottom_right_radius(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_bottom_right_radius(
                reset_struct,
            );
    }

    /// Set the `border_bottom_right_radius` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_bottom_right_radius(
        &mut self,
        value: longhands::border_bottom_right_radius::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_bottom_right_radius(
                value,
            );
    }
    /// Inherit `border_top_left_radius` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_top_left_radius(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_top_left_radius_from(
                inherited_struct,
            );
    }

    /// Reset `border_top_left_radius` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_top_left_radius(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_top_left_radius(
                reset_struct,
            );
    }

    /// Set the `border_top_left_radius` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_top_left_radius(
        &mut self,
        value: longhands::border_top_left_radius::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_top_left_radius(
                value,
            );
    }
    /// Inherit `border_top_right_radius` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_top_right_radius(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_top_right_radius_from(
                inherited_struct,
            );
    }

    /// Reset `border_top_right_radius` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_top_right_radius(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_top_right_radius(
                reset_struct,
            );
    }

    /// Set the `border_top_right_radius` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_top_right_radius(
        &mut self,
        value: longhands::border_top_right_radius::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_top_right_radius(
                value,
            );
    }
    /// Inherit `_moz_outline_radius_bottomleft` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_outline_radius_bottomleft(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy__moz_outline_radius_bottomleft_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_outline_radius_bottomleft` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_outline_radius_bottomleft(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset__moz_outline_radius_bottomleft(
                reset_struct,
            );
    }

    /// Set the `_moz_outline_radius_bottomleft` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_outline_radius_bottomleft(
        &mut self,
        value: longhands::_moz_outline_radius_bottomleft::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set__moz_outline_radius_bottomleft(
                value,
            );
    }
    /// Inherit `_moz_outline_radius_bottomright` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_outline_radius_bottomright(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy__moz_outline_radius_bottomright_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_outline_radius_bottomright` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_outline_radius_bottomright(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset__moz_outline_radius_bottomright(
                reset_struct,
            );
    }

    /// Set the `_moz_outline_radius_bottomright` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_outline_radius_bottomright(
        &mut self,
        value: longhands::_moz_outline_radius_bottomright::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set__moz_outline_radius_bottomright(
                value,
            );
    }
    /// Inherit `_moz_outline_radius_topleft` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_outline_radius_topleft(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy__moz_outline_radius_topleft_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_outline_radius_topleft` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_outline_radius_topleft(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset__moz_outline_radius_topleft(
                reset_struct,
            );
    }

    /// Set the `_moz_outline_radius_topleft` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_outline_radius_topleft(
        &mut self,
        value: longhands::_moz_outline_radius_topleft::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set__moz_outline_radius_topleft(
                value,
            );
    }
    /// Inherit `_moz_outline_radius_topright` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_outline_radius_topright(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy__moz_outline_radius_topright_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_outline_radius_topright` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_outline_radius_topright(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset__moz_outline_radius_topright(
                reset_struct,
            );
    }

    /// Set the `_moz_outline_radius_topright` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_outline_radius_topright(
        &mut self,
        value: longhands::_moz_outline_radius_topright::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set__moz_outline_radius_topright(
                value,
            );
    }
    /// Inherit `block_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_block_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_block_size_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `block_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_block_size(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_block_size(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `block_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_block_size(
        &mut self,
        value: longhands::block_size::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_block_size(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `flex_basis` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flex_basis(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_flex_basis_from(
                inherited_struct,
            );
    }

    /// Reset `flex_basis` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_flex_basis(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_flex_basis(
                reset_struct,
            );
    }

    /// Set the `flex_basis` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flex_basis(
        &mut self,
        value: longhands::flex_basis::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_flex_basis(
                value,
            );
    }
    /// Inherit `height` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_height(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_height_from(
                inherited_struct,
            );
    }

    /// Reset `height` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_height(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_height(
                reset_struct,
            );
    }

    /// Set the `height` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_height(
        &mut self,
        value: longhands::height::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_height(
                value,
            );
    }
    /// Inherit `inline_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_inline_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_inline_size_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `inline_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_inline_size(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_inline_size(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `inline_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_inline_size(
        &mut self,
        value: longhands::inline_size::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_inline_size(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `min_block_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_min_block_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_min_block_size_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `min_block_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_min_block_size(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_min_block_size(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `min_block_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_min_block_size(
        &mut self,
        value: longhands::min_block_size::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_min_block_size(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `min_height` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_min_height(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_min_height_from(
                inherited_struct,
            );
    }

    /// Reset `min_height` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_min_height(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_min_height(
                reset_struct,
            );
    }

    /// Set the `min_height` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_min_height(
        &mut self,
        value: longhands::min_height::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_min_height(
                value,
            );
    }
    /// Inherit `min_inline_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_min_inline_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_min_inline_size_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `min_inline_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_min_inline_size(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_min_inline_size(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `min_inline_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_min_inline_size(
        &mut self,
        value: longhands::min_inline_size::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_min_inline_size(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `min_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_min_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_min_width_from(
                inherited_struct,
            );
    }

    /// Reset `min_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_min_width(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_min_width(
                reset_struct,
            );
    }

    /// Set the `min_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_min_width(
        &mut self,
        value: longhands::min_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_min_width(
                value,
            );
    }
    /// Inherit `width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_width_from(
                inherited_struct,
            );
    }

    /// Reset `width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_width(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_width(
                reset_struct,
            );
    }

    /// Set the `width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_width(
        &mut self,
        value: longhands::width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_width(
                value,
            );
    }
    /// Inherit `grid_column_gap` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_column_gap(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_column_gap_from(
                inherited_struct,
            );
    }

    /// Reset `grid_column_gap` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_column_gap(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_column_gap(
                reset_struct,
            );
    }

    /// Set the `grid_column_gap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_column_gap(
        &mut self,
        value: longhands::grid_column_gap::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_column_gap(
                value,
            );
    }
    /// Inherit `grid_row_gap` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_row_gap(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_row_gap_from(
                inherited_struct,
            );
    }

    /// Reset `grid_row_gap` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_row_gap(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_row_gap(
                reset_struct,
            );
    }

    /// Set the `grid_row_gap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_row_gap(
        &mut self,
        value: longhands::grid_row_gap::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_row_gap(
                value,
            );
    }
    /// Inherit `padding_block_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_block_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_block_end_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `padding_block_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_block_end(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_block_end(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `padding_block_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_block_end(
        &mut self,
        value: longhands::padding_block_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_block_end(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `padding_block_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_block_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_block_start_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `padding_block_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_block_start(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_block_start(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `padding_block_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_block_start(
        &mut self,
        value: longhands::padding_block_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_block_start(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `padding_bottom` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_bottom(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_bottom_from(
                inherited_struct,
            );
    }

    /// Reset `padding_bottom` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_bottom(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_bottom(
                reset_struct,
            );
    }

    /// Set the `padding_bottom` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_bottom(
        &mut self,
        value: longhands::padding_bottom::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_bottom(
                value,
            );
    }
    /// Inherit `padding_inline_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_inline_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_inline_end_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `padding_inline_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_inline_end(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_inline_end(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `padding_inline_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_inline_end(
        &mut self,
        value: longhands::padding_inline_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_inline_end(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `padding_inline_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_inline_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_inline_start_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `padding_inline_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_inline_start(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_inline_start(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `padding_inline_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_inline_start(
        &mut self,
        value: longhands::padding_inline_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_inline_start(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `padding_left` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_left(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_left_from(
                inherited_struct,
            );
    }

    /// Reset `padding_left` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_left(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_left(
                reset_struct,
            );
    }

    /// Set the `padding_left` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_left(
        &mut self,
        value: longhands::padding_left::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_left(
                value,
            );
    }
    /// Inherit `padding_right` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_right(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_right_from(
                inherited_struct,
            );
    }

    /// Reset `padding_right` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_right(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_right(
                reset_struct,
            );
    }

    /// Set the `padding_right` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_right(
        &mut self,
        value: longhands::padding_right::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_right(
                value,
            );
    }
    /// Inherit `padding_top` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_top(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_top_from(
                inherited_struct,
            );
    }

    /// Reset `padding_top` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_top(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_top(
                reset_struct,
            );
    }

    /// Set the `padding_top` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_top(
        &mut self,
        value: longhands::padding_top::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_top(
                value,
            );
    }
    /// Inherit `border_block_end_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_block_end_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_block_end_width_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_block_end_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_block_end_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_block_end_width(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_block_end_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_block_end_width(
        &mut self,
        value: longhands::border_block_end_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_block_end_width(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_block_start_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_block_start_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_block_start_width_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_block_start_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_block_start_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_block_start_width(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_block_start_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_block_start_width(
        &mut self,
        value: longhands::border_block_start_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_block_start_width(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_bottom_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_bottom_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_bottom_width_from(
                inherited_struct,
            );
    }

    /// Reset `border_bottom_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_bottom_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_bottom_width(
                reset_struct,
            );
    }

    /// Set the `border_bottom_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_bottom_width(
        &mut self,
        value: longhands::border_bottom_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_bottom_width(
                value,
            );
    }
    /// Inherit `border_inline_end_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_inline_end_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_inline_end_width_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_inline_end_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_inline_end_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_inline_end_width(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_inline_end_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_inline_end_width(
        &mut self,
        value: longhands::border_inline_end_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_inline_end_width(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_inline_start_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_inline_start_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_inline_start_width_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_inline_start_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_inline_start_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_inline_start_width(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_inline_start_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_inline_start_width(
        &mut self,
        value: longhands::border_inline_start_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_inline_start_width(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_left_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_left_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_left_width_from(
                inherited_struct,
            );
    }

    /// Reset `border_left_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_left_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_left_width(
                reset_struct,
            );
    }

    /// Set the `border_left_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_left_width(
        &mut self,
        value: longhands::border_left_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_left_width(
                value,
            );
    }
    /// Inherit `border_right_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_right_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_right_width_from(
                inherited_struct,
            );
    }

    /// Reset `border_right_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_right_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_right_width(
                reset_struct,
            );
    }

    /// Set the `border_right_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_right_width(
        &mut self,
        value: longhands::border_right_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_right_width(
                value,
            );
    }
    /// Inherit `border_top_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_top_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_top_width_from(
                inherited_struct,
            );
    }

    /// Reset `border_top_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_top_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_top_width(
                reset_struct,
            );
    }

    /// Set the `border_top_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_top_width(
        &mut self,
        value: longhands::border_top_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_top_width(
                value,
            );
    }
    /// Inherit `column_rule_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_rule_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_rule_width_from(
                inherited_struct,
            );
    }

    /// Reset `column_rule_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_rule_width(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_rule_width(
                reset_struct,
            );
    }

    /// Set the `column_rule_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_rule_width(
        &mut self,
        value: longhands::column_rule_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_rule_width(
                value,
            );
    }
    /// Inherit `outline_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_outline_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy_outline_width_from(
                inherited_struct,
            );
    }

    /// Reset `outline_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_outline_width(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset_outline_width(
                reset_struct,
            );
    }

    /// Set the `outline_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_outline_width(
        &mut self,
        value: longhands::outline_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set_outline_width(
                value,
            );
    }
    /// Inherit `_webkit_text_stroke_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__webkit_text_stroke_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy__webkit_text_stroke_width_from(
                inherited_struct,
            );
    }

    /// Reset `_webkit_text_stroke_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__webkit_text_stroke_width(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset__webkit_text_stroke_width(
                reset_struct,
            );
    }

    /// Set the `_webkit_text_stroke_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__webkit_text_stroke_width(
        &mut self,
        value: longhands::_webkit_text_stroke_width::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set__webkit_text_stroke_width(
                value,
            );
    }
    /// Inherit `background_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_color_from(
                inherited_struct,
            );
    }

    /// Reset `background_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_color(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_color(
                reset_struct,
            );
    }

    /// Set the `background_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_background_color(
        &mut self,
        value: longhands::background_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.background.mutate()
            .set_background_color(
                value,
            );
    }
    /// Inherit `border_block_end_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_block_end_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_block_end_color_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_block_end_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_block_end_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_block_end_color(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_block_end_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_block_end_color(
        &mut self,
        value: longhands::border_block_end_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_block_end_color(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_block_start_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_block_start_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_block_start_color_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_block_start_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_block_start_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_block_start_color(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_block_start_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_block_start_color(
        &mut self,
        value: longhands::border_block_start_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_block_start_color(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_bottom_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_bottom_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_bottom_color_from(
                inherited_struct,
            );
    }

    /// Reset `border_bottom_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_bottom_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_bottom_color(
                reset_struct,
            );
    }

    /// Set the `border_bottom_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_bottom_color(
        &mut self,
        value: longhands::border_bottom_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_bottom_color(
                value,
            );
    }
    /// Inherit `border_inline_end_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_inline_end_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_inline_end_color_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_inline_end_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_inline_end_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_inline_end_color(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_inline_end_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_inline_end_color(
        &mut self,
        value: longhands::border_inline_end_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_inline_end_color(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_inline_start_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_inline_start_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_inline_start_color_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_inline_start_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_inline_start_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_inline_start_color(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_inline_start_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_inline_start_color(
        &mut self,
        value: longhands::border_inline_start_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_inline_start_color(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_left_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_left_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_left_color_from(
                inherited_struct,
            );
    }

    /// Reset `border_left_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_left_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_left_color(
                reset_struct,
            );
    }

    /// Set the `border_left_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_left_color(
        &mut self,
        value: longhands::border_left_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_left_color(
                value,
            );
    }
    /// Inherit `border_right_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_right_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_right_color_from(
                inherited_struct,
            );
    }

    /// Reset `border_right_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_right_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_right_color(
                reset_struct,
            );
    }

    /// Set the `border_right_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_right_color(
        &mut self,
        value: longhands::border_right_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_right_color(
                value,
            );
    }
    /// Inherit `border_top_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_top_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_top_color_from(
                inherited_struct,
            );
    }

    /// Reset `border_top_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_top_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_top_color(
                reset_struct,
            );
    }

    /// Set the `border_top_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_top_color(
        &mut self,
        value: longhands::border_top_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_top_color(
                value,
            );
    }
    /// Inherit `column_rule_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_rule_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_rule_color_from(
                inherited_struct,
            );
    }

    /// Reset `column_rule_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_rule_color(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_rule_color(
                reset_struct,
            );
    }

    /// Set the `column_rule_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_rule_color(
        &mut self,
        value: longhands::column_rule_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_rule_color(
                value,
            );
    }
    /// Inherit `outline_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_outline_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy_outline_color_from(
                inherited_struct,
            );
    }

    /// Reset `outline_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_outline_color(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset_outline_color(
                reset_struct,
            );
    }

    /// Set the `outline_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_outline_color(
        &mut self,
        value: longhands::outline_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set_outline_color(
                value,
            );
    }
    /// Inherit `text_decoration_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_decoration_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_text();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.text.mutate()
            .copy_text_decoration_color_from(
                inherited_struct,
            );
    }

    /// Reset `text_decoration_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_decoration_color(&mut self) {
        let reset_struct =
            self.reset_style.get_text();

        self.modified_reset = true;

        self.text.mutate()
            .reset_text_decoration_color(
                reset_struct,
            );
    }

    /// Set the `text_decoration_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_decoration_color(
        &mut self,
        value: longhands::text_decoration_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.text.mutate()
            .set_text_decoration_color(
                value,
            );
    }
    /// Inherit `text_emphasis_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_emphasis_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_emphasis_color_from(
                inherited_struct,
            );
    }

    /// Reset `text_emphasis_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_emphasis_color(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_emphasis_color(
                reset_struct,
            );
    }

    /// Set the `text_emphasis_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_emphasis_color(
        &mut self,
        value: longhands::text_emphasis_color::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_emphasis_color(
                value,
            );
    }
    /// Inherit `_webkit_text_fill_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__webkit_text_fill_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy__webkit_text_fill_color_from(
                inherited_struct,
            );
    }

    /// Reset `_webkit_text_fill_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__webkit_text_fill_color(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset__webkit_text_fill_color(
                reset_struct,
            );
    }

    /// Set the `_webkit_text_fill_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__webkit_text_fill_color(
        &mut self,
        value: longhands::_webkit_text_fill_color::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set__webkit_text_fill_color(
                value,
            );
    }
    /// Inherit `_webkit_text_stroke_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__webkit_text_stroke_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy__webkit_text_stroke_color_from(
                inherited_struct,
            );
    }

    /// Reset `_webkit_text_stroke_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__webkit_text_stroke_color(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset__webkit_text_stroke_color(
                reset_struct,
            );
    }

    /// Set the `_webkit_text_stroke_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__webkit_text_stroke_color(
        &mut self,
        value: longhands::_webkit_text_stroke_color::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set__webkit_text_stroke_color(
                value,
            );
    }
    /// Inherit `bottom` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_bottom(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_bottom_from(
                inherited_struct,
            );
    }

    /// Reset `bottom` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_bottom(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_bottom(
                reset_struct,
            );
    }

    /// Set the `bottom` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_bottom(
        &mut self,
        value: longhands::bottom::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_bottom(
                value,
            );
    }
    /// Inherit `left` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_left(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_left_from(
                inherited_struct,
            );
    }

    /// Reset `left` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_left(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_left(
                reset_struct,
            );
    }

    /// Set the `left` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_left(
        &mut self,
        value: longhands::left::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_left(
                value,
            );
    }
    /// Inherit `margin_block_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_block_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_block_end_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `margin_block_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_block_end(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_block_end(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `margin_block_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_block_end(
        &mut self,
        value: longhands::margin_block_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_block_end(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `margin_block_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_block_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_block_start_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `margin_block_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_block_start(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_block_start(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `margin_block_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_block_start(
        &mut self,
        value: longhands::margin_block_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_block_start(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `margin_bottom` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_bottom(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_bottom_from(
                inherited_struct,
            );
    }

    /// Reset `margin_bottom` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_bottom(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_bottom(
                reset_struct,
            );
    }

    /// Set the `margin_bottom` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_bottom(
        &mut self,
        value: longhands::margin_bottom::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_bottom(
                value,
            );
    }
    /// Inherit `margin_inline_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_inline_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_inline_end_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `margin_inline_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_inline_end(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_inline_end(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `margin_inline_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_inline_end(
        &mut self,
        value: longhands::margin_inline_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_inline_end(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `margin_inline_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_inline_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_inline_start_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `margin_inline_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_inline_start(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_inline_start(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `margin_inline_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_inline_start(
        &mut self,
        value: longhands::margin_inline_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_inline_start(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `margin_left` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_left(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_left_from(
                inherited_struct,
            );
    }

    /// Reset `margin_left` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_left(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_left(
                reset_struct,
            );
    }

    /// Set the `margin_left` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_left(
        &mut self,
        value: longhands::margin_left::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_left(
                value,
            );
    }
    /// Inherit `margin_right` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_right(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_right_from(
                inherited_struct,
            );
    }

    /// Reset `margin_right` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_right(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_right(
                reset_struct,
            );
    }

    /// Set the `margin_right` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_right(
        &mut self,
        value: longhands::margin_right::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_right(
                value,
            );
    }
    /// Inherit `margin_top` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_top(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_top_from(
                inherited_struct,
            );
    }

    /// Reset `margin_top` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_top(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_top(
                reset_struct,
            );
    }

    /// Set the `margin_top` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_top(
        &mut self,
        value: longhands::margin_top::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_top(
                value,
            );
    }
    /// Inherit `offset_block_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_offset_block_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_offset_block_end_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `offset_block_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_offset_block_end(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_offset_block_end(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `offset_block_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_offset_block_end(
        &mut self,
        value: longhands::offset_block_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_offset_block_end(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `offset_block_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_offset_block_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_offset_block_start_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `offset_block_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_offset_block_start(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_offset_block_start(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `offset_block_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_offset_block_start(
        &mut self,
        value: longhands::offset_block_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_offset_block_start(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `offset_inline_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_offset_inline_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_offset_inline_end_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `offset_inline_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_offset_inline_end(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_offset_inline_end(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `offset_inline_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_offset_inline_end(
        &mut self,
        value: longhands::offset_inline_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_offset_inline_end(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `offset_inline_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_offset_inline_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_offset_inline_start_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `offset_inline_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_offset_inline_start(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_offset_inline_start(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `offset_inline_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_offset_inline_start(
        &mut self,
        value: longhands::offset_inline_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_offset_inline_start(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `right` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_right(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_right_from(
                inherited_struct,
            );
    }

    /// Reset `right` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_right(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_right(
                reset_struct,
            );
    }

    /// Set the `right` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_right(
        &mut self,
        value: longhands::right::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_right(
                value,
            );
    }
    /// Inherit `top` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_top(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_top_from(
                inherited_struct,
            );
    }

    /// Reset `top` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_top(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_top(
                reset_struct,
            );
    }

    /// Set the `top` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_top(
        &mut self,
        value: longhands::top::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_top(
                value,
            );
    }

    /// Inherits style from the parent element, accounting for the default
    /// computed values that need to be provided as well.
    pub fn for_inheritance(
        device: &'a Device,
        parent: Option<&'a ComputedValues>,
        pseudo: Option<&'a PseudoElement>,
    ) -> Self {
        // Rebuild the visited style from the parent, ensuring that it will also
        // not have rules.  This matches the unvisited style that will be
        // produced by this builder.  This assumes that the caller doesn't need
        // to adjust or process visited style, so we can just build visited
        // style here for simplicity.
        let visited_style = parent.and_then(|parent| {
            parent.visited_style().map(|style| {
                Self::for_inheritance(
                    device,
                    Some(style),
                    pseudo,
                ).build()
            })
        });
        Self::new(
            device,
            parent,
            parent,
            pseudo,
            CascadeFlags::empty(),
            /* rules = */ None,
            parent.and_then(|p| p.custom_properties().cloned()),
            visited_style,
        )
    }

    /// Returns whether we have a visited style.
    pub fn has_visited_style(&self) -> bool {
        self.visited_style.is_some()
    }

    /// Returns whether we're a pseudo-elements style.
    pub fn is_pseudo_element(&self) -> bool {
        self.pseudo.map_or(false, |p| !p.is_anon_box())
    }

    /// Returns the style we're getting reset properties from.
    pub fn default_style(&self) -> &'a ComputedValues {
        self.reset_style
    }

        /// Gets an immutable view of the current `Background` style.
        pub fn get_background(&self) -> &style_structs::Background {
            &self.background
        }

        /// Gets a mutable view of the current `Background` style.
        pub fn mutate_background(&mut self) -> &mut style_structs::Background {
            self.modified_reset = true;
            self.background.mutate()
        }

        /// Gets a mutable view of the current `Background` style.
        pub fn take_background(&mut self) -> UniqueArc<style_structs::Background> {
            self.modified_reset = true;
            self.background.take()
        }

        /// Gets a mutable view of the current `Background` style.
        pub fn put_background(&mut self, s: UniqueArc<style_structs::Background>) {
            self.background.put(s)
        }

        /// Gets a mutable view of the current `Background` style,
        /// only if it's been mutated before.
        pub fn get_background_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Background> {
            self.background.get_if_mutated()
        }

        /// Reset the current `Background` style to its default value.
        pub fn reset_background_struct(&mut self) {
            self.background =
                StyleStructRef::Borrowed(self.reset_style.background_arc());
        }
        /// Gets an immutable view of the current `Border` style.
        pub fn get_border(&self) -> &style_structs::Border {
            &self.border
        }

        /// Gets a mutable view of the current `Border` style.
        pub fn mutate_border(&mut self) -> &mut style_structs::Border {
            self.modified_reset = true;
            self.border.mutate()
        }

        /// Gets a mutable view of the current `Border` style.
        pub fn take_border(&mut self) -> UniqueArc<style_structs::Border> {
            self.modified_reset = true;
            self.border.take()
        }

        /// Gets a mutable view of the current `Border` style.
        pub fn put_border(&mut self, s: UniqueArc<style_structs::Border>) {
            self.border.put(s)
        }

        /// Gets a mutable view of the current `Border` style,
        /// only if it's been mutated before.
        pub fn get_border_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Border> {
            self.border.get_if_mutated()
        }

        /// Reset the current `Border` style to its default value.
        pub fn reset_border_struct(&mut self) {
            self.border =
                StyleStructRef::Borrowed(self.reset_style.border_arc());
        }
        /// Gets an immutable view of the current `Box` style.
        pub fn get_box(&self) -> &style_structs::Box {
            &self.box_
        }

        /// Gets a mutable view of the current `Box` style.
        pub fn mutate_box(&mut self) -> &mut style_structs::Box {
            self.modified_reset = true;
            self.box_.mutate()
        }

        /// Gets a mutable view of the current `Box` style.
        pub fn take_box(&mut self) -> UniqueArc<style_structs::Box> {
            self.modified_reset = true;
            self.box_.take()
        }

        /// Gets a mutable view of the current `Box` style.
        pub fn put_box(&mut self, s: UniqueArc<style_structs::Box>) {
            self.box_.put(s)
        }

        /// Gets a mutable view of the current `Box` style,
        /// only if it's been mutated before.
        pub fn get_box_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Box> {
            self.box_.get_if_mutated()
        }

        /// Reset the current `Box` style to its default value.
        pub fn reset_box_struct(&mut self) {
            self.box_ =
                StyleStructRef::Borrowed(self.reset_style.box_arc());
        }
        /// Gets an immutable view of the current `Color` style.
        pub fn get_color(&self) -> &style_structs::Color {
            &self.color
        }

        /// Gets a mutable view of the current `Color` style.
        pub fn mutate_color(&mut self) -> &mut style_structs::Color {
            self.modified_reset = true;
            self.color.mutate()
        }

        /// Gets a mutable view of the current `Color` style.
        pub fn take_color(&mut self) -> UniqueArc<style_structs::Color> {
            self.modified_reset = true;
            self.color.take()
        }

        /// Gets a mutable view of the current `Color` style.
        pub fn put_color(&mut self, s: UniqueArc<style_structs::Color>) {
            self.color.put(s)
        }

        /// Gets a mutable view of the current `Color` style,
        /// only if it's been mutated before.
        pub fn get_color_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Color> {
            self.color.get_if_mutated()
        }

        /// Reset the current `Color` style to its default value.
        pub fn reset_color_struct(&mut self) {
            self.color =
                StyleStructRef::Borrowed(self.reset_style.color_arc());
        }
        /// Gets an immutable view of the current `Column` style.
        pub fn get_column(&self) -> &style_structs::Column {
            &self.column
        }

        /// Gets a mutable view of the current `Column` style.
        pub fn mutate_column(&mut self) -> &mut style_structs::Column {
            self.modified_reset = true;
            self.column.mutate()
        }

        /// Gets a mutable view of the current `Column` style.
        pub fn take_column(&mut self) -> UniqueArc<style_structs::Column> {
            self.modified_reset = true;
            self.column.take()
        }

        /// Gets a mutable view of the current `Column` style.
        pub fn put_column(&mut self, s: UniqueArc<style_structs::Column>) {
            self.column.put(s)
        }

        /// Gets a mutable view of the current `Column` style,
        /// only if it's been mutated before.
        pub fn get_column_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Column> {
            self.column.get_if_mutated()
        }

        /// Reset the current `Column` style to its default value.
        pub fn reset_column_struct(&mut self) {
            self.column =
                StyleStructRef::Borrowed(self.reset_style.column_arc());
        }
        /// Gets an immutable view of the current `Counters` style.
        pub fn get_counters(&self) -> &style_structs::Counters {
            &self.counters
        }

        /// Gets a mutable view of the current `Counters` style.
        pub fn mutate_counters(&mut self) -> &mut style_structs::Counters {
            self.modified_reset = true;
            self.counters.mutate()
        }

        /// Gets a mutable view of the current `Counters` style.
        pub fn take_counters(&mut self) -> UniqueArc<style_structs::Counters> {
            self.modified_reset = true;
            self.counters.take()
        }

        /// Gets a mutable view of the current `Counters` style.
        pub fn put_counters(&mut self, s: UniqueArc<style_structs::Counters>) {
            self.counters.put(s)
        }

        /// Gets a mutable view of the current `Counters` style,
        /// only if it's been mutated before.
        pub fn get_counters_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Counters> {
            self.counters.get_if_mutated()
        }

        /// Reset the current `Counters` style to its default value.
        pub fn reset_counters_struct(&mut self) {
            self.counters =
                StyleStructRef::Borrowed(self.reset_style.counters_arc());
        }
        /// Gets an immutable view of the current `Effects` style.
        pub fn get_effects(&self) -> &style_structs::Effects {
            &self.effects
        }

        /// Gets a mutable view of the current `Effects` style.
        pub fn mutate_effects(&mut self) -> &mut style_structs::Effects {
            self.modified_reset = true;
            self.effects.mutate()
        }

        /// Gets a mutable view of the current `Effects` style.
        pub fn take_effects(&mut self) -> UniqueArc<style_structs::Effects> {
            self.modified_reset = true;
            self.effects.take()
        }

        /// Gets a mutable view of the current `Effects` style.
        pub fn put_effects(&mut self, s: UniqueArc<style_structs::Effects>) {
            self.effects.put(s)
        }

        /// Gets a mutable view of the current `Effects` style,
        /// only if it's been mutated before.
        pub fn get_effects_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Effects> {
            self.effects.get_if_mutated()
        }

        /// Reset the current `Effects` style to its default value.
        pub fn reset_effects_struct(&mut self) {
            self.effects =
                StyleStructRef::Borrowed(self.reset_style.effects_arc());
        }
        /// Gets an immutable view of the current `Font` style.
        pub fn get_font(&self) -> &style_structs::Font {
            &self.font
        }

        /// Gets a mutable view of the current `Font` style.
        pub fn mutate_font(&mut self) -> &mut style_structs::Font {
            self.modified_reset = true;
            self.font.mutate()
        }

        /// Gets a mutable view of the current `Font` style.
        pub fn take_font(&mut self) -> UniqueArc<style_structs::Font> {
            self.modified_reset = true;
            self.font.take()
        }

        /// Gets a mutable view of the current `Font` style.
        pub fn put_font(&mut self, s: UniqueArc<style_structs::Font>) {
            self.font.put(s)
        }

        /// Gets a mutable view of the current `Font` style,
        /// only if it's been mutated before.
        pub fn get_font_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Font> {
            self.font.get_if_mutated()
        }

        /// Reset the current `Font` style to its default value.
        pub fn reset_font_struct(&mut self) {
            self.font =
                StyleStructRef::Borrowed(self.reset_style.font_arc());
        }
        /// Gets an immutable view of the current `InheritedBox` style.
        pub fn get_inheritedbox(&self) -> &style_structs::InheritedBox {
            &self.inheritedbox
        }

        /// Gets a mutable view of the current `InheritedBox` style.
        pub fn mutate_inheritedbox(&mut self) -> &mut style_structs::InheritedBox {
            self.modified_reset = true;
            self.inheritedbox.mutate()
        }

        /// Gets a mutable view of the current `InheritedBox` style.
        pub fn take_inheritedbox(&mut self) -> UniqueArc<style_structs::InheritedBox> {
            self.modified_reset = true;
            self.inheritedbox.take()
        }

        /// Gets a mutable view of the current `InheritedBox` style.
        pub fn put_inheritedbox(&mut self, s: UniqueArc<style_structs::InheritedBox>) {
            self.inheritedbox.put(s)
        }

        /// Gets a mutable view of the current `InheritedBox` style,
        /// only if it's been mutated before.
        pub fn get_inheritedbox_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::InheritedBox> {
            self.inheritedbox.get_if_mutated()
        }

        /// Reset the current `InheritedBox` style to its default value.
        pub fn reset_inheritedbox_struct(&mut self) {
            self.inheritedbox =
                StyleStructRef::Borrowed(self.reset_style.inheritedbox_arc());
        }
        /// Gets an immutable view of the current `InheritedTable` style.
        pub fn get_inheritedtable(&self) -> &style_structs::InheritedTable {
            &self.inheritedtable
        }

        /// Gets a mutable view of the current `InheritedTable` style.
        pub fn mutate_inheritedtable(&mut self) -> &mut style_structs::InheritedTable {
            self.modified_reset = true;
            self.inheritedtable.mutate()
        }

        /// Gets a mutable view of the current `InheritedTable` style.
        pub fn take_inheritedtable(&mut self) -> UniqueArc<style_structs::InheritedTable> {
            self.modified_reset = true;
            self.inheritedtable.take()
        }

        /// Gets a mutable view of the current `InheritedTable` style.
        pub fn put_inheritedtable(&mut self, s: UniqueArc<style_structs::InheritedTable>) {
            self.inheritedtable.put(s)
        }

        /// Gets a mutable view of the current `InheritedTable` style,
        /// only if it's been mutated before.
        pub fn get_inheritedtable_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::InheritedTable> {
            self.inheritedtable.get_if_mutated()
        }

        /// Reset the current `InheritedTable` style to its default value.
        pub fn reset_inheritedtable_struct(&mut self) {
            self.inheritedtable =
                StyleStructRef::Borrowed(self.reset_style.inheritedtable_arc());
        }
        /// Gets an immutable view of the current `InheritedText` style.
        pub fn get_inheritedtext(&self) -> &style_structs::InheritedText {
            &self.inheritedtext
        }

        /// Gets a mutable view of the current `InheritedText` style.
        pub fn mutate_inheritedtext(&mut self) -> &mut style_structs::InheritedText {
            self.modified_reset = true;
            self.inheritedtext.mutate()
        }

        /// Gets a mutable view of the current `InheritedText` style.
        pub fn take_inheritedtext(&mut self) -> UniqueArc<style_structs::InheritedText> {
            self.modified_reset = true;
            self.inheritedtext.take()
        }

        /// Gets a mutable view of the current `InheritedText` style.
        pub fn put_inheritedtext(&mut self, s: UniqueArc<style_structs::InheritedText>) {
            self.inheritedtext.put(s)
        }

        /// Gets a mutable view of the current `InheritedText` style,
        /// only if it's been mutated before.
        pub fn get_inheritedtext_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::InheritedText> {
            self.inheritedtext.get_if_mutated()
        }

        /// Reset the current `InheritedText` style to its default value.
        pub fn reset_inheritedtext_struct(&mut self) {
            self.inheritedtext =
                StyleStructRef::Borrowed(self.reset_style.inheritedtext_arc());
        }
        /// Gets an immutable view of the current `List` style.
        pub fn get_list(&self) -> &style_structs::List {
            &self.list
        }

        /// Gets a mutable view of the current `List` style.
        pub fn mutate_list(&mut self) -> &mut style_structs::List {
            self.modified_reset = true;
            self.list.mutate()
        }

        /// Gets a mutable view of the current `List` style.
        pub fn take_list(&mut self) -> UniqueArc<style_structs::List> {
            self.modified_reset = true;
            self.list.take()
        }

        /// Gets a mutable view of the current `List` style.
        pub fn put_list(&mut self, s: UniqueArc<style_structs::List>) {
            self.list.put(s)
        }

        /// Gets a mutable view of the current `List` style,
        /// only if it's been mutated before.
        pub fn get_list_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::List> {
            self.list.get_if_mutated()
        }

        /// Reset the current `List` style to its default value.
        pub fn reset_list_struct(&mut self) {
            self.list =
                StyleStructRef::Borrowed(self.reset_style.list_arc());
        }
        /// Gets an immutable view of the current `Margin` style.
        pub fn get_margin(&self) -> &style_structs::Margin {
            &self.margin
        }

        /// Gets a mutable view of the current `Margin` style.
        pub fn mutate_margin(&mut self) -> &mut style_structs::Margin {
            self.modified_reset = true;
            self.margin.mutate()
        }

        /// Gets a mutable view of the current `Margin` style.
        pub fn take_margin(&mut self) -> UniqueArc<style_structs::Margin> {
            self.modified_reset = true;
            self.margin.take()
        }

        /// Gets a mutable view of the current `Margin` style.
        pub fn put_margin(&mut self, s: UniqueArc<style_structs::Margin>) {
            self.margin.put(s)
        }

        /// Gets a mutable view of the current `Margin` style,
        /// only if it's been mutated before.
        pub fn get_margin_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Margin> {
            self.margin.get_if_mutated()
        }

        /// Reset the current `Margin` style to its default value.
        pub fn reset_margin_struct(&mut self) {
            self.margin =
                StyleStructRef::Borrowed(self.reset_style.margin_arc());
        }
        /// Gets an immutable view of the current `Outline` style.
        pub fn get_outline(&self) -> &style_structs::Outline {
            &self.outline
        }

        /// Gets a mutable view of the current `Outline` style.
        pub fn mutate_outline(&mut self) -> &mut style_structs::Outline {
            self.modified_reset = true;
            self.outline.mutate()
        }

        /// Gets a mutable view of the current `Outline` style.
        pub fn take_outline(&mut self) -> UniqueArc<style_structs::Outline> {
            self.modified_reset = true;
            self.outline.take()
        }

        /// Gets a mutable view of the current `Outline` style.
        pub fn put_outline(&mut self, s: UniqueArc<style_structs::Outline>) {
            self.outline.put(s)
        }

        /// Gets a mutable view of the current `Outline` style,
        /// only if it's been mutated before.
        pub fn get_outline_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Outline> {
            self.outline.get_if_mutated()
        }

        /// Reset the current `Outline` style to its default value.
        pub fn reset_outline_struct(&mut self) {
            self.outline =
                StyleStructRef::Borrowed(self.reset_style.outline_arc());
        }
        /// Gets an immutable view of the current `Padding` style.
        pub fn get_padding(&self) -> &style_structs::Padding {
            &self.padding
        }

        /// Gets a mutable view of the current `Padding` style.
        pub fn mutate_padding(&mut self) -> &mut style_structs::Padding {
            self.modified_reset = true;
            self.padding.mutate()
        }

        /// Gets a mutable view of the current `Padding` style.
        pub fn take_padding(&mut self) -> UniqueArc<style_structs::Padding> {
            self.modified_reset = true;
            self.padding.take()
        }

        /// Gets a mutable view of the current `Padding` style.
        pub fn put_padding(&mut self, s: UniqueArc<style_structs::Padding>) {
            self.padding.put(s)
        }

        /// Gets a mutable view of the current `Padding` style,
        /// only if it's been mutated before.
        pub fn get_padding_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Padding> {
            self.padding.get_if_mutated()
        }

        /// Reset the current `Padding` style to its default value.
        pub fn reset_padding_struct(&mut self) {
            self.padding =
                StyleStructRef::Borrowed(self.reset_style.padding_arc());
        }
        /// Gets an immutable view of the current `Pointing` style.
        pub fn get_pointing(&self) -> &style_structs::Pointing {
            &self.pointing
        }

        /// Gets a mutable view of the current `Pointing` style.
        pub fn mutate_pointing(&mut self) -> &mut style_structs::Pointing {
            self.modified_reset = true;
            self.pointing.mutate()
        }

        /// Gets a mutable view of the current `Pointing` style.
        pub fn take_pointing(&mut self) -> UniqueArc<style_structs::Pointing> {
            self.modified_reset = true;
            self.pointing.take()
        }

        /// Gets a mutable view of the current `Pointing` style.
        pub fn put_pointing(&mut self, s: UniqueArc<style_structs::Pointing>) {
            self.pointing.put(s)
        }

        /// Gets a mutable view of the current `Pointing` style,
        /// only if it's been mutated before.
        pub fn get_pointing_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Pointing> {
            self.pointing.get_if_mutated()
        }

        /// Reset the current `Pointing` style to its default value.
        pub fn reset_pointing_struct(&mut self) {
            self.pointing =
                StyleStructRef::Borrowed(self.reset_style.pointing_arc());
        }
        /// Gets an immutable view of the current `Position` style.
        pub fn get_position(&self) -> &style_structs::Position {
            &self.position
        }

        /// Gets a mutable view of the current `Position` style.
        pub fn mutate_position(&mut self) -> &mut style_structs::Position {
            self.modified_reset = true;
            self.position.mutate()
        }

        /// Gets a mutable view of the current `Position` style.
        pub fn take_position(&mut self) -> UniqueArc<style_structs::Position> {
            self.modified_reset = true;
            self.position.take()
        }

        /// Gets a mutable view of the current `Position` style.
        pub fn put_position(&mut self, s: UniqueArc<style_structs::Position>) {
            self.position.put(s)
        }

        /// Gets a mutable view of the current `Position` style,
        /// only if it's been mutated before.
        pub fn get_position_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Position> {
            self.position.get_if_mutated()
        }

        /// Reset the current `Position` style to its default value.
        pub fn reset_position_struct(&mut self) {
            self.position =
                StyleStructRef::Borrowed(self.reset_style.position_arc());
        }
        /// Gets an immutable view of the current `Table` style.
        pub fn get_table(&self) -> &style_structs::Table {
            &self.table
        }

        /// Gets a mutable view of the current `Table` style.
        pub fn mutate_table(&mut self) -> &mut style_structs::Table {
            self.modified_reset = true;
            self.table.mutate()
        }

        /// Gets a mutable view of the current `Table` style.
        pub fn take_table(&mut self) -> UniqueArc<style_structs::Table> {
            self.modified_reset = true;
            self.table.take()
        }

        /// Gets a mutable view of the current `Table` style.
        pub fn put_table(&mut self, s: UniqueArc<style_structs::Table>) {
            self.table.put(s)
        }

        /// Gets a mutable view of the current `Table` style,
        /// only if it's been mutated before.
        pub fn get_table_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Table> {
            self.table.get_if_mutated()
        }

        /// Reset the current `Table` style to its default value.
        pub fn reset_table_struct(&mut self) {
            self.table =
                StyleStructRef::Borrowed(self.reset_style.table_arc());
        }
        /// Gets an immutable view of the current `Text` style.
        pub fn get_text(&self) -> &style_structs::Text {
            &self.text
        }

        /// Gets a mutable view of the current `Text` style.
        pub fn mutate_text(&mut self) -> &mut style_structs::Text {
            self.modified_reset = true;
            self.text.mutate()
        }

        /// Gets a mutable view of the current `Text` style.
        pub fn take_text(&mut self) -> UniqueArc<style_structs::Text> {
            self.modified_reset = true;
            self.text.take()
        }

        /// Gets a mutable view of the current `Text` style.
        pub fn put_text(&mut self, s: UniqueArc<style_structs::Text>) {
            self.text.put(s)
        }

        /// Gets a mutable view of the current `Text` style,
        /// only if it's been mutated before.
        pub fn get_text_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Text> {
            self.text.get_if_mutated()
        }

        /// Reset the current `Text` style to its default value.
        pub fn reset_text_struct(&mut self) {
            self.text =
                StyleStructRef::Borrowed(self.reset_style.text_arc());
        }
        /// Gets an immutable view of the current `UI` style.
        pub fn get_ui(&self) -> &style_structs::UI {
            &self.ui
        }

        /// Gets a mutable view of the current `UI` style.
        pub fn mutate_ui(&mut self) -> &mut style_structs::UI {
            self.modified_reset = true;
            self.ui.mutate()
        }

        /// Gets a mutable view of the current `UI` style.
        pub fn take_ui(&mut self) -> UniqueArc<style_structs::UI> {
            self.modified_reset = true;
            self.ui.take()
        }

        /// Gets a mutable view of the current `UI` style.
        pub fn put_ui(&mut self, s: UniqueArc<style_structs::UI>) {
            self.ui.put(s)
        }

        /// Gets a mutable view of the current `UI` style,
        /// only if it's been mutated before.
        pub fn get_ui_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::UI> {
            self.ui.get_if_mutated()
        }

        /// Reset the current `UI` style to its default value.
        pub fn reset_ui_struct(&mut self) {
            self.ui =
                StyleStructRef::Borrowed(self.reset_style.ui_arc());
        }
        /// Gets an immutable view of the current `InheritedSVG` style.
        pub fn get_inheritedsvg(&self) -> &style_structs::InheritedSVG {
            &self.inheritedsvg
        }

        /// Gets a mutable view of the current `InheritedSVG` style.
        pub fn mutate_inheritedsvg(&mut self) -> &mut style_structs::InheritedSVG {
            self.modified_reset = true;
            self.inheritedsvg.mutate()
        }

        /// Gets a mutable view of the current `InheritedSVG` style.
        pub fn take_inheritedsvg(&mut self) -> UniqueArc<style_structs::InheritedSVG> {
            self.modified_reset = true;
            self.inheritedsvg.take()
        }

        /// Gets a mutable view of the current `InheritedSVG` style.
        pub fn put_inheritedsvg(&mut self, s: UniqueArc<style_structs::InheritedSVG>) {
            self.inheritedsvg.put(s)
        }

        /// Gets a mutable view of the current `InheritedSVG` style,
        /// only if it's been mutated before.
        pub fn get_inheritedsvg_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::InheritedSVG> {
            self.inheritedsvg.get_if_mutated()
        }

        /// Reset the current `InheritedSVG` style to its default value.
        pub fn reset_inheritedsvg_struct(&mut self) {
            self.inheritedsvg =
                StyleStructRef::Borrowed(self.reset_style.inheritedsvg_arc());
        }
        /// Gets an immutable view of the current `SVG` style.
        pub fn get_svg(&self) -> &style_structs::SVG {
            &self.svg
        }

        /// Gets a mutable view of the current `SVG` style.
        pub fn mutate_svg(&mut self) -> &mut style_structs::SVG {
            self.modified_reset = true;
            self.svg.mutate()
        }

        /// Gets a mutable view of the current `SVG` style.
        pub fn take_svg(&mut self) -> UniqueArc<style_structs::SVG> {
            self.modified_reset = true;
            self.svg.take()
        }

        /// Gets a mutable view of the current `SVG` style.
        pub fn put_svg(&mut self, s: UniqueArc<style_structs::SVG>) {
            self.svg.put(s)
        }

        /// Gets a mutable view of the current `SVG` style,
        /// only if it's been mutated before.
        pub fn get_svg_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::SVG> {
            self.svg.get_if_mutated()
        }

        /// Reset the current `SVG` style to its default value.
        pub fn reset_svg_struct(&mut self) {
            self.svg =
                StyleStructRef::Borrowed(self.reset_style.svg_arc());
        }
        /// Gets an immutable view of the current `XUL` style.
        pub fn get_xul(&self) -> &style_structs::XUL {
            &self.xul
        }

        /// Gets a mutable view of the current `XUL` style.
        pub fn mutate_xul(&mut self) -> &mut style_structs::XUL {
            self.modified_reset = true;
            self.xul.mutate()
        }

        /// Gets a mutable view of the current `XUL` style.
        pub fn take_xul(&mut self) -> UniqueArc<style_structs::XUL> {
            self.modified_reset = true;
            self.xul.take()
        }

        /// Gets a mutable view of the current `XUL` style.
        pub fn put_xul(&mut self, s: UniqueArc<style_structs::XUL>) {
            self.xul.put(s)
        }

        /// Gets a mutable view of the current `XUL` style,
        /// only if it's been mutated before.
        pub fn get_xul_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::XUL> {
            self.xul.get_if_mutated()
        }

        /// Reset the current `XUL` style to its default value.
        pub fn reset_xul_struct(&mut self) {
            self.xul =
                StyleStructRef::Borrowed(self.reset_style.xul_arc());
        }

    /// Returns whether this computed style represents a floated object.
    pub fn floated(&self) -> bool {
        self.get_box().clone_float() != longhands::float::computed_value::T::None
    }

    /// Returns whether this computed style represents an out of flow-positioned
    /// object.
    pub fn out_of_flow_positioned(&self) -> bool {
        use properties::longhands::position::computed_value::T as Position;
        matches!(self.get_box().clone_position(),
                 Position::Absolute | Position::Fixed)
    }

    /// Whether this style has a top-layer style. That's implemented in Gecko
    /// via the -moz-top-layer property, but servo doesn't have any concept of a
    /// top layer (yet, it's needed for fullscreen).
    #[cfg(feature = "servo")]
    pub fn in_top_layer(&self) -> bool { false }

    /// Whether this style has a top-layer style.
    #[cfg(feature = "gecko")]
    pub fn in_top_layer(&self) -> bool {
        matches!(self.get_box().clone__moz_top_layer(),
                 longhands::_moz_top_layer::computed_value::T::Top)
    }

    /// Clears the "have any reset structs been modified" flag.
    fn clear_modified_reset(&mut self) {
        self.modified_reset = false;
    }

    /// Returns whether we have mutated any reset structs since the the last
    /// time `clear_modified_reset` was called.
    fn modified_reset(&self) -> bool {
        self.modified_reset
    }

    /// Turns this `StyleBuilder` into a proper `ComputedValues` instance.
    pub fn build(self) -> Arc<ComputedValues> {
        ComputedValues::new(
            self.device,
            self.parent_style,
            self.pseudo,
            self.custom_properties,
            self.writing_mode,
            self.flags,
            self.rules,
            self.visited_style,
            self.background.build(),
            self.border.build(),
            self.box_.build(),
            self.color.build(),
            self.column.build(),
            self.counters.build(),
            self.effects.build(),
            self.font.build(),
            self.inheritedbox.build(),
            self.inheritedtable.build(),
            self.inheritedtext.build(),
            self.list.build(),
            self.margin.build(),
            self.outline.build(),
            self.padding.build(),
            self.pointing.build(),
            self.position.build(),
            self.table.build(),
            self.text.build(),
            self.ui.build(),
            self.inheritedsvg.build(),
            self.svg.build(),
            self.xul.build(),
        )
    }

    /// Get the custom properties map if necessary.
    ///
    /// Cloning the Arc here is fine because it only happens in the case where
    /// we have custom properties, and those are both rare and expensive.
    fn custom_properties(&self) -> Option<&Arc<::custom_properties::CustomPropertiesMap>> {
        self.custom_properties.as_ref()
    }

    /// Access to various information about our inherited styles.  We don't
    /// expose an inherited ComputedValues directly, because in the
    /// ::first-line case some of the inherited information needs to come from
    /// one ComputedValues instance and some from a different one.

    /// Inherited writing-mode.
    pub fn inherited_writing_mode(&self) -> &WritingMode {
        &self.inherited_style.writing_mode
    }

    /// The computed value flags of our parent.
    #[inline]
    pub fn get_parent_flags(&self) -> ComputedValueFlags {
        self.inherited_style.flags
    }

    /// And access to inherited style structs.
        /// Gets our inherited `Background`.  We don't name these
        /// accessors `inherited_background` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_background`
        /// instead.
        pub fn get_parent_background(&self) -> &style_structs::Background {
            self.inherited_style_ignoring_first_line.get_background()
        }
        /// Gets our inherited `Border`.  We don't name these
        /// accessors `inherited_border` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_border`
        /// instead.
        pub fn get_parent_border(&self) -> &style_structs::Border {
            self.inherited_style_ignoring_first_line.get_border()
        }
        /// Gets our inherited `Box`.  We don't name these
        /// accessors `inherited_box` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_box`
        /// instead.
        pub fn get_parent_box(&self) -> &style_structs::Box {
            self.inherited_style_ignoring_first_line.get_box()
        }
        /// Gets our inherited `Color`.  We don't name these
        /// accessors `inherited_color` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_color`
        /// instead.
        pub fn get_parent_color(&self) -> &style_structs::Color {
            self.inherited_style.get_color()
        }
        /// Gets our inherited `Column`.  We don't name these
        /// accessors `inherited_column` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_column`
        /// instead.
        pub fn get_parent_column(&self) -> &style_structs::Column {
            self.inherited_style_ignoring_first_line.get_column()
        }
        /// Gets our inherited `Counters`.  We don't name these
        /// accessors `inherited_counters` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_counters`
        /// instead.
        pub fn get_parent_counters(&self) -> &style_structs::Counters {
            self.inherited_style_ignoring_first_line.get_counters()
        }
        /// Gets our inherited `Effects`.  We don't name these
        /// accessors `inherited_effects` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_effects`
        /// instead.
        pub fn get_parent_effects(&self) -> &style_structs::Effects {
            self.inherited_style_ignoring_first_line.get_effects()
        }
        /// Gets our inherited `Font`.  We don't name these
        /// accessors `inherited_font` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_font`
        /// instead.
        pub fn get_parent_font(&self) -> &style_structs::Font {
            self.inherited_style.get_font()
        }
        /// Gets our inherited `InheritedBox`.  We don't name these
        /// accessors `inherited_inheritedbox` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_inheritedbox`
        /// instead.
        pub fn get_parent_inheritedbox(&self) -> &style_structs::InheritedBox {
            self.inherited_style.get_inheritedbox()
        }
        /// Gets our inherited `InheritedTable`.  We don't name these
        /// accessors `inherited_inheritedtable` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_inheritedtable`
        /// instead.
        pub fn get_parent_inheritedtable(&self) -> &style_structs::InheritedTable {
            self.inherited_style.get_inheritedtable()
        }
        /// Gets our inherited `InheritedText`.  We don't name these
        /// accessors `inherited_inheritedtext` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_inheritedtext`
        /// instead.
        pub fn get_parent_inheritedtext(&self) -> &style_structs::InheritedText {
            self.inherited_style.get_inheritedtext()
        }
        /// Gets our inherited `List`.  We don't name these
        /// accessors `inherited_list` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_list`
        /// instead.
        pub fn get_parent_list(&self) -> &style_structs::List {
            self.inherited_style.get_list()
        }
        /// Gets our inherited `Margin`.  We don't name these
        /// accessors `inherited_margin` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_margin`
        /// instead.
        pub fn get_parent_margin(&self) -> &style_structs::Margin {
            self.inherited_style_ignoring_first_line.get_margin()
        }
        /// Gets our inherited `Outline`.  We don't name these
        /// accessors `inherited_outline` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_outline`
        /// instead.
        pub fn get_parent_outline(&self) -> &style_structs::Outline {
            self.inherited_style_ignoring_first_line.get_outline()
        }
        /// Gets our inherited `Padding`.  We don't name these
        /// accessors `inherited_padding` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_padding`
        /// instead.
        pub fn get_parent_padding(&self) -> &style_structs::Padding {
            self.inherited_style_ignoring_first_line.get_padding()
        }
        /// Gets our inherited `Pointing`.  We don't name these
        /// accessors `inherited_pointing` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_pointing`
        /// instead.
        pub fn get_parent_pointing(&self) -> &style_structs::Pointing {
            self.inherited_style.get_pointing()
        }
        /// Gets our inherited `Position`.  We don't name these
        /// accessors `inherited_position` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_position`
        /// instead.
        pub fn get_parent_position(&self) -> &style_structs::Position {
            self.inherited_style_ignoring_first_line.get_position()
        }
        /// Gets our inherited `Table`.  We don't name these
        /// accessors `inherited_table` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_table`
        /// instead.
        pub fn get_parent_table(&self) -> &style_structs::Table {
            self.inherited_style_ignoring_first_line.get_table()
        }
        /// Gets our inherited `Text`.  We don't name these
        /// accessors `inherited_text` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_text`
        /// instead.
        pub fn get_parent_text(&self) -> &style_structs::Text {
            self.inherited_style_ignoring_first_line.get_text()
        }
        /// Gets our inherited `UI`.  We don't name these
        /// accessors `inherited_ui` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_ui`
        /// instead.
        pub fn get_parent_ui(&self) -> &style_structs::UI {
            self.inherited_style_ignoring_first_line.get_ui()
        }
        /// Gets our inherited `InheritedSVG`.  We don't name these
        /// accessors `inherited_inheritedsvg` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_inheritedsvg`
        /// instead.
        pub fn get_parent_inheritedsvg(&self) -> &style_structs::InheritedSVG {
            self.inherited_style.get_inheritedsvg()
        }
        /// Gets our inherited `SVG`.  We don't name these
        /// accessors `inherited_svg` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_svg`
        /// instead.
        pub fn get_parent_svg(&self) -> &style_structs::SVG {
            self.inherited_style_ignoring_first_line.get_svg()
        }
        /// Gets our inherited `XUL`.  We don't name these
        /// accessors `inherited_xul` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_xul`
        /// instead.
        pub fn get_parent_xul(&self) -> &style_structs::XUL {
            self.inherited_style_ignoring_first_line.get_xul()
        }
}

#[cfg(feature = "servo")]
pub use self::lazy_static_module::INITIAL_SERVO_VALUES;

// Use a module to work around #[cfg] on lazy_static! not being applied to every generated item.
#[cfg(feature = "servo")]
#[allow(missing_docs)]
mod lazy_static_module {
    use logical_geometry::WritingMode;
    use servo_arc::Arc;
    use super::{ComputedValues, ComputedValuesInner, longhands, style_structs};
    use super::computed_value_flags::ComputedValueFlags;

    /// The initial values for all style structs as defined by the specification.
    lazy_static! {
        pub static ref INITIAL_SERVO_VALUES: ComputedValues = ComputedValues {
            inner: ComputedValuesInner {
                    background: Arc::new(style_structs::Background {
                            background_color: longhands::background_color::get_initial_value(),
                            background_image: longhands::background_image::get_initial_value(),
                            background_position_x: longhands::background_position_x::get_initial_value(),
                            background_position_y: longhands::background_position_y::get_initial_value(),
                            background_repeat: longhands::background_repeat::get_initial_value(),
                            background_attachment: longhands::background_attachment::get_initial_value(),
                            background_clip: longhands::background_clip::get_initial_value(),
                            background_origin: longhands::background_origin::get_initial_value(),
                            background_size: longhands::background_size::get_initial_value(),
                            background_blend_mode: longhands::background_blend_mode::get_initial_value(),
                    }),
                    border: Arc::new(style_structs::Border {
                            border_top_color: longhands::border_top_color::get_initial_value(),
                            border_top_style: longhands::border_top_style::get_initial_value(),
                            border_top_width: longhands::border_top_width::get_initial_value(),
                            border_left_color: longhands::border_left_color::get_initial_value(),
                            border_left_style: longhands::border_left_style::get_initial_value(),
                            border_left_width: longhands::border_left_width::get_initial_value(),
                            border_bottom_color: longhands::border_bottom_color::get_initial_value(),
                            border_bottom_style: longhands::border_bottom_style::get_initial_value(),
                            border_bottom_width: longhands::border_bottom_width::get_initial_value(),
                            border_right_color: longhands::border_right_color::get_initial_value(),
                            border_right_style: longhands::border_right_style::get_initial_value(),
                            border_right_width: longhands::border_right_width::get_initial_value(),
                            border_block_start_color: longhands::border_block_start_color::get_initial_value(),
                            border_block_start_style: longhands::border_block_start_style::get_initial_value(),
                            border_block_start_width: longhands::border_block_start_width::get_initial_value(),
                            border_block_end_color: longhands::border_block_end_color::get_initial_value(),
                            border_block_end_style: longhands::border_block_end_style::get_initial_value(),
                            border_block_end_width: longhands::border_block_end_width::get_initial_value(),
                            border_inline_start_color: longhands::border_inline_start_color::get_initial_value(),
                            border_inline_start_style: longhands::border_inline_start_style::get_initial_value(),
                            border_inline_start_width: longhands::border_inline_start_width::get_initial_value(),
                            border_inline_end_color: longhands::border_inline_end_color::get_initial_value(),
                            border_inline_end_style: longhands::border_inline_end_style::get_initial_value(),
                            border_inline_end_width: longhands::border_inline_end_width::get_initial_value(),
                            border_top_left_radius: longhands::border_top_left_radius::get_initial_value(),
                            border_top_right_radius: longhands::border_top_right_radius::get_initial_value(),
                            border_bottom_right_radius: longhands::border_bottom_right_radius::get_initial_value(),
                            border_bottom_left_radius: longhands::border_bottom_left_radius::get_initial_value(),
                            box_decoration_break: longhands::box_decoration_break::get_initial_value(),
                            _moz_float_edge: longhands::_moz_float_edge::get_initial_value(),
                            border_image_source: longhands::border_image_source::get_initial_value(),
                            border_image_outset: longhands::border_image_outset::get_initial_value(),
                            border_image_repeat: longhands::border_image_repeat::get_initial_value(),
                            border_image_width: longhands::border_image_width::get_initial_value(),
                            border_image_slice: longhands::border_image_slice::get_initial_value(),
                    }),
                    box_: Arc::new(style_structs::Box {
                            display: longhands::display::get_initial_value(),
                            _moz_top_layer: longhands::_moz_top_layer::get_initial_value(),
                            position: longhands::position::get_initial_value(),
                            float: longhands::float::get_initial_value(),
                            clear: longhands::clear::get_initial_value(),
                            vertical_align: longhands::vertical_align::get_initial_value(),
                            overflow_clip_box_inline: longhands::overflow_clip_box_inline::get_initial_value(),
                            overflow_clip_box_block: longhands::overflow_clip_box_block::get_initial_value(),
                            overflow_x: longhands::overflow_x::get_initial_value(),
                            overflow_y: longhands::overflow_y::get_initial_value(),
                            transition_duration: longhands::transition_duration::get_initial_value(),
                            transition_timing_function: longhands::transition_timing_function::get_initial_value(),
                            transition_property: longhands::transition_property::get_initial_value(),
                            transition_delay: longhands::transition_delay::get_initial_value(),
                            animation_name: longhands::animation_name::get_initial_value(),
                            animation_duration: longhands::animation_duration::get_initial_value(),
                            animation_timing_function: longhands::animation_timing_function::get_initial_value(),
                            animation_iteration_count: longhands::animation_iteration_count::get_initial_value(),
                            animation_direction: longhands::animation_direction::get_initial_value(),
                            animation_play_state: longhands::animation_play_state::get_initial_value(),
                            animation_fill_mode: longhands::animation_fill_mode::get_initial_value(),
                            animation_delay: longhands::animation_delay::get_initial_value(),
                            scroll_snap_points_x: longhands::scroll_snap_points_x::get_initial_value(),
                            scroll_snap_points_y: longhands::scroll_snap_points_y::get_initial_value(),
                            scroll_snap_destination: longhands::scroll_snap_destination::get_initial_value(),
                            scroll_snap_coordinate: longhands::scroll_snap_coordinate::get_initial_value(),
                            transform: longhands::transform::get_initial_value(),
                            rotate: longhands::rotate::get_initial_value(),
                            scale: longhands::scale::get_initial_value(),
                            translate: longhands::translate::get_initial_value(),
                            scroll_behavior: longhands::scroll_behavior::get_initial_value(),
                            scroll_snap_type_x: longhands::scroll_snap_type_x::get_initial_value(),
                            scroll_snap_type_y: longhands::scroll_snap_type_y::get_initial_value(),
                            overscroll_behavior_x: longhands::overscroll_behavior_x::get_initial_value(),
                            overscroll_behavior_y: longhands::overscroll_behavior_y::get_initial_value(),
                            isolation: longhands::isolation::get_initial_value(),
                            page_break_after: longhands::page_break_after::get_initial_value(),
                            page_break_before: longhands::page_break_before::get_initial_value(),
                            page_break_inside: longhands::page_break_inside::get_initial_value(),
                            resize: longhands::resize::get_initial_value(),
                            perspective: longhands::perspective::get_initial_value(),
                            perspective_origin: longhands::perspective_origin::get_initial_value(),
                            backface_visibility: longhands::backface_visibility::get_initial_value(),
                            transform_box: longhands::transform_box::get_initial_value(),
                            transform_style: longhands::transform_style::get_initial_value(),
                            transform_origin: longhands::transform_origin::get_initial_value(),
                            contain: longhands::contain::get_initial_value(),
                            _moz_appearance: longhands::_moz_appearance::get_initial_value(),
                            _moz_binding: longhands::_moz_binding::get_initial_value(),
                            _moz_orient: longhands::_moz_orient::get_initial_value(),
                            will_change: longhands::will_change::get_initial_value(),
                            shape_image_threshold: longhands::shape_image_threshold::get_initial_value(),
                            shape_outside: longhands::shape_outside::get_initial_value(),
                            touch_action: longhands::touch_action::get_initial_value(),
                            original_display: longhands::display::get_initial_value(),
                    }),
                    color: Arc::new(style_structs::Color {
                            color: longhands::color::get_initial_value(),
                    }),
                    column: Arc::new(style_structs::Column {
                            column_width: longhands::column_width::get_initial_value(),
                            column_count: longhands::column_count::get_initial_value(),
                            column_gap: longhands::column_gap::get_initial_value(),
                            column_fill: longhands::column_fill::get_initial_value(),
                            column_rule_width: longhands::column_rule_width::get_initial_value(),
                            column_rule_color: longhands::column_rule_color::get_initial_value(),
                            column_span: longhands::column_span::get_initial_value(),
                            column_rule_style: longhands::column_rule_style::get_initial_value(),
                    }),
                    counters: Arc::new(style_structs::Counters {
                            content: longhands::content::get_initial_value(),
                            counter_increment: longhands::counter_increment::get_initial_value(),
                            counter_reset: longhands::counter_reset::get_initial_value(),
                    }),
                    effects: Arc::new(style_structs::Effects {
                            opacity: longhands::opacity::get_initial_value(),
                            box_shadow: longhands::box_shadow::get_initial_value(),
                            clip: longhands::clip::get_initial_value(),
                            filter: longhands::filter::get_initial_value(),
                            mix_blend_mode: longhands::mix_blend_mode::get_initial_value(),
                    }),
                    font: Arc::new(style_structs::Font {
                            font_family: longhands::font_family::get_initial_value(),
                            font_style: longhands::font_style::get_initial_value(),
                            font_variant_caps: longhands::font_variant_caps::get_initial_value(),
                            font_weight: longhands::font_weight::get_initial_value(),
                            font_size: longhands::font_size::get_initial_value(),
                            font_size_adjust: longhands::font_size_adjust::get_initial_value(),
                            font_synthesis: longhands::font_synthesis::get_initial_value(),
                            font_stretch: longhands::font_stretch::get_initial_value(),
                            font_kerning: longhands::font_kerning::get_initial_value(),
                            font_variant_alternates: longhands::font_variant_alternates::get_initial_value(),
                            font_variant_east_asian: longhands::font_variant_east_asian::get_initial_value(),
                            font_variant_ligatures: longhands::font_variant_ligatures::get_initial_value(),
                            font_variant_numeric: longhands::font_variant_numeric::get_initial_value(),
                            font_variant_position: longhands::font_variant_position::get_initial_value(),
                            font_feature_settings: longhands::font_feature_settings::get_initial_value(),
                            font_variation_settings: longhands::font_variation_settings::get_initial_value(),
                            font_language_override: longhands::font_language_override::get_initial_value(),
                            font_optical_sizing: longhands::font_optical_sizing::get_initial_value(),
                            _x_lang: longhands::_x_lang::get_initial_value(),
                            _moz_script_size_multiplier: longhands::_moz_script_size_multiplier::get_initial_value(),
                            _moz_script_level: longhands::_moz_script_level::get_initial_value(),
                            _moz_math_display: longhands::_moz_math_display::get_initial_value(),
                            _moz_math_variant: longhands::_moz_math_variant::get_initial_value(),
                            _moz_script_min_size: longhands::_moz_script_min_size::get_initial_value(),
                            _x_text_zoom: longhands::_x_text_zoom::get_initial_value(),
                            _moz_osx_font_smoothing: longhands::_moz_osx_font_smoothing::get_initial_value(),
                            _moz_font_smoothing_background_color: longhands::_moz_font_smoothing_background_color::get_initial_value(),
                            _moz_min_font_size_ratio: longhands::_moz_min_font_size_ratio::get_initial_value(),
                            hash: 0,
                    }),
                    inheritedbox: Arc::new(style_structs::InheritedBox {
                            visibility: longhands::visibility::get_initial_value(),
                            writing_mode: longhands::writing_mode::get_initial_value(),
                            direction: longhands::direction::get_initial_value(),
                            text_orientation: longhands::text_orientation::get_initial_value(),
                            color_adjust: longhands::color_adjust::get_initial_value(),
                            image_rendering: longhands::image_rendering::get_initial_value(),
                            image_orientation: longhands::image_orientation::get_initial_value(),
                    }),
                    inheritedtable: Arc::new(style_structs::InheritedTable {
                            border_collapse: longhands::border_collapse::get_initial_value(),
                            empty_cells: longhands::empty_cells::get_initial_value(),
                            caption_side: longhands::caption_side::get_initial_value(),
                            border_spacing: longhands::border_spacing::get_initial_value(),
                    }),
                    inheritedtext: Arc::new(style_structs::InheritedText {
                            line_height: longhands::line_height::get_initial_value(),
                            text_transform: longhands::text_transform::get_initial_value(),
                            hyphens: longhands::hyphens::get_initial_value(),
                            _moz_text_size_adjust: longhands::_moz_text_size_adjust::get_initial_value(),
                            text_indent: longhands::text_indent::get_initial_value(),
                            overflow_wrap: longhands::overflow_wrap::get_initial_value(),
                            word_break: longhands::word_break::get_initial_value(),
                            text_justify: longhands::text_justify::get_initial_value(),
                            text_align_last: longhands::text_align_last::get_initial_value(),
                            text_align: longhands::text_align::get_initial_value(),
                            letter_spacing: longhands::letter_spacing::get_initial_value(),
                            word_spacing: longhands::word_spacing::get_initial_value(),
                            white_space: longhands::white_space::get_initial_value(),
                            text_shadow: longhands::text_shadow::get_initial_value(),
                            text_emphasis_style: longhands::text_emphasis_style::get_initial_value(),
                            text_emphasis_position: longhands::text_emphasis_position::get_initial_value(),
                            text_emphasis_color: longhands::text_emphasis_color::get_initial_value(),
                            _moz_tab_size: longhands::_moz_tab_size::get_initial_value(),
                            _webkit_text_fill_color: longhands::_webkit_text_fill_color::get_initial_value(),
                            _webkit_text_stroke_color: longhands::_webkit_text_stroke_color::get_initial_value(),
                            _webkit_text_stroke_width: longhands::_webkit_text_stroke_width::get_initial_value(),
                            ruby_align: longhands::ruby_align::get_initial_value(),
                            ruby_position: longhands::ruby_position::get_initial_value(),
                            text_combine_upright: longhands::text_combine_upright::get_initial_value(),
                            text_rendering: longhands::text_rendering::get_initial_value(),
                            _moz_control_character_visibility: longhands::_moz_control_character_visibility::get_initial_value(),
                            text_decorations_in_effect: ::values::computed::text::TextDecorationsInEffect::default(),
                    }),
                    list: Arc::new(style_structs::List {
                            list_style_position: longhands::list_style_position::get_initial_value(),
                            list_style_type: longhands::list_style_type::get_initial_value(),
                            list_style_image: longhands::list_style_image::get_initial_value(),
                            quotes: longhands::quotes::get_initial_value(),
                            _moz_image_region: longhands::_moz_image_region::get_initial_value(),
                    }),
                    margin: Arc::new(style_structs::Margin {
                            margin_top: longhands::margin_top::get_initial_value(),
                            margin_left: longhands::margin_left::get_initial_value(),
                            margin_bottom: longhands::margin_bottom::get_initial_value(),
                            margin_right: longhands::margin_right::get_initial_value(),
                            margin_block_start: longhands::margin_block_start::get_initial_value(),
                            margin_block_end: longhands::margin_block_end::get_initial_value(),
                            margin_inline_start: longhands::margin_inline_start::get_initial_value(),
                            margin_inline_end: longhands::margin_inline_end::get_initial_value(),
                    }),
                    outline: Arc::new(style_structs::Outline {
                            outline_color: longhands::outline_color::get_initial_value(),
                            outline_style: longhands::outline_style::get_initial_value(),
                            outline_width: longhands::outline_width::get_initial_value(),
                            _moz_outline_radius_topleft: longhands::_moz_outline_radius_topleft::get_initial_value(),
                            _moz_outline_radius_topright: longhands::_moz_outline_radius_topright::get_initial_value(),
                            _moz_outline_radius_bottomright: longhands::_moz_outline_radius_bottomright::get_initial_value(),
                            _moz_outline_radius_bottomleft: longhands::_moz_outline_radius_bottomleft::get_initial_value(),
                            outline_offset: longhands::outline_offset::get_initial_value(),
                    }),
                    padding: Arc::new(style_structs::Padding {
                            padding_top: longhands::padding_top::get_initial_value(),
                            padding_left: longhands::padding_left::get_initial_value(),
                            padding_bottom: longhands::padding_bottom::get_initial_value(),
                            padding_right: longhands::padding_right::get_initial_value(),
                            padding_block_start: longhands::padding_block_start::get_initial_value(),
                            padding_block_end: longhands::padding_block_end::get_initial_value(),
                            padding_inline_start: longhands::padding_inline_start::get_initial_value(),
                            padding_inline_end: longhands::padding_inline_end::get_initial_value(),
                    }),
                    pointing: Arc::new(style_structs::Pointing {
                            cursor: longhands::cursor::get_initial_value(),
                            pointer_events: longhands::pointer_events::get_initial_value(),
                            _moz_user_input: longhands::_moz_user_input::get_initial_value(),
                            _moz_user_modify: longhands::_moz_user_modify::get_initial_value(),
                            _moz_user_focus: longhands::_moz_user_focus::get_initial_value(),
                            caret_color: longhands::caret_color::get_initial_value(),
                    }),
                    position: Arc::new(style_structs::Position {
                            top: longhands::top::get_initial_value(),
                            left: longhands::left::get_initial_value(),
                            bottom: longhands::bottom::get_initial_value(),
                            right: longhands::right::get_initial_value(),
                            offset_block_start: longhands::offset_block_start::get_initial_value(),
                            offset_block_end: longhands::offset_block_end::get_initial_value(),
                            offset_inline_start: longhands::offset_inline_start::get_initial_value(),
                            offset_inline_end: longhands::offset_inline_end::get_initial_value(),
                            z_index: longhands::z_index::get_initial_value(),
                            flex_direction: longhands::flex_direction::get_initial_value(),
                            flex_wrap: longhands::flex_wrap::get_initial_value(),
                            justify_content: longhands::justify_content::get_initial_value(),
                            align_content: longhands::align_content::get_initial_value(),
                            align_items: longhands::align_items::get_initial_value(),
                            justify_items: longhands::justify_items::get_initial_value(),
                            flex_grow: longhands::flex_grow::get_initial_value(),
                            flex_shrink: longhands::flex_shrink::get_initial_value(),
                            align_self: longhands::align_self::get_initial_value(),
                            justify_self: longhands::justify_self::get_initial_value(),
                            order: longhands::order::get_initial_value(),
                            flex_basis: longhands::flex_basis::get_initial_value(),
                            width: longhands::width::get_initial_value(),
                            min_width: longhands::min_width::get_initial_value(),
                            max_width: longhands::max_width::get_initial_value(),
                            height: longhands::height::get_initial_value(),
                            min_height: longhands::min_height::get_initial_value(),
                            max_height: longhands::max_height::get_initial_value(),
                            block_size: longhands::block_size::get_initial_value(),
                            min_block_size: longhands::min_block_size::get_initial_value(),
                            max_block_size: longhands::max_block_size::get_initial_value(),
                            inline_size: longhands::inline_size::get_initial_value(),
                            min_inline_size: longhands::min_inline_size::get_initial_value(),
                            max_inline_size: longhands::max_inline_size::get_initial_value(),
                            box_sizing: longhands::box_sizing::get_initial_value(),
                            object_fit: longhands::object_fit::get_initial_value(),
                            object_position: longhands::object_position::get_initial_value(),
                            grid_row_gap: longhands::grid_row_gap::get_initial_value(),
                            grid_row_start: longhands::grid_row_start::get_initial_value(),
                            grid_row_end: longhands::grid_row_end::get_initial_value(),
                            grid_auto_rows: longhands::grid_auto_rows::get_initial_value(),
                            grid_template_rows: longhands::grid_template_rows::get_initial_value(),
                            grid_column_gap: longhands::grid_column_gap::get_initial_value(),
                            grid_column_start: longhands::grid_column_start::get_initial_value(),
                            grid_column_end: longhands::grid_column_end::get_initial_value(),
                            grid_auto_columns: longhands::grid_auto_columns::get_initial_value(),
                            grid_template_columns: longhands::grid_template_columns::get_initial_value(),
                            grid_auto_flow: longhands::grid_auto_flow::get_initial_value(),
                            grid_template_areas: longhands::grid_template_areas::get_initial_value(),
                    }),
                    table: Arc::new(style_structs::Table {
                            table_layout: longhands::table_layout::get_initial_value(),
                            _x_span: longhands::_x_span::get_initial_value(),
                    }),
                    text: Arc::new(style_structs::Text {
                            text_overflow: longhands::text_overflow::get_initial_value(),
                            unicode_bidi: longhands::unicode_bidi::get_initial_value(),
                            text_decoration_line: longhands::text_decoration_line::get_initial_value(),
                            text_decoration_style: longhands::text_decoration_style::get_initial_value(),
                            text_decoration_color: longhands::text_decoration_color::get_initial_value(),
                            initial_letter: longhands::initial_letter::get_initial_value(),
                    }),
                    ui: Arc::new(style_structs::UI {
                            ime_mode: longhands::ime_mode::get_initial_value(),
                            _moz_user_select: longhands::_moz_user_select::get_initial_value(),
                            _moz_window_dragging: longhands::_moz_window_dragging::get_initial_value(),
                            _moz_window_shadow: longhands::_moz_window_shadow::get_initial_value(),
                            _moz_window_opacity: longhands::_moz_window_opacity::get_initial_value(),
                            _moz_window_transform: longhands::_moz_window_transform::get_initial_value(),
                            _moz_window_transform_origin: longhands::_moz_window_transform_origin::get_initial_value(),
                            _moz_force_broken_image_icon: longhands::_moz_force_broken_image_icon::get_initial_value(),
                    }),
                    inheritedsvg: Arc::new(style_structs::InheritedSVG {
                            text_anchor: longhands::text_anchor::get_initial_value(),
                            color_interpolation: longhands::color_interpolation::get_initial_value(),
                            color_interpolation_filters: longhands::color_interpolation_filters::get_initial_value(),
                            fill: longhands::fill::get_initial_value(),
                            fill_opacity: longhands::fill_opacity::get_initial_value(),
                            fill_rule: longhands::fill_rule::get_initial_value(),
                            shape_rendering: longhands::shape_rendering::get_initial_value(),
                            stroke: longhands::stroke::get_initial_value(),
                            stroke_width: longhands::stroke_width::get_initial_value(),
                            stroke_linecap: longhands::stroke_linecap::get_initial_value(),
                            stroke_linejoin: longhands::stroke_linejoin::get_initial_value(),
                            stroke_miterlimit: longhands::stroke_miterlimit::get_initial_value(),
                            stroke_opacity: longhands::stroke_opacity::get_initial_value(),
                            stroke_dasharray: longhands::stroke_dasharray::get_initial_value(),
                            stroke_dashoffset: longhands::stroke_dashoffset::get_initial_value(),
                            clip_rule: longhands::clip_rule::get_initial_value(),
                            marker_start: longhands::marker_start::get_initial_value(),
                            marker_mid: longhands::marker_mid::get_initial_value(),
                            marker_end: longhands::marker_end::get_initial_value(),
                            paint_order: longhands::paint_order::get_initial_value(),
                            _moz_context_properties: longhands::_moz_context_properties::get_initial_value(),
                    }),
                    svg: Arc::new(style_structs::SVG {
                            dominant_baseline: longhands::dominant_baseline::get_initial_value(),
                            vector_effect: longhands::vector_effect::get_initial_value(),
                            stop_color: longhands::stop_color::get_initial_value(),
                            stop_opacity: longhands::stop_opacity::get_initial_value(),
                            flood_color: longhands::flood_color::get_initial_value(),
                            flood_opacity: longhands::flood_opacity::get_initial_value(),
                            lighting_color: longhands::lighting_color::get_initial_value(),
                            mask_type: longhands::mask_type::get_initial_value(),
                            clip_path: longhands::clip_path::get_initial_value(),
                            mask_mode: longhands::mask_mode::get_initial_value(),
                            mask_repeat: longhands::mask_repeat::get_initial_value(),
                            mask_position_x: longhands::mask_position_x::get_initial_value(),
                            mask_position_y: longhands::mask_position_y::get_initial_value(),
                            mask_clip: longhands::mask_clip::get_initial_value(),
                            mask_origin: longhands::mask_origin::get_initial_value(),
                            mask_size: longhands::mask_size::get_initial_value(),
                            mask_composite: longhands::mask_composite::get_initial_value(),
                            mask_image: longhands::mask_image::get_initial_value(),
                    }),
                    xul: Arc::new(style_structs::XUL {
                            _moz_box_align: longhands::_moz_box_align::get_initial_value(),
                            _moz_box_direction: longhands::_moz_box_direction::get_initial_value(),
                            _moz_box_flex: longhands::_moz_box_flex::get_initial_value(),
                            _moz_box_orient: longhands::_moz_box_orient::get_initial_value(),
                            _moz_box_pack: longhands::_moz_box_pack::get_initial_value(),
                            _moz_stack_sizing: longhands::_moz_stack_sizing::get_initial_value(),
                            _moz_box_ordinal_group: longhands::_moz_box_ordinal_group::get_initial_value(),
                    }),
                custom_properties: None,
                writing_mode: WritingMode::empty(),
                rules: None,
                visited_style: None,
                flags: ComputedValueFlags::empty(),
            }
        };
    }
}

/// A per-longhand function that performs the CSS cascade for that longhand.
pub type CascadePropertyFn =
    extern "Rust" fn(
        declaration: &PropertyDeclaration,
        context: &mut computed::Context,
    );

/// A per-longhand array of functions to perform the CSS cascade on each of
/// them, effectively doing virtual dispatch.
static CASCADE_PROPERTY: [CascadePropertyFn; 326] = [
        longhands::align_content::cascade_property,
        longhands::align_items::cascade_property,
        longhands::align_self::cascade_property,
        longhands::backface_visibility::cascade_property,
        longhands::border_collapse::cascade_property,
        longhands::border_image_repeat::cascade_property,
        longhands::box_decoration_break::cascade_property,
        longhands::box_sizing::cascade_property,
        longhands::caption_side::cascade_property,
        longhands::clear::cascade_property,
        longhands::clip_rule::cascade_property,
        longhands::color_adjust::cascade_property,
        longhands::color_interpolation::cascade_property,
        longhands::color_interpolation_filters::cascade_property,
        longhands::column_count::cascade_property,
        longhands::column_fill::cascade_property,
        longhands::column_rule_style::cascade_property,
        longhands::column_span::cascade_property,
        longhands::contain::cascade_property,
        longhands::direction::cascade_property,
        longhands::dominant_baseline::cascade_property,
        longhands::empty_cells::cascade_property,
        longhands::fill_rule::cascade_property,
        longhands::flex_direction::cascade_property,
        longhands::flex_wrap::cascade_property,
        longhands::float::cascade_property,
        longhands::font_kerning::cascade_property,
        longhands::font_optical_sizing::cascade_property,
        longhands::font_stretch::cascade_property,
        longhands::font_style::cascade_property,
        longhands::font_synthesis::cascade_property,
        longhands::font_variant_caps::cascade_property,
        longhands::font_variant_position::cascade_property,
        longhands::font_weight::cascade_property,
        longhands::grid_auto_flow::cascade_property,
        longhands::hyphens::cascade_property,
        longhands::image_orientation::cascade_property,
        longhands::image_rendering::cascade_property,
        longhands::ime_mode::cascade_property,
        longhands::initial_letter::cascade_property,
        longhands::isolation::cascade_property,
        longhands::justify_content::cascade_property,
        longhands::justify_items::cascade_property,
        longhands::justify_self::cascade_property,
        longhands::list_style_position::cascade_property,
        longhands::mask_type::cascade_property,
        longhands::mix_blend_mode::cascade_property,
        longhands::_moz_appearance::cascade_property,
        longhands::_moz_box_align::cascade_property,
        longhands::_moz_box_direction::cascade_property,
        longhands::_moz_box_orient::cascade_property,
        longhands::_moz_box_pack::cascade_property,
        longhands::_moz_control_character_visibility::cascade_property,
        longhands::_moz_float_edge::cascade_property,
        longhands::_moz_force_broken_image_icon::cascade_property,
        longhands::_moz_math_display::cascade_property,
        longhands::_moz_math_variant::cascade_property,
        longhands::_moz_min_font_size_ratio::cascade_property,
        longhands::_moz_orient::cascade_property,
        longhands::_moz_osx_font_smoothing::cascade_property,
        longhands::_moz_script_level::cascade_property,
        longhands::_moz_script_min_size::cascade_property,
        longhands::_moz_script_size_multiplier::cascade_property,
        longhands::_moz_stack_sizing::cascade_property,
        longhands::_moz_text_size_adjust::cascade_property,
        longhands::_moz_top_layer::cascade_property,
        longhands::_moz_user_focus::cascade_property,
        longhands::_moz_user_input::cascade_property,
        longhands::_moz_user_modify::cascade_property,
        longhands::_moz_user_select::cascade_property,
        longhands::_moz_window_dragging::cascade_property,
        longhands::_moz_window_shadow::cascade_property,
        longhands::object_fit::cascade_property,
        longhands::outline_style::cascade_property,
        longhands::overflow_wrap::cascade_property,
        longhands::overflow_x::cascade_property,
        longhands::page_break_after::cascade_property,
        longhands::page_break_before::cascade_property,
        longhands::page_break_inside::cascade_property,
        longhands::paint_order::cascade_property,
        longhands::pointer_events::cascade_property,
        longhands::position::cascade_property,
        longhands::resize::cascade_property,
        longhands::ruby_align::cascade_property,
        longhands::ruby_position::cascade_property,
        longhands::scroll_behavior::cascade_property,
        longhands::shape_rendering::cascade_property,
        longhands::stroke_linecap::cascade_property,
        longhands::stroke_linejoin::cascade_property,
        longhands::table_layout::cascade_property,
        longhands::text_align_last::cascade_property,
        longhands::text_anchor::cascade_property,
        longhands::text_combine_upright::cascade_property,
        longhands::text_decoration_line::cascade_property,
        longhands::text_decoration_style::cascade_property,
        longhands::text_justify::cascade_property,
        longhands::text_orientation::cascade_property,
        longhands::text_rendering::cascade_property,
        longhands::text_transform::cascade_property,
        longhands::touch_action::cascade_property,
        longhands::transform_box::cascade_property,
        longhands::transform_style::cascade_property,
        longhands::unicode_bidi::cascade_property,
        longhands::vector_effect::cascade_property,
        longhands::visibility::cascade_property,
        longhands::white_space::cascade_property,
        longhands::word_break::cascade_property,
        longhands::writing_mode::cascade_property,
        longhands::_x_span::cascade_property,
        longhands::_x_text_zoom::cascade_property,
        longhands::z_index::cascade_property,
        longhands::_moz_box_ordinal_group::cascade_property,
        longhands::order::cascade_property,
        longhands::overscroll_behavior_x::cascade_property,
        longhands::overscroll_behavior_y::cascade_property,
        longhands::scroll_snap_type_x::cascade_property,
        longhands::scroll_snap_type_y::cascade_property,
        longhands::flex_grow::cascade_property,
        longhands::flex_shrink::cascade_property,
        longhands::_moz_box_flex::cascade_property,
        longhands::flood_opacity::cascade_property,
        longhands::_moz_window_opacity::cascade_property,
        longhands::opacity::cascade_property,
        longhands::shape_image_threshold::cascade_property,
        longhands::stop_opacity::cascade_property,
        longhands::border_block_end_style::cascade_property,
        longhands::border_block_start_style::cascade_property,
        longhands::border_bottom_style::cascade_property,
        longhands::border_inline_end_style::cascade_property,
        longhands::border_inline_start_style::cascade_property,
        longhands::border_left_style::cascade_property,
        longhands::border_right_style::cascade_property,
        longhands::border_top_style::cascade_property,
        longhands::animation_delay::cascade_property,
        longhands::animation_direction::cascade_property,
        longhands::animation_duration::cascade_property,
        longhands::animation_fill_mode::cascade_property,
        longhands::animation_iteration_count::cascade_property,
        longhands::animation_name::cascade_property,
        longhands::animation_play_state::cascade_property,
        longhands::animation_timing_function::cascade_property,
        longhands::background_attachment::cascade_property,
        longhands::background_blend_mode::cascade_property,
        longhands::background_clip::cascade_property,
        longhands::background_image::cascade_property,
        longhands::background_origin::cascade_property,
        longhands::background_position_x::cascade_property,
        longhands::background_position_y::cascade_property,
        longhands::background_repeat::cascade_property,
        longhands::background_size::cascade_property,
        longhands::border_image_outset::cascade_property,
        longhands::border_image_slice::cascade_property,
        longhands::border_image_source::cascade_property,
        longhands::border_image_width::cascade_property,
        longhands::border_spacing::cascade_property,
        longhands::box_shadow::cascade_property,
        longhands::caret_color::cascade_property,
        longhands::clip_path::cascade_property,
        longhands::color::cascade_property,
        longhands::column_gap::cascade_property,
        longhands::column_width::cascade_property,
        longhands::content::cascade_property,
        longhands::counter_increment::cascade_property,
        longhands::counter_reset::cascade_property,
        longhands::cursor::cascade_property,
        longhands::display::cascade_property,
        longhands::filter::cascade_property,
        longhands::font_family::cascade_property,
        longhands::font_feature_settings::cascade_property,
        longhands::font_language_override::cascade_property,
        longhands::font_size::cascade_property,
        longhands::font_size_adjust::cascade_property,
        longhands::font_variant_alternates::cascade_property,
        longhands::font_variant_east_asian::cascade_property,
        longhands::font_variant_ligatures::cascade_property,
        longhands::font_variant_numeric::cascade_property,
        longhands::font_variation_settings::cascade_property,
        longhands::grid_template_areas::cascade_property,
        longhands::letter_spacing::cascade_property,
        longhands::line_height::cascade_property,
        longhands::list_style_image::cascade_property,
        longhands::list_style_type::cascade_property,
        longhands::mask_clip::cascade_property,
        longhands::mask_composite::cascade_property,
        longhands::mask_image::cascade_property,
        longhands::mask_mode::cascade_property,
        longhands::mask_origin::cascade_property,
        longhands::mask_position_x::cascade_property,
        longhands::mask_position_y::cascade_property,
        longhands::mask_repeat::cascade_property,
        longhands::mask_size::cascade_property,
        longhands::_moz_context_properties::cascade_property,
        longhands::_moz_tab_size::cascade_property,
        longhands::outline_offset::cascade_property,
        longhands::overflow_y::cascade_property,
        longhands::perspective::cascade_property,
        longhands::perspective_origin::cascade_property,
        longhands::quotes::cascade_property,
        longhands::rotate::cascade_property,
        longhands::scale::cascade_property,
        longhands::scroll_snap_coordinate::cascade_property,
        longhands::shape_outside::cascade_property,
        longhands::stroke_dasharray::cascade_property,
        longhands::stroke_dashoffset::cascade_property,
        longhands::stroke_miterlimit::cascade_property,
        longhands::stroke_width::cascade_property,
        longhands::text_align::cascade_property,
        longhands::text_emphasis_position::cascade_property,
        longhands::text_emphasis_style::cascade_property,
        longhands::text_indent::cascade_property,
        longhands::text_overflow::cascade_property,
        longhands::text_shadow::cascade_property,
        longhands::transition_delay::cascade_property,
        longhands::transition_duration::cascade_property,
        longhands::transition_property::cascade_property,
        longhands::transition_timing_function::cascade_property,
        longhands::translate::cascade_property,
        longhands::vertical_align::cascade_property,
        longhands::will_change::cascade_property,
        longhands::word_spacing::cascade_property,
        longhands::_x_lang::cascade_property,
        longhands::overflow_clip_box_block::cascade_property,
        longhands::overflow_clip_box_inline::cascade_property,
        longhands::fill_opacity::cascade_property,
        longhands::stroke_opacity::cascade_property,
        longhands::scroll_snap_points_x::cascade_property,
        longhands::scroll_snap_points_y::cascade_property,
        longhands::_moz_window_transform::cascade_property,
        longhands::transform::cascade_property,
        longhands::clip::cascade_property,
        longhands::_moz_image_region::cascade_property,
        longhands::grid_template_columns::cascade_property,
        longhands::grid_template_rows::cascade_property,
        longhands::object_position::cascade_property,
        longhands::scroll_snap_destination::cascade_property,
        longhands::fill::cascade_property,
        longhands::stroke::cascade_property,
        longhands::grid_auto_columns::cascade_property,
        longhands::grid_auto_rows::cascade_property,
        longhands::_moz_window_transform_origin::cascade_property,
        longhands::transform_origin::cascade_property,
        longhands::max_block_size::cascade_property,
        longhands::max_height::cascade_property,
        longhands::max_inline_size::cascade_property,
        longhands::max_width::cascade_property,
        longhands::flood_color::cascade_property,
        longhands::lighting_color::cascade_property,
        longhands::_moz_font_smoothing_background_color::cascade_property,
        longhands::stop_color::cascade_property,
        longhands::marker_end::cascade_property,
        longhands::marker_mid::cascade_property,
        longhands::marker_start::cascade_property,
        longhands::_moz_binding::cascade_property,
        longhands::grid_column_end::cascade_property,
        longhands::grid_column_start::cascade_property,
        longhands::grid_row_end::cascade_property,
        longhands::grid_row_start::cascade_property,
        longhands::border_bottom_left_radius::cascade_property,
        longhands::border_bottom_right_radius::cascade_property,
        longhands::border_top_left_radius::cascade_property,
        longhands::border_top_right_radius::cascade_property,
        longhands::_moz_outline_radius_bottomleft::cascade_property,
        longhands::_moz_outline_radius_bottomright::cascade_property,
        longhands::_moz_outline_radius_topleft::cascade_property,
        longhands::_moz_outline_radius_topright::cascade_property,
        longhands::block_size::cascade_property,
        longhands::flex_basis::cascade_property,
        longhands::height::cascade_property,
        longhands::inline_size::cascade_property,
        longhands::min_block_size::cascade_property,
        longhands::min_height::cascade_property,
        longhands::min_inline_size::cascade_property,
        longhands::min_width::cascade_property,
        longhands::width::cascade_property,
        longhands::grid_column_gap::cascade_property,
        longhands::grid_row_gap::cascade_property,
        longhands::padding_block_end::cascade_property,
        longhands::padding_block_start::cascade_property,
        longhands::padding_bottom::cascade_property,
        longhands::padding_inline_end::cascade_property,
        longhands::padding_inline_start::cascade_property,
        longhands::padding_left::cascade_property,
        longhands::padding_right::cascade_property,
        longhands::padding_top::cascade_property,
        longhands::border_block_end_width::cascade_property,
        longhands::border_block_start_width::cascade_property,
        longhands::border_bottom_width::cascade_property,
        longhands::border_inline_end_width::cascade_property,
        longhands::border_inline_start_width::cascade_property,
        longhands::border_left_width::cascade_property,
        longhands::border_right_width::cascade_property,
        longhands::border_top_width::cascade_property,
        longhands::column_rule_width::cascade_property,
        longhands::outline_width::cascade_property,
        longhands::_webkit_text_stroke_width::cascade_property,
        longhands::background_color::cascade_property,
        longhands::border_block_end_color::cascade_property,
        longhands::border_block_start_color::cascade_property,
        longhands::border_bottom_color::cascade_property,
        longhands::border_inline_end_color::cascade_property,
        longhands::border_inline_start_color::cascade_property,
        longhands::border_left_color::cascade_property,
        longhands::border_right_color::cascade_property,
        longhands::border_top_color::cascade_property,
        longhands::column_rule_color::cascade_property,
        longhands::outline_color::cascade_property,
        longhands::text_decoration_color::cascade_property,
        longhands::text_emphasis_color::cascade_property,
        longhands::_webkit_text_fill_color::cascade_property,
        longhands::_webkit_text_stroke_color::cascade_property,
        longhands::bottom::cascade_property,
        longhands::left::cascade_property,
        longhands::margin_block_end::cascade_property,
        longhands::margin_block_start::cascade_property,
        longhands::margin_bottom::cascade_property,
        longhands::margin_inline_end::cascade_property,
        longhands::margin_inline_start::cascade_property,
        longhands::margin_left::cascade_property,
        longhands::margin_right::cascade_property,
        longhands::margin_top::cascade_property,
        longhands::offset_block_end::cascade_property,
        longhands::offset_block_start::cascade_property,
        longhands::offset_inline_end::cascade_property,
        longhands::offset_inline_start::cascade_property,
        longhands::right::cascade_property,
        longhands::top::cascade_property,
];

bitflags! {
    /// A set of flags to tweak the behavior of the `cascade` function.
    pub struct CascadeFlags: u8 {
        /// Whether to inherit all styles from the parent. If this flag is not
        /// present, non-inherited styles are reset to their initial values.
        const INHERIT_ALL = 1;

        /// Whether to only cascade properties that are visited dependent.
        const VISITED_DEPENDENT_ONLY = 1 << 1;
    }
}

/// Performs the CSS cascade, computing new styles for an element from its parent style.
///
/// The arguments are:
///
///   * `device`: Used to get the initial viewport and other external state.
///
///   * `rule_node`: The rule node in the tree that represent the CSS rules that
///   matched.
///
///   * `parent_style`: The parent style, if applicable; if `None`, this is the root node.
///
/// Returns the computed values.
///   * `flags`: Various flags.
///
pub fn cascade<E>(
    device: &Device,
    pseudo: Option<&PseudoElement>,
    rule_node: &StrongRuleNode,
    guards: &StylesheetGuards,
    parent_style: Option<&ComputedValues>,
    parent_style_ignoring_first_line: Option<&ComputedValues>,
    layout_parent_style: Option<&ComputedValues>,
    visited_style: Option<Arc<ComputedValues>>,
    font_metrics_provider: &FontMetricsProvider,
    flags: CascadeFlags,
    quirks_mode: QuirksMode,
    rule_cache: Option<&RuleCache>,
    rule_cache_conditions: &mut RuleCacheConditions,
    element: Option<E>,
) -> Arc<ComputedValues>
where
    E: TElement,
{
    debug_assert_eq!(parent_style.is_some(), parent_style_ignoring_first_line.is_some());
    let empty = SmallBitVec::new();

    let property_restriction = pseudo.and_then(|p| p.property_restriction());

    let iter_declarations = || {
        rule_node.self_and_ancestors().flat_map(|node| {
            let cascade_level = node.cascade_level();
            let source = node.style_source();

            let declarations = if source.is_some() {
                source.read(cascade_level.guard(guards)).declaration_importance_iter()
            } else {
                // The root node has no style source.
                DeclarationImportanceIterator::new(&[], &empty)
            };
            let node_importance = node.importance();

            declarations
                // Yield declarations later in source order (with more precedence) first.
                .rev()
                .filter_map(move |(declaration, declaration_importance)| {
                    if let Some(property_restriction) = property_restriction {
                        // declaration.id() is either a longhand or a custom
                        // property.  Custom properties are always allowed, but
                        // longhands are only allowed if they have our
                        // property_restriction flag set.
                        if let PropertyDeclarationId::Longhand(id) = declaration.id() {
                            if !id.flags().contains(property_restriction) {
                                return None
                            }
                        }
                    }

                    if declaration_importance == node_importance {
                        Some((declaration, cascade_level))
                    } else {
                        None
                    }
                })
        })
    };

    apply_declarations(
        device,
        pseudo,
        rule_node,
        guards,
        iter_declarations,
        parent_style,
        parent_style_ignoring_first_line,
        layout_parent_style,
        visited_style,
        font_metrics_provider,
        flags,
        quirks_mode,
        rule_cache,
        rule_cache_conditions,
        element,
    )
}

/// NOTE: This function expects the declaration with more priority to appear
/// first.
pub fn apply_declarations<'a, E, F, I>(
    device: &Device,
    pseudo: Option<&PseudoElement>,
    rules: &StrongRuleNode,
    guards: &StylesheetGuards,
    iter_declarations: F,
    parent_style: Option<&ComputedValues>,
    parent_style_ignoring_first_line: Option<&ComputedValues>,
    layout_parent_style: Option<&ComputedValues>,
    visited_style: Option<Arc<ComputedValues>>,
    font_metrics_provider: &FontMetricsProvider,
    flags: CascadeFlags,
    quirks_mode: QuirksMode,
    rule_cache: Option<&RuleCache>,
    rule_cache_conditions: &mut RuleCacheConditions,
    element: Option<E>,
) -> Arc<ComputedValues>
where
    E: TElement,
    F: Fn() -> I,
    I: Iterator<Item = (&'a PropertyDeclaration, CascadeLevel)>,
{
    debug_assert!(layout_parent_style.is_none() || parent_style.is_some());
    debug_assert_eq!(parent_style.is_some(), parent_style_ignoring_first_line.is_some());
    #[cfg(feature = "gecko")]
    debug_assert!(parent_style.is_none() ||
                  ::std::ptr::eq(parent_style.unwrap(),
                                 parent_style_ignoring_first_line.unwrap()) ||
                  parent_style.unwrap().pseudo() == Some(PseudoElement::FirstLine));
    let (inherited_style, layout_parent_style) = match parent_style {
        Some(parent_style) => {
            (parent_style,
             layout_parent_style.unwrap_or(parent_style))
        },
        None => {
            (device.default_computed_values(),
             device.default_computed_values())
        }
    };

    let custom_properties = {
        let mut builder =
            CustomPropertiesBuilder::new(inherited_style.custom_properties());

        for (declaration, _cascade_level) in iter_declarations() {
            if let PropertyDeclaration::Custom(ref declaration) = *declaration {
                builder.cascade(&declaration.name, declaration.value.borrow());
            }
        }

        builder.build()
    };

    let mut context = computed::Context {
        is_root_element: pseudo.is_none() && element.map_or(false, |e| e.is_root()),
        // We'd really like to own the rules here to avoid refcount traffic, but
        // animation's usage of `apply_declarations` make this tricky. See bug
        // 1375525.
        builder: StyleBuilder::new(
            device,
            parent_style,
            parent_style_ignoring_first_line,
            pseudo,
            flags,
            Some(rules.clone()),
            custom_properties,
            visited_style,
        ),
        cached_system_font: None,
        in_media_query: false,
        for_smil_animation: false,
        for_non_inherited_property: None,
        font_metrics_provider,
        quirks_mode,
        rule_cache_conditions: RefCell::new(rule_cache_conditions),
    };

    let ignore_colors = !device.use_document_colors();

    // Set computed values, overwriting earlier declarations for the same
    // property.
    let mut seen = LonghandIdSet::new();

    // Declaration blocks are stored in increasing precedence order, we want
    // them in decreasing order here.
    //
    // We could (and used to) use a pattern match here, but that bloats this
    // function to over 100K of compiled code!
    //
    // To improve i-cache behavior, we outline the individual functions and use
    // virtual dispatch instead.
    let mut apply_reset = true;
            // Pull these out so that we can compute them in a specific order
            // without introducing more iterations.
            let mut font_size = None;
            let mut font_family = None;
        for (declaration, cascade_level) in iter_declarations() {
            let declaration_id = declaration.id();
            let longhand_id = match declaration_id {
                PropertyDeclarationId::Longhand(id) => id,
                PropertyDeclarationId::Custom(..) => continue,
            };

            // Only a few properties are allowed to depend on the visited state
            // of links.  When cascading visited styles, we can save time by
            // only processing these properties.
            if flags.contains(CascadeFlags::VISITED_DEPENDENT_ONLY) &&
               !longhand_id.is_visited_dependent() {
                continue
            }

            if !apply_reset && !longhand_id.inherited() {
                continue;
            }

            if
                    !
                longhand_id.is_early_property()
            {
                continue
            }

            
            let physical_longhand_id = longhand_id ;
            if seen.contains(physical_longhand_id) {
                continue
            }

            let mut declaration = match *declaration {
                PropertyDeclaration::WithVariables(ref declaration) => {
                    if !declaration.id.inherited() {
                        context.rule_cache_conditions.borrow_mut()
                            .set_uncacheable();
                    }
                    Cow::Owned(declaration.value.substitute_variables(
                        declaration.id,
                        context.builder.custom_properties.as_ref(),
                        context.quirks_mode
                    ))
                }
                ref d => Cow::Borrowed(d)
            };

            // When document colors are disabled, skip properties that are
            // marked as ignored in that mode, unless they come from a UA or
            // user style sheet.
            if ignore_colors &&
               longhand_id.is_ignored_when_document_colors_disabled(
                   cascade_level,
                   context.builder.pseudo
                )
            {
                let non_transparent_background = match *declaration {
                    PropertyDeclaration::BackgroundColor(ref color) => {
                        // Treat background-color a bit differently.  If the specified
                        // color is anything other than a fully transparent color, convert
                        // it into the Device's default background color.
                        color.is_non_transparent()
                    }
                    _ => continue
                };

                // FIXME: moving this out of `match` is a work around for
                // borrows being lexical.
                if non_transparent_background {
                    let color = device.default_background_color();
                    declaration =
                        Cow::Owned(PropertyDeclaration::BackgroundColor(color.into()));
                }
            }

            seen.insert(physical_longhand_id);

                if LonghandId::FontSize == longhand_id {
                    font_size = Some(declaration.clone());
                    continue;
                }
                if LonghandId::FontFamily == longhand_id {
                    font_family = Some(declaration.clone());
                    continue;
                }

            let discriminant = longhand_id as usize;
            (CASCADE_PROPERTY[discriminant])(&*declaration, &mut context);
        }
            let writing_mode =
                WritingMode::new(context.builder.get_inheritedbox());
            context.builder.writing_mode = writing_mode;

            let mut _skip_font_family = false;


                // <svg:text> is not affected by text zoom, and it uses a preshint to
                // disable it. We fix up the struct when this happens by unzooming
                // its contained font values, which will have been zoomed in the parent
                if seen.contains(LonghandId::XTextZoom) {
                    let zoom = context.builder.get_font().gecko().mAllowZoom;
                    let parent_zoom = context.style().get_parent_font().gecko().mAllowZoom;
                    if  zoom != parent_zoom {
                        debug_assert!(!zoom,
                                      "We only ever disable text zoom (in svg:text), never enable it");
                        // can't borrow both device and font, use the take/put machinery
                        let mut font = context.builder.take_font();
                        font.unzoom_fonts(context.device());
                        context.builder.put_font(font);
                    }
                }

                // Whenever a single generic value is specified, gecko will do a bunch of
                // recalculation walking up the rule tree, including handling the font-size stuff.
                // It basically repopulates the font struct with the default font for a given
                // generic and language. We handle the font-size stuff separately, so this boils
                // down to just copying over the font-family lists (no other aspect of the default
                // font can be configured).

                if seen.contains(LonghandId::XLang) || font_family.is_some() {
                    // if just the language changed, the inherited generic is all we need
                    let mut generic = inherited_style.get_font().gecko().mGenericID;
                    if let Some(ref declaration) = font_family {
                        if let PropertyDeclaration::FontFamily(ref fam) = **declaration {
                            if let Some(id) = fam.single_generic() {
                                generic = id;
                                // In case of a specified font family with a single generic, we will
                                // end up setting font family below, but its value would get
                                // overwritten later in the pipeline when cascading.
                                //
                                // We instead skip cascading font-family in that case.
                                //
                                // In case of the language changing, we wish for a specified font-
                                // family to override this, so we do not skip cascading then.
                                _skip_font_family = true;
                            }
                        }
                    }

                    let pres_context = context.builder.device.pres_context();
                    let gecko_font = context.builder.mutate_font().gecko_mut();
                    gecko_font.mGenericID = generic;
                    unsafe {
                        bindings::Gecko_nsStyleFont_PrefillDefaultForGeneric(
                            gecko_font,
                            pres_context,
                            generic,
                        );
                    }
                }

            // It is important that font_size is computed before
            // the late properties (for em units), but after font-family
            // (for the base-font-size dependence for default and keyword font-sizes)
            // Additionally, when we support system fonts they will have to be
            // computed early, and *before* font_family, so I'm including
            // font_family here preemptively instead of keeping it within
            // the early properties.
            //
            // To avoid an extra iteration, we just pull out the property
            // during the early iteration and cascade them in order
            // after it.
            if !_skip_font_family {
                if let Some(ref declaration) = font_family {

                    let discriminant = LonghandId::FontFamily as usize;
                    (CASCADE_PROPERTY[discriminant])(declaration, &mut context);
                        let device = context.builder.device;
                        if let PropertyDeclaration::FontFamily(ref val) = **declaration {
                            if val.get_system().is_some() {
                                let default = context.cached_system_font
                                                     .as_ref().unwrap().default_font_type;
                                context.builder.mutate_font().fixup_system(default);
                            } else {
                                context.builder.mutate_font().fixup_none_generic(device);
                            }
                        }
                }
            }

            if let Some(ref declaration) = font_size {
                let discriminant = LonghandId::FontSize as usize;
                (CASCADE_PROPERTY[discriminant])(declaration, &mut context);
            // Font size must be explicitly inherited to handle lang changes and
            // scriptlevel changes.
            } else if seen.contains(LonghandId::XLang) ||
                      seen.contains(LonghandId::MozScriptLevel) ||
                      seen.contains(LonghandId::MozMinFontSizeRatio) ||
                      font_family.is_some() {
                let discriminant = LonghandId::FontSize as usize;
                let size = PropertyDeclaration::CSSWideKeyword(WideKeywordDeclaration {
                    id: LonghandId::FontSize,
                    keyword: CSSWideKeyword::Inherit,
                });

                (CASCADE_PROPERTY[discriminant])(&size, &mut context);
            }

            if let Some(style) = rule_cache.and_then(|c| c.find(guards, &context.builder)) {
                context.builder.copy_reset_from(style);
                apply_reset = false;
            }
        for (declaration, cascade_level) in iter_declarations() {
            let declaration_id = declaration.id();
            let longhand_id = match declaration_id {
                PropertyDeclarationId::Longhand(id) => id,
                PropertyDeclarationId::Custom(..) => continue,
            };

            // Only a few properties are allowed to depend on the visited state
            // of links.  When cascading visited styles, we can save time by
            // only processing these properties.
            if flags.contains(CascadeFlags::VISITED_DEPENDENT_ONLY) &&
               !longhand_id.is_visited_dependent() {
                continue
            }

            if !apply_reset && !longhand_id.inherited() {
                continue;
            }

            if
                longhand_id.is_early_property()
            {
                continue
            }

            
            let physical_longhand_id = longhand_id .to_physical(writing_mode);
            if seen.contains(physical_longhand_id) {
                continue
            }

            let mut declaration = match *declaration {
                PropertyDeclaration::WithVariables(ref declaration) => {
                    if !declaration.id.inherited() {
                        context.rule_cache_conditions.borrow_mut()
                            .set_uncacheable();
                    }
                    Cow::Owned(declaration.value.substitute_variables(
                        declaration.id,
                        context.builder.custom_properties.as_ref(),
                        context.quirks_mode
                    ))
                }
                ref d => Cow::Borrowed(d)
            };

            // When document colors are disabled, skip properties that are
            // marked as ignored in that mode, unless they come from a UA or
            // user style sheet.
            if ignore_colors &&
               longhand_id.is_ignored_when_document_colors_disabled(
                   cascade_level,
                   context.builder.pseudo
                )
            {
                let non_transparent_background = match *declaration {
                    PropertyDeclaration::BackgroundColor(ref color) => {
                        // Treat background-color a bit differently.  If the specified
                        // color is anything other than a fully transparent color, convert
                        // it into the Device's default background color.
                        color.is_non_transparent()
                    }
                    _ => continue
                };

                // FIXME: moving this out of `match` is a work around for
                // borrows being lexical.
                if non_transparent_background {
                    let color = device.default_background_color();
                    declaration =
                        Cow::Owned(PropertyDeclaration::BackgroundColor(color.into()));
                }
            }

            seen.insert(physical_longhand_id);


            let discriminant = longhand_id as usize;
            (CASCADE_PROPERTY[discriminant])(&*declaration, &mut context);
        }

    let mut builder = context.builder;

        if let Some(ref mut bg) = builder.get_background_if_mutated() {
            bg.fill_arrays();
        }

        if let Some(ref mut svg) = builder.get_svg_if_mutated() {
            svg.fill_arrays();
        }


    builder.clear_modified_reset();

    StyleAdjuster::new(&mut builder).adjust(
        layout_parent_style,
        element,
        flags,
    );

    if builder.modified_reset() || !apply_reset {
        // If we adjusted any reset structs, we can't cache this ComputedValues.
        //
        // Also, if we re-used existing reset structs, don't bother caching it
        // back again. (Aside from being wasted effort, it will be wrong, since
        // context.rule_cache_conditions won't be set appropriately if we
        // didn't compute those reset properties.)
        context.rule_cache_conditions.borrow_mut()
            .set_uncacheable();
    }

    builder.build()
}

/// See StyleAdjuster::adjust_for_border_width.
pub fn adjust_border_width(style: &mut StyleBuilder) {
        // Like calling to_computed_value, which wouldn't type check.
        if style.get_border().clone_border_top_style().none_or_hidden() &&
           style.get_border().border_top_has_nonzero_width() {
            style.set_border_top_width(NonNegativeLength::zero());
        }
        // Like calling to_computed_value, which wouldn't type check.
        if style.get_border().clone_border_right_style().none_or_hidden() &&
           style.get_border().border_right_has_nonzero_width() {
            style.set_border_right_width(NonNegativeLength::zero());
        }
        // Like calling to_computed_value, which wouldn't type check.
        if style.get_border().clone_border_bottom_style().none_or_hidden() &&
           style.get_border().border_bottom_has_nonzero_width() {
            style.set_border_bottom_width(NonNegativeLength::zero());
        }
        // Like calling to_computed_value, which wouldn't type check.
        if style.get_border().clone_border_left_style().none_or_hidden() &&
           style.get_border().border_left_has_nonzero_width() {
            style.set_border_left_width(NonNegativeLength::zero());
        }
}

/// An identifier for a given alias property.
#[derive(Clone, Copy, Eq, PartialEq)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub enum AliasId {
        /// -webkit-background-clip
        WebkitBackgroundClip = 0,
        /// -webkit-background-origin
        WebkitBackgroundOrigin = 1,
        /// -webkit-background-size
        WebkitBackgroundSize = 2,
        /// -moz-border-start-color
        MozBorderStartColor = 3,
        /// -moz-border-start-style
        MozBorderStartStyle = 4,
        /// -moz-border-start-width
        MozBorderStartWidth = 5,
        /// -moz-border-end-color
        MozBorderEndColor = 6,
        /// -moz-border-end-style
        MozBorderEndStyle = 7,
        /// -moz-border-end-width
        MozBorderEndWidth = 8,
        /// -webkit-border-top-left-radius
        WebkitBorderTopLeftRadius = 9,
        /// -webkit-border-top-right-radius
        WebkitBorderTopRightRadius = 10,
        /// -webkit-border-bottom-right-radius
        WebkitBorderBottomRightRadius = 11,
        /// -webkit-border-bottom-left-radius
        WebkitBorderBottomLeftRadius = 12,
        /// -moz-transition-duration
        MozTransitionDuration = 13,
        /// -webkit-transition-duration
        WebkitTransitionDuration = 14,
        /// -moz-transition-timing-function
        MozTransitionTimingFunction = 15,
        /// -webkit-transition-timing-function
        WebkitTransitionTimingFunction = 16,
        /// -moz-transition-property
        MozTransitionProperty = 17,
        /// -webkit-transition-property
        WebkitTransitionProperty = 18,
        /// -moz-transition-delay
        MozTransitionDelay = 19,
        /// -webkit-transition-delay
        WebkitTransitionDelay = 20,
        /// -moz-animation-name
        MozAnimationName = 21,
        /// -webkit-animation-name
        WebkitAnimationName = 22,
        /// -moz-animation-duration
        MozAnimationDuration = 23,
        /// -webkit-animation-duration
        WebkitAnimationDuration = 24,
        /// -moz-animation-timing-function
        MozAnimationTimingFunction = 25,
        /// -webkit-animation-timing-function
        WebkitAnimationTimingFunction = 26,
        /// -moz-animation-iteration-count
        MozAnimationIterationCount = 27,
        /// -webkit-animation-iteration-count
        WebkitAnimationIterationCount = 28,
        /// -moz-animation-direction
        MozAnimationDirection = 29,
        /// -webkit-animation-direction
        WebkitAnimationDirection = 30,
        /// -moz-animation-play-state
        MozAnimationPlayState = 31,
        /// -webkit-animation-play-state
        WebkitAnimationPlayState = 32,
        /// -moz-animation-fill-mode
        MozAnimationFillMode = 33,
        /// -webkit-animation-fill-mode
        WebkitAnimationFillMode = 34,
        /// -moz-animation-delay
        MozAnimationDelay = 35,
        /// -webkit-animation-delay
        WebkitAnimationDelay = 36,
        /// -webkit-transform
        WebkitTransform = 37,
        /// -moz-transform
        MozTransform = 38,
        /// -moz-perspective
        MozPerspective = 39,
        /// -webkit-perspective
        WebkitPerspective = 40,
        /// -moz-perspective-origin
        MozPerspectiveOrigin = 41,
        /// -webkit-perspective-origin
        WebkitPerspectiveOrigin = 42,
        /// -moz-backface-visibility
        MozBackfaceVisibility = 43,
        /// -webkit-backface-visibility
        WebkitBackfaceVisibility = 44,
        /// -moz-transform-style
        MozTransformStyle = 45,
        /// -webkit-transform-style
        WebkitTransformStyle = 46,
        /// -moz-transform-origin
        MozTransformOrigin = 47,
        /// -webkit-transform-origin
        WebkitTransformOrigin = 48,
        /// -moz-column-width
        MozColumnWidth = 49,
        /// -moz-column-count
        MozColumnCount = 50,
        /// -moz-column-gap
        MozColumnGap = 51,
        /// -moz-column-fill
        MozColumnFill = 52,
        /// -moz-column-rule-width
        MozColumnRuleWidth = 53,
        /// -moz-column-rule-color
        MozColumnRuleColor = 54,
        /// -moz-column-span
        MozColumnSpan = 55,
        /// -moz-column-rule-style
        MozColumnRuleStyle = 56,
        /// -webkit-box-shadow
        WebkitBoxShadow = 57,
        /// -webkit-filter
        WebkitFilter = 58,
        /// -moz-font-feature-settings
        MozFontFeatureSettings = 59,
        /// -moz-font-language-override
        MozFontLanguageOverride = 60,
        /// -moz-hyphens
        MozHyphens = 61,
        /// -webkit-text-size-adjust
        WebkitTextSizeAdjust = 62,
        /// word-wrap
        WordWrap = 63,
        /// -moz-margin-start
        MozMarginStart = 64,
        /// -moz-margin-end
        MozMarginEnd = 65,
        /// -moz-padding-start
        MozPaddingStart = 66,
        /// -moz-padding-end
        MozPaddingEnd = 67,
        /// -webkit-flex-direction
        WebkitFlexDirection = 68,
        /// -webkit-flex-wrap
        WebkitFlexWrap = 69,
        /// -webkit-justify-content
        WebkitJustifyContent = 70,
        /// -webkit-align-content
        WebkitAlignContent = 71,
        /// -webkit-align-items
        WebkitAlignItems = 72,
        /// -webkit-flex-grow
        WebkitFlexGrow = 73,
        /// -webkit-flex-shrink
        WebkitFlexShrink = 74,
        /// -webkit-align-self
        WebkitAlignSelf = 75,
        /// -webkit-order
        WebkitOrder = 76,
        /// -webkit-flex-basis
        WebkitFlexBasis = 77,
        /// -moz-box-sizing
        MozBoxSizing = 78,
        /// -webkit-box-sizing
        WebkitBoxSizing = 79,
        /// -webkit-user-select
        WebkitUserSelect = 80,
        /// -webkit-mask-repeat
        WebkitMaskRepeat = 81,
        /// -webkit-mask-position-x
        WebkitMaskPositionX = 82,
        /// -webkit-mask-position-y
        WebkitMaskPositionY = 83,
        /// -webkit-mask-clip
        WebkitMaskClip = 84,
        /// -webkit-mask-origin
        WebkitMaskOrigin = 85,
        /// -webkit-mask-size
        WebkitMaskSize = 86,
        /// -webkit-mask-composite
        WebkitMaskComposite = 87,
        /// -webkit-mask-image
        WebkitMaskImage = 88,
        /// -webkit-box-align
        WebkitBoxAlign = 89,
        /// -webkit-box-direction
        WebkitBoxDirection = 90,
        /// -webkit-box-flex
        WebkitBoxFlex = 91,
        /// -webkit-box-orient
        WebkitBoxOrient = 92,
        /// -webkit-box-pack
        WebkitBoxPack = 93,
        /// -webkit-box-ordinal-group
        WebkitBoxOrdinalGroup = 94,
        /// -moz-border-start
        MozBorderStart = 95,
        /// -moz-border-end
        MozBorderEnd = 96,
        /// -webkit-border-radius
        WebkitBorderRadius = 97,
        /// -moz-border-image
        MozBorderImage = 98,
        /// -webkit-border-image
        WebkitBorderImage = 99,
        /// -moz-transition
        MozTransition = 100,
        /// -webkit-transition
        WebkitTransition = 101,
        /// -moz-animation
        MozAnimation = 102,
        /// -webkit-animation
        WebkitAnimation = 103,
        /// -moz-columns
        MozColumns = 104,
        /// -moz-column-rule
        MozColumnRule = 105,
        /// -webkit-mask
        WebkitMask = 106,
        /// -webkit-mask-position
        WebkitMaskPosition = 107,
        /// -webkit-flex-flow
        WebkitFlexFlow = 108,
        /// -webkit-flex
        WebkitFlex = 109,
}

impl fmt::Debug for AliasId {
    fn fmt(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
        let name = match *self {
                AliasId::WebkitBackgroundClip => "WebkitBackgroundClip",
                AliasId::WebkitBackgroundOrigin => "WebkitBackgroundOrigin",
                AliasId::WebkitBackgroundSize => "WebkitBackgroundSize",
                AliasId::MozBorderStartColor => "MozBorderStartColor",
                AliasId::MozBorderStartStyle => "MozBorderStartStyle",
                AliasId::MozBorderStartWidth => "MozBorderStartWidth",
                AliasId::MozBorderEndColor => "MozBorderEndColor",
                AliasId::MozBorderEndStyle => "MozBorderEndStyle",
                AliasId::MozBorderEndWidth => "MozBorderEndWidth",
                AliasId::WebkitBorderTopLeftRadius => "WebkitBorderTopLeftRadius",
                AliasId::WebkitBorderTopRightRadius => "WebkitBorderTopRightRadius",
                AliasId::WebkitBorderBottomRightRadius => "WebkitBorderBottomRightRadius",
                AliasId::WebkitBorderBottomLeftRadius => "WebkitBorderBottomLeftRadius",
                AliasId::MozTransitionDuration => "MozTransitionDuration",
                AliasId::WebkitTransitionDuration => "WebkitTransitionDuration",
                AliasId::MozTransitionTimingFunction => "MozTransitionTimingFunction",
                AliasId::WebkitTransitionTimingFunction => "WebkitTransitionTimingFunction",
                AliasId::MozTransitionProperty => "MozTransitionProperty",
                AliasId::WebkitTransitionProperty => "WebkitTransitionProperty",
                AliasId::MozTransitionDelay => "MozTransitionDelay",
                AliasId::WebkitTransitionDelay => "WebkitTransitionDelay",
                AliasId::MozAnimationName => "MozAnimationName",
                AliasId::WebkitAnimationName => "WebkitAnimationName",
                AliasId::MozAnimationDuration => "MozAnimationDuration",
                AliasId::WebkitAnimationDuration => "WebkitAnimationDuration",
                AliasId::MozAnimationTimingFunction => "MozAnimationTimingFunction",
                AliasId::WebkitAnimationTimingFunction => "WebkitAnimationTimingFunction",
                AliasId::MozAnimationIterationCount => "MozAnimationIterationCount",
                AliasId::WebkitAnimationIterationCount => "WebkitAnimationIterationCount",
                AliasId::MozAnimationDirection => "MozAnimationDirection",
                AliasId::WebkitAnimationDirection => "WebkitAnimationDirection",
                AliasId::MozAnimationPlayState => "MozAnimationPlayState",
                AliasId::WebkitAnimationPlayState => "WebkitAnimationPlayState",
                AliasId::MozAnimationFillMode => "MozAnimationFillMode",
                AliasId::WebkitAnimationFillMode => "WebkitAnimationFillMode",
                AliasId::MozAnimationDelay => "MozAnimationDelay",
                AliasId::WebkitAnimationDelay => "WebkitAnimationDelay",
                AliasId::WebkitTransform => "WebkitTransform",
                AliasId::MozTransform => "MozTransform",
                AliasId::MozPerspective => "MozPerspective",
                AliasId::WebkitPerspective => "WebkitPerspective",
                AliasId::MozPerspectiveOrigin => "MozPerspectiveOrigin",
                AliasId::WebkitPerspectiveOrigin => "WebkitPerspectiveOrigin",
                AliasId::MozBackfaceVisibility => "MozBackfaceVisibility",
                AliasId::WebkitBackfaceVisibility => "WebkitBackfaceVisibility",
                AliasId::MozTransformStyle => "MozTransformStyle",
                AliasId::WebkitTransformStyle => "WebkitTransformStyle",
                AliasId::MozTransformOrigin => "MozTransformOrigin",
                AliasId::WebkitTransformOrigin => "WebkitTransformOrigin",
                AliasId::MozColumnWidth => "MozColumnWidth",
                AliasId::MozColumnCount => "MozColumnCount",
                AliasId::MozColumnGap => "MozColumnGap",
                AliasId::MozColumnFill => "MozColumnFill",
                AliasId::MozColumnRuleWidth => "MozColumnRuleWidth",
                AliasId::MozColumnRuleColor => "MozColumnRuleColor",
                AliasId::MozColumnSpan => "MozColumnSpan",
                AliasId::MozColumnRuleStyle => "MozColumnRuleStyle",
                AliasId::WebkitBoxShadow => "WebkitBoxShadow",
                AliasId::WebkitFilter => "WebkitFilter",
                AliasId::MozFontFeatureSettings => "MozFontFeatureSettings",
                AliasId::MozFontLanguageOverride => "MozFontLanguageOverride",
                AliasId::MozHyphens => "MozHyphens",
                AliasId::WebkitTextSizeAdjust => "WebkitTextSizeAdjust",
                AliasId::WordWrap => "WordWrap",
                AliasId::MozMarginStart => "MozMarginStart",
                AliasId::MozMarginEnd => "MozMarginEnd",
                AliasId::MozPaddingStart => "MozPaddingStart",
                AliasId::MozPaddingEnd => "MozPaddingEnd",
                AliasId::WebkitFlexDirection => "WebkitFlexDirection",
                AliasId::WebkitFlexWrap => "WebkitFlexWrap",
                AliasId::WebkitJustifyContent => "WebkitJustifyContent",
                AliasId::WebkitAlignContent => "WebkitAlignContent",
                AliasId::WebkitAlignItems => "WebkitAlignItems",
                AliasId::WebkitFlexGrow => "WebkitFlexGrow",
                AliasId::WebkitFlexShrink => "WebkitFlexShrink",
                AliasId::WebkitAlignSelf => "WebkitAlignSelf",
                AliasId::WebkitOrder => "WebkitOrder",
                AliasId::WebkitFlexBasis => "WebkitFlexBasis",
                AliasId::MozBoxSizing => "MozBoxSizing",
                AliasId::WebkitBoxSizing => "WebkitBoxSizing",
                AliasId::WebkitUserSelect => "WebkitUserSelect",
                AliasId::WebkitMaskRepeat => "WebkitMaskRepeat",
                AliasId::WebkitMaskPositionX => "WebkitMaskPositionX",
                AliasId::WebkitMaskPositionY => "WebkitMaskPositionY",
                AliasId::WebkitMaskClip => "WebkitMaskClip",
                AliasId::WebkitMaskOrigin => "WebkitMaskOrigin",
                AliasId::WebkitMaskSize => "WebkitMaskSize",
                AliasId::WebkitMaskComposite => "WebkitMaskComposite",
                AliasId::WebkitMaskImage => "WebkitMaskImage",
                AliasId::WebkitBoxAlign => "WebkitBoxAlign",
                AliasId::WebkitBoxDirection => "WebkitBoxDirection",
                AliasId::WebkitBoxFlex => "WebkitBoxFlex",
                AliasId::WebkitBoxOrient => "WebkitBoxOrient",
                AliasId::WebkitBoxPack => "WebkitBoxPack",
                AliasId::WebkitBoxOrdinalGroup => "WebkitBoxOrdinalGroup",
                AliasId::MozBorderStart => "MozBorderStart",
                AliasId::MozBorderEnd => "MozBorderEnd",
                AliasId::WebkitBorderRadius => "WebkitBorderRadius",
                AliasId::MozBorderImage => "MozBorderImage",
                AliasId::WebkitBorderImage => "WebkitBorderImage",
                AliasId::MozTransition => "MozTransition",
                AliasId::WebkitTransition => "WebkitTransition",
                AliasId::MozAnimation => "MozAnimation",
                AliasId::WebkitAnimation => "WebkitAnimation",
                AliasId::MozColumns => "MozColumns",
                AliasId::MozColumnRule => "MozColumnRule",
                AliasId::WebkitMask => "WebkitMask",
                AliasId::WebkitMaskPosition => "WebkitMaskPosition",
                AliasId::WebkitFlexFlow => "WebkitFlexFlow",
                AliasId::WebkitFlex => "WebkitFlex",
        };
        formatter.write_str(name)
    }
}

/// Callers are responsible to deal with prefs.
#[macro_export]
macro_rules! css_properties_accessors {
    ($macro_name: ident) => {
        $macro_name! {
                                [Align_content, SetAlign_content,
                                 PropertyId::Longhand(LonghandId::AlignContent)],
                            [AlignContent, SetAlignContent,
                             PropertyId::Longhand(LonghandId::AlignContent)],
                                [_webkit_align_content, Set_webkit_align_content,
                                 PropertyId::Longhand(LonghandId::AlignContent)],
                            [WebkitAlignContent, SetWebkitAlignContent,
                             PropertyId::Longhand(LonghandId::AlignContent)],
                                [Align_items, SetAlign_items,
                                 PropertyId::Longhand(LonghandId::AlignItems)],
                            [AlignItems, SetAlignItems,
                             PropertyId::Longhand(LonghandId::AlignItems)],
                                [_webkit_align_items, Set_webkit_align_items,
                                 PropertyId::Longhand(LonghandId::AlignItems)],
                            [WebkitAlignItems, SetWebkitAlignItems,
                             PropertyId::Longhand(LonghandId::AlignItems)],
                                [Align_self, SetAlign_self,
                                 PropertyId::Longhand(LonghandId::AlignSelf)],
                            [AlignSelf, SetAlignSelf,
                             PropertyId::Longhand(LonghandId::AlignSelf)],
                                [_webkit_align_self, Set_webkit_align_self,
                                 PropertyId::Longhand(LonghandId::AlignSelf)],
                            [WebkitAlignSelf, SetWebkitAlignSelf,
                             PropertyId::Longhand(LonghandId::AlignSelf)],
                                [Backface_visibility, SetBackface_visibility,
                                 PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                            [BackfaceVisibility, SetBackfaceVisibility,
                             PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                                [_moz_backface_visibility, Set_moz_backface_visibility,
                                 PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                            [MozBackfaceVisibility, SetMozBackfaceVisibility,
                             PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                                [_webkit_backface_visibility, Set_webkit_backface_visibility,
                                 PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                            [WebkitBackfaceVisibility, SetWebkitBackfaceVisibility,
                             PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                                [Border_collapse, SetBorder_collapse,
                                 PropertyId::Longhand(LonghandId::BorderCollapse)],
                            [BorderCollapse, SetBorderCollapse,
                             PropertyId::Longhand(LonghandId::BorderCollapse)],
                                [Border_image_repeat, SetBorder_image_repeat,
                                 PropertyId::Longhand(LonghandId::BorderImageRepeat)],
                            [BorderImageRepeat, SetBorderImageRepeat,
                             PropertyId::Longhand(LonghandId::BorderImageRepeat)],
                                [Box_decoration_break, SetBox_decoration_break,
                                 PropertyId::Longhand(LonghandId::BoxDecorationBreak)],
                            [BoxDecorationBreak, SetBoxDecorationBreak,
                             PropertyId::Longhand(LonghandId::BoxDecorationBreak)],
                                [Box_sizing, SetBox_sizing,
                                 PropertyId::Longhand(LonghandId::BoxSizing)],
                            [BoxSizing, SetBoxSizing,
                             PropertyId::Longhand(LonghandId::BoxSizing)],
                                [_moz_box_sizing, Set_moz_box_sizing,
                                 PropertyId::Longhand(LonghandId::BoxSizing)],
                            [MozBoxSizing, SetMozBoxSizing,
                             PropertyId::Longhand(LonghandId::BoxSizing)],
                                [_webkit_box_sizing, Set_webkit_box_sizing,
                                 PropertyId::Longhand(LonghandId::BoxSizing)],
                            [WebkitBoxSizing, SetWebkitBoxSizing,
                             PropertyId::Longhand(LonghandId::BoxSizing)],
                                [Caption_side, SetCaption_side,
                                 PropertyId::Longhand(LonghandId::CaptionSide)],
                            [CaptionSide, SetCaptionSide,
                             PropertyId::Longhand(LonghandId::CaptionSide)],
                            [Clear, SetClear,
                             PropertyId::Longhand(LonghandId::Clear)],
                                [Clip_rule, SetClip_rule,
                                 PropertyId::Longhand(LonghandId::ClipRule)],
                            [ClipRule, SetClipRule,
                             PropertyId::Longhand(LonghandId::ClipRule)],
                                [Color_adjust, SetColor_adjust,
                                 PropertyId::Longhand(LonghandId::ColorAdjust)],
                            [ColorAdjust, SetColorAdjust,
                             PropertyId::Longhand(LonghandId::ColorAdjust)],
                                [Color_interpolation, SetColor_interpolation,
                                 PropertyId::Longhand(LonghandId::ColorInterpolation)],
                            [ColorInterpolation, SetColorInterpolation,
                             PropertyId::Longhand(LonghandId::ColorInterpolation)],
                                [Color_interpolation_filters, SetColor_interpolation_filters,
                                 PropertyId::Longhand(LonghandId::ColorInterpolationFilters)],
                            [ColorInterpolationFilters, SetColorInterpolationFilters,
                             PropertyId::Longhand(LonghandId::ColorInterpolationFilters)],
                                [Column_count, SetColumn_count,
                                 PropertyId::Longhand(LonghandId::ColumnCount)],
                            [ColumnCount, SetColumnCount,
                             PropertyId::Longhand(LonghandId::ColumnCount)],
                                [_moz_column_count, Set_moz_column_count,
                                 PropertyId::Longhand(LonghandId::ColumnCount)],
                            [MozColumnCount, SetMozColumnCount,
                             PropertyId::Longhand(LonghandId::ColumnCount)],
                                [Column_fill, SetColumn_fill,
                                 PropertyId::Longhand(LonghandId::ColumnFill)],
                            [ColumnFill, SetColumnFill,
                             PropertyId::Longhand(LonghandId::ColumnFill)],
                                [_moz_column_fill, Set_moz_column_fill,
                                 PropertyId::Longhand(LonghandId::ColumnFill)],
                            [MozColumnFill, SetMozColumnFill,
                             PropertyId::Longhand(LonghandId::ColumnFill)],
                                [Column_rule_style, SetColumn_rule_style,
                                 PropertyId::Longhand(LonghandId::ColumnRuleStyle)],
                            [ColumnRuleStyle, SetColumnRuleStyle,
                             PropertyId::Longhand(LonghandId::ColumnRuleStyle)],
                                [_moz_column_rule_style, Set_moz_column_rule_style,
                                 PropertyId::Longhand(LonghandId::ColumnRuleStyle)],
                            [MozColumnRuleStyle, SetMozColumnRuleStyle,
                             PropertyId::Longhand(LonghandId::ColumnRuleStyle)],
                                [Column_span, SetColumn_span,
                                 PropertyId::Longhand(LonghandId::ColumnSpan)],
                            [ColumnSpan, SetColumnSpan,
                             PropertyId::Longhand(LonghandId::ColumnSpan)],
                                [_moz_column_span, Set_moz_column_span,
                                 PropertyId::Longhand(LonghandId::ColumnSpan)],
                            [MozColumnSpan, SetMozColumnSpan,
                             PropertyId::Longhand(LonghandId::ColumnSpan)],
                            [Contain, SetContain,
                             PropertyId::Longhand(LonghandId::Contain)],
                            [Direction, SetDirection,
                             PropertyId::Longhand(LonghandId::Direction)],
                                [Dominant_baseline, SetDominant_baseline,
                                 PropertyId::Longhand(LonghandId::DominantBaseline)],
                            [DominantBaseline, SetDominantBaseline,
                             PropertyId::Longhand(LonghandId::DominantBaseline)],
                                [Empty_cells, SetEmpty_cells,
                                 PropertyId::Longhand(LonghandId::EmptyCells)],
                            [EmptyCells, SetEmptyCells,
                             PropertyId::Longhand(LonghandId::EmptyCells)],
                                [Fill_rule, SetFill_rule,
                                 PropertyId::Longhand(LonghandId::FillRule)],
                            [FillRule, SetFillRule,
                             PropertyId::Longhand(LonghandId::FillRule)],
                                [Flex_direction, SetFlex_direction,
                                 PropertyId::Longhand(LonghandId::FlexDirection)],
                            [FlexDirection, SetFlexDirection,
                             PropertyId::Longhand(LonghandId::FlexDirection)],
                                [_webkit_flex_direction, Set_webkit_flex_direction,
                                 PropertyId::Longhand(LonghandId::FlexDirection)],
                            [WebkitFlexDirection, SetWebkitFlexDirection,
                             PropertyId::Longhand(LonghandId::FlexDirection)],
                                [Flex_wrap, SetFlex_wrap,
                                 PropertyId::Longhand(LonghandId::FlexWrap)],
                            [FlexWrap, SetFlexWrap,
                             PropertyId::Longhand(LonghandId::FlexWrap)],
                                [_webkit_flex_wrap, Set_webkit_flex_wrap,
                                 PropertyId::Longhand(LonghandId::FlexWrap)],
                            [WebkitFlexWrap, SetWebkitFlexWrap,
                             PropertyId::Longhand(LonghandId::FlexWrap)],
                            [Float, SetFloat,
                             PropertyId::Longhand(LonghandId::Float)],
                                [Font_kerning, SetFont_kerning,
                                 PropertyId::Longhand(LonghandId::FontKerning)],
                            [FontKerning, SetFontKerning,
                             PropertyId::Longhand(LonghandId::FontKerning)],
                                [Font_optical_sizing, SetFont_optical_sizing,
                                 PropertyId::Longhand(LonghandId::FontOpticalSizing)],
                            [FontOpticalSizing, SetFontOpticalSizing,
                             PropertyId::Longhand(LonghandId::FontOpticalSizing)],
                                [Font_stretch, SetFont_stretch,
                                 PropertyId::Longhand(LonghandId::FontStretch)],
                            [FontStretch, SetFontStretch,
                             PropertyId::Longhand(LonghandId::FontStretch)],
                                [Font_style, SetFont_style,
                                 PropertyId::Longhand(LonghandId::FontStyle)],
                            [FontStyle, SetFontStyle,
                             PropertyId::Longhand(LonghandId::FontStyle)],
                                [Font_synthesis, SetFont_synthesis,
                                 PropertyId::Longhand(LonghandId::FontSynthesis)],
                            [FontSynthesis, SetFontSynthesis,
                             PropertyId::Longhand(LonghandId::FontSynthesis)],
                                [Font_variant_caps, SetFont_variant_caps,
                                 PropertyId::Longhand(LonghandId::FontVariantCaps)],
                            [FontVariantCaps, SetFontVariantCaps,
                             PropertyId::Longhand(LonghandId::FontVariantCaps)],
                                [Font_variant_position, SetFont_variant_position,
                                 PropertyId::Longhand(LonghandId::FontVariantPosition)],
                            [FontVariantPosition, SetFontVariantPosition,
                             PropertyId::Longhand(LonghandId::FontVariantPosition)],
                                [Font_weight, SetFont_weight,
                                 PropertyId::Longhand(LonghandId::FontWeight)],
                            [FontWeight, SetFontWeight,
                             PropertyId::Longhand(LonghandId::FontWeight)],
                                [Grid_auto_flow, SetGrid_auto_flow,
                                 PropertyId::Longhand(LonghandId::GridAutoFlow)],
                            [GridAutoFlow, SetGridAutoFlow,
                             PropertyId::Longhand(LonghandId::GridAutoFlow)],
                            [Hyphens, SetHyphens,
                             PropertyId::Longhand(LonghandId::Hyphens)],
                                [_moz_hyphens, Set_moz_hyphens,
                                 PropertyId::Longhand(LonghandId::Hyphens)],
                            [MozHyphens, SetMozHyphens,
                             PropertyId::Longhand(LonghandId::Hyphens)],
                                [Image_orientation, SetImage_orientation,
                                 PropertyId::Longhand(LonghandId::ImageOrientation)],
                            [ImageOrientation, SetImageOrientation,
                             PropertyId::Longhand(LonghandId::ImageOrientation)],
                                [Image_rendering, SetImage_rendering,
                                 PropertyId::Longhand(LonghandId::ImageRendering)],
                            [ImageRendering, SetImageRendering,
                             PropertyId::Longhand(LonghandId::ImageRendering)],
                                [Ime_mode, SetIme_mode,
                                 PropertyId::Longhand(LonghandId::ImeMode)],
                            [ImeMode, SetImeMode,
                             PropertyId::Longhand(LonghandId::ImeMode)],
                                [Initial_letter, SetInitial_letter,
                                 PropertyId::Longhand(LonghandId::InitialLetter)],
                            [InitialLetter, SetInitialLetter,
                             PropertyId::Longhand(LonghandId::InitialLetter)],
                            [Isolation, SetIsolation,
                             PropertyId::Longhand(LonghandId::Isolation)],
                                [Justify_content, SetJustify_content,
                                 PropertyId::Longhand(LonghandId::JustifyContent)],
                            [JustifyContent, SetJustifyContent,
                             PropertyId::Longhand(LonghandId::JustifyContent)],
                                [_webkit_justify_content, Set_webkit_justify_content,
                                 PropertyId::Longhand(LonghandId::JustifyContent)],
                            [WebkitJustifyContent, SetWebkitJustifyContent,
                             PropertyId::Longhand(LonghandId::JustifyContent)],
                                [Justify_items, SetJustify_items,
                                 PropertyId::Longhand(LonghandId::JustifyItems)],
                            [JustifyItems, SetJustifyItems,
                             PropertyId::Longhand(LonghandId::JustifyItems)],
                                [Justify_self, SetJustify_self,
                                 PropertyId::Longhand(LonghandId::JustifySelf)],
                            [JustifySelf, SetJustifySelf,
                             PropertyId::Longhand(LonghandId::JustifySelf)],
                                [List_style_position, SetList_style_position,
                                 PropertyId::Longhand(LonghandId::ListStylePosition)],
                            [ListStylePosition, SetListStylePosition,
                             PropertyId::Longhand(LonghandId::ListStylePosition)],
                                [Mask_type, SetMask_type,
                                 PropertyId::Longhand(LonghandId::MaskType)],
                            [MaskType, SetMaskType,
                             PropertyId::Longhand(LonghandId::MaskType)],
                                [Mix_blend_mode, SetMix_blend_mode,
                                 PropertyId::Longhand(LonghandId::MixBlendMode)],
                            [MixBlendMode, SetMixBlendMode,
                             PropertyId::Longhand(LonghandId::MixBlendMode)],
                                [_moz_appearance, Set_moz_appearance,
                                 PropertyId::Longhand(LonghandId::MozAppearance)],
                            [MozAppearance, SetMozAppearance,
                             PropertyId::Longhand(LonghandId::MozAppearance)],
                                [_moz_box_align, Set_moz_box_align,
                                 PropertyId::Longhand(LonghandId::MozBoxAlign)],
                            [MozBoxAlign, SetMozBoxAlign,
                             PropertyId::Longhand(LonghandId::MozBoxAlign)],
                                [_webkit_box_align, Set_webkit_box_align,
                                 PropertyId::Longhand(LonghandId::MozBoxAlign)],
                            [WebkitBoxAlign, SetWebkitBoxAlign,
                             PropertyId::Longhand(LonghandId::MozBoxAlign)],
                                [_moz_box_direction, Set_moz_box_direction,
                                 PropertyId::Longhand(LonghandId::MozBoxDirection)],
                            [MozBoxDirection, SetMozBoxDirection,
                             PropertyId::Longhand(LonghandId::MozBoxDirection)],
                                [_webkit_box_direction, Set_webkit_box_direction,
                                 PropertyId::Longhand(LonghandId::MozBoxDirection)],
                            [WebkitBoxDirection, SetWebkitBoxDirection,
                             PropertyId::Longhand(LonghandId::MozBoxDirection)],
                                [_moz_box_orient, Set_moz_box_orient,
                                 PropertyId::Longhand(LonghandId::MozBoxOrient)],
                            [MozBoxOrient, SetMozBoxOrient,
                             PropertyId::Longhand(LonghandId::MozBoxOrient)],
                                [_webkit_box_orient, Set_webkit_box_orient,
                                 PropertyId::Longhand(LonghandId::MozBoxOrient)],
                            [WebkitBoxOrient, SetWebkitBoxOrient,
                             PropertyId::Longhand(LonghandId::MozBoxOrient)],
                                [_moz_box_pack, Set_moz_box_pack,
                                 PropertyId::Longhand(LonghandId::MozBoxPack)],
                            [MozBoxPack, SetMozBoxPack,
                             PropertyId::Longhand(LonghandId::MozBoxPack)],
                                [_webkit_box_pack, Set_webkit_box_pack,
                                 PropertyId::Longhand(LonghandId::MozBoxPack)],
                            [WebkitBoxPack, SetWebkitBoxPack,
                             PropertyId::Longhand(LonghandId::MozBoxPack)],
                                [_moz_control_character_visibility, Set_moz_control_character_visibility,
                                 PropertyId::Longhand(LonghandId::MozControlCharacterVisibility)],
                            [MozControlCharacterVisibility, SetMozControlCharacterVisibility,
                             PropertyId::Longhand(LonghandId::MozControlCharacterVisibility)],
                                [_moz_float_edge, Set_moz_float_edge,
                                 PropertyId::Longhand(LonghandId::MozFloatEdge)],
                            [MozFloatEdge, SetMozFloatEdge,
                             PropertyId::Longhand(LonghandId::MozFloatEdge)],
                                [_moz_force_broken_image_icon, Set_moz_force_broken_image_icon,
                                 PropertyId::Longhand(LonghandId::MozForceBrokenImageIcon)],
                            [MozForceBrokenImageIcon, SetMozForceBrokenImageIcon,
                             PropertyId::Longhand(LonghandId::MozForceBrokenImageIcon)],
                                [_moz_orient, Set_moz_orient,
                                 PropertyId::Longhand(LonghandId::MozOrient)],
                            [MozOrient, SetMozOrient,
                             PropertyId::Longhand(LonghandId::MozOrient)],
                                [_moz_osx_font_smoothing, Set_moz_osx_font_smoothing,
                                 PropertyId::Longhand(LonghandId::MozOsxFontSmoothing)],
                            [MozOsxFontSmoothing, SetMozOsxFontSmoothing,
                             PropertyId::Longhand(LonghandId::MozOsxFontSmoothing)],
                                [_moz_stack_sizing, Set_moz_stack_sizing,
                                 PropertyId::Longhand(LonghandId::MozStackSizing)],
                            [MozStackSizing, SetMozStackSizing,
                             PropertyId::Longhand(LonghandId::MozStackSizing)],
                                [_moz_text_size_adjust, Set_moz_text_size_adjust,
                                 PropertyId::Longhand(LonghandId::MozTextSizeAdjust)],
                            [MozTextSizeAdjust, SetMozTextSizeAdjust,
                             PropertyId::Longhand(LonghandId::MozTextSizeAdjust)],
                                [_webkit_text_size_adjust, Set_webkit_text_size_adjust,
                                 PropertyId::Longhand(LonghandId::MozTextSizeAdjust)],
                            [WebkitTextSizeAdjust, SetWebkitTextSizeAdjust,
                             PropertyId::Longhand(LonghandId::MozTextSizeAdjust)],
                                [_moz_user_focus, Set_moz_user_focus,
                                 PropertyId::Longhand(LonghandId::MozUserFocus)],
                            [MozUserFocus, SetMozUserFocus,
                             PropertyId::Longhand(LonghandId::MozUserFocus)],
                                [_moz_user_input, Set_moz_user_input,
                                 PropertyId::Longhand(LonghandId::MozUserInput)],
                            [MozUserInput, SetMozUserInput,
                             PropertyId::Longhand(LonghandId::MozUserInput)],
                                [_moz_user_modify, Set_moz_user_modify,
                                 PropertyId::Longhand(LonghandId::MozUserModify)],
                            [MozUserModify, SetMozUserModify,
                             PropertyId::Longhand(LonghandId::MozUserModify)],
                                [_moz_user_select, Set_moz_user_select,
                                 PropertyId::Longhand(LonghandId::MozUserSelect)],
                            [MozUserSelect, SetMozUserSelect,
                             PropertyId::Longhand(LonghandId::MozUserSelect)],
                                [_webkit_user_select, Set_webkit_user_select,
                                 PropertyId::Longhand(LonghandId::MozUserSelect)],
                            [WebkitUserSelect, SetWebkitUserSelect,
                             PropertyId::Longhand(LonghandId::MozUserSelect)],
                                [_moz_window_dragging, Set_moz_window_dragging,
                                 PropertyId::Longhand(LonghandId::MozWindowDragging)],
                            [MozWindowDragging, SetMozWindowDragging,
                             PropertyId::Longhand(LonghandId::MozWindowDragging)],
                                [Object_fit, SetObject_fit,
                                 PropertyId::Longhand(LonghandId::ObjectFit)],
                            [ObjectFit, SetObjectFit,
                             PropertyId::Longhand(LonghandId::ObjectFit)],
                                [Outline_style, SetOutline_style,
                                 PropertyId::Longhand(LonghandId::OutlineStyle)],
                            [OutlineStyle, SetOutlineStyle,
                             PropertyId::Longhand(LonghandId::OutlineStyle)],
                                [Overflow_wrap, SetOverflow_wrap,
                                 PropertyId::Longhand(LonghandId::OverflowWrap)],
                            [OverflowWrap, SetOverflowWrap,
                             PropertyId::Longhand(LonghandId::OverflowWrap)],
                                [Word_wrap, SetWord_wrap,
                                 PropertyId::Longhand(LonghandId::OverflowWrap)],
                            [WordWrap, SetWordWrap,
                             PropertyId::Longhand(LonghandId::OverflowWrap)],
                                [Overflow_x, SetOverflow_x,
                                 PropertyId::Longhand(LonghandId::OverflowX)],
                            [OverflowX, SetOverflowX,
                             PropertyId::Longhand(LonghandId::OverflowX)],
                                [Page_break_after, SetPage_break_after,
                                 PropertyId::Longhand(LonghandId::PageBreakAfter)],
                            [PageBreakAfter, SetPageBreakAfter,
                             PropertyId::Longhand(LonghandId::PageBreakAfter)],
                                [Page_break_before, SetPage_break_before,
                                 PropertyId::Longhand(LonghandId::PageBreakBefore)],
                            [PageBreakBefore, SetPageBreakBefore,
                             PropertyId::Longhand(LonghandId::PageBreakBefore)],
                                [Page_break_inside, SetPage_break_inside,
                                 PropertyId::Longhand(LonghandId::PageBreakInside)],
                            [PageBreakInside, SetPageBreakInside,
                             PropertyId::Longhand(LonghandId::PageBreakInside)],
                                [Paint_order, SetPaint_order,
                                 PropertyId::Longhand(LonghandId::PaintOrder)],
                            [PaintOrder, SetPaintOrder,
                             PropertyId::Longhand(LonghandId::PaintOrder)],
                                [Pointer_events, SetPointer_events,
                                 PropertyId::Longhand(LonghandId::PointerEvents)],
                            [PointerEvents, SetPointerEvents,
                             PropertyId::Longhand(LonghandId::PointerEvents)],
                            [Position, SetPosition,
                             PropertyId::Longhand(LonghandId::Position)],
                            [Resize, SetResize,
                             PropertyId::Longhand(LonghandId::Resize)],
                                [Ruby_align, SetRuby_align,
                                 PropertyId::Longhand(LonghandId::RubyAlign)],
                            [RubyAlign, SetRubyAlign,
                             PropertyId::Longhand(LonghandId::RubyAlign)],
                                [Ruby_position, SetRuby_position,
                                 PropertyId::Longhand(LonghandId::RubyPosition)],
                            [RubyPosition, SetRubyPosition,
                             PropertyId::Longhand(LonghandId::RubyPosition)],
                                [Scroll_behavior, SetScroll_behavior,
                                 PropertyId::Longhand(LonghandId::ScrollBehavior)],
                            [ScrollBehavior, SetScrollBehavior,
                             PropertyId::Longhand(LonghandId::ScrollBehavior)],
                                [Shape_rendering, SetShape_rendering,
                                 PropertyId::Longhand(LonghandId::ShapeRendering)],
                            [ShapeRendering, SetShapeRendering,
                             PropertyId::Longhand(LonghandId::ShapeRendering)],
                                [Stroke_linecap, SetStroke_linecap,
                                 PropertyId::Longhand(LonghandId::StrokeLinecap)],
                            [StrokeLinecap, SetStrokeLinecap,
                             PropertyId::Longhand(LonghandId::StrokeLinecap)],
                                [Stroke_linejoin, SetStroke_linejoin,
                                 PropertyId::Longhand(LonghandId::StrokeLinejoin)],
                            [StrokeLinejoin, SetStrokeLinejoin,
                             PropertyId::Longhand(LonghandId::StrokeLinejoin)],
                                [Table_layout, SetTable_layout,
                                 PropertyId::Longhand(LonghandId::TableLayout)],
                            [TableLayout, SetTableLayout,
                             PropertyId::Longhand(LonghandId::TableLayout)],
                                [Text_align_last, SetText_align_last,
                                 PropertyId::Longhand(LonghandId::TextAlignLast)],
                            [TextAlignLast, SetTextAlignLast,
                             PropertyId::Longhand(LonghandId::TextAlignLast)],
                                [Text_anchor, SetText_anchor,
                                 PropertyId::Longhand(LonghandId::TextAnchor)],
                            [TextAnchor, SetTextAnchor,
                             PropertyId::Longhand(LonghandId::TextAnchor)],
                                [Text_combine_upright, SetText_combine_upright,
                                 PropertyId::Longhand(LonghandId::TextCombineUpright)],
                            [TextCombineUpright, SetTextCombineUpright,
                             PropertyId::Longhand(LonghandId::TextCombineUpright)],
                                [Text_decoration_line, SetText_decoration_line,
                                 PropertyId::Longhand(LonghandId::TextDecorationLine)],
                            [TextDecorationLine, SetTextDecorationLine,
                             PropertyId::Longhand(LonghandId::TextDecorationLine)],
                                [Text_decoration_style, SetText_decoration_style,
                                 PropertyId::Longhand(LonghandId::TextDecorationStyle)],
                            [TextDecorationStyle, SetTextDecorationStyle,
                             PropertyId::Longhand(LonghandId::TextDecorationStyle)],
                                [Text_justify, SetText_justify,
                                 PropertyId::Longhand(LonghandId::TextJustify)],
                            [TextJustify, SetTextJustify,
                             PropertyId::Longhand(LonghandId::TextJustify)],
                                [Text_orientation, SetText_orientation,
                                 PropertyId::Longhand(LonghandId::TextOrientation)],
                            [TextOrientation, SetTextOrientation,
                             PropertyId::Longhand(LonghandId::TextOrientation)],
                                [Text_rendering, SetText_rendering,
                                 PropertyId::Longhand(LonghandId::TextRendering)],
                            [TextRendering, SetTextRendering,
                             PropertyId::Longhand(LonghandId::TextRendering)],
                                [Text_transform, SetText_transform,
                                 PropertyId::Longhand(LonghandId::TextTransform)],
                            [TextTransform, SetTextTransform,
                             PropertyId::Longhand(LonghandId::TextTransform)],
                                [Touch_action, SetTouch_action,
                                 PropertyId::Longhand(LonghandId::TouchAction)],
                            [TouchAction, SetTouchAction,
                             PropertyId::Longhand(LonghandId::TouchAction)],
                                [Transform_box, SetTransform_box,
                                 PropertyId::Longhand(LonghandId::TransformBox)],
                            [TransformBox, SetTransformBox,
                             PropertyId::Longhand(LonghandId::TransformBox)],
                                [Transform_style, SetTransform_style,
                                 PropertyId::Longhand(LonghandId::TransformStyle)],
                            [TransformStyle, SetTransformStyle,
                             PropertyId::Longhand(LonghandId::TransformStyle)],
                                [_moz_transform_style, Set_moz_transform_style,
                                 PropertyId::Longhand(LonghandId::TransformStyle)],
                            [MozTransformStyle, SetMozTransformStyle,
                             PropertyId::Longhand(LonghandId::TransformStyle)],
                                [_webkit_transform_style, Set_webkit_transform_style,
                                 PropertyId::Longhand(LonghandId::TransformStyle)],
                            [WebkitTransformStyle, SetWebkitTransformStyle,
                             PropertyId::Longhand(LonghandId::TransformStyle)],
                                [Unicode_bidi, SetUnicode_bidi,
                                 PropertyId::Longhand(LonghandId::UnicodeBidi)],
                            [UnicodeBidi, SetUnicodeBidi,
                             PropertyId::Longhand(LonghandId::UnicodeBidi)],
                                [Vector_effect, SetVector_effect,
                                 PropertyId::Longhand(LonghandId::VectorEffect)],
                            [VectorEffect, SetVectorEffect,
                             PropertyId::Longhand(LonghandId::VectorEffect)],
                            [Visibility, SetVisibility,
                             PropertyId::Longhand(LonghandId::Visibility)],
                                [White_space, SetWhite_space,
                                 PropertyId::Longhand(LonghandId::WhiteSpace)],
                            [WhiteSpace, SetWhiteSpace,
                             PropertyId::Longhand(LonghandId::WhiteSpace)],
                                [Word_break, SetWord_break,
                                 PropertyId::Longhand(LonghandId::WordBreak)],
                            [WordBreak, SetWordBreak,
                             PropertyId::Longhand(LonghandId::WordBreak)],
                                [Writing_mode, SetWriting_mode,
                                 PropertyId::Longhand(LonghandId::WritingMode)],
                            [WritingMode, SetWritingMode,
                             PropertyId::Longhand(LonghandId::WritingMode)],
                                [Z_index, SetZ_index,
                                 PropertyId::Longhand(LonghandId::ZIndex)],
                            [ZIndex, SetZIndex,
                             PropertyId::Longhand(LonghandId::ZIndex)],
                                [_moz_box_ordinal_group, Set_moz_box_ordinal_group,
                                 PropertyId::Longhand(LonghandId::MozBoxOrdinalGroup)],
                            [MozBoxOrdinalGroup, SetMozBoxOrdinalGroup,
                             PropertyId::Longhand(LonghandId::MozBoxOrdinalGroup)],
                                [_webkit_box_ordinal_group, Set_webkit_box_ordinal_group,
                                 PropertyId::Longhand(LonghandId::MozBoxOrdinalGroup)],
                            [WebkitBoxOrdinalGroup, SetWebkitBoxOrdinalGroup,
                             PropertyId::Longhand(LonghandId::MozBoxOrdinalGroup)],
                            [Order, SetOrder,
                             PropertyId::Longhand(LonghandId::Order)],
                                [_webkit_order, Set_webkit_order,
                                 PropertyId::Longhand(LonghandId::Order)],
                            [WebkitOrder, SetWebkitOrder,
                             PropertyId::Longhand(LonghandId::Order)],
                                [Overscroll_behavior_x, SetOverscroll_behavior_x,
                                 PropertyId::Longhand(LonghandId::OverscrollBehaviorX)],
                            [OverscrollBehaviorX, SetOverscrollBehaviorX,
                             PropertyId::Longhand(LonghandId::OverscrollBehaviorX)],
                                [Overscroll_behavior_y, SetOverscroll_behavior_y,
                                 PropertyId::Longhand(LonghandId::OverscrollBehaviorY)],
                            [OverscrollBehaviorY, SetOverscrollBehaviorY,
                             PropertyId::Longhand(LonghandId::OverscrollBehaviorY)],
                                [Scroll_snap_type_x, SetScroll_snap_type_x,
                                 PropertyId::Longhand(LonghandId::ScrollSnapTypeX)],
                            [ScrollSnapTypeX, SetScrollSnapTypeX,
                             PropertyId::Longhand(LonghandId::ScrollSnapTypeX)],
                                [Scroll_snap_type_y, SetScroll_snap_type_y,
                                 PropertyId::Longhand(LonghandId::ScrollSnapTypeY)],
                            [ScrollSnapTypeY, SetScrollSnapTypeY,
                             PropertyId::Longhand(LonghandId::ScrollSnapTypeY)],
                                [Flex_grow, SetFlex_grow,
                                 PropertyId::Longhand(LonghandId::FlexGrow)],
                            [FlexGrow, SetFlexGrow,
                             PropertyId::Longhand(LonghandId::FlexGrow)],
                                [_webkit_flex_grow, Set_webkit_flex_grow,
                                 PropertyId::Longhand(LonghandId::FlexGrow)],
                            [WebkitFlexGrow, SetWebkitFlexGrow,
                             PropertyId::Longhand(LonghandId::FlexGrow)],
                                [Flex_shrink, SetFlex_shrink,
                                 PropertyId::Longhand(LonghandId::FlexShrink)],
                            [FlexShrink, SetFlexShrink,
                             PropertyId::Longhand(LonghandId::FlexShrink)],
                                [_webkit_flex_shrink, Set_webkit_flex_shrink,
                                 PropertyId::Longhand(LonghandId::FlexShrink)],
                            [WebkitFlexShrink, SetWebkitFlexShrink,
                             PropertyId::Longhand(LonghandId::FlexShrink)],
                                [_moz_box_flex, Set_moz_box_flex,
                                 PropertyId::Longhand(LonghandId::MozBoxFlex)],
                            [MozBoxFlex, SetMozBoxFlex,
                             PropertyId::Longhand(LonghandId::MozBoxFlex)],
                                [_webkit_box_flex, Set_webkit_box_flex,
                                 PropertyId::Longhand(LonghandId::MozBoxFlex)],
                            [WebkitBoxFlex, SetWebkitBoxFlex,
                             PropertyId::Longhand(LonghandId::MozBoxFlex)],
                                [Flood_opacity, SetFlood_opacity,
                                 PropertyId::Longhand(LonghandId::FloodOpacity)],
                            [FloodOpacity, SetFloodOpacity,
                             PropertyId::Longhand(LonghandId::FloodOpacity)],
                            [Opacity, SetOpacity,
                             PropertyId::Longhand(LonghandId::Opacity)],
                                [Shape_image_threshold, SetShape_image_threshold,
                                 PropertyId::Longhand(LonghandId::ShapeImageThreshold)],
                            [ShapeImageThreshold, SetShapeImageThreshold,
                             PropertyId::Longhand(LonghandId::ShapeImageThreshold)],
                                [Stop_opacity, SetStop_opacity,
                                 PropertyId::Longhand(LonghandId::StopOpacity)],
                            [StopOpacity, SetStopOpacity,
                             PropertyId::Longhand(LonghandId::StopOpacity)],
                                [Border_block_end_style, SetBorder_block_end_style,
                                 PropertyId::Longhand(LonghandId::BorderBlockEndStyle)],
                            [BorderBlockEndStyle, SetBorderBlockEndStyle,
                             PropertyId::Longhand(LonghandId::BorderBlockEndStyle)],
                                [Border_block_start_style, SetBorder_block_start_style,
                                 PropertyId::Longhand(LonghandId::BorderBlockStartStyle)],
                            [BorderBlockStartStyle, SetBorderBlockStartStyle,
                             PropertyId::Longhand(LonghandId::BorderBlockStartStyle)],
                                [Border_bottom_style, SetBorder_bottom_style,
                                 PropertyId::Longhand(LonghandId::BorderBottomStyle)],
                            [BorderBottomStyle, SetBorderBottomStyle,
                             PropertyId::Longhand(LonghandId::BorderBottomStyle)],
                                [Border_inline_end_style, SetBorder_inline_end_style,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndStyle)],
                            [BorderInlineEndStyle, SetBorderInlineEndStyle,
                             PropertyId::Longhand(LonghandId::BorderInlineEndStyle)],
                                [_moz_border_end_style, Set_moz_border_end_style,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndStyle)],
                            [MozBorderEndStyle, SetMozBorderEndStyle,
                             PropertyId::Longhand(LonghandId::BorderInlineEndStyle)],
                                [Border_inline_start_style, SetBorder_inline_start_style,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartStyle)],
                            [BorderInlineStartStyle, SetBorderInlineStartStyle,
                             PropertyId::Longhand(LonghandId::BorderInlineStartStyle)],
                                [_moz_border_start_style, Set_moz_border_start_style,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartStyle)],
                            [MozBorderStartStyle, SetMozBorderStartStyle,
                             PropertyId::Longhand(LonghandId::BorderInlineStartStyle)],
                                [Border_left_style, SetBorder_left_style,
                                 PropertyId::Longhand(LonghandId::BorderLeftStyle)],
                            [BorderLeftStyle, SetBorderLeftStyle,
                             PropertyId::Longhand(LonghandId::BorderLeftStyle)],
                                [Border_right_style, SetBorder_right_style,
                                 PropertyId::Longhand(LonghandId::BorderRightStyle)],
                            [BorderRightStyle, SetBorderRightStyle,
                             PropertyId::Longhand(LonghandId::BorderRightStyle)],
                                [Border_top_style, SetBorder_top_style,
                                 PropertyId::Longhand(LonghandId::BorderTopStyle)],
                            [BorderTopStyle, SetBorderTopStyle,
                             PropertyId::Longhand(LonghandId::BorderTopStyle)],
                                [Animation_delay, SetAnimation_delay,
                                 PropertyId::Longhand(LonghandId::AnimationDelay)],
                            [AnimationDelay, SetAnimationDelay,
                             PropertyId::Longhand(LonghandId::AnimationDelay)],
                                [_moz_animation_delay, Set_moz_animation_delay,
                                 PropertyId::Longhand(LonghandId::AnimationDelay)],
                            [MozAnimationDelay, SetMozAnimationDelay,
                             PropertyId::Longhand(LonghandId::AnimationDelay)],
                                [_webkit_animation_delay, Set_webkit_animation_delay,
                                 PropertyId::Longhand(LonghandId::AnimationDelay)],
                            [WebkitAnimationDelay, SetWebkitAnimationDelay,
                             PropertyId::Longhand(LonghandId::AnimationDelay)],
                                [Animation_direction, SetAnimation_direction,
                                 PropertyId::Longhand(LonghandId::AnimationDirection)],
                            [AnimationDirection, SetAnimationDirection,
                             PropertyId::Longhand(LonghandId::AnimationDirection)],
                                [_moz_animation_direction, Set_moz_animation_direction,
                                 PropertyId::Longhand(LonghandId::AnimationDirection)],
                            [MozAnimationDirection, SetMozAnimationDirection,
                             PropertyId::Longhand(LonghandId::AnimationDirection)],
                                [_webkit_animation_direction, Set_webkit_animation_direction,
                                 PropertyId::Longhand(LonghandId::AnimationDirection)],
                            [WebkitAnimationDirection, SetWebkitAnimationDirection,
                             PropertyId::Longhand(LonghandId::AnimationDirection)],
                                [Animation_duration, SetAnimation_duration,
                                 PropertyId::Longhand(LonghandId::AnimationDuration)],
                            [AnimationDuration, SetAnimationDuration,
                             PropertyId::Longhand(LonghandId::AnimationDuration)],
                                [_moz_animation_duration, Set_moz_animation_duration,
                                 PropertyId::Longhand(LonghandId::AnimationDuration)],
                            [MozAnimationDuration, SetMozAnimationDuration,
                             PropertyId::Longhand(LonghandId::AnimationDuration)],
                                [_webkit_animation_duration, Set_webkit_animation_duration,
                                 PropertyId::Longhand(LonghandId::AnimationDuration)],
                            [WebkitAnimationDuration, SetWebkitAnimationDuration,
                             PropertyId::Longhand(LonghandId::AnimationDuration)],
                                [Animation_fill_mode, SetAnimation_fill_mode,
                                 PropertyId::Longhand(LonghandId::AnimationFillMode)],
                            [AnimationFillMode, SetAnimationFillMode,
                             PropertyId::Longhand(LonghandId::AnimationFillMode)],
                                [_moz_animation_fill_mode, Set_moz_animation_fill_mode,
                                 PropertyId::Longhand(LonghandId::AnimationFillMode)],
                            [MozAnimationFillMode, SetMozAnimationFillMode,
                             PropertyId::Longhand(LonghandId::AnimationFillMode)],
                                [_webkit_animation_fill_mode, Set_webkit_animation_fill_mode,
                                 PropertyId::Longhand(LonghandId::AnimationFillMode)],
                            [WebkitAnimationFillMode, SetWebkitAnimationFillMode,
                             PropertyId::Longhand(LonghandId::AnimationFillMode)],
                                [Animation_iteration_count, SetAnimation_iteration_count,
                                 PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                            [AnimationIterationCount, SetAnimationIterationCount,
                             PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                                [_moz_animation_iteration_count, Set_moz_animation_iteration_count,
                                 PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                            [MozAnimationIterationCount, SetMozAnimationIterationCount,
                             PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                                [_webkit_animation_iteration_count, Set_webkit_animation_iteration_count,
                                 PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                            [WebkitAnimationIterationCount, SetWebkitAnimationIterationCount,
                             PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                                [Animation_name, SetAnimation_name,
                                 PropertyId::Longhand(LonghandId::AnimationName)],
                            [AnimationName, SetAnimationName,
                             PropertyId::Longhand(LonghandId::AnimationName)],
                                [_moz_animation_name, Set_moz_animation_name,
                                 PropertyId::Longhand(LonghandId::AnimationName)],
                            [MozAnimationName, SetMozAnimationName,
                             PropertyId::Longhand(LonghandId::AnimationName)],
                                [_webkit_animation_name, Set_webkit_animation_name,
                                 PropertyId::Longhand(LonghandId::AnimationName)],
                            [WebkitAnimationName, SetWebkitAnimationName,
                             PropertyId::Longhand(LonghandId::AnimationName)],
                                [Animation_play_state, SetAnimation_play_state,
                                 PropertyId::Longhand(LonghandId::AnimationPlayState)],
                            [AnimationPlayState, SetAnimationPlayState,
                             PropertyId::Longhand(LonghandId::AnimationPlayState)],
                                [_moz_animation_play_state, Set_moz_animation_play_state,
                                 PropertyId::Longhand(LonghandId::AnimationPlayState)],
                            [MozAnimationPlayState, SetMozAnimationPlayState,
                             PropertyId::Longhand(LonghandId::AnimationPlayState)],
                                [_webkit_animation_play_state, Set_webkit_animation_play_state,
                                 PropertyId::Longhand(LonghandId::AnimationPlayState)],
                            [WebkitAnimationPlayState, SetWebkitAnimationPlayState,
                             PropertyId::Longhand(LonghandId::AnimationPlayState)],
                                [Animation_timing_function, SetAnimation_timing_function,
                                 PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                            [AnimationTimingFunction, SetAnimationTimingFunction,
                             PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                                [_moz_animation_timing_function, Set_moz_animation_timing_function,
                                 PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                            [MozAnimationTimingFunction, SetMozAnimationTimingFunction,
                             PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                                [_webkit_animation_timing_function, Set_webkit_animation_timing_function,
                                 PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                            [WebkitAnimationTimingFunction, SetWebkitAnimationTimingFunction,
                             PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                                [Background_attachment, SetBackground_attachment,
                                 PropertyId::Longhand(LonghandId::BackgroundAttachment)],
                            [BackgroundAttachment, SetBackgroundAttachment,
                             PropertyId::Longhand(LonghandId::BackgroundAttachment)],
                                [Background_blend_mode, SetBackground_blend_mode,
                                 PropertyId::Longhand(LonghandId::BackgroundBlendMode)],
                            [BackgroundBlendMode, SetBackgroundBlendMode,
                             PropertyId::Longhand(LonghandId::BackgroundBlendMode)],
                                [Background_clip, SetBackground_clip,
                                 PropertyId::Longhand(LonghandId::BackgroundClip)],
                            [BackgroundClip, SetBackgroundClip,
                             PropertyId::Longhand(LonghandId::BackgroundClip)],
                                [_webkit_background_clip, Set_webkit_background_clip,
                                 PropertyId::Longhand(LonghandId::BackgroundClip)],
                            [WebkitBackgroundClip, SetWebkitBackgroundClip,
                             PropertyId::Longhand(LonghandId::BackgroundClip)],
                                [Background_image, SetBackground_image,
                                 PropertyId::Longhand(LonghandId::BackgroundImage)],
                            [BackgroundImage, SetBackgroundImage,
                             PropertyId::Longhand(LonghandId::BackgroundImage)],
                                [Background_origin, SetBackground_origin,
                                 PropertyId::Longhand(LonghandId::BackgroundOrigin)],
                            [BackgroundOrigin, SetBackgroundOrigin,
                             PropertyId::Longhand(LonghandId::BackgroundOrigin)],
                                [_webkit_background_origin, Set_webkit_background_origin,
                                 PropertyId::Longhand(LonghandId::BackgroundOrigin)],
                            [WebkitBackgroundOrigin, SetWebkitBackgroundOrigin,
                             PropertyId::Longhand(LonghandId::BackgroundOrigin)],
                                [Background_position_x, SetBackground_position_x,
                                 PropertyId::Longhand(LonghandId::BackgroundPositionX)],
                            [BackgroundPositionX, SetBackgroundPositionX,
                             PropertyId::Longhand(LonghandId::BackgroundPositionX)],
                                [Background_position_y, SetBackground_position_y,
                                 PropertyId::Longhand(LonghandId::BackgroundPositionY)],
                            [BackgroundPositionY, SetBackgroundPositionY,
                             PropertyId::Longhand(LonghandId::BackgroundPositionY)],
                                [Background_repeat, SetBackground_repeat,
                                 PropertyId::Longhand(LonghandId::BackgroundRepeat)],
                            [BackgroundRepeat, SetBackgroundRepeat,
                             PropertyId::Longhand(LonghandId::BackgroundRepeat)],
                                [Background_size, SetBackground_size,
                                 PropertyId::Longhand(LonghandId::BackgroundSize)],
                            [BackgroundSize, SetBackgroundSize,
                             PropertyId::Longhand(LonghandId::BackgroundSize)],
                                [_webkit_background_size, Set_webkit_background_size,
                                 PropertyId::Longhand(LonghandId::BackgroundSize)],
                            [WebkitBackgroundSize, SetWebkitBackgroundSize,
                             PropertyId::Longhand(LonghandId::BackgroundSize)],
                                [Border_image_outset, SetBorder_image_outset,
                                 PropertyId::Longhand(LonghandId::BorderImageOutset)],
                            [BorderImageOutset, SetBorderImageOutset,
                             PropertyId::Longhand(LonghandId::BorderImageOutset)],
                                [Border_image_slice, SetBorder_image_slice,
                                 PropertyId::Longhand(LonghandId::BorderImageSlice)],
                            [BorderImageSlice, SetBorderImageSlice,
                             PropertyId::Longhand(LonghandId::BorderImageSlice)],
                                [Border_image_source, SetBorder_image_source,
                                 PropertyId::Longhand(LonghandId::BorderImageSource)],
                            [BorderImageSource, SetBorderImageSource,
                             PropertyId::Longhand(LonghandId::BorderImageSource)],
                                [Border_image_width, SetBorder_image_width,
                                 PropertyId::Longhand(LonghandId::BorderImageWidth)],
                            [BorderImageWidth, SetBorderImageWidth,
                             PropertyId::Longhand(LonghandId::BorderImageWidth)],
                                [Border_spacing, SetBorder_spacing,
                                 PropertyId::Longhand(LonghandId::BorderSpacing)],
                            [BorderSpacing, SetBorderSpacing,
                             PropertyId::Longhand(LonghandId::BorderSpacing)],
                                [Box_shadow, SetBox_shadow,
                                 PropertyId::Longhand(LonghandId::BoxShadow)],
                            [BoxShadow, SetBoxShadow,
                             PropertyId::Longhand(LonghandId::BoxShadow)],
                                [_webkit_box_shadow, Set_webkit_box_shadow,
                                 PropertyId::Longhand(LonghandId::BoxShadow)],
                            [WebkitBoxShadow, SetWebkitBoxShadow,
                             PropertyId::Longhand(LonghandId::BoxShadow)],
                                [Caret_color, SetCaret_color,
                                 PropertyId::Longhand(LonghandId::CaretColor)],
                            [CaretColor, SetCaretColor,
                             PropertyId::Longhand(LonghandId::CaretColor)],
                                [Clip_path, SetClip_path,
                                 PropertyId::Longhand(LonghandId::ClipPath)],
                            [ClipPath, SetClipPath,
                             PropertyId::Longhand(LonghandId::ClipPath)],
                            [Color, SetColor,
                             PropertyId::Longhand(LonghandId::Color)],
                                [Column_gap, SetColumn_gap,
                                 PropertyId::Longhand(LonghandId::ColumnGap)],
                            [ColumnGap, SetColumnGap,
                             PropertyId::Longhand(LonghandId::ColumnGap)],
                                [_moz_column_gap, Set_moz_column_gap,
                                 PropertyId::Longhand(LonghandId::ColumnGap)],
                            [MozColumnGap, SetMozColumnGap,
                             PropertyId::Longhand(LonghandId::ColumnGap)],
                                [Column_width, SetColumn_width,
                                 PropertyId::Longhand(LonghandId::ColumnWidth)],
                            [ColumnWidth, SetColumnWidth,
                             PropertyId::Longhand(LonghandId::ColumnWidth)],
                                [_moz_column_width, Set_moz_column_width,
                                 PropertyId::Longhand(LonghandId::ColumnWidth)],
                            [MozColumnWidth, SetMozColumnWidth,
                             PropertyId::Longhand(LonghandId::ColumnWidth)],
                            [Content, SetContent,
                             PropertyId::Longhand(LonghandId::Content)],
                                [Counter_increment, SetCounter_increment,
                                 PropertyId::Longhand(LonghandId::CounterIncrement)],
                            [CounterIncrement, SetCounterIncrement,
                             PropertyId::Longhand(LonghandId::CounterIncrement)],
                                [Counter_reset, SetCounter_reset,
                                 PropertyId::Longhand(LonghandId::CounterReset)],
                            [CounterReset, SetCounterReset,
                             PropertyId::Longhand(LonghandId::CounterReset)],
                            [Cursor, SetCursor,
                             PropertyId::Longhand(LonghandId::Cursor)],
                            [Display, SetDisplay,
                             PropertyId::Longhand(LonghandId::Display)],
                            [Filter, SetFilter,
                             PropertyId::Longhand(LonghandId::Filter)],
                                [_webkit_filter, Set_webkit_filter,
                                 PropertyId::Longhand(LonghandId::Filter)],
                            [WebkitFilter, SetWebkitFilter,
                             PropertyId::Longhand(LonghandId::Filter)],
                                [Font_family, SetFont_family,
                                 PropertyId::Longhand(LonghandId::FontFamily)],
                            [FontFamily, SetFontFamily,
                             PropertyId::Longhand(LonghandId::FontFamily)],
                                [Font_feature_settings, SetFont_feature_settings,
                                 PropertyId::Longhand(LonghandId::FontFeatureSettings)],
                            [FontFeatureSettings, SetFontFeatureSettings,
                             PropertyId::Longhand(LonghandId::FontFeatureSettings)],
                                [_moz_font_feature_settings, Set_moz_font_feature_settings,
                                 PropertyId::Longhand(LonghandId::FontFeatureSettings)],
                            [MozFontFeatureSettings, SetMozFontFeatureSettings,
                             PropertyId::Longhand(LonghandId::FontFeatureSettings)],
                                [Font_language_override, SetFont_language_override,
                                 PropertyId::Longhand(LonghandId::FontLanguageOverride)],
                            [FontLanguageOverride, SetFontLanguageOverride,
                             PropertyId::Longhand(LonghandId::FontLanguageOverride)],
                                [_moz_font_language_override, Set_moz_font_language_override,
                                 PropertyId::Longhand(LonghandId::FontLanguageOverride)],
                            [MozFontLanguageOverride, SetMozFontLanguageOverride,
                             PropertyId::Longhand(LonghandId::FontLanguageOverride)],
                                [Font_size, SetFont_size,
                                 PropertyId::Longhand(LonghandId::FontSize)],
                            [FontSize, SetFontSize,
                             PropertyId::Longhand(LonghandId::FontSize)],
                                [Font_size_adjust, SetFont_size_adjust,
                                 PropertyId::Longhand(LonghandId::FontSizeAdjust)],
                            [FontSizeAdjust, SetFontSizeAdjust,
                             PropertyId::Longhand(LonghandId::FontSizeAdjust)],
                                [Font_variant_alternates, SetFont_variant_alternates,
                                 PropertyId::Longhand(LonghandId::FontVariantAlternates)],
                            [FontVariantAlternates, SetFontVariantAlternates,
                             PropertyId::Longhand(LonghandId::FontVariantAlternates)],
                                [Font_variant_east_asian, SetFont_variant_east_asian,
                                 PropertyId::Longhand(LonghandId::FontVariantEastAsian)],
                            [FontVariantEastAsian, SetFontVariantEastAsian,
                             PropertyId::Longhand(LonghandId::FontVariantEastAsian)],
                                [Font_variant_ligatures, SetFont_variant_ligatures,
                                 PropertyId::Longhand(LonghandId::FontVariantLigatures)],
                            [FontVariantLigatures, SetFontVariantLigatures,
                             PropertyId::Longhand(LonghandId::FontVariantLigatures)],
                                [Font_variant_numeric, SetFont_variant_numeric,
                                 PropertyId::Longhand(LonghandId::FontVariantNumeric)],
                            [FontVariantNumeric, SetFontVariantNumeric,
                             PropertyId::Longhand(LonghandId::FontVariantNumeric)],
                                [Font_variation_settings, SetFont_variation_settings,
                                 PropertyId::Longhand(LonghandId::FontVariationSettings)],
                            [FontVariationSettings, SetFontVariationSettings,
                             PropertyId::Longhand(LonghandId::FontVariationSettings)],
                                [Grid_template_areas, SetGrid_template_areas,
                                 PropertyId::Longhand(LonghandId::GridTemplateAreas)],
                            [GridTemplateAreas, SetGridTemplateAreas,
                             PropertyId::Longhand(LonghandId::GridTemplateAreas)],
                                [Letter_spacing, SetLetter_spacing,
                                 PropertyId::Longhand(LonghandId::LetterSpacing)],
                            [LetterSpacing, SetLetterSpacing,
                             PropertyId::Longhand(LonghandId::LetterSpacing)],
                                [Line_height, SetLine_height,
                                 PropertyId::Longhand(LonghandId::LineHeight)],
                            [LineHeight, SetLineHeight,
                             PropertyId::Longhand(LonghandId::LineHeight)],
                                [List_style_image, SetList_style_image,
                                 PropertyId::Longhand(LonghandId::ListStyleImage)],
                            [ListStyleImage, SetListStyleImage,
                             PropertyId::Longhand(LonghandId::ListStyleImage)],
                                [List_style_type, SetList_style_type,
                                 PropertyId::Longhand(LonghandId::ListStyleType)],
                            [ListStyleType, SetListStyleType,
                             PropertyId::Longhand(LonghandId::ListStyleType)],
                                [Mask_clip, SetMask_clip,
                                 PropertyId::Longhand(LonghandId::MaskClip)],
                            [MaskClip, SetMaskClip,
                             PropertyId::Longhand(LonghandId::MaskClip)],
                                [_webkit_mask_clip, Set_webkit_mask_clip,
                                 PropertyId::Longhand(LonghandId::MaskClip)],
                            [WebkitMaskClip, SetWebkitMaskClip,
                             PropertyId::Longhand(LonghandId::MaskClip)],
                                [Mask_composite, SetMask_composite,
                                 PropertyId::Longhand(LonghandId::MaskComposite)],
                            [MaskComposite, SetMaskComposite,
                             PropertyId::Longhand(LonghandId::MaskComposite)],
                                [_webkit_mask_composite, Set_webkit_mask_composite,
                                 PropertyId::Longhand(LonghandId::MaskComposite)],
                            [WebkitMaskComposite, SetWebkitMaskComposite,
                             PropertyId::Longhand(LonghandId::MaskComposite)],
                                [Mask_image, SetMask_image,
                                 PropertyId::Longhand(LonghandId::MaskImage)],
                            [MaskImage, SetMaskImage,
                             PropertyId::Longhand(LonghandId::MaskImage)],
                                [_webkit_mask_image, Set_webkit_mask_image,
                                 PropertyId::Longhand(LonghandId::MaskImage)],
                            [WebkitMaskImage, SetWebkitMaskImage,
                             PropertyId::Longhand(LonghandId::MaskImage)],
                                [Mask_mode, SetMask_mode,
                                 PropertyId::Longhand(LonghandId::MaskMode)],
                            [MaskMode, SetMaskMode,
                             PropertyId::Longhand(LonghandId::MaskMode)],
                                [Mask_origin, SetMask_origin,
                                 PropertyId::Longhand(LonghandId::MaskOrigin)],
                            [MaskOrigin, SetMaskOrigin,
                             PropertyId::Longhand(LonghandId::MaskOrigin)],
                                [_webkit_mask_origin, Set_webkit_mask_origin,
                                 PropertyId::Longhand(LonghandId::MaskOrigin)],
                            [WebkitMaskOrigin, SetWebkitMaskOrigin,
                             PropertyId::Longhand(LonghandId::MaskOrigin)],
                                [Mask_position_x, SetMask_position_x,
                                 PropertyId::Longhand(LonghandId::MaskPositionX)],
                            [MaskPositionX, SetMaskPositionX,
                             PropertyId::Longhand(LonghandId::MaskPositionX)],
                                [_webkit_mask_position_x, Set_webkit_mask_position_x,
                                 PropertyId::Longhand(LonghandId::MaskPositionX)],
                            [WebkitMaskPositionX, SetWebkitMaskPositionX,
                             PropertyId::Longhand(LonghandId::MaskPositionX)],
                                [Mask_position_y, SetMask_position_y,
                                 PropertyId::Longhand(LonghandId::MaskPositionY)],
                            [MaskPositionY, SetMaskPositionY,
                             PropertyId::Longhand(LonghandId::MaskPositionY)],
                                [_webkit_mask_position_y, Set_webkit_mask_position_y,
                                 PropertyId::Longhand(LonghandId::MaskPositionY)],
                            [WebkitMaskPositionY, SetWebkitMaskPositionY,
                             PropertyId::Longhand(LonghandId::MaskPositionY)],
                                [Mask_repeat, SetMask_repeat,
                                 PropertyId::Longhand(LonghandId::MaskRepeat)],
                            [MaskRepeat, SetMaskRepeat,
                             PropertyId::Longhand(LonghandId::MaskRepeat)],
                                [_webkit_mask_repeat, Set_webkit_mask_repeat,
                                 PropertyId::Longhand(LonghandId::MaskRepeat)],
                            [WebkitMaskRepeat, SetWebkitMaskRepeat,
                             PropertyId::Longhand(LonghandId::MaskRepeat)],
                                [Mask_size, SetMask_size,
                                 PropertyId::Longhand(LonghandId::MaskSize)],
                            [MaskSize, SetMaskSize,
                             PropertyId::Longhand(LonghandId::MaskSize)],
                                [_webkit_mask_size, Set_webkit_mask_size,
                                 PropertyId::Longhand(LonghandId::MaskSize)],
                            [WebkitMaskSize, SetWebkitMaskSize,
                             PropertyId::Longhand(LonghandId::MaskSize)],
                                [_moz_context_properties, Set_moz_context_properties,
                                 PropertyId::Longhand(LonghandId::MozContextProperties)],
                            [MozContextProperties, SetMozContextProperties,
                             PropertyId::Longhand(LonghandId::MozContextProperties)],
                                [_moz_tab_size, Set_moz_tab_size,
                                 PropertyId::Longhand(LonghandId::MozTabSize)],
                            [MozTabSize, SetMozTabSize,
                             PropertyId::Longhand(LonghandId::MozTabSize)],
                                [Outline_offset, SetOutline_offset,
                                 PropertyId::Longhand(LonghandId::OutlineOffset)],
                            [OutlineOffset, SetOutlineOffset,
                             PropertyId::Longhand(LonghandId::OutlineOffset)],
                                [Overflow_y, SetOverflow_y,
                                 PropertyId::Longhand(LonghandId::OverflowY)],
                            [OverflowY, SetOverflowY,
                             PropertyId::Longhand(LonghandId::OverflowY)],
                            [Perspective, SetPerspective,
                             PropertyId::Longhand(LonghandId::Perspective)],
                                [_moz_perspective, Set_moz_perspective,
                                 PropertyId::Longhand(LonghandId::Perspective)],
                            [MozPerspective, SetMozPerspective,
                             PropertyId::Longhand(LonghandId::Perspective)],
                                [_webkit_perspective, Set_webkit_perspective,
                                 PropertyId::Longhand(LonghandId::Perspective)],
                            [WebkitPerspective, SetWebkitPerspective,
                             PropertyId::Longhand(LonghandId::Perspective)],
                                [Perspective_origin, SetPerspective_origin,
                                 PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                            [PerspectiveOrigin, SetPerspectiveOrigin,
                             PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                                [_moz_perspective_origin, Set_moz_perspective_origin,
                                 PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                            [MozPerspectiveOrigin, SetMozPerspectiveOrigin,
                             PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                                [_webkit_perspective_origin, Set_webkit_perspective_origin,
                                 PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                            [WebkitPerspectiveOrigin, SetWebkitPerspectiveOrigin,
                             PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                            [Quotes, SetQuotes,
                             PropertyId::Longhand(LonghandId::Quotes)],
                            [Rotate, SetRotate,
                             PropertyId::Longhand(LonghandId::Rotate)],
                            [Scale, SetScale,
                             PropertyId::Longhand(LonghandId::Scale)],
                                [Scroll_snap_coordinate, SetScroll_snap_coordinate,
                                 PropertyId::Longhand(LonghandId::ScrollSnapCoordinate)],
                            [ScrollSnapCoordinate, SetScrollSnapCoordinate,
                             PropertyId::Longhand(LonghandId::ScrollSnapCoordinate)],
                                [Shape_outside, SetShape_outside,
                                 PropertyId::Longhand(LonghandId::ShapeOutside)],
                            [ShapeOutside, SetShapeOutside,
                             PropertyId::Longhand(LonghandId::ShapeOutside)],
                                [Stroke_dasharray, SetStroke_dasharray,
                                 PropertyId::Longhand(LonghandId::StrokeDasharray)],
                            [StrokeDasharray, SetStrokeDasharray,
                             PropertyId::Longhand(LonghandId::StrokeDasharray)],
                                [Stroke_dashoffset, SetStroke_dashoffset,
                                 PropertyId::Longhand(LonghandId::StrokeDashoffset)],
                            [StrokeDashoffset, SetStrokeDashoffset,
                             PropertyId::Longhand(LonghandId::StrokeDashoffset)],
                                [Stroke_miterlimit, SetStroke_miterlimit,
                                 PropertyId::Longhand(LonghandId::StrokeMiterlimit)],
                            [StrokeMiterlimit, SetStrokeMiterlimit,
                             PropertyId::Longhand(LonghandId::StrokeMiterlimit)],
                                [Stroke_width, SetStroke_width,
                                 PropertyId::Longhand(LonghandId::StrokeWidth)],
                            [StrokeWidth, SetStrokeWidth,
                             PropertyId::Longhand(LonghandId::StrokeWidth)],
                                [Text_align, SetText_align,
                                 PropertyId::Longhand(LonghandId::TextAlign)],
                            [TextAlign, SetTextAlign,
                             PropertyId::Longhand(LonghandId::TextAlign)],
                                [Text_emphasis_position, SetText_emphasis_position,
                                 PropertyId::Longhand(LonghandId::TextEmphasisPosition)],
                            [TextEmphasisPosition, SetTextEmphasisPosition,
                             PropertyId::Longhand(LonghandId::TextEmphasisPosition)],
                                [Text_emphasis_style, SetText_emphasis_style,
                                 PropertyId::Longhand(LonghandId::TextEmphasisStyle)],
                            [TextEmphasisStyle, SetTextEmphasisStyle,
                             PropertyId::Longhand(LonghandId::TextEmphasisStyle)],
                                [Text_indent, SetText_indent,
                                 PropertyId::Longhand(LonghandId::TextIndent)],
                            [TextIndent, SetTextIndent,
                             PropertyId::Longhand(LonghandId::TextIndent)],
                                [Text_overflow, SetText_overflow,
                                 PropertyId::Longhand(LonghandId::TextOverflow)],
                            [TextOverflow, SetTextOverflow,
                             PropertyId::Longhand(LonghandId::TextOverflow)],
                                [Text_shadow, SetText_shadow,
                                 PropertyId::Longhand(LonghandId::TextShadow)],
                            [TextShadow, SetTextShadow,
                             PropertyId::Longhand(LonghandId::TextShadow)],
                                [Transition_delay, SetTransition_delay,
                                 PropertyId::Longhand(LonghandId::TransitionDelay)],
                            [TransitionDelay, SetTransitionDelay,
                             PropertyId::Longhand(LonghandId::TransitionDelay)],
                                [_moz_transition_delay, Set_moz_transition_delay,
                                 PropertyId::Longhand(LonghandId::TransitionDelay)],
                            [MozTransitionDelay, SetMozTransitionDelay,
                             PropertyId::Longhand(LonghandId::TransitionDelay)],
                                [_webkit_transition_delay, Set_webkit_transition_delay,
                                 PropertyId::Longhand(LonghandId::TransitionDelay)],
                            [WebkitTransitionDelay, SetWebkitTransitionDelay,
                             PropertyId::Longhand(LonghandId::TransitionDelay)],
                                [Transition_duration, SetTransition_duration,
                                 PropertyId::Longhand(LonghandId::TransitionDuration)],
                            [TransitionDuration, SetTransitionDuration,
                             PropertyId::Longhand(LonghandId::TransitionDuration)],
                                [_moz_transition_duration, Set_moz_transition_duration,
                                 PropertyId::Longhand(LonghandId::TransitionDuration)],
                            [MozTransitionDuration, SetMozTransitionDuration,
                             PropertyId::Longhand(LonghandId::TransitionDuration)],
                                [_webkit_transition_duration, Set_webkit_transition_duration,
                                 PropertyId::Longhand(LonghandId::TransitionDuration)],
                            [WebkitTransitionDuration, SetWebkitTransitionDuration,
                             PropertyId::Longhand(LonghandId::TransitionDuration)],
                                [Transition_property, SetTransition_property,
                                 PropertyId::Longhand(LonghandId::TransitionProperty)],
                            [TransitionProperty, SetTransitionProperty,
                             PropertyId::Longhand(LonghandId::TransitionProperty)],
                                [_moz_transition_property, Set_moz_transition_property,
                                 PropertyId::Longhand(LonghandId::TransitionProperty)],
                            [MozTransitionProperty, SetMozTransitionProperty,
                             PropertyId::Longhand(LonghandId::TransitionProperty)],
                                [_webkit_transition_property, Set_webkit_transition_property,
                                 PropertyId::Longhand(LonghandId::TransitionProperty)],
                            [WebkitTransitionProperty, SetWebkitTransitionProperty,
                             PropertyId::Longhand(LonghandId::TransitionProperty)],
                                [Transition_timing_function, SetTransition_timing_function,
                                 PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                            [TransitionTimingFunction, SetTransitionTimingFunction,
                             PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                                [_moz_transition_timing_function, Set_moz_transition_timing_function,
                                 PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                            [MozTransitionTimingFunction, SetMozTransitionTimingFunction,
                             PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                                [_webkit_transition_timing_function, Set_webkit_transition_timing_function,
                                 PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                            [WebkitTransitionTimingFunction, SetWebkitTransitionTimingFunction,
                             PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                            [Translate, SetTranslate,
                             PropertyId::Longhand(LonghandId::Translate)],
                                [Vertical_align, SetVertical_align,
                                 PropertyId::Longhand(LonghandId::VerticalAlign)],
                            [VerticalAlign, SetVerticalAlign,
                             PropertyId::Longhand(LonghandId::VerticalAlign)],
                                [Will_change, SetWill_change,
                                 PropertyId::Longhand(LonghandId::WillChange)],
                            [WillChange, SetWillChange,
                             PropertyId::Longhand(LonghandId::WillChange)],
                                [Word_spacing, SetWord_spacing,
                                 PropertyId::Longhand(LonghandId::WordSpacing)],
                            [WordSpacing, SetWordSpacing,
                             PropertyId::Longhand(LonghandId::WordSpacing)],
                                [Fill_opacity, SetFill_opacity,
                                 PropertyId::Longhand(LonghandId::FillOpacity)],
                            [FillOpacity, SetFillOpacity,
                             PropertyId::Longhand(LonghandId::FillOpacity)],
                                [Stroke_opacity, SetStroke_opacity,
                                 PropertyId::Longhand(LonghandId::StrokeOpacity)],
                            [StrokeOpacity, SetStrokeOpacity,
                             PropertyId::Longhand(LonghandId::StrokeOpacity)],
                                [Scroll_snap_points_x, SetScroll_snap_points_x,
                                 PropertyId::Longhand(LonghandId::ScrollSnapPointsX)],
                            [ScrollSnapPointsX, SetScrollSnapPointsX,
                             PropertyId::Longhand(LonghandId::ScrollSnapPointsX)],
                                [Scroll_snap_points_y, SetScroll_snap_points_y,
                                 PropertyId::Longhand(LonghandId::ScrollSnapPointsY)],
                            [ScrollSnapPointsY, SetScrollSnapPointsY,
                             PropertyId::Longhand(LonghandId::ScrollSnapPointsY)],
                            [Transform, SetTransform,
                             PropertyId::Longhand(LonghandId::Transform)],
                                [_webkit_transform, Set_webkit_transform,
                                 PropertyId::Longhand(LonghandId::Transform)],
                            [WebkitTransform, SetWebkitTransform,
                             PropertyId::Longhand(LonghandId::Transform)],
                                [_moz_transform, Set_moz_transform,
                                 PropertyId::Longhand(LonghandId::Transform)],
                            [MozTransform, SetMozTransform,
                             PropertyId::Longhand(LonghandId::Transform)],
                            [Clip, SetClip,
                             PropertyId::Longhand(LonghandId::Clip)],
                                [_moz_image_region, Set_moz_image_region,
                                 PropertyId::Longhand(LonghandId::MozImageRegion)],
                            [MozImageRegion, SetMozImageRegion,
                             PropertyId::Longhand(LonghandId::MozImageRegion)],
                                [Grid_template_columns, SetGrid_template_columns,
                                 PropertyId::Longhand(LonghandId::GridTemplateColumns)],
                            [GridTemplateColumns, SetGridTemplateColumns,
                             PropertyId::Longhand(LonghandId::GridTemplateColumns)],
                                [Grid_template_rows, SetGrid_template_rows,
                                 PropertyId::Longhand(LonghandId::GridTemplateRows)],
                            [GridTemplateRows, SetGridTemplateRows,
                             PropertyId::Longhand(LonghandId::GridTemplateRows)],
                                [Object_position, SetObject_position,
                                 PropertyId::Longhand(LonghandId::ObjectPosition)],
                            [ObjectPosition, SetObjectPosition,
                             PropertyId::Longhand(LonghandId::ObjectPosition)],
                                [Scroll_snap_destination, SetScroll_snap_destination,
                                 PropertyId::Longhand(LonghandId::ScrollSnapDestination)],
                            [ScrollSnapDestination, SetScrollSnapDestination,
                             PropertyId::Longhand(LonghandId::ScrollSnapDestination)],
                            [Fill, SetFill,
                             PropertyId::Longhand(LonghandId::Fill)],
                            [Stroke, SetStroke,
                             PropertyId::Longhand(LonghandId::Stroke)],
                                [Grid_auto_columns, SetGrid_auto_columns,
                                 PropertyId::Longhand(LonghandId::GridAutoColumns)],
                            [GridAutoColumns, SetGridAutoColumns,
                             PropertyId::Longhand(LonghandId::GridAutoColumns)],
                                [Grid_auto_rows, SetGrid_auto_rows,
                                 PropertyId::Longhand(LonghandId::GridAutoRows)],
                            [GridAutoRows, SetGridAutoRows,
                             PropertyId::Longhand(LonghandId::GridAutoRows)],
                                [Transform_origin, SetTransform_origin,
                                 PropertyId::Longhand(LonghandId::TransformOrigin)],
                            [TransformOrigin, SetTransformOrigin,
                             PropertyId::Longhand(LonghandId::TransformOrigin)],
                                [_moz_transform_origin, Set_moz_transform_origin,
                                 PropertyId::Longhand(LonghandId::TransformOrigin)],
                            [MozTransformOrigin, SetMozTransformOrigin,
                             PropertyId::Longhand(LonghandId::TransformOrigin)],
                                [_webkit_transform_origin, Set_webkit_transform_origin,
                                 PropertyId::Longhand(LonghandId::TransformOrigin)],
                            [WebkitTransformOrigin, SetWebkitTransformOrigin,
                             PropertyId::Longhand(LonghandId::TransformOrigin)],
                                [Max_block_size, SetMax_block_size,
                                 PropertyId::Longhand(LonghandId::MaxBlockSize)],
                            [MaxBlockSize, SetMaxBlockSize,
                             PropertyId::Longhand(LonghandId::MaxBlockSize)],
                                [Max_height, SetMax_height,
                                 PropertyId::Longhand(LonghandId::MaxHeight)],
                            [MaxHeight, SetMaxHeight,
                             PropertyId::Longhand(LonghandId::MaxHeight)],
                                [Max_inline_size, SetMax_inline_size,
                                 PropertyId::Longhand(LonghandId::MaxInlineSize)],
                            [MaxInlineSize, SetMaxInlineSize,
                             PropertyId::Longhand(LonghandId::MaxInlineSize)],
                                [Max_width, SetMax_width,
                                 PropertyId::Longhand(LonghandId::MaxWidth)],
                            [MaxWidth, SetMaxWidth,
                             PropertyId::Longhand(LonghandId::MaxWidth)],
                                [Flood_color, SetFlood_color,
                                 PropertyId::Longhand(LonghandId::FloodColor)],
                            [FloodColor, SetFloodColor,
                             PropertyId::Longhand(LonghandId::FloodColor)],
                                [Lighting_color, SetLighting_color,
                                 PropertyId::Longhand(LonghandId::LightingColor)],
                            [LightingColor, SetLightingColor,
                             PropertyId::Longhand(LonghandId::LightingColor)],
                                [Stop_color, SetStop_color,
                                 PropertyId::Longhand(LonghandId::StopColor)],
                            [StopColor, SetStopColor,
                             PropertyId::Longhand(LonghandId::StopColor)],
                                [Marker_end, SetMarker_end,
                                 PropertyId::Longhand(LonghandId::MarkerEnd)],
                            [MarkerEnd, SetMarkerEnd,
                             PropertyId::Longhand(LonghandId::MarkerEnd)],
                                [Marker_mid, SetMarker_mid,
                                 PropertyId::Longhand(LonghandId::MarkerMid)],
                            [MarkerMid, SetMarkerMid,
                             PropertyId::Longhand(LonghandId::MarkerMid)],
                                [Marker_start, SetMarker_start,
                                 PropertyId::Longhand(LonghandId::MarkerStart)],
                            [MarkerStart, SetMarkerStart,
                             PropertyId::Longhand(LonghandId::MarkerStart)],
                                [_moz_binding, Set_moz_binding,
                                 PropertyId::Longhand(LonghandId::MozBinding)],
                            [MozBinding, SetMozBinding,
                             PropertyId::Longhand(LonghandId::MozBinding)],
                                [Grid_column_end, SetGrid_column_end,
                                 PropertyId::Longhand(LonghandId::GridColumnEnd)],
                            [GridColumnEnd, SetGridColumnEnd,
                             PropertyId::Longhand(LonghandId::GridColumnEnd)],
                                [Grid_column_start, SetGrid_column_start,
                                 PropertyId::Longhand(LonghandId::GridColumnStart)],
                            [GridColumnStart, SetGridColumnStart,
                             PropertyId::Longhand(LonghandId::GridColumnStart)],
                                [Grid_row_end, SetGrid_row_end,
                                 PropertyId::Longhand(LonghandId::GridRowEnd)],
                            [GridRowEnd, SetGridRowEnd,
                             PropertyId::Longhand(LonghandId::GridRowEnd)],
                                [Grid_row_start, SetGrid_row_start,
                                 PropertyId::Longhand(LonghandId::GridRowStart)],
                            [GridRowStart, SetGridRowStart,
                             PropertyId::Longhand(LonghandId::GridRowStart)],
                                [Border_bottom_left_radius, SetBorder_bottom_left_radius,
                                 PropertyId::Longhand(LonghandId::BorderBottomLeftRadius)],
                            [BorderBottomLeftRadius, SetBorderBottomLeftRadius,
                             PropertyId::Longhand(LonghandId::BorderBottomLeftRadius)],
                                [_webkit_border_bottom_left_radius, Set_webkit_border_bottom_left_radius,
                                 PropertyId::Longhand(LonghandId::BorderBottomLeftRadius)],
                            [WebkitBorderBottomLeftRadius, SetWebkitBorderBottomLeftRadius,
                             PropertyId::Longhand(LonghandId::BorderBottomLeftRadius)],
                                [Border_bottom_right_radius, SetBorder_bottom_right_radius,
                                 PropertyId::Longhand(LonghandId::BorderBottomRightRadius)],
                            [BorderBottomRightRadius, SetBorderBottomRightRadius,
                             PropertyId::Longhand(LonghandId::BorderBottomRightRadius)],
                                [_webkit_border_bottom_right_radius, Set_webkit_border_bottom_right_radius,
                                 PropertyId::Longhand(LonghandId::BorderBottomRightRadius)],
                            [WebkitBorderBottomRightRadius, SetWebkitBorderBottomRightRadius,
                             PropertyId::Longhand(LonghandId::BorderBottomRightRadius)],
                                [Border_top_left_radius, SetBorder_top_left_radius,
                                 PropertyId::Longhand(LonghandId::BorderTopLeftRadius)],
                            [BorderTopLeftRadius, SetBorderTopLeftRadius,
                             PropertyId::Longhand(LonghandId::BorderTopLeftRadius)],
                                [_webkit_border_top_left_radius, Set_webkit_border_top_left_radius,
                                 PropertyId::Longhand(LonghandId::BorderTopLeftRadius)],
                            [WebkitBorderTopLeftRadius, SetWebkitBorderTopLeftRadius,
                             PropertyId::Longhand(LonghandId::BorderTopLeftRadius)],
                                [Border_top_right_radius, SetBorder_top_right_radius,
                                 PropertyId::Longhand(LonghandId::BorderTopRightRadius)],
                            [BorderTopRightRadius, SetBorderTopRightRadius,
                             PropertyId::Longhand(LonghandId::BorderTopRightRadius)],
                                [_webkit_border_top_right_radius, Set_webkit_border_top_right_radius,
                                 PropertyId::Longhand(LonghandId::BorderTopRightRadius)],
                            [WebkitBorderTopRightRadius, SetWebkitBorderTopRightRadius,
                             PropertyId::Longhand(LonghandId::BorderTopRightRadius)],
                                [_moz_outline_radius_bottomleft, Set_moz_outline_radius_bottomleft,
                                 PropertyId::Longhand(LonghandId::MozOutlineRadiusBottomleft)],
                            [MozOutlineRadiusBottomleft, SetMozOutlineRadiusBottomleft,
                             PropertyId::Longhand(LonghandId::MozOutlineRadiusBottomleft)],
                                [_moz_outline_radius_bottomright, Set_moz_outline_radius_bottomright,
                                 PropertyId::Longhand(LonghandId::MozOutlineRadiusBottomright)],
                            [MozOutlineRadiusBottomright, SetMozOutlineRadiusBottomright,
                             PropertyId::Longhand(LonghandId::MozOutlineRadiusBottomright)],
                                [_moz_outline_radius_topleft, Set_moz_outline_radius_topleft,
                                 PropertyId::Longhand(LonghandId::MozOutlineRadiusTopleft)],
                            [MozOutlineRadiusTopleft, SetMozOutlineRadiusTopleft,
                             PropertyId::Longhand(LonghandId::MozOutlineRadiusTopleft)],
                                [_moz_outline_radius_topright, Set_moz_outline_radius_topright,
                                 PropertyId::Longhand(LonghandId::MozOutlineRadiusTopright)],
                            [MozOutlineRadiusTopright, SetMozOutlineRadiusTopright,
                             PropertyId::Longhand(LonghandId::MozOutlineRadiusTopright)],
                                [Block_size, SetBlock_size,
                                 PropertyId::Longhand(LonghandId::BlockSize)],
                            [BlockSize, SetBlockSize,
                             PropertyId::Longhand(LonghandId::BlockSize)],
                                [Flex_basis, SetFlex_basis,
                                 PropertyId::Longhand(LonghandId::FlexBasis)],
                            [FlexBasis, SetFlexBasis,
                             PropertyId::Longhand(LonghandId::FlexBasis)],
                                [_webkit_flex_basis, Set_webkit_flex_basis,
                                 PropertyId::Longhand(LonghandId::FlexBasis)],
                            [WebkitFlexBasis, SetWebkitFlexBasis,
                             PropertyId::Longhand(LonghandId::FlexBasis)],
                            [Height, SetHeight,
                             PropertyId::Longhand(LonghandId::Height)],
                                [Inline_size, SetInline_size,
                                 PropertyId::Longhand(LonghandId::InlineSize)],
                            [InlineSize, SetInlineSize,
                             PropertyId::Longhand(LonghandId::InlineSize)],
                                [Min_block_size, SetMin_block_size,
                                 PropertyId::Longhand(LonghandId::MinBlockSize)],
                            [MinBlockSize, SetMinBlockSize,
                             PropertyId::Longhand(LonghandId::MinBlockSize)],
                                [Min_height, SetMin_height,
                                 PropertyId::Longhand(LonghandId::MinHeight)],
                            [MinHeight, SetMinHeight,
                             PropertyId::Longhand(LonghandId::MinHeight)],
                                [Min_inline_size, SetMin_inline_size,
                                 PropertyId::Longhand(LonghandId::MinInlineSize)],
                            [MinInlineSize, SetMinInlineSize,
                             PropertyId::Longhand(LonghandId::MinInlineSize)],
                                [Min_width, SetMin_width,
                                 PropertyId::Longhand(LonghandId::MinWidth)],
                            [MinWidth, SetMinWidth,
                             PropertyId::Longhand(LonghandId::MinWidth)],
                            [Width, SetWidth,
                             PropertyId::Longhand(LonghandId::Width)],
                                [Grid_column_gap, SetGrid_column_gap,
                                 PropertyId::Longhand(LonghandId::GridColumnGap)],
                            [GridColumnGap, SetGridColumnGap,
                             PropertyId::Longhand(LonghandId::GridColumnGap)],
                                [Grid_row_gap, SetGrid_row_gap,
                                 PropertyId::Longhand(LonghandId::GridRowGap)],
                            [GridRowGap, SetGridRowGap,
                             PropertyId::Longhand(LonghandId::GridRowGap)],
                                [Padding_block_end, SetPadding_block_end,
                                 PropertyId::Longhand(LonghandId::PaddingBlockEnd)],
                            [PaddingBlockEnd, SetPaddingBlockEnd,
                             PropertyId::Longhand(LonghandId::PaddingBlockEnd)],
                                [Padding_block_start, SetPadding_block_start,
                                 PropertyId::Longhand(LonghandId::PaddingBlockStart)],
                            [PaddingBlockStart, SetPaddingBlockStart,
                             PropertyId::Longhand(LonghandId::PaddingBlockStart)],
                                [Padding_bottom, SetPadding_bottom,
                                 PropertyId::Longhand(LonghandId::PaddingBottom)],
                            [PaddingBottom, SetPaddingBottom,
                             PropertyId::Longhand(LonghandId::PaddingBottom)],
                                [Padding_inline_end, SetPadding_inline_end,
                                 PropertyId::Longhand(LonghandId::PaddingInlineEnd)],
                            [PaddingInlineEnd, SetPaddingInlineEnd,
                             PropertyId::Longhand(LonghandId::PaddingInlineEnd)],
                                [_moz_padding_end, Set_moz_padding_end,
                                 PropertyId::Longhand(LonghandId::PaddingInlineEnd)],
                            [MozPaddingEnd, SetMozPaddingEnd,
                             PropertyId::Longhand(LonghandId::PaddingInlineEnd)],
                                [Padding_inline_start, SetPadding_inline_start,
                                 PropertyId::Longhand(LonghandId::PaddingInlineStart)],
                            [PaddingInlineStart, SetPaddingInlineStart,
                             PropertyId::Longhand(LonghandId::PaddingInlineStart)],
                                [_moz_padding_start, Set_moz_padding_start,
                                 PropertyId::Longhand(LonghandId::PaddingInlineStart)],
                            [MozPaddingStart, SetMozPaddingStart,
                             PropertyId::Longhand(LonghandId::PaddingInlineStart)],
                                [Padding_left, SetPadding_left,
                                 PropertyId::Longhand(LonghandId::PaddingLeft)],
                            [PaddingLeft, SetPaddingLeft,
                             PropertyId::Longhand(LonghandId::PaddingLeft)],
                                [Padding_right, SetPadding_right,
                                 PropertyId::Longhand(LonghandId::PaddingRight)],
                            [PaddingRight, SetPaddingRight,
                             PropertyId::Longhand(LonghandId::PaddingRight)],
                                [Padding_top, SetPadding_top,
                                 PropertyId::Longhand(LonghandId::PaddingTop)],
                            [PaddingTop, SetPaddingTop,
                             PropertyId::Longhand(LonghandId::PaddingTop)],
                                [Border_block_end_width, SetBorder_block_end_width,
                                 PropertyId::Longhand(LonghandId::BorderBlockEndWidth)],
                            [BorderBlockEndWidth, SetBorderBlockEndWidth,
                             PropertyId::Longhand(LonghandId::BorderBlockEndWidth)],
                                [Border_block_start_width, SetBorder_block_start_width,
                                 PropertyId::Longhand(LonghandId::BorderBlockStartWidth)],
                            [BorderBlockStartWidth, SetBorderBlockStartWidth,
                             PropertyId::Longhand(LonghandId::BorderBlockStartWidth)],
                                [Border_bottom_width, SetBorder_bottom_width,
                                 PropertyId::Longhand(LonghandId::BorderBottomWidth)],
                            [BorderBottomWidth, SetBorderBottomWidth,
                             PropertyId::Longhand(LonghandId::BorderBottomWidth)],
                                [Border_inline_end_width, SetBorder_inline_end_width,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndWidth)],
                            [BorderInlineEndWidth, SetBorderInlineEndWidth,
                             PropertyId::Longhand(LonghandId::BorderInlineEndWidth)],
                                [_moz_border_end_width, Set_moz_border_end_width,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndWidth)],
                            [MozBorderEndWidth, SetMozBorderEndWidth,
                             PropertyId::Longhand(LonghandId::BorderInlineEndWidth)],
                                [Border_inline_start_width, SetBorder_inline_start_width,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartWidth)],
                            [BorderInlineStartWidth, SetBorderInlineStartWidth,
                             PropertyId::Longhand(LonghandId::BorderInlineStartWidth)],
                                [_moz_border_start_width, Set_moz_border_start_width,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartWidth)],
                            [MozBorderStartWidth, SetMozBorderStartWidth,
                             PropertyId::Longhand(LonghandId::BorderInlineStartWidth)],
                                [Border_left_width, SetBorder_left_width,
                                 PropertyId::Longhand(LonghandId::BorderLeftWidth)],
                            [BorderLeftWidth, SetBorderLeftWidth,
                             PropertyId::Longhand(LonghandId::BorderLeftWidth)],
                                [Border_right_width, SetBorder_right_width,
                                 PropertyId::Longhand(LonghandId::BorderRightWidth)],
                            [BorderRightWidth, SetBorderRightWidth,
                             PropertyId::Longhand(LonghandId::BorderRightWidth)],
                                [Border_top_width, SetBorder_top_width,
                                 PropertyId::Longhand(LonghandId::BorderTopWidth)],
                            [BorderTopWidth, SetBorderTopWidth,
                             PropertyId::Longhand(LonghandId::BorderTopWidth)],
                                [Column_rule_width, SetColumn_rule_width,
                                 PropertyId::Longhand(LonghandId::ColumnRuleWidth)],
                            [ColumnRuleWidth, SetColumnRuleWidth,
                             PropertyId::Longhand(LonghandId::ColumnRuleWidth)],
                                [_moz_column_rule_width, Set_moz_column_rule_width,
                                 PropertyId::Longhand(LonghandId::ColumnRuleWidth)],
                            [MozColumnRuleWidth, SetMozColumnRuleWidth,
                             PropertyId::Longhand(LonghandId::ColumnRuleWidth)],
                                [Outline_width, SetOutline_width,
                                 PropertyId::Longhand(LonghandId::OutlineWidth)],
                            [OutlineWidth, SetOutlineWidth,
                             PropertyId::Longhand(LonghandId::OutlineWidth)],
                                [_webkit_text_stroke_width, Set_webkit_text_stroke_width,
                                 PropertyId::Longhand(LonghandId::WebkitTextStrokeWidth)],
                            [WebkitTextStrokeWidth, SetWebkitTextStrokeWidth,
                             PropertyId::Longhand(LonghandId::WebkitTextStrokeWidth)],
                                [Background_color, SetBackground_color,
                                 PropertyId::Longhand(LonghandId::BackgroundColor)],
                            [BackgroundColor, SetBackgroundColor,
                             PropertyId::Longhand(LonghandId::BackgroundColor)],
                                [Border_block_end_color, SetBorder_block_end_color,
                                 PropertyId::Longhand(LonghandId::BorderBlockEndColor)],
                            [BorderBlockEndColor, SetBorderBlockEndColor,
                             PropertyId::Longhand(LonghandId::BorderBlockEndColor)],
                                [Border_block_start_color, SetBorder_block_start_color,
                                 PropertyId::Longhand(LonghandId::BorderBlockStartColor)],
                            [BorderBlockStartColor, SetBorderBlockStartColor,
                             PropertyId::Longhand(LonghandId::BorderBlockStartColor)],
                                [Border_bottom_color, SetBorder_bottom_color,
                                 PropertyId::Longhand(LonghandId::BorderBottomColor)],
                            [BorderBottomColor, SetBorderBottomColor,
                             PropertyId::Longhand(LonghandId::BorderBottomColor)],
                                [Border_inline_end_color, SetBorder_inline_end_color,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndColor)],
                            [BorderInlineEndColor, SetBorderInlineEndColor,
                             PropertyId::Longhand(LonghandId::BorderInlineEndColor)],
                                [_moz_border_end_color, Set_moz_border_end_color,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndColor)],
                            [MozBorderEndColor, SetMozBorderEndColor,
                             PropertyId::Longhand(LonghandId::BorderInlineEndColor)],
                                [Border_inline_start_color, SetBorder_inline_start_color,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartColor)],
                            [BorderInlineStartColor, SetBorderInlineStartColor,
                             PropertyId::Longhand(LonghandId::BorderInlineStartColor)],
                                [_moz_border_start_color, Set_moz_border_start_color,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartColor)],
                            [MozBorderStartColor, SetMozBorderStartColor,
                             PropertyId::Longhand(LonghandId::BorderInlineStartColor)],
                                [Border_left_color, SetBorder_left_color,
                                 PropertyId::Longhand(LonghandId::BorderLeftColor)],
                            [BorderLeftColor, SetBorderLeftColor,
                             PropertyId::Longhand(LonghandId::BorderLeftColor)],
                                [Border_right_color, SetBorder_right_color,
                                 PropertyId::Longhand(LonghandId::BorderRightColor)],
                            [BorderRightColor, SetBorderRightColor,
                             PropertyId::Longhand(LonghandId::BorderRightColor)],
                                [Border_top_color, SetBorder_top_color,
                                 PropertyId::Longhand(LonghandId::BorderTopColor)],
                            [BorderTopColor, SetBorderTopColor,
                             PropertyId::Longhand(LonghandId::BorderTopColor)],
                                [Column_rule_color, SetColumn_rule_color,
                                 PropertyId::Longhand(LonghandId::ColumnRuleColor)],
                            [ColumnRuleColor, SetColumnRuleColor,
                             PropertyId::Longhand(LonghandId::ColumnRuleColor)],
                                [_moz_column_rule_color, Set_moz_column_rule_color,
                                 PropertyId::Longhand(LonghandId::ColumnRuleColor)],
                            [MozColumnRuleColor, SetMozColumnRuleColor,
                             PropertyId::Longhand(LonghandId::ColumnRuleColor)],
                                [Outline_color, SetOutline_color,
                                 PropertyId::Longhand(LonghandId::OutlineColor)],
                            [OutlineColor, SetOutlineColor,
                             PropertyId::Longhand(LonghandId::OutlineColor)],
                                [Text_decoration_color, SetText_decoration_color,
                                 PropertyId::Longhand(LonghandId::TextDecorationColor)],
                            [TextDecorationColor, SetTextDecorationColor,
                             PropertyId::Longhand(LonghandId::TextDecorationColor)],
                                [Text_emphasis_color, SetText_emphasis_color,
                                 PropertyId::Longhand(LonghandId::TextEmphasisColor)],
                            [TextEmphasisColor, SetTextEmphasisColor,
                             PropertyId::Longhand(LonghandId::TextEmphasisColor)],
                                [_webkit_text_fill_color, Set_webkit_text_fill_color,
                                 PropertyId::Longhand(LonghandId::WebkitTextFillColor)],
                            [WebkitTextFillColor, SetWebkitTextFillColor,
                             PropertyId::Longhand(LonghandId::WebkitTextFillColor)],
                                [_webkit_text_stroke_color, Set_webkit_text_stroke_color,
                                 PropertyId::Longhand(LonghandId::WebkitTextStrokeColor)],
                            [WebkitTextStrokeColor, SetWebkitTextStrokeColor,
                             PropertyId::Longhand(LonghandId::WebkitTextStrokeColor)],
                            [Bottom, SetBottom,
                             PropertyId::Longhand(LonghandId::Bottom)],
                            [Left, SetLeft,
                             PropertyId::Longhand(LonghandId::Left)],
                                [Margin_block_end, SetMargin_block_end,
                                 PropertyId::Longhand(LonghandId::MarginBlockEnd)],
                            [MarginBlockEnd, SetMarginBlockEnd,
                             PropertyId::Longhand(LonghandId::MarginBlockEnd)],
                                [Margin_block_start, SetMargin_block_start,
                                 PropertyId::Longhand(LonghandId::MarginBlockStart)],
                            [MarginBlockStart, SetMarginBlockStart,
                             PropertyId::Longhand(LonghandId::MarginBlockStart)],
                                [Margin_bottom, SetMargin_bottom,
                                 PropertyId::Longhand(LonghandId::MarginBottom)],
                            [MarginBottom, SetMarginBottom,
                             PropertyId::Longhand(LonghandId::MarginBottom)],
                                [Margin_inline_end, SetMargin_inline_end,
                                 PropertyId::Longhand(LonghandId::MarginInlineEnd)],
                            [MarginInlineEnd, SetMarginInlineEnd,
                             PropertyId::Longhand(LonghandId::MarginInlineEnd)],
                                [_moz_margin_end, Set_moz_margin_end,
                                 PropertyId::Longhand(LonghandId::MarginInlineEnd)],
                            [MozMarginEnd, SetMozMarginEnd,
                             PropertyId::Longhand(LonghandId::MarginInlineEnd)],
                                [Margin_inline_start, SetMargin_inline_start,
                                 PropertyId::Longhand(LonghandId::MarginInlineStart)],
                            [MarginInlineStart, SetMarginInlineStart,
                             PropertyId::Longhand(LonghandId::MarginInlineStart)],
                                [_moz_margin_start, Set_moz_margin_start,
                                 PropertyId::Longhand(LonghandId::MarginInlineStart)],
                            [MozMarginStart, SetMozMarginStart,
                             PropertyId::Longhand(LonghandId::MarginInlineStart)],
                                [Margin_left, SetMargin_left,
                                 PropertyId::Longhand(LonghandId::MarginLeft)],
                            [MarginLeft, SetMarginLeft,
                             PropertyId::Longhand(LonghandId::MarginLeft)],
                                [Margin_right, SetMargin_right,
                                 PropertyId::Longhand(LonghandId::MarginRight)],
                            [MarginRight, SetMarginRight,
                             PropertyId::Longhand(LonghandId::MarginRight)],
                                [Margin_top, SetMargin_top,
                                 PropertyId::Longhand(LonghandId::MarginTop)],
                            [MarginTop, SetMarginTop,
                             PropertyId::Longhand(LonghandId::MarginTop)],
                                [Offset_block_end, SetOffset_block_end,
                                 PropertyId::Longhand(LonghandId::OffsetBlockEnd)],
                            [OffsetBlockEnd, SetOffsetBlockEnd,
                             PropertyId::Longhand(LonghandId::OffsetBlockEnd)],
                                [Offset_block_start, SetOffset_block_start,
                                 PropertyId::Longhand(LonghandId::OffsetBlockStart)],
                            [OffsetBlockStart, SetOffsetBlockStart,
                             PropertyId::Longhand(LonghandId::OffsetBlockStart)],
                                [Offset_inline_end, SetOffset_inline_end,
                                 PropertyId::Longhand(LonghandId::OffsetInlineEnd)],
                            [OffsetInlineEnd, SetOffsetInlineEnd,
                             PropertyId::Longhand(LonghandId::OffsetInlineEnd)],
                                [Offset_inline_start, SetOffset_inline_start,
                                 PropertyId::Longhand(LonghandId::OffsetInlineStart)],
                            [OffsetInlineStart, SetOffsetInlineStart,
                             PropertyId::Longhand(LonghandId::OffsetInlineStart)],
                            [Right, SetRight,
                             PropertyId::Longhand(LonghandId::Right)],
                            [Top, SetTop,
                             PropertyId::Longhand(LonghandId::Top)],
                            [Background, SetBackground,
                             PropertyId::Shorthand(ShorthandId::Background)],
                                [Background_position, SetBackground_position,
                                 PropertyId::Shorthand(ShorthandId::BackgroundPosition)],
                            [BackgroundPosition, SetBackgroundPosition,
                             PropertyId::Shorthand(ShorthandId::BackgroundPosition)],
                                [Border_color, SetBorder_color,
                                 PropertyId::Shorthand(ShorthandId::BorderColor)],
                            [BorderColor, SetBorderColor,
                             PropertyId::Shorthand(ShorthandId::BorderColor)],
                                [Border_style, SetBorder_style,
                                 PropertyId::Shorthand(ShorthandId::BorderStyle)],
                            [BorderStyle, SetBorderStyle,
                             PropertyId::Shorthand(ShorthandId::BorderStyle)],
                                [Border_width, SetBorder_width,
                                 PropertyId::Shorthand(ShorthandId::BorderWidth)],
                            [BorderWidth, SetBorderWidth,
                             PropertyId::Shorthand(ShorthandId::BorderWidth)],
                                [Border_top, SetBorder_top,
                                 PropertyId::Shorthand(ShorthandId::BorderTop)],
                            [BorderTop, SetBorderTop,
                             PropertyId::Shorthand(ShorthandId::BorderTop)],
                                [Border_left, SetBorder_left,
                                 PropertyId::Shorthand(ShorthandId::BorderLeft)],
                            [BorderLeft, SetBorderLeft,
                             PropertyId::Shorthand(ShorthandId::BorderLeft)],
                                [Border_bottom, SetBorder_bottom,
                                 PropertyId::Shorthand(ShorthandId::BorderBottom)],
                            [BorderBottom, SetBorderBottom,
                             PropertyId::Shorthand(ShorthandId::BorderBottom)],
                                [Border_right, SetBorder_right,
                                 PropertyId::Shorthand(ShorthandId::BorderRight)],
                            [BorderRight, SetBorderRight,
                             PropertyId::Shorthand(ShorthandId::BorderRight)],
                                [Border_block_start, SetBorder_block_start,
                                 PropertyId::Shorthand(ShorthandId::BorderBlockStart)],
                            [BorderBlockStart, SetBorderBlockStart,
                             PropertyId::Shorthand(ShorthandId::BorderBlockStart)],
                                [Border_block_end, SetBorder_block_end,
                                 PropertyId::Shorthand(ShorthandId::BorderBlockEnd)],
                            [BorderBlockEnd, SetBorderBlockEnd,
                             PropertyId::Shorthand(ShorthandId::BorderBlockEnd)],
                                [Border_inline_start, SetBorder_inline_start,
                                 PropertyId::Shorthand(ShorthandId::BorderInlineStart)],
                            [BorderInlineStart, SetBorderInlineStart,
                             PropertyId::Shorthand(ShorthandId::BorderInlineStart)],
                                [_moz_border_start, Set_moz_border_start,
                                 PropertyId::Shorthand(ShorthandId::BorderInlineStart)],
                            [MozBorderStart, SetMozBorderStart,
                             PropertyId::Shorthand(ShorthandId::BorderInlineStart)],
                                [Border_inline_end, SetBorder_inline_end,
                                 PropertyId::Shorthand(ShorthandId::BorderInlineEnd)],
                            [BorderInlineEnd, SetBorderInlineEnd,
                             PropertyId::Shorthand(ShorthandId::BorderInlineEnd)],
                                [_moz_border_end, Set_moz_border_end,
                                 PropertyId::Shorthand(ShorthandId::BorderInlineEnd)],
                            [MozBorderEnd, SetMozBorderEnd,
                             PropertyId::Shorthand(ShorthandId::BorderInlineEnd)],
                            [Border, SetBorder,
                             PropertyId::Shorthand(ShorthandId::Border)],
                                [Border_radius, SetBorder_radius,
                                 PropertyId::Shorthand(ShorthandId::BorderRadius)],
                            [BorderRadius, SetBorderRadius,
                             PropertyId::Shorthand(ShorthandId::BorderRadius)],
                                [_webkit_border_radius, Set_webkit_border_radius,
                                 PropertyId::Shorthand(ShorthandId::BorderRadius)],
                            [WebkitBorderRadius, SetWebkitBorderRadius,
                             PropertyId::Shorthand(ShorthandId::BorderRadius)],
                                [Border_image, SetBorder_image,
                                 PropertyId::Shorthand(ShorthandId::BorderImage)],
                            [BorderImage, SetBorderImage,
                             PropertyId::Shorthand(ShorthandId::BorderImage)],
                                [_moz_border_image, Set_moz_border_image,
                                 PropertyId::Shorthand(ShorthandId::BorderImage)],
                            [MozBorderImage, SetMozBorderImage,
                             PropertyId::Shorthand(ShorthandId::BorderImage)],
                                [_webkit_border_image, Set_webkit_border_image,
                                 PropertyId::Shorthand(ShorthandId::BorderImage)],
                            [WebkitBorderImage, SetWebkitBorderImage,
                             PropertyId::Shorthand(ShorthandId::BorderImage)],
                            [Overflow, SetOverflow,
                             PropertyId::Shorthand(ShorthandId::Overflow)],
                            [Transition, SetTransition,
                             PropertyId::Shorthand(ShorthandId::Transition)],
                                [_moz_transition, Set_moz_transition,
                                 PropertyId::Shorthand(ShorthandId::Transition)],
                            [MozTransition, SetMozTransition,
                             PropertyId::Shorthand(ShorthandId::Transition)],
                                [_webkit_transition, Set_webkit_transition,
                                 PropertyId::Shorthand(ShorthandId::Transition)],
                            [WebkitTransition, SetWebkitTransition,
                             PropertyId::Shorthand(ShorthandId::Transition)],
                            [Animation, SetAnimation,
                             PropertyId::Shorthand(ShorthandId::Animation)],
                                [_moz_animation, Set_moz_animation,
                                 PropertyId::Shorthand(ShorthandId::Animation)],
                            [MozAnimation, SetMozAnimation,
                             PropertyId::Shorthand(ShorthandId::Animation)],
                                [_webkit_animation, Set_webkit_animation,
                                 PropertyId::Shorthand(ShorthandId::Animation)],
                            [WebkitAnimation, SetWebkitAnimation,
                             PropertyId::Shorthand(ShorthandId::Animation)],
                                [Scroll_snap_type, SetScroll_snap_type,
                                 PropertyId::Shorthand(ShorthandId::ScrollSnapType)],
                            [ScrollSnapType, SetScrollSnapType,
                             PropertyId::Shorthand(ShorthandId::ScrollSnapType)],
                                [Overscroll_behavior, SetOverscroll_behavior,
                                 PropertyId::Shorthand(ShorthandId::OverscrollBehavior)],
                            [OverscrollBehavior, SetOverscrollBehavior,
                             PropertyId::Shorthand(ShorthandId::OverscrollBehavior)],
                            [Columns, SetColumns,
                             PropertyId::Shorthand(ShorthandId::Columns)],
                                [_moz_columns, Set_moz_columns,
                                 PropertyId::Shorthand(ShorthandId::Columns)],
                            [MozColumns, SetMozColumns,
                             PropertyId::Shorthand(ShorthandId::Columns)],
                                [Column_rule, SetColumn_rule,
                                 PropertyId::Shorthand(ShorthandId::ColumnRule)],
                            [ColumnRule, SetColumnRule,
                             PropertyId::Shorthand(ShorthandId::ColumnRule)],
                                [_moz_column_rule, Set_moz_column_rule,
                                 PropertyId::Shorthand(ShorthandId::ColumnRule)],
                            [MozColumnRule, SetMozColumnRule,
                             PropertyId::Shorthand(ShorthandId::ColumnRule)],
                            [Font, SetFont,
                             PropertyId::Shorthand(ShorthandId::Font)],
                                [Font_variant, SetFont_variant,
                                 PropertyId::Shorthand(ShorthandId::FontVariant)],
                            [FontVariant, SetFontVariant,
                             PropertyId::Shorthand(ShorthandId::FontVariant)],
                                [Text_emphasis, SetText_emphasis,
                                 PropertyId::Shorthand(ShorthandId::TextEmphasis)],
                            [TextEmphasis, SetTextEmphasis,
                             PropertyId::Shorthand(ShorthandId::TextEmphasis)],
                                [_webkit_text_stroke, Set_webkit_text_stroke,
                                 PropertyId::Shorthand(ShorthandId::WebkitTextStroke)],
                            [WebkitTextStroke, SetWebkitTextStroke,
                             PropertyId::Shorthand(ShorthandId::WebkitTextStroke)],
                                [List_style, SetList_style,
                                 PropertyId::Shorthand(ShorthandId::ListStyle)],
                            [ListStyle, SetListStyle,
                             PropertyId::Shorthand(ShorthandId::ListStyle)],
                            [Margin, SetMargin,
                             PropertyId::Shorthand(ShorthandId::Margin)],
                            [Mask, SetMask,
                             PropertyId::Shorthand(ShorthandId::Mask)],
                                [_webkit_mask, Set_webkit_mask,
                                 PropertyId::Shorthand(ShorthandId::Mask)],
                            [WebkitMask, SetWebkitMask,
                             PropertyId::Shorthand(ShorthandId::Mask)],
                                [Mask_position, SetMask_position,
                                 PropertyId::Shorthand(ShorthandId::MaskPosition)],
                            [MaskPosition, SetMaskPosition,
                             PropertyId::Shorthand(ShorthandId::MaskPosition)],
                                [_webkit_mask_position, Set_webkit_mask_position,
                                 PropertyId::Shorthand(ShorthandId::MaskPosition)],
                            [WebkitMaskPosition, SetWebkitMaskPosition,
                             PropertyId::Shorthand(ShorthandId::MaskPosition)],
                            [Outline, SetOutline,
                             PropertyId::Shorthand(ShorthandId::Outline)],
                                [_moz_outline_radius, Set_moz_outline_radius,
                                 PropertyId::Shorthand(ShorthandId::MozOutlineRadius)],
                            [MozOutlineRadius, SetMozOutlineRadius,
                             PropertyId::Shorthand(ShorthandId::MozOutlineRadius)],
                            [Padding, SetPadding,
                             PropertyId::Shorthand(ShorthandId::Padding)],
                                [Flex_flow, SetFlex_flow,
                                 PropertyId::Shorthand(ShorthandId::FlexFlow)],
                            [FlexFlow, SetFlexFlow,
                             PropertyId::Shorthand(ShorthandId::FlexFlow)],
                                [_webkit_flex_flow, Set_webkit_flex_flow,
                                 PropertyId::Shorthand(ShorthandId::FlexFlow)],
                            [WebkitFlexFlow, SetWebkitFlexFlow,
                             PropertyId::Shorthand(ShorthandId::FlexFlow)],
                            [Flex, SetFlex,
                             PropertyId::Shorthand(ShorthandId::Flex)],
                                [_webkit_flex, Set_webkit_flex,
                                 PropertyId::Shorthand(ShorthandId::Flex)],
                            [WebkitFlex, SetWebkitFlex,
                             PropertyId::Shorthand(ShorthandId::Flex)],
                                [Grid_gap, SetGrid_gap,
                                 PropertyId::Shorthand(ShorthandId::GridGap)],
                            [GridGap, SetGridGap,
                             PropertyId::Shorthand(ShorthandId::GridGap)],
                                [Grid_row, SetGrid_row,
                                 PropertyId::Shorthand(ShorthandId::GridRow)],
                            [GridRow, SetGridRow,
                             PropertyId::Shorthand(ShorthandId::GridRow)],
                                [Grid_column, SetGrid_column,
                                 PropertyId::Shorthand(ShorthandId::GridColumn)],
                            [GridColumn, SetGridColumn,
                             PropertyId::Shorthand(ShorthandId::GridColumn)],
                                [Grid_area, SetGrid_area,
                                 PropertyId::Shorthand(ShorthandId::GridArea)],
                            [GridArea, SetGridArea,
                             PropertyId::Shorthand(ShorthandId::GridArea)],
                                [Grid_template, SetGrid_template,
                                 PropertyId::Shorthand(ShorthandId::GridTemplate)],
                            [GridTemplate, SetGridTemplate,
                             PropertyId::Shorthand(ShorthandId::GridTemplate)],
                            [Grid, SetGrid,
                             PropertyId::Shorthand(ShorthandId::Grid)],
                                [Place_content, SetPlace_content,
                                 PropertyId::Shorthand(ShorthandId::PlaceContent)],
                            [PlaceContent, SetPlaceContent,
                             PropertyId::Shorthand(ShorthandId::PlaceContent)],
                                [Place_self, SetPlace_self,
                                 PropertyId::Shorthand(ShorthandId::PlaceSelf)],
                            [PlaceSelf, SetPlaceSelf,
                             PropertyId::Shorthand(ShorthandId::PlaceSelf)],
                                [Place_items, SetPlace_items,
                                 PropertyId::Shorthand(ShorthandId::PlaceItems)],
                            [PlaceItems, SetPlaceItems,
                             PropertyId::Shorthand(ShorthandId::PlaceItems)],
                            [Marker, SetMarker,
                             PropertyId::Shorthand(ShorthandId::Marker)],
                                [Text_decoration, SetText_decoration,
                                 PropertyId::Shorthand(ShorthandId::TextDecoration)],
                            [TextDecoration, SetTextDecoration,
                             PropertyId::Shorthand(ShorthandId::TextDecoration)],
                            [All, SetAll,
                             PropertyId::Shorthand(ShorthandId::All)],
        }
    }
}

/// Neco
#[macro_export]
macro_rules! longhand_properties_idents {
    ($macro_name: ident) => {
        $macro_name! {
                { align_content, false }
                { align_items, false }
                { align_self, false }
                { backface_visibility, false }
                { border_collapse, false }
                { border_image_repeat, false }
                { box_decoration_break, false }
                { box_sizing, false }
                { caption_side, false }
                { clear, false }
                { clip_rule, false }
                { color_adjust, false }
                { color_interpolation, false }
                { color_interpolation_filters, false }
                { column_count, false }
                { column_fill, false }
                { column_rule_style, false }
                { column_span, false }
                { contain, false }
                { direction, false }
                { dominant_baseline, false }
                { empty_cells, false }
                { fill_rule, false }
                { flex_direction, false }
                { flex_wrap, false }
                { float, false }
                { font_kerning, false }
                { font_optical_sizing, false }
                { font_stretch, false }
                { font_style, false }
                { font_synthesis, false }
                { font_variant_caps, false }
                { font_variant_position, false }
                { font_weight, false }
                { grid_auto_flow, false }
                { hyphens, false }
                { image_orientation, false }
                { image_rendering, false }
                { ime_mode, false }
                { initial_letter, false }
                { isolation, false }
                { justify_content, false }
                { justify_items, false }
                { justify_self, false }
                { list_style_position, false }
                { mask_type, false }
                { mix_blend_mode, false }
                { _moz_appearance, false }
                { _moz_box_align, false }
                { _moz_box_direction, false }
                { _moz_box_orient, false }
                { _moz_box_pack, false }
                { _moz_control_character_visibility, false }
                { _moz_float_edge, false }
                { _moz_force_broken_image_icon, false }
                { _moz_math_display, false }
                { _moz_math_variant, false }
                { _moz_min_font_size_ratio, false }
                { _moz_orient, false }
                { _moz_osx_font_smoothing, false }
                { _moz_script_level, false }
                { _moz_script_min_size, false }
                { _moz_script_size_multiplier, false }
                { _moz_stack_sizing, false }
                { _moz_text_size_adjust, false }
                { _moz_top_layer, false }
                { _moz_user_focus, false }
                { _moz_user_input, false }
                { _moz_user_modify, false }
                { _moz_user_select, false }
                { _moz_window_dragging, false }
                { _moz_window_shadow, false }
                { object_fit, false }
                { outline_style, false }
                { overflow_wrap, false }
                { overflow_x, false }
                { page_break_after, false }
                { page_break_before, false }
                { page_break_inside, false }
                { paint_order, false }
                { pointer_events, false }
                { position, false }
                { resize, false }
                { ruby_align, false }
                { ruby_position, false }
                { scroll_behavior, false }
                { shape_rendering, false }
                { stroke_linecap, false }
                { stroke_linejoin, false }
                { table_layout, false }
                { text_align_last, false }
                { text_anchor, false }
                { text_combine_upright, false }
                { text_decoration_line, false }
                { text_decoration_style, false }
                { text_justify, false }
                { text_orientation, false }
                { text_rendering, false }
                { text_transform, false }
                { touch_action, false }
                { transform_box, false }
                { transform_style, false }
                { unicode_bidi, false }
                { vector_effect, false }
                { visibility, false }
                { white_space, false }
                { word_break, false }
                { writing_mode, false }
                { _x_span, false }
                { _x_text_zoom, false }
                { z_index, false }
                { _moz_box_ordinal_group, false }
                { order, false }
                { overscroll_behavior_x, false }
                { overscroll_behavior_y, false }
                { scroll_snap_type_x, false }
                { scroll_snap_type_y, false }
                { flex_grow, false }
                { flex_shrink, false }
                { _moz_box_flex, false }
                { flood_opacity, false }
                { _moz_window_opacity, false }
                { opacity, false }
                { shape_image_threshold, false }
                { stop_opacity, false }
                { border_block_end_style, false }
                { border_block_start_style, false }
                { border_bottom_style, false }
                { border_inline_end_style, false }
                { border_inline_start_style, false }
                { border_left_style, false }
                { border_right_style, false }
                { border_top_style, false }
                { animation_delay, false }
                { animation_direction, false }
                { animation_duration, false }
                { animation_fill_mode, false }
                { animation_iteration_count, false }
                { animation_name, false }
                { animation_play_state, false }
                { animation_timing_function, false }
                { background_attachment, false }
                { background_blend_mode, false }
                { background_clip, false }
                { background_image, false }
                { background_origin, false }
                { background_position_x, false }
                { background_position_y, false }
                { background_repeat, false }
                { background_size, false }
                { border_image_outset, true }
                { border_image_slice, true }
                { border_image_source, true }
                { border_image_width, true }
                { border_spacing, true }
                { box_shadow, false }
                { caret_color, false }
                { clip_path, true }
                { color, false }
                { column_gap, false }
                { column_width, false }
                { content, false }
                { counter_increment, false }
                { counter_reset, false }
                { cursor, false }
                { display, false }
                { filter, false }
                { font_family, false }
                { font_feature_settings, false }
                { font_language_override, false }
                { font_size, false }
                { font_size_adjust, false }
                { font_variant_alternates, false }
                { font_variant_east_asian, false }
                { font_variant_ligatures, false }
                { font_variant_numeric, false }
                { font_variation_settings, false }
                { grid_template_areas, false }
                { letter_spacing, false }
                { line_height, false }
                { list_style_image, false }
                { list_style_type, true }
                { mask_clip, false }
                { mask_composite, false }
                { mask_image, false }
                { mask_mode, false }
                { mask_origin, false }
                { mask_position_x, false }
                { mask_position_y, false }
                { mask_repeat, false }
                { mask_size, false }
                { _moz_context_properties, false }
                { _moz_tab_size, false }
                { outline_offset, false }
                { overflow_y, false }
                { perspective, false }
                { perspective_origin, true }
                { quotes, false }
                { rotate, true }
                { scale, true }
                { scroll_snap_coordinate, false }
                { shape_outside, true }
                { stroke_dasharray, false }
                { stroke_dashoffset, false }
                { stroke_miterlimit, false }
                { stroke_width, false }
                { text_align, false }
                { text_emphasis_position, false }
                { text_emphasis_style, true }
                { text_indent, false }
                { text_overflow, true }
                { text_shadow, false }
                { transition_delay, false }
                { transition_duration, false }
                { transition_property, false }
                { transition_timing_function, false }
                { translate, true }
                { vertical_align, false }
                { will_change, false }
                { word_spacing, false }
                { _x_lang, false }
                { overflow_clip_box_block, false }
                { overflow_clip_box_inline, false }
                { fill_opacity, false }
                { stroke_opacity, false }
                { scroll_snap_points_x, false }
                { scroll_snap_points_y, false }
                { _moz_window_transform, false }
                { transform, false }
                { clip, true }
                { _moz_image_region, true }
                { grid_template_columns, true }
                { grid_template_rows, true }
                { object_position, true }
                { scroll_snap_destination, true }
                { fill, true }
                { stroke, true }
                { grid_auto_columns, true }
                { grid_auto_rows, true }
                { _moz_window_transform_origin, true }
                { transform_origin, true }
                { max_block_size, false }
                { max_height, false }
                { max_inline_size, false }
                { max_width, false }
                { flood_color, false }
                { lighting_color, false }
                { _moz_font_smoothing_background_color, false }
                { stop_color, false }
                { marker_end, false }
                { marker_mid, false }
                { marker_start, false }
                { _moz_binding, false }
                { grid_column_end, true }
                { grid_column_start, true }
                { grid_row_end, true }
                { grid_row_start, true }
                { border_bottom_left_radius, true }
                { border_bottom_right_radius, true }
                { border_top_left_radius, true }
                { border_top_right_radius, true }
                { _moz_outline_radius_bottomleft, true }
                { _moz_outline_radius_bottomright, true }
                { _moz_outline_radius_topleft, true }
                { _moz_outline_radius_topright, true }
                { block_size, false }
                { flex_basis, false }
                { height, false }
                { inline_size, false }
                { min_block_size, false }
                { min_height, false }
                { min_inline_size, false }
                { min_width, false }
                { width, false }
                { grid_column_gap, false }
                { grid_row_gap, false }
                { padding_block_end, false }
                { padding_block_start, false }
                { padding_bottom, false }
                { padding_inline_end, false }
                { padding_inline_start, false }
                { padding_left, false }
                { padding_right, false }
                { padding_top, false }
                { border_block_end_width, false }
                { border_block_start_width, false }
                { border_bottom_width, false }
                { border_inline_end_width, false }
                { border_inline_start_width, false }
                { border_left_width, false }
                { border_right_width, false }
                { border_top_width, false }
                { column_rule_width, false }
                { outline_width, false }
                { _webkit_text_stroke_width, false }
                { background_color, false }
                { border_block_end_color, false }
                { border_block_start_color, false }
                { border_bottom_color, false }
                { border_inline_end_color, false }
                { border_inline_start_color, false }
                { border_left_color, false }
                { border_right_color, false }
                { border_top_color, false }
                { column_rule_color, false }
                { outline_color, false }
                { text_decoration_color, false }
                { text_emphasis_color, false }
                { _webkit_text_fill_color, false }
                { _webkit_text_stroke_color, false }
                { bottom, false }
                { left, false }
                { margin_block_end, false }
                { margin_block_start, false }
                { margin_bottom, false }
                { margin_inline_end, false }
                { margin_inline_start, false }
                { margin_left, false }
                { margin_right, false }
                { margin_top, false }
                { offset_block_end, false }
                { offset_block_start, false }
                { offset_inline_end, false }
                { offset_inline_start, false }
                { right, false }
                { top, false }
        }
    }
}

